@@ -95,6 +95,9 @@ namespace MagickLib
 #  define MagickDLLDeclExtern
 #endif
 
+#if defined(WIN32) && defined(_VISUALC_)
+#  pragma warning(disable : 4996) /* function deprecation warnings */
+#endif
 
 //
 // Import ImageMagick symbols and types which are used as part of the
