@@ -185,15 +185,18 @@ static Image *ReadARTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   k=(unsigned char) ((-ldblk) & 0x01);
   if (GetBlobSize(image) != (MagickSizeType) (8+(ldblk+(long) k)*height))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
- image->columns=width;
- image->rows=height;
- image->depth=1;
- image->colors=1l << image->depth;
+  image->columns=width;
+  image->rows=height;
+  image->depth=1;
+  image->colors=1l << image->depth;
 
 /* printf("ART header checked OK %d,%d\n",image->colors,image->depth); */
 
  if (AllocateImageColormap(image,image->colors) == MagickFalse) goto NoMemory;
 
+  i=0;
+ if (image_info->ping) goto DONE_READING;
+
 /* ----- Load RLE compressed raster ----- */
  BImgBuff=(unsigned char *) AcquireMagickMemory((size_t) ldblk);  /*Ldblk was set in the check phase*/
  if (BImgBuff==NULL)
@@ -209,6 +212,8 @@ NoMemory:
       break;
     InsertRow(BImgBuff,i,image);
   }
+
+DONE_READING:
   BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
   if (i < (long) height)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
