@@ -844,7 +844,7 @@ static MagickBooleanType DecodeImage(Image *image,
       break;
     if (count != 0)
       {
-        count=(ssize_t) MagickMin(count,(size_t) (q-p));
+        count=(ssize_t) MagickMin((size_t) count,(size_t) (q-p));
         /*
           Encoded mode.
         */
@@ -897,7 +897,7 @@ static MagickBooleanType DecodeImage(Image *image,
             /*
               Absolute mode.
             */
-            count=(long) MagickMin(count,(size_t) (q-p));
+            count=(ssize_t) MagickMin((size_t) count,(size_t) (q-p));
             if (compression == BI_RLE8)
               for (i=0; i < (long) count; i++)
                 *p++=(unsigned char) ReadBlobByte(image);
