@@ -641,8 +641,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         if (bmp_info.size < 40)
           ThrowReaderException(CorruptImageError,"NonOS2HeaderSizeError");
-        bmp_info.width=(short) ReadBlobLSBLong(image);
-        bmp_info.height=(short) ReadBlobLSBLong(image);
+        bmp_info.width=ReadBlobLSBLong(image);
+        bmp_info.height=ReadBlobLSBLong(image);
         bmp_info.planes=ReadBlobLSBShort(image);
         bmp_info.bits_per_pixel=ReadBlobLSBShort(image);
         bmp_info.compression=ReadBlobLSBLong(image);
@@ -1099,7 +1099,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(ssize_t) image->rows-y-1;
+          offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -1167,7 +1167,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(ssize_t) image->rows-y-1;
+          offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -1201,7 +1201,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(ssize_t) image->rows-y-1;
+          offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -1262,7 +1262,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(ssize_t) image->rows-y-1;
+          offset=(MagickOffsetType) (image->rows-y-1);
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -2000,7 +2000,7 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
         if (bmp_colormap == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         q=bmp_colormap;
-        for (i=0; i < (long) MagickMin(image->colors,bmp_info.number_colors); i++)
+        for (i=0; i < (long) MagickMin((long) image->colors,(long) bmp_info.number_colors); i++)
         {
           *q++=ScaleQuantumToChar(image->colormap[i].blue);
           *q++=ScaleQuantumToChar(image->colormap[i].green);
