@@ -96,7 +96,7 @@ static void InsertRow(long depth,unsigned char *p,long y,Image *image)
   register IndexPacket *indexes;
 
 
-  index=0;
+  index=(IndexPacket) 0;
   switch (depth)
     {
     case 1:  /* Convert bitmap scanline. */
@@ -385,6 +385,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->depth=8;
   image->colors=1UL << (unsigned long) i;
 
+  if (image_info->ping) goto Finish;
 
   /* ----- Do something with palette ----- */
   if ((clone_info=CloneImageInfo(image_info)) == NULL) goto NoPalette;
@@ -455,9 +456,9 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image->colors=PalHeader.MaxIndex+1;
       if (AllocateImageColormap(image,image->colors) == MagickFalse) goto NoMemory;
 
-      if(PalHeader.MaxRed==0) PalHeader.MaxRed=QuantumRange;  /*avoid division by 0*/
-      if(PalHeader.MaxGreen==0) PalHeader.MaxGreen=QuantumRange;
-      if(PalHeader.MaxBlue==0) PalHeader.MaxBlue=QuantumRange;
+      if(PalHeader.MaxRed==0) PalHeader.MaxRed=(unsigned int) QuantumRange;  /*avoid division by 0*/
+      if(PalHeader.MaxGreen==0) PalHeader.MaxGreen=(unsigned int) QuantumRange;
+      if(PalHeader.MaxBlue==0) PalHeader.MaxBlue=(unsigned int) QuantumRange;
 
       for(i=0;i<=(int) PalHeader.MaxIndex;i++)
         {      /*this may be wrong- I don't know why is palette such strange*/
@@ -469,24 +470,24 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
               if (offset < 0)
                 ThrowReaderException(CorruptImageError,"ImproperImageHeader");
             }
-          image->colormap[i].red=ReadBlobLSBShort(palette);
+          image->colormap[i].red=(Quantum) ReadBlobLSBShort(palette);
           if(QuantumRange!=(Quantum) PalHeader.MaxRed)
             {
-              image->colormap[i].red=(Quantum) (((double)
+              image->colormap[i].red=RoundToQuantum(((double)
                 image->colormap[i].red*QuantumRange+(PalHeader.MaxRed>>1))/
-                PalHeader.MaxRed+0.5);
+                PalHeader.MaxRed);
             }
-          image->colormap[i].green=ReadBlobLSBShort(palette);
+          image->colormap[i].green=(Quantum) ReadBlobLSBShort(palette);
           if(QuantumRange!=(Quantum) PalHeader.MaxGreen)
             {
-              image->colormap[i].green=(Quantum)
-                (((double) image->colormap[i].green*QuantumRange+(PalHeader.MaxGreen>>1))/PalHeader.MaxGreen+0.5);
+              image->colormap[i].green=RoundToQuantum
+                (((double) image->colormap[i].green*QuantumRange+(PalHeader.MaxGreen>>1))/PalHeader.MaxGreen);
             }
-          image->colormap[i].blue=ReadBlobLSBShort(palette);
+          image->colormap[i].blue=(Quantum) ReadBlobLSBShort(palette);
           if(QuantumRange!=(Quantum) PalHeader.MaxBlue)
             {
-              image->colormap[i].blue=(Quantum)
-                (((double)image->colormap[i].blue*QuantumRange+(PalHeader.MaxBlue>>1))/PalHeader.MaxBlue+0.5);
+              image->colormap[i].blue=RoundToQuantum
+                (((double)image->colormap[i].blue*QuantumRange+(PalHeader.MaxBlue>>1))/PalHeader.MaxBlue);
             }
 
         }
