@@ -193,7 +193,7 @@ static MagickBooleanType DecodeImage(Image *image,
       break;
     if (count != 0)
       {
-        count=(int) MagickMin(count,(size_t) (q-p));
+        count=(int) MagickMin((size_t) count,(size_t) (q-p));
         /*
           Encoded mode.
         */
@@ -246,7 +246,7 @@ static MagickBooleanType DecodeImage(Image *image,
             /*
               Absolute mode.
             */
-            count=(int) MagickMin(count,(size_t) (q-p));
+            count=(int) MagickMin((size_t) count,(size_t) (q-p));
             if (compression == BI_RLE8)
               for (i=0; i < count; i++)
                 *p++=(unsigned char) ReadBlobByte(image);
@@ -1111,7 +1111,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         for (x=0; x < (long) image->columns; x++)
         {
           byte<<=1;
-          byte|=indexes[x] ? 0x01 : 0x00;
+          byte|=indexes[x] != 0 ? 0x01 : 0x00;
           bit++;
           if (bit == 8)
             {
