@@ -209,8 +209,9 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
     q=SetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    ImfInputSetFrameBuffer(file,scanline-(y*image->columns),1,image->columns);
-    ImfInputReadPixels(file,y,y);
+    ImfInputSetFrameBuffer(file,scanline-min_x-image->columns*(min_y+y),1,
+      image->columns);
+    ImfInputReadPixels(file,min_y+y,min_y+y);
     for (x=0; x < (long) image->columns; x++)
     {
       q->red=RoundToQuantum((MagickRealType) QuantumRange*ImfHalfToFloat(
