@@ -399,7 +399,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     if ((fits_info.min_data != 0.0) || (fits_info.max_data != 0.0))
       {
         if ((fits_info.bits_per_pixel != 0) && (fits_info.max_data == 0.0))
-          fits_info.max_data=(1UL << fits_info.bits_per_pixel)-1;
+          fits_info.max_data=(double) (1UL << fits_info.bits_per_pixel)-1;
       }
     else
       {
@@ -418,9 +418,9 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         if (fits_info.bits_per_pixel == 16)
           {
             if ((long_quantum[0] & 0x80) == 0)
-              pixel=(long_quantum[0] << 8) | long_quantum[1];
+              pixel=(double) ((long_quantum[0] << 8) | long_quantum[1]);
             else
-              pixel=((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
+              pixel=(double) ((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
           }
         if (fits_info.bits_per_pixel == -32)
           {
@@ -428,8 +428,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
                (long) long_quantum[3];
             k=(int) *long_quantum;
             exponent=((k & 0x7f) << 1) | (j >> 23);
-            *(float *) long_quantum=
-              exponential[exponent]*(float) (j | 0x800000);
+            *(float *) long_quantum=exponential[exponent]*
+              (float) (j | 0x800000);
             if ((exponent | j) == 0)
               *(float *) long_quantum=0.0;
             if (k & 0x7f)
@@ -467,9 +467,9 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           if (fits_info.bits_per_pixel == 16)
             {
               if ((long_quantum[0] & 0x80) == 0)
-                pixel=(long_quantum[0] << 8) | long_quantum[1];
+                pixel=(double) ((long_quantum[0] << 8) | long_quantum[1]);
               else
-                pixel=((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
+                pixel=(double) ((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
             }
           if (fits_info.bits_per_pixel == -32)
             {
@@ -537,9 +537,9 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         if (fits_info.bits_per_pixel == 16)
           {
             if ((long_quantum[0] & 0x80) == 0)
-              pixel=(long_quantum[0] << 8) | long_quantum[1];
+              pixel=(double) ((long_quantum[0] << 8) | long_quantum[1]);
             else
-              pixel=((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
+              pixel=(double) ((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
           }
         if (fits_info.bits_per_pixel == -32)
           {
@@ -577,7 +577,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         index=(IndexPacket) ((scale_pixel < 0.0) ? 0 : ((unsigned long)
           scale_pixel > ((1UL << image->depth)-1)) ? ((1UL << image->depth)-1) :
           (unsigned long) (scale_pixel+0.5));
-        index=ConstrainColormapIndex(image,index);
+        index=ConstrainColormapIndex(image,1UL*index);
         indexes[x]=index;
         *q++=image->colormap[(long) index];
       }
@@ -892,15 +892,16 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
           pixel+=1.0*(1UL << (image->depth-1UL));
         if (image->depth > 16)
           {
-            (void) WriteBlobByte(image,((unsigned long)
-              (pixel+0.5) >> 24) & 0xff);
-            (void) WriteBlobByte(image,((unsigned long)
-              (pixel+0.5) >> 16) & 0xff);
+            (void) WriteBlobByte(image,((unsigned char)
+              ((unsigned long) (pixel+0.5) >> 24) & 0xff));
+            (void) WriteBlobByte(image,((unsigned char)
+              ((unsigned long) (pixel+0.5) >> 16) & 0xff));
           }
         if (image->depth > 8)
-          (void) WriteBlobByte(image,((unsigned long)
-            (pixel+0.5) >> 8) & 0xff);
-        (void) WriteBlobByte(image,(unsigned long) (pixel+0.5) & 0xff);
+          (void) WriteBlobByte(image,((unsigned char)
+            ((unsigned long) (pixel+0.5) >> 8) & 0xff));
+        (void) WriteBlobByte(image,(unsigned char)
+          ((unsigned long) (pixel+0.5) & 0xff));
         p++;
       }
     }
