@@ -50,6 +50,7 @@
 #include "magick/image.h"
 #include "magick/image-private.h"
 #include "magick/list.h"
+#include "magick/profile.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
@@ -520,7 +521,6 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
 %
 %    o data_size:  The number of bits in the compressed packet.
 %
-%
 */
 static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
   const unsigned long data_size)
@@ -665,9 +665,9 @@ static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
       /*
         Probe hash table.
       */
-      index=(long) indexes[x] & 0xff;
+      index=(IndexPacket) ((unsigned long) indexes[x] & 0xff);
       p++;
-      k=((long) index << (MaxGIFBits-8))+waiting_code;
+      k=(long) (((unsigned long) index << (MaxGIFBits-8))+waiting_code);
       if (k >= MaxHashTable)
         k-=MaxHashTable;
       next_pixel=MagickFalse;
@@ -837,7 +837,6 @@ static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsGIF(const unsigned char *magick,const size_t length)
 {
@@ -861,7 +860,7 @@ static MagickBooleanType IsGIF(const unsigned char *magick,const size_t length)
 %
 %  ReadBlobBlock() reads data from the image file and returns it.  The
 %  amount of data is determined by first reading a count byte.  The number
-%  or bytes read is returned.
+%  of bytes read is returned.
 %
 %  The format of the ReadBlobBlock method is:
 %
@@ -874,7 +873,6 @@ static MagickBooleanType IsGIF(const unsigned char *magick,const size_t length)
 %    o data:  Specifies an area to place the information requested from
 %      the file.
 %
-%
 */
 static ssize_t ReadBlobBlock(Image *image,unsigned char *data)
 {
@@ -918,7 +916,6 @@ static ssize_t ReadBlobBlock(Image *image,unsigned char *data)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 static inline size_t MagickMax(const size_t x,const size_t y)
@@ -954,7 +951,7 @@ static MagickBooleanType PingGIFImage(Image *image)
     ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
   while (length != 0)
   {
-    if (ReadBlob(image,length,buffer) != length)
+    if (ReadBlob(image,length,buffer) != (ssize_t) length)
       ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
     if (ReadBlob(image,1,&length) != 1)
       ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
@@ -970,6 +967,9 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Image
     *image;
 
+  int
+    number_extensionss=0;
+
   long
     opacity;
 
@@ -1056,6 +1056,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           GIF Extension block.
         */
+
         count=ReadBlob(image,1,&c);
         if (count != 1)
           {
@@ -1101,6 +1102,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           case 0xff:
           {
+            /* Read GIF application extension */
+
             MagickBooleanType
               loop;
 
@@ -1111,9 +1114,78 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if (ReadBlobBlock(image,header) != 0)
               loop=LocaleNCompare((char *) header,"NETSCAPE2.0",11) == 0 ?
                 MagickTrue : MagickFalse;
-            while (ReadBlobBlock(image,header) != 0)
             if (loop != MagickFalse)
-              iterations=(unsigned long) ((header[2] << 8) | header[1]);
+              {
+                while (ReadBlobBlock(image,header) != 0)
+                  iterations=(unsigned long) ((header[2] << 8) | header[1]);
+                break;
+              }
+            else
+              {
+                /* store GIF application extension as a generic profile */
+                char
+                  name[MaxTextExtent];
+
+                StringInfo
+                  *profile;
+
+                unsigned char
+                  *info;
+
+                MagickBooleanType
+                  i8bim,
+                  icc,
+                  iptc;
+
+                int
+                   block_length,
+                   info_length,
+                   reserved_length;
+
+                i8bim=LocaleNCompare((char *) header,"MGK8BIM0000",11) == 0 ?
+                  MagickTrue : MagickFalse;
+                icc=LocaleNCompare((char *) header,"ICCRGBG1012",11) == 0 ?
+                  MagickTrue : MagickFalse;
+                iptc=LocaleNCompare((char *) header,"MGKIPTC0000",11) == 0 ?
+                  MagickTrue : MagickFalse;
+                number_extensionss++;
+                (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                  "    Reading GIF application extension");
+                info=(unsigned char *) AcquireMagickMemory(255*sizeof(*info));
+                info_length=0;
+                reserved_length=255;
+                for ( ; ; )
+                {
+                  block_length=(int) ReadBlobBlock(image,&info[info_length]);
+                  if (block_length == 0)
+                    break;
+                  info_length+=block_length;
+                  if (info_length > (reserved_length-255))
+                    {
+                       reserved_length+=4096;
+                       info=(unsigned char *) ResizeMagickMemory(info,
+                         (size_t) reserved_length);
+                    }
+                }
+                info=(unsigned char *) ResizeMagickMemory(info,(size_t)
+                  (info_length+1)*sizeof(*info));
+                profile=AcquireStringInfo((size_t) info_length);
+                SetStringInfoDatum(profile,(const unsigned char *) info);
+                if (i8bim == MagickTrue)
+                  (void) CopyMagickString(name,"8bim",sizeof(name));
+                if (icc == MagickTrue)
+                  (void) CopyMagickString(name,"icc",sizeof(name));
+                else
+                  if (iptc == MagickTrue)
+                    (void) CopyMagickString(name,"iptc",sizeof(name));
+                  else
+                    (void) FormatMagickString(name,sizeof(name),"gif:%.11s",
+                      header);
+                (void) SetImageProfile(image,name,profile);
+                profile=DestroyStringInfo(profile);
+                (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                  "      profile name=%s",name);
+              }
             break;
           }
           default:
@@ -1159,7 +1231,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->rows=ReadBlobLSBShort(image);
     image->depth=8;
     flag=(unsigned char) ReadBlobByte(image);
-    image->interlace=BitSet((int) flag,0x40) != 0 ? PlaneInterlace :
+    image->interlace=BitSet((int) flag,0x40) != 0 ? GIFInterlace :
       NoInterlace;
     image->colors=BitSet((int) flag,0x80) == 0 ? global_colors :
       1UL << ((unsigned long) (flag & 0x07)+1);
@@ -1462,10 +1534,10 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
     {
       page.x=next_image->page.x;
       page.y=next_image->page.y;
-      if ((next_image->columns+page.x) > page.width)
-        page.width=next_image->columns+page.x;
-      if ((next_image->rows+page.y) > page.height)
-        page.height=next_image->rows+page.y;
+      if ((next_image->page.width+page.x) > page.width)
+        page.width=next_image->page.width+page.x;
+      if ((next_image->page.height+page.y) > page.height)
+        page.height=next_image->page.height+page.y;
       next_image=GetNextImageInList(next_image);
     }
   page.x=image->page.x;
@@ -1593,7 +1665,8 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
         if (opacity >= 0)
           c|=0x01;
         (void) WriteBlobByte(image,(unsigned char) c);
-        delay=(unsigned long) (100*image->delay/MagickMax((size_t) image->ticks_per_second,1));
+        delay=(unsigned long) (100*image->delay/MagickMax((size_t)
+          image->ticks_per_second,1));
         (void) WriteBlobLSBShort(image,(unsigned short) delay);
         (void) WriteBlobByte(image,(unsigned char) (opacity >= 0 ? opacity :
           0));
@@ -1633,6 +1706,8 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             /*
               Write Netscape Loop extension.
             */
+            (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+               "  Writing GIF Extension %s","NETSCAPE2.0");
             (void) WriteBlobByte(image,(unsigned char) 0x21);
             (void) WriteBlobByte(image,(unsigned char) 0xff);
             (void) WriteBlobByte(image,(unsigned char) 0x0b);
@@ -1642,6 +1717,95 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             (void) WriteBlobLSBShort(image,(unsigned short) image->iterations);
             (void) WriteBlobByte(image,(unsigned char) 0x00);
           }
+
+        ResetImageProfileIterator(image);
+        for (;;)
+        {
+          const StringInfo
+            *profile;
+
+          char
+            *name;
+
+          name=GetNextImageProfile(image);
+          if (name == (const char *) NULL)
+            break;
+          profile=GetImageProfile(image,name);
+          if (profile != (StringInfo *) NULL)
+          {
+            if ((LocaleCompare(name,"ICC") == 0) ||
+                (LocaleCompare(name,"ICM") == 0) ||
+                (LocaleCompare(name,"IPTC") == 0) ||
+                (LocaleCompare(name,"8BIM") == 0) ||
+                (LocaleNCompare(name,"gif:",4) == 0))
+            {
+               int
+                 profile_length,
+                 profile_ptr;
+              
+               unsigned char
+                 *profile_data;
+
+               profile_data=GetStringInfoDatum(profile);
+               profile_length=(int) GetStringInfoLength(profile);
+
+               (void) WriteBlobByte(image,(unsigned char) 0x21);
+               (void) WriteBlobByte(image,(unsigned char) 0xff);
+               (void) WriteBlobByte(image,(unsigned char) 0x0b);
+
+               if ((LocaleCompare(name,"ICC") == 0) ||
+                   (LocaleCompare(name,"ICM") == 0))
+               {
+                 /* write ICC extension */
+                 (void) WriteBlob(image,11,(unsigned char *)"ICCRGBG1012");
+                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                     "  Writing GIF Extension %s","ICCRGBG1012");
+               }
+               else if ((LocaleCompare(name,"IPTC") == 0))
+               {
+                 /* write IPTC extension */
+                 (void) WriteBlob(image,11,(unsigned char *)"MGKIPTC0000");
+                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                     "  Writing GIF Extension %s","MGKIPTC0000");
+               }
+               else if ((LocaleCompare(name,"8BIM") == 0))
+               {
+                 /* write 8BIM extension */
+                 (void) WriteBlob(image,11,(unsigned char *)"MGK8BIM0000");
+                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                     "  Writing GIF Extension %s","MGK8BIM0000");
+               }
+               else
+               {
+                 char
+                   extension[MaxTextExtent];
+
+                 /* write generic extension */
+                 (void) CopyMagickString(extension,name+4,sizeof(extension));
+                 (void) WriteBlob(image,11,(unsigned char *) extension);
+                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                     "  Writing GIF Extension %s",name);
+               }
+
+               profile_ptr=0;
+               while (profile_length > profile_ptr)
+               {
+                 int
+                   block_length;
+
+                 if (profile_length - profile_ptr < 255)
+                   block_length=profile_length-profile_ptr;
+                 else
+                   block_length=255;
+                 (void) WriteBlobByte(image,(unsigned char) block_length);
+                 (void) WriteBlob(image,(size_t) block_length,
+                   &profile_data[profile_ptr]);
+                 profile_ptr+=block_length;
+               }
+               (void) WriteBlobByte(image,(unsigned char) 0x00);
+            }
+          }
+        }
       }
     (void) WriteBlobByte(image,',');  /* image separator */
     /*
