@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -292,7 +292,12 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
       /*
         Write the HTML image file.
       */
-      (void) WriteBlobString(image,"<html version=\"2.0\">\n");
+      (void) WriteBlobString(image,"<?xml version=\"1.0\" "
+        "encoding=\"US-ASCII\"?>\n");
+      (void) WriteBlobString(image,"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML "
+        "1.0 Strict//EN\" "
+        "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n");
+      (void) WriteBlobString(image,"<html>\n");
       (void) WriteBlobString(image,"<head>\n");
       value=GetImageProperty(image,"Label");
       if (value != (const char *) NULL)
@@ -306,17 +311,16 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
         }
       (void) WriteBlobString(image,buffer);
       (void) WriteBlobString(image,"</head>\n");
-      (void) WriteBlobString(image,"<body>\n");
-      (void) WriteBlobString(image,"<center>\n");
+      (void) WriteBlobString(image,"<body style=\"text-align: center;\">\n");
       (void) FormatMagickString(buffer,MaxTextExtent,"<h1>%s</h1>\n",
         image->filename);
       (void) WriteBlobString(image,buffer);
-      (void) WriteBlobString(image,"<br><br>\n");
+      (void) WriteBlobString(image,"<div>\n");
       (void) CopyMagickString(filename,image->filename,MaxTextExtent);
-      AppendImageFormat("gif",filename);
-      (void) FormatMagickString(buffer,MaxTextExtent,
-        "<img ismap usemap=\"#%s\" src=\"%s\" border=0>\n",
-        mapname,filename);
+      AppendImageFormat("png",filename);
+      (void) FormatMagickString(buffer,MaxTextExtent,"<img usemap=\"#%s\" "
+        "src=\"%s\" style=\"border: 0;\" alt=\"Image map\" />\n",mapname,
+        filename);
       (void) WriteBlobString(image,buffer);
       /*
         Determine the size and location of each image tile.
@@ -327,8 +331,8 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
       /*
         Write an image map.
       */
-      (void) FormatMagickString(buffer,MaxTextExtent,"<map name=\"%s\">\n",
-        mapname);
+      (void) FormatMagickString(buffer,MaxTextExtent,
+        "<map id=\"%s\" name=\"%s\">\n",mapname,mapname);
       (void) WriteBlobString(image,buffer);
       (void) FormatMagickString(buffer,MaxTextExtent,"  <area href=\"%s",
         url);
@@ -336,8 +340,8 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
       if (image->directory == (char *) NULL)
         {
           (void) FormatMagickString(buffer,MaxTextExtent,
-            "%s\" shape=rect coords=\"0,0,%lu,%lu\">\n",image->filename,
-            geometry.width-1,geometry.height-1);
+            "%s\" shape=\"rect\" coords=\"0,0,%lu,%lu\" alt=\"\" />\n",
+            image->filename,geometry.width-1,geometry.height-1);
           (void) WriteBlobString(image,buffer);
         }
       else
@@ -347,9 +351,9 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
           else
             {
               (void) FormatMagickString(buffer,MaxTextExtent,
-                "\" shape=rect coords=\"%ld,%ld,%ld,%ld\">\n",geometry.x,
-                geometry.y,geometry.x+(long) geometry.width-1,geometry.y+
-                (long) geometry.height-1);
+                "\" shape=\"rect\" coords=\"%ld,%ld,%ld,%ld\" alt=\"\" />\n",
+                geometry.x,geometry.y,geometry.x+(long) geometry.width-1,
+                geometry.y+(long) geometry.height-1);
               (void) WriteBlobString(image,buffer);
               if (*(p+1) != '\0')
                 {
@@ -358,7 +362,7 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
                   (void) WriteBlobString(image,buffer);
                 }
               geometry.x+=geometry.width;
-              if (geometry.x >= (long) image->columns)
+              if ((geometry.x+4) >= (long) image->columns)
                 {
                   geometry.x=0;
                   geometry.y+=geometry.height;
@@ -366,18 +370,18 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
             }
       (void) WriteBlobString(image,"</map>\n");
       (void) CopyMagickString(filename,image->filename,MaxTextExtent);
-      (void) WriteBlobString(image,"</center>\n");
+      (void) WriteBlobString(image,"</div>\n");
       (void) WriteBlobString(image,"</body>\n");
       (void) WriteBlobString(image,"</html>\n");
       CloseBlob(image);
       /*
-        Write the image as GIF.
+        Write the image as PNG.
       */
       (void) CopyMagickString(image->filename,filename,MaxTextExtent);
-      AppendImageFormat("gif",image->filename);
+      AppendImageFormat("png",image->filename);
       next=GetNextImageInList(image);
       image->next=NewImageList();
-      (void) CopyMagickString(image->magick,"GIF",MaxTextExtent);
+      (void) CopyMagickString(image->magick,"PNG",MaxTextExtent);
       (void) WriteImage(write_info,image);
       image->next=next;
       /*
@@ -403,15 +407,16 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
   /*
     Write an image map.
   */
-  (void) FormatMagickString(buffer,MaxTextExtent,"<map name=\"%s\">\n",mapname);
+  (void) FormatMagickString(buffer,MaxTextExtent,
+    "<map id=\"%s\" name=\"%s\">\n",mapname,mapname);
   (void) WriteBlobString(image,buffer);
   (void) FormatMagickString(buffer,MaxTextExtent,"  <area href=\"%s",url);
   (void) WriteBlobString(image,buffer);
   if (image->directory == (char *) NULL)
     {
       (void) FormatMagickString(buffer,MaxTextExtent,
-        "%s\" shape=rect coords=\"0,0,%lu,%lu\">\n",image->filename,
-        geometry.width-1,geometry.height-1);
+        "%s\" shape=\"rect\" coords=\"0,0,%lu,%lu\" alt=\"\" />\n",
+        image->filename,geometry.width-1,geometry.height-1);
       (void) WriteBlobString(image,buffer);
     }
   else
@@ -421,9 +426,9 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
       else
         {
           (void) FormatMagickString(buffer,MaxTextExtent,
-            "\" shape=rect coords=\"%ld,%ld,%ld,%ld\">\n",geometry.x,geometry.y,
-            geometry.x+(long) geometry.width-1,geometry.y+(long)
-            geometry.height-1);
+            "\" shape=\"rect\" coords=\"%ld,%ld,%ld,%ld\" alt=\"\" />\n",
+            geometry.x,geometry.y,geometry.x+(long) geometry.width-1,
+            geometry.y+(long) geometry.height-1);
           (void) WriteBlobString(image,buffer);
           if (*(p+1) != '\0')
             {
@@ -432,7 +437,7 @@ static MagickBooleanType WriteHTMLImage(const ImageInfo *image_info,
               (void) WriteBlobString(image,buffer);
             }
           geometry.x+=geometry.width;
-          if (geometry.x >= (long) image->columns)
+          if ((geometry.x+4) >= (long) image->columns)
             {
               geometry.x=0;
               geometry.y+=geometry.height;
