@@ -255,7 +255,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
     icon_info.height=(unsigned char) ReadBlobLSBLong(image)/2;
     icon_info.planes=ReadBlobLSBShort(image);
     icon_info.bits_per_pixel=ReadBlobLSBShort(image);
-    if (icon_info.bits_per_pixel > 32)
+    if (icon_info.bits_per_pixel > 32U)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     icon_info.compression=ReadBlobLSBLong(image);
     icon_info.image_size=ReadBlobLSBLong(image);
@@ -264,26 +264,26 @@ static Image *ReadICONImage(const ImageInfo *image_info,
     icon_info.number_colors=ReadBlobLSBLong(image);
     icon_info.colors_important=ReadBlobLSBLong(image);
     image->matte=MagickTrue;
-    image->columns=(unsigned long) icon_info.width;
-    image->rows=(unsigned long) icon_info.height;
+    image->columns=(unsigned long) icon_file.directory[i].width;
+    image->rows=(unsigned long) icon_file.directory[i].height;
     image->depth=8;
     if (image->debug != MagickFalse)
-    {
-      (void) LogMagickEvent(CoderEvent,GetMagickModule()," scene    = %ld",i);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   size   = %ld",
-        icon_info.size);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   width  = %d",
-        icon_file.directory[i].width);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   height = %d",
-        icon_file.directory[i].height);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   colors = %ld",
-        icon_info.number_colors);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   planes = %d",
-        icon_info.planes);
-      (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   bpp    = %d",
-        icon_info.bits_per_pixel);
-    }
-  if ((icon_info.number_colors != 0) || (icon_info.bits_per_pixel <= 16))
+      {
+        (void) LogMagickEvent(CoderEvent,GetMagickModule()," scene    = %ld",i);
+        (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   size   = %ld",
+          icon_info.size);
+        (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   width  = %d",
+          icon_file.directory[i].width);
+        (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   height = %d",
+          icon_file.directory[i].height);
+        (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   colors = %ld",
+          icon_info.number_colors);
+        (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   planes = %d",
+          icon_info.planes);
+        (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   bpp    = %d",
+          icon_info.bits_per_pixel);
+      }
+  if ((icon_info.number_colors != 0) || (icon_info.bits_per_pixel <= 16U))
     {
       image->storage_class=PseudoClass;
       image->colors=icon_info.number_colors;
@@ -307,8 +307,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
       number_colors=1UL << icon_info.bits_per_pixel;
       if (AllocateImageColormap(image,number_colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-      icon_colormap=(unsigned char *)
-        AcquireMagickMemory((size_t) (4*image->colors));
+      icon_colormap=(unsigned char *) AcquireMagickMemory((size_t)
+        (4*image->colors));
       if (icon_colormap == (unsigned char *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       count=ReadBlob(image,(size_t) (4*image->colors),icon_colormap);
@@ -327,8 +327,6 @@ static Image *ReadICONImage(const ImageInfo *image_info,
     /*
       Convert Icon raster image to pixel packets.
     */
-    image->columns=(unsigned long) icon_file.directory[i].width;
-    image->rows=(unsigned long) icon_file.directory[i].height;
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
@@ -523,7 +521,6 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     }
     (void) SyncImage(image);
-
     image->storage_class=DirectClass;
     image->matte=MagickTrue;
     for (y=(long) image->rows-1; y >= 0; y--)
