@@ -163,7 +163,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsJPEG(const unsigned char *magick,const size_t length)
 {
@@ -201,7 +200,6 @@ static MagickBooleanType IsJPEG(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickBooleanType EmitMessage(j_common_ptr jpeg_info,int level)
@@ -430,8 +428,7 @@ static boolean ReadIPTCProfile(j_decompress_ptr jpeg_info)
     *p;
 
   size_t
-    length,
-    tag_length;
+    length;
 
   StringInfo
     *iptc_profile,
@@ -442,45 +439,43 @@ static boolean ReadIPTCProfile(j_decompress_ptr jpeg_info)
   */
   length=(size_t) ((unsigned long) GetCharacter(jpeg_info) << 8);
   length+=(size_t) GetCharacter(jpeg_info);
-  if (length <= 2)
-    return(MagickTrue);
   length-=2;
-  tag_length=0;
-  error_manager=(ErrorManager *) jpeg_info->client_data;
-  image=error_manager->image;
-  iptc_profile=(StringInfo *) GetImageProfile(image,"8bim");
-  if (iptc_profile == (StringInfo *) NULL)
+  if (length <= 14)
+    {
+      while (length-- > 0)
+        (void) GetCharacter(jpeg_info);
+      return(MagickTrue);
+    }
+  /*
+    Validate that this was written as a Photoshop resource format slug.
+  */
+  for (i=0; i < 10; i++)
+    magick[i]=(char) GetCharacter(jpeg_info);
+  magick[10]='\0';
+  if (length <= 10)
+    return(MagickTrue);
+  length-=10;
+  if (LocaleCompare(magick,"Photoshop ") != 0)
     {
       /*
-        Validate that this was written as a Photoshop resource format slug.
+        Not a IPTC profile, return.
       */
-      for (i=0; i < 10; i++)
-        magick[i]=(char) GetCharacter(jpeg_info);
-      magick[10]='\0';
-      if (length <= 10)
-        return(MagickTrue);
-      length-=10;
-      if (LocaleCompare(magick,"Photoshop ") != 0)
-        {
-          /*
-            Not a IPTC profile, return.
-          */
-          for (i=0; i < (long) length; i++)
-            (void) GetCharacter(jpeg_info);
-          return(MagickTrue);
-        }
-      /*
-        Remove the version number.
-      */
-      for (i=0; i < 4; i++)
+      for (i=0; i < (long) length; i++)
         (void) GetCharacter(jpeg_info);
-      if (length <= 4)
-        return(MagickTrue);
-      length-=4;
-      tag_length=0;
+      return(MagickTrue);
     }
+  /*
+    Remove the version number.
+  */
+  for (i=0; i < 4; i++)
+    (void) GetCharacter(jpeg_info);
+  if (length <= 4)
+    return(MagickTrue);
+  length-=4;
   if (length == 0)
     return(MagickTrue);
+  error_manager=(ErrorManager *) jpeg_info->client_data;
+  image=error_manager->image;
   profile=AcquireStringInfo(length);
   if (profile == (StringInfo *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -546,9 +541,9 @@ static boolean ReadProfile(j_decompress_ptr jpeg_info)
     return(MagickTrue);
   length-=2;
   marker=jpeg_info->unread_marker-JPEG_APP0;
+  (void) FormatMagickString(name,MaxTextExtent,"APP%d",marker);
   error_manager=(ErrorManager *) jpeg_info->client_data;
   image=error_manager->image;
-  (void) FormatMagickString(name,MaxTextExtent,"APP%d",marker);
   profile=AcquireStringInfo(length);
   if (profile == (StringInfo *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -1091,18 +1086,30 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
             p++;
           }
         else
-          for (x=0; x < (long) image->columns; x++)
-          {
-            q->red=ScaleShortToQuantum((unsigned char) (GETJSAMPLE(*p++) << 4));
-            q->green=ScaleShortToQuantum((unsigned char)
-              (GETJSAMPLE(*p++) << 4));
-            q->blue=ScaleShortToQuantum((unsigned char)
-              (GETJSAMPLE(*p++) << 4));
-            if (image->colorspace == CMYKColorspace)
-              indexes[x]=ScaleShortToQuantum((unsigned char)
+          if (image->colorspace != CMYKColorspace)
+            for (x=0; x < (long) image->columns; x++)
+            {
+              q->red=ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4));
-            q++;
-          }
+              q->green=ScaleShortToQuantum((unsigned char)
+                (GETJSAMPLE(*p++) << 4));
+              q->blue=ScaleShortToQuantum((unsigned char)
+                (GETJSAMPLE(*p++) << 4));
+              q++;
+            }
+          else
+            for (x=0; x < (long) image->columns; x++)
+            {
+              q->red=QuantumRange-ScaleShortToQuantum((unsigned char)
+                (GETJSAMPLE(*p++) << 4));
+              q->green=QuantumRange-ScaleShortToQuantum((unsigned char)
+                (GETJSAMPLE(*p++) << 4));
+              q->blue=QuantumRange-ScaleShortToQuantum((unsigned char)
+                (GETJSAMPLE(*p++) << 4));
+              indexes[x]=QuantumRange-ScaleShortToQuantum((unsigned char)
+                (GETJSAMPLE(*p++) << 4));
+              q++;
+            }
       }
     else
       if (jpeg_info.output_components == 1)
@@ -1114,15 +1121,27 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
           p++;
         }
       else
-        for (x=0; x < (long) image->columns; x++)
-        {
-          q->red=ScaleCharToQuantum((unsigned char) GETJSAMPLE(*p++));
-          q->green=ScaleCharToQuantum((unsigned char) GETJSAMPLE(*p++));
-          q->blue=ScaleCharToQuantum((unsigned char) GETJSAMPLE(*p++));
-          if (image->colorspace == CMYKColorspace)
-            indexes[x]=ScaleCharToQuantum((unsigned char) GETJSAMPLE(*p++));
-          q++;
-        }
+        if (image->colorspace != CMYKColorspace)
+          for (x=0; x < (long) image->columns; x++)
+          {
+            q->red=ScaleCharToQuantum((unsigned char) GETJSAMPLE(*p++));
+            q->green=ScaleCharToQuantum((unsigned char) GETJSAMPLE(*p++));
+            q->blue=ScaleCharToQuantum((unsigned char) GETJSAMPLE(*p++));
+            q++;
+          }
+        else
+          for (x=0; x < (long) image->columns; x++)
+          {
+            q->red=QuantumRange-ScaleCharToQuantum((unsigned char)
+              GETJSAMPLE(*p++));
+            q->green=QuantumRange-ScaleCharToQuantum((unsigned char)
+              GETJSAMPLE(*p++));
+            q->blue=QuantumRange-ScaleCharToQuantum((unsigned char)
+              GETJSAMPLE(*p++));
+            indexes[x]=QuantumRange-ScaleCharToQuantum((unsigned char)
+              GETJSAMPLE(*p++));
+            q++;
+          }
     if (SyncImagePixels(image) == MagickFalse)
       break;
     if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -1134,29 +1153,6 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
           break;
       }
   }
-  if (image->colorspace == CMYKColorspace)
-    {
-      /*
-        Correct CMYK levels.
-      */
-      for (y=0; y < (long) image->rows; y++)
-      {
-        q=GetImagePixels(image,0,y,image->columns,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        indexes=GetIndexes(image);
-        for (x=0; x < (long) image->columns; x++)
-        {
-          q->red=(Quantum) (QuantumRange-q->red);
-          q->green=(Quantum) (QuantumRange-q->green);
-          q->blue=(Quantum) (QuantumRange-q->blue);
-          indexes[x]=(IndexPacket) (QuantumRange-indexes[x]);
-          q++;
-        }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-      }
-    }
   /*
     Free jpeg resources.
   */
