@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -135,9 +135,9 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       for ( ; status != MagickFalse; draw_info->pointsize*=2.0)
       {
         width=(unsigned long) (metrics.width+draw_info->stroke_width+0.5);
-        height=(unsigned long) (metrics.height+0.5);
-        if (((image->columns != 0) && (width >= image->columns)) ||
-            ((image->rows != 0) && (height >= image->rows)))
+        height=(unsigned long) (metrics.height+draw_info->stroke_width+0.5);
+        if (((image->columns != 0) && (width > (image->columns+1))) ||
+            ((image->rows != 0) && (height > (image->rows+1))))
           break;
         status=GetMultilineTypeMetrics(image,draw_info,&metrics);
       }
@@ -145,11 +145,11 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       {
         width=(unsigned long) (metrics.width+draw_info->stroke_width+0.5);
         height=(unsigned long) (metrics.height+draw_info->stroke_width+0.5);
-        if ((image->columns != 0) && (width <= image->columns) &&
-           ((image->rows == 0) || (height <= image->rows)))
+        if ((image->columns != 0) && (width <= (image->columns+1)) &&
+           ((image->rows == 0) || (height <= (image->rows+1))))
           break;
-        if ((image->rows != 0) && (height <= image->rows) &&
-           ((image->columns == 0) || (width <= image->columns)))
+        if ((image->rows != 0) && (height <= (image->rows+1)) &&
+           ((image->columns == 0) || (width <= (image->columns+1))))
           break;
         if (draw_info->pointsize < 2.0)
           break;
