@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -90,8 +90,8 @@ ModuleExport void RegisterMATTEImage(void)
 
   entry=SetMagickInfo("MATTE");
   entry->encoder=(EncoderHandler *) WriteMATTEImage;
-  entry->description=AcquireString("MATTE format");
-  entry->module=AcquireString("MATTE");
+  entry->description=ConstantString("MATTE format");
+  entry->module=ConstantString("MATTE");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -173,7 +173,7 @@ static MagickBooleanType WriteMATTEImage(const ImageInfo *image_info,
     CloneImage(image,image->columns,image->rows,MagickTrue,&image->exception);
   if (matte_image == (Image *) NULL)
     return(MagickFalse);
-  (void) SetImageType(matte_image,TrueColorType);
+  (void) SetImageType(matte_image,TrueColorMatteType);
   matte_image->matte=MagickFalse;
   /*
     Convert image to matte pixels.
