@@ -17,7 +17,7 @@
 %                                 July 2001                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -413,11 +413,18 @@ static long parse8BIM(Image *ifile, Image *ofile)
 
                 if (savedolen > 0)
                   {
+                    MagickOffsetType
+                      offset;
+
                     long diff = outputlen - savedolen;
                     currentpos = TellBlob(ofile);
-                    (void) SeekBlob(ofile,savedpos,SEEK_SET);
+                    offset=SeekBlob(ofile,savedpos,SEEK_SET);
+                    if (offset < 0)
+                      return(-1);
                     (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
-                    (void) SeekBlob(ofile,currentpos,SEEK_SET);
+                    offset=SeekBlob(ofile,currentpos,SEEK_SET);
+                    if (offset < 0)
+                      return(-1);
                     savedolen = 0L;
                   }
                 if (outputlen & 1)
@@ -485,18 +492,26 @@ static long parse8BIM(Image *ifile, Image *ofile)
     }
     token=DestroyString(token);
     newstr=DestroyString(newstr);
-    name=DestroyString(name);
+    if (name != (char *) NULL)
+      name=DestroyString(name);
   }
   token_info=DestroyTokenInfo(token_info);
   line=DestroyString(line);
   if (savedolen > 0)
     {
+      MagickOffsetType
+        offset;
+
       long diff = outputlen - savedolen;
 
       currentpos = TellBlob(ofile);
-      (void) SeekBlob(ofile,savedpos,SEEK_SET);
+      offset=SeekBlob(ofile,savedpos,SEEK_SET);
+      if (offset < 0)
+        return(-1);
       (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
-      (void) SeekBlob(ofile,currentpos,SEEK_SET);
+      offset=SeekBlob(ofile,currentpos,SEEK_SET);
+      if (offset < 0)
+        return(-1);
       savedolen = 0L;
     }
   return outputlen;
@@ -676,11 +691,18 @@ static long parse8BIMW(Image *ifile, Image *ofile)
 
                 if (savedolen > 0)
                   {
+                    MagickOffsetType
+                      offset;
+
                     long diff = outputlen - savedolen;
                     currentpos = TellBlob(ofile);
-                    (void) SeekBlob(ofile,savedpos,SEEK_SET);
+                    offset=SeekBlob(ofile,savedpos,SEEK_SET);
+                    if (offset < 0)
+                      return(-1);
                     (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
-                    (void) SeekBlob(ofile,currentpos,SEEK_SET);
+                    offset=SeekBlob(ofile,currentpos,SEEK_SET);
+                    if (offset < 0)
+                      return(-1);
                     savedolen = 0L;
                   }
                 if (outputlen & 1)
@@ -754,12 +776,19 @@ static long parse8BIMW(Image *ifile, Image *ofile)
   line=DestroyString(line);
   if (savedolen > 0)
     {
+      MagickOffsetType
+        offset;
+
       long diff = outputlen - savedolen;
 
       currentpos = TellBlob(ofile);
-      (void) SeekBlob(ofile,savedpos,SEEK_SET);
+      offset=SeekBlob(ofile,savedpos,SEEK_SET);
+      if (offset < 0)
+        return(-1);
       (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
-      (void) SeekBlob(ofile,currentpos,SEEK_SET);
+      offset=SeekBlob(ofile,currentpos,SEEK_SET);
+      if (offset < 0)
+        return(-1);
       savedolen = 0L;
     }
   return outputlen;
@@ -1312,6 +1341,33 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
       blob=(unsigned char *) RelinquishMagickMemory(blob);
       buff=DestroyImage(buff);
     }
+  if (LocaleCompare(image_info->magick,"XMP") == 0)
+    {
+      buff=AllocateImage((ImageInfo *) NULL);
+      if (buff == (Image *) NULL)
+        ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+      blob=(unsigned char *) AcquireMagickMemory(length);
+      if (blob == (unsigned char *) NULL)
+        {
+          buff=DestroyImage(buff);
+          ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+        }
+      AttachBlob(buff->blob,blob,length);
+      for ( ; ; )
+      {
+        c=ReadBlobByte(image);
+        if (c == EOF)
+          break;
+        (void) WriteBlobByte(buff,(unsigned char) c);
+      }
+      profile=AcquireStringInfo((size_t) GetBlobSize(buff));
+      SetStringInfoDatum(profile,GetBlobStreamData(buff));
+      (void) SetImageProfile(image,"xmp",profile);
+      profile=DestroyStringInfo(profile);
+      blob=DetachBlob(buff->blob);
+      blob=(unsigned char *) RelinquishMagickMemory(blob);
+      buff=DestroyImage(buff);
+    }
   CloseBlob(image);
   return(GetFirstImageInList(image));
 }
@@ -2172,6 +2228,8 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
         *info;
 
       profile=GetImageProfile(image,"iptc");
+      if (profile == (StringInfo *) NULL)
+        profile=GetImageProfile(image,"8bim");
       if (profile == (StringInfo *) NULL)
         ThrowWriterException(CoderError,"No8BIMDataIsAvailable");
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
