@@ -123,7 +123,6 @@ static MagickBooleanType IsMVG(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -198,7 +197,7 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Render drawing.
   */
   primitive=GetBlobStreamData(image);
-  if (primitive != (unsigned char) NULL)
+  if (primitive != (unsigned char *) NULL)
     draw_info->primitive=AcquireString((char *) primitive);
   else
     draw_info->primitive=FileToString(image->filename,~0,exception);
@@ -296,7 +295,6 @@ ModuleExport void UnregisterMVGImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteMVGImage(const ImageInfo *image_info,Image *image)
 {
