@@ -812,9 +812,10 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
         {
           for (x=0; x < (int) image->columns; x++)
           {
-            color16=(unsigned short) ((((31*(unsigned long) p->red)/QuantumRange) << 11) |
-              (((63*(unsigned long) p->green)/QuantumRange) << 5) |
-              ((31*(unsigned long) p->blue)/QuantumRange));
+            color16=(unsigned short) ((((31*(unsigned long) p->red)/
+              (unsigned long) QuantumRange) << 11) |
+              (((63*(unsigned long) p->green)/(unsigned long) QuantumRange) << 5) |
+              ((31*(unsigned long) p->blue)/(unsigned long) QuantumRange));
             if (p->opacity == TransparentOpacity)
               {
                 transpix.red=p->red;
