@@ -299,8 +299,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       magic=ReadBlobLSBLong(image);
       if (magic != 987654321)
         ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-      page_table=(MagickOffsetType *)
-         AcquireMagickMemory(1024*sizeof(*page_table));
+      page_table=(MagickOffsetType *) AcquireMagickMemory(1024*
+        sizeof(*page_table));
       if (page_table == (MagickOffsetType *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       for (id=0; id < 1024; id++)
@@ -337,8 +337,10 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Read PCX raster colormap.
     */
-    image->columns=MagickAbsoluteValue(pcx_info.right-pcx_info.left)+1UL;
-    image->rows=MagickAbsoluteValue(pcx_info.bottom-pcx_info.top)+1UL;
+    image->columns=(unsigned long) MagickAbsoluteValue((long) pcx_info.right-
+      pcx_info.left)+1UL;
+    image->rows=(unsigned long) MagickAbsoluteValue((long) pcx_info.bottom-
+      pcx_info.top)+1UL;
     if ((image->columns == 0) || (image->rows == 0) ||
         (pcx_info.bits_per_pixel == 0))
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -357,8 +359,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((pcx_info.bits_per_pixel != 8) || (pcx_info.planes == 1))
       if ((pcx_info.version == 3) || (pcx_info.version == 5) ||
           ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
-        image->colors=(unsigned long) MagickMin(1UL << (pcx_info.bits_per_pixel*
-          pcx_info.planes),256UL);
+        image->colors=(unsigned long) MagickMin(1UL << (1UL*
+          pcx_info.bits_per_pixel*pcx_info.planes),256UL);
     if (AllocateImageColormap(image,image->colors) == MagickFalse)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((pcx_info.bits_per_pixel >= 8) && (pcx_info.planes != 1))
@@ -442,9 +444,9 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
               /*
                 Monochrome colormap.
               */
-              image->colormap[0].red=0;
-              image->colormap[0].green=0;
-              image->colormap[0].blue=0;
+              image->colormap[0].red=(Quantum) 0;
+              image->colormap[0].green=(Quantum) 0;
+              image->colormap[0].blue=(Quantum) 0;
               image->colormap[1].red=QuantumRange;
               image->colormap[1].green=QuantumRange;
               image->colormap[1].blue=QuantumRange;
@@ -598,7 +600,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       for (x=0; x < (long) image->columns; x++)
       {
         if (image->storage_class == PseudoClass)
-          indexes[x]=(*r++);
+          indexes[x]=(IndexPacket) (*r++);
         else
           {
             q->red=ScaleCharToQuantum(*r++);
