@@ -465,8 +465,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
     if (count != 4)
       continue;
-    if (((unsigned long) (bounds.x2-bounds.x1+0.5) > page.width) ||
-        ((unsigned long) (bounds.y2-bounds.y1+0.5) > page.height))
+    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
       {
         /*
           Set PDF render geometry.
@@ -1244,7 +1243,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     if (image->matte != MagickFalse)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,"/SMask %lu 0 R\n",
-          object+7);
+          object+6);
         (void) WriteBlobString(image,buffer);
       }
     (void) FormatMagickString(buffer,MaxTextExtent,"/Length %lu 0 R\n",
@@ -2047,12 +2046,14 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     /*
       Write softmask object.
     */
-    if (image->matte != MagickFalse)
+    xref[object++]=TellBlob(image);
+    (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
+    (void) WriteBlobString(image,buffer);
+    (void) WriteBlobString(image,"<<\n");
+    if (image->matte == MagickFalse)
+      (void) WriteBlobString(image,">>\n");
+    else
       {
-        xref[object++]=TellBlob(image);
-        (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
-        (void) WriteBlobString(image,buffer);
-        (void) WriteBlobString(image,"<<\n");
         (void) WriteBlobString(image,"/Type /XObject\n");
         (void) WriteBlobString(image,"/Subtype /Image\n");
         (void) FormatMagickString(buffer,MaxTextExtent,"/Name /Ma%lu\n",
@@ -2178,9 +2179,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         }
         offset=TellBlob(image)-offset;
         (void) WriteBlobString(image,"\nendstream\n");
-        (void) WriteBlobString(image,"endobj\n");
       }
-
+    (void) WriteBlobString(image,"endobj\n");
     /*
       Write Length object.
     */
