@@ -82,6 +82,10 @@
   pixmap.plane_bytes=ReadBlobMSBLong(image); \
   pixmap.table=ReadBlobMSBLong(image); \
   pixmap.reserved=ReadBlobMSBLong(image); \
+  if ((pixmap.bits_per_pixel <= 0) || (pixmap.bits_per_pixel > 32) || \
+      (pixmap.component_count <= 0) || (pixmap.component_count > 4) || \
+      (pixmap.component_size <= 0)) \
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader"); \
 }
 
 #define ReadRectangle(image,rectangle) \
