@@ -90,14 +90,15 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsPNM(const unsigned char *magick,const size_t length)
 {
   if (length < 2)
     return(MagickFalse);
   if ((*magick == (unsigned char) 'P') &&
-      (isdigit((int) magick[1]) != MagickFalse))
+      ((magick[1] == '1') || (magick[1] == '2') || (magick[1] == '3') ||
+       (magick[1] == '4') || (magick[1] == '5') || (magick[1] == '6') ||
+       (magick[1] == '7') || (magick[1] == 'F') || (magick[1] == 'f')))
     return(MagickTrue);
   return(MagickFalse);
 }
@@ -215,31 +216,54 @@ static unsigned long PNMInteger(Image *image,const unsigned int base)
     c=ReadBlobByte(image);
     if (c == EOF)
       return(value);
-  }
-  while (isdigit(c) != MagickFalse);
+  } while (isdigit(c) != MagickFalse);
   return(value);
 }
 
+static inline unsigned char PushCharPixel(const unsigned char **pixels)
+{
+  unsigned char
+    pixel;
+
+  pixel=(unsigned char) *(*pixels)++;
+  return(pixel);
+}
+
+static inline unsigned long PushLongPixel(const unsigned char **pixels)
+{
+  unsigned long
+    pixel;
+
+  pixel=(unsigned long) (*(*pixels)++ << 24);
+  pixel|=(unsigned long) (*(*pixels)++ << 16);
+  pixel|=(unsigned long) (*(*pixels)++ << 8);
+  pixel|=(unsigned long) (*(*pixels)++);
+  return(pixel);
+}
+
+static inline unsigned short PushShortPixel(const unsigned char **pixels)
+{
+  unsigned short
+    pixel;
+
+  pixel=(unsigned short) (*(*pixels)++ << 8);
+  pixel|=(unsigned short) (*(*pixels)++);
+  return(pixel);
+}
+
 static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-#define PushCharPixel(pixel,p) \
-{ \
-  pixel=(unsigned long) (*(p)); \
-  (p)++; \
-}
-#define PushShortPixel(pixel,p) \
-{ \
-  pixel=(unsigned long) ((*(p) << 8) | *((p)+1)); \
-  (p)+=2; \
-}
-
   char
     format;
 
+  const unsigned char
+    *p;
+
   Image
     *image;
 
   long
+    index,
     y;
 
   MagickBooleanType
@@ -249,6 +273,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Quantum
     *scale;
 
+  QuantumInfo
+    quantum_info;
+
   register IndexPacket
     *indexes;
 
@@ -261,9 +288,6 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register long
     i;
 
-  register unsigned char
-    *p;
-
   size_t
     length,
     packet_size;
@@ -275,7 +299,6 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *pixels;
 
   unsigned long
-    index,
     max_value;
 
   /*
@@ -308,6 +331,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     max_value=1;
     grayscale=MagickFalse;
+    GetQuantumInfo(image_info,&quantum_info);
     format=(char) ReadBlobByte(image);
     if (format != '7')
       {
@@ -316,11 +340,24 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         image->columns=PNMInteger(image,10);
         image->rows=PNMInteger(image,10);
-        if ((format == '1') || (format == '4'))
-          max_value=1;  /* bitmap */
+        if ((format == 'f') || (format == 'F'))
+          {
+            char
+              scale[MaxTextExtent];
+
+            (void) ReadBlobString(image,scale);
+            quantum_info.scale=fabs(atof(scale));
+            image->endian=atof(scale) < 0.0 ? LSBEndian : MSBEndian;
+          }
         else
-          max_value=PNMInteger(image,10);
-        if ((format != '3') && (format != '6'))
+          {
+            if ((format == '1') || (format == '4'))
+              max_value=1;  /* bitmap */
+            else
+              max_value=PNMInteger(image,10);
+          }
+        if ((format == '1') || (format == '2') || (format == '4') ||
+            (format == '5'))
           {
             image->storage_class=PseudoClass;
             image->colors=(unsigned long) (max_value >= MaxColormapSize ?
@@ -411,7 +448,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image->storage_class == PseudoClass)
       if (AllocateImageColormap(image,image->colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    if ((image->storage_class != PseudoClass) || (max_value > QuantumRange))
+    if ((image->storage_class != PseudoClass) ||
+        (max_value > (1U*QuantumRange)))
       {
         /*
           Compute pixel scaling table.
@@ -421,7 +459,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (scale == (Quantum *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (i=0; i <= (long) max_value; i++)
-          scale[i]=ScaleAnyToQuantum((unsigned long) i,max_value);
+          scale[i]=ScaleAnyToQuantum((QuantumAny) i,image->depth);
       }
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
@@ -444,7 +482,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           indexes=GetIndexes(image);
           for (x=0; x < (long) image->columns; x++)
           {
-            index=(IndexPacket) (PNMInteger(image,2) == 0);
+            index=PNMInteger(image,2) == 0 ? 1 : 0;
             if ((unsigned long) index >= image->colors)
               {
                 (void) ThrowMagickException(&image->exception,GetMagickModule(),
@@ -487,8 +525,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             intensity=PNMInteger(image,10);
             if (scale != (Quantum *) NULL)
-              intensity=scale[intensity];
-            index=(IndexPacket) intensity;
+              intensity=(unsigned long) scale[ConstrainPixel(image,(long)
+                intensity,max_value)];
+            index=(long) intensity;
             if ((unsigned long) index >= image->colors)
               {
                 (void) ThrowMagickException(&image->exception,GetMagickModule(),
@@ -515,7 +554,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
       case '3':
       {
-        LongPixelPacket
+        MagickPixelPacket
           pixel;
 
         /*
@@ -528,14 +567,17 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           for (x=0; x < (long) image->columns; x++)
           {
-            pixel.red=PNMInteger(image,10);
-            pixel.green=PNMInteger(image,10);
-            pixel.blue=PNMInteger(image,10);
+            pixel.red=(MagickRealType) PNMInteger(image,10);
+            pixel.green=(MagickRealType) PNMInteger(image,10);
+            pixel.blue=(MagickRealType) PNMInteger(image,10);
             if (scale != (Quantum *) NULL)
               {
-                pixel.red=scale[ConstrainPixel(image,pixel.red,max_value)];
-                pixel.green=scale[ConstrainPixel(image,pixel.green,max_value)];
-                pixel.blue=scale[ConstrainPixel(image,pixel.blue,max_value)];
+                pixel.red=(MagickRealType) scale[ConstrainPixel(image,(long)
+                  pixel.red,max_value)];
+                pixel.green=(MagickRealType) scale[ConstrainPixel(image,(long)
+                  pixel.green,max_value)];
+                pixel.blue=(MagickRealType) scale[ConstrainPixel(image,(long)
+                  pixel.blue,max_value)];
               }
             q->red=(Quantum) pixel.red;
             q->green=(Quantum) pixel.green;
@@ -577,7 +619,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             if (bit == 0)
               byte=(unsigned long) ReadBlobByte(image);
-            index=(IndexPacket) ((byte & 0x80) != 0 ? 0x00 : 0x01);
+            index=(long) ((byte & 0x80) != 0 ? 0x00 : 0x01);
             indexes[x]=(IndexPacket) index;
             *q++=image->colormap[index];
             bit++;
@@ -625,7 +667,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (image->depth <= 8)
             for (x=0; x < (long) image->columns; x++)
             {
-              index=(IndexPacket) (*p++);
+              index=(long) (*p++);
               if ((unsigned long) index >= image->colors)
                 {
                   (void) ThrowMagickException(&image->exception,
@@ -639,8 +681,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              PushShortPixel(index,p);
-              if (index >= image->colors)
+              index=(long) PushShortPixel(&p);
+              if (index >= (long) image->colors)
                 {
                   (void) ThrowMagickException(&image->exception,
                     GetMagickModule(),CorruptImageError,"InvalidColormapIndex",
@@ -670,7 +712,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
       case '6':
       {
-        LongPixelPacket
+        MagickPixelPacket
           pixel;
 
         /*
@@ -696,14 +738,17 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (image->depth <= 8)
             for (x=0; x < (long) image->columns; x++)
             {
-              PushCharPixel(pixel.red,p);
-              PushCharPixel(pixel.green,p);
-              PushCharPixel(pixel.blue,p);
+              pixel.red=(MagickRealType) PushCharPixel(&p);
+              pixel.green=(MagickRealType) PushCharPixel(&p);
+              pixel.blue=(MagickRealType) PushCharPixel(&p);
               if (scale != (Quantum *) NULL)
                 {
-                  pixel.red=scale[ConstrainPixel(image,pixel.red,max_value)];
-                  pixel.green=scale[ConstrainPixel(image,pixel.green,max_value)];
-                  pixel.blue=scale[ConstrainPixel(image,pixel.blue,max_value)];
+                  pixel.red=(MagickRealType) scale[ConstrainPixel(image,(long)
+                    pixel.red,max_value)];
+                  pixel.green=(MagickRealType) scale[ConstrainPixel(image,(long)
+                    pixel.green,max_value)];
+                  pixel.blue=(MagickRealType) scale[ConstrainPixel(image,(long) 
+                    pixel.blue,max_value)];
                 }
               q->red=(Quantum) pixel.red;
               q->green=(Quantum) pixel.green;
@@ -713,14 +758,17 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              PushShortPixel(pixel.red,p);
-              PushShortPixel(pixel.green,p);
-              PushShortPixel(pixel.blue,p);
+              pixel.red=(MagickRealType) PushShortPixel(&p);
+              pixel.green=(MagickRealType) PushShortPixel(&p);
+              pixel.blue=(MagickRealType) PushShortPixel(&p);
               if (scale != (Quantum *) NULL)
                 {
-                  pixel.red=scale[ConstrainPixel(image,pixel.red,max_value)];
-                  pixel.green=scale[ConstrainPixel(image,pixel.green,max_value)];
-                  pixel.blue=scale[ConstrainPixel(image,pixel.blue,max_value)];
+                  pixel.red=(MagickRealType) scale[ConstrainPixel(image,(long)
+                    pixel.red,max_value)];
+                  pixel.green=(MagickRealType) scale[ConstrainPixel(image,(long)
+                    pixel.green,max_value)];
+                  pixel.blue=(MagickRealType) scale[ConstrainPixel(image,(long)
+                    pixel.blue,max_value)];
                 }
               q->red=(Quantum) pixel.red;
               q->green=(Quantum) pixel.green;
@@ -784,42 +832,42 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               if (image->depth <= 8)
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  PushCharPixel(pixel,p);
-                  q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                  pixel=PushCharPixel(&p);
+                  q->red=ScaleAnyToQuantum(pixel,image->depth);
                   q->green=q->red;
                   q->blue=q->red;
                   if (image->colorspace == CMYKColorspace)
                     {
-                      PushCharPixel(pixel,p);
+                      pixel=PushCharPixel(&p);
                       indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                        image->depth);
                     }
                   if (image->matte != MagickFalse)
                     {
-                      PushCharPixel(pixel,p);
+                      pixel=PushCharPixel(&p);
                       q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                        image->depth);
                     }
                   q++;
                 }
               else
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  PushShortPixel(pixel,p);
-                  q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                  pixel=PushShortPixel(&p);
+                  q->red=ScaleAnyToQuantum(pixel,image->depth);
                   q->green=q->red;
                   q->blue=q->red;
                   if (image->colorspace == CMYKColorspace)
                     {
-                      PushShortPixel(pixel,p);
+                      pixel=PushShortPixel(&p);
                       indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                        image->depth);
                     }
                   if (image->matte != MagickFalse)
                     {
-                      PushShortPixel(pixel,p);
+                      pixel=PushShortPixel(&p);
                       q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                        (1UL << image->depth)-1);
+                        image->depth);
                     }
                   q++;
                 }
@@ -828,46 +876,46 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if (image->depth <= 8)
               for (x=0; x < (long) image->columns; x++)
               {
-                PushCharPixel(pixel,p);
-                q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                PushCharPixel(pixel,p);
-                q->green=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                PushCharPixel(pixel,p);
-                q->blue=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                pixel=PushCharPixel(&p);
+                q->red=ScaleAnyToQuantum(pixel,image->depth);
+                pixel=PushCharPixel(&p);
+                q->green=ScaleAnyToQuantum(pixel,image->depth);
+                pixel=PushCharPixel(&p);
+                q->blue=ScaleAnyToQuantum(pixel,image->depth);
                 if (image->colorspace == CMYKColorspace)
                   {
-                    PushCharPixel(pixel,p);
+                    pixel=PushCharPixel(&p);
                     indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                      image->depth);
                   }
                 if (image->matte != MagickFalse)
                   {
-                    PushCharPixel(pixel,p);
+                    pixel=PushCharPixel(&p);
                     q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                      image->depth);
                   }
                 q++;
               }
             else
               for (x=0; x < (long) image->columns; x++)
               {
-                PushShortPixel(pixel,p);
-                q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                PushShortPixel(pixel,p);
-                q->green=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                PushShortPixel(pixel,p);
-                q->blue=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
+                pixel=PushShortPixel(&p);
+                q->red=ScaleAnyToQuantum(pixel,image->depth);
+                pixel=PushShortPixel(&p);
+                q->green=ScaleAnyToQuantum(pixel,image->depth);
+                pixel=PushShortPixel(&p);
+                q->blue=ScaleAnyToQuantum(pixel,image->depth);
                 if (image->colorspace == CMYKColorspace)
                   {
-                    PushShortPixel(pixel,p);
+                    pixel=PushShortPixel(&p);
                     indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                      image->depth);
                   }
                 if (image->matte != MagickFalse)
                   {
-                    PushShortPixel(pixel,p);
+                    pixel=PushShortPixel(&p);
                     q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
-                      (1UL << image->depth)-1);
+                      image->depth);
                   }
                 q++;
               }
@@ -889,6 +937,50 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             CorruptImageError,"UnexpectedEndOfFile","`%s'",image->filename);
         break;
       }
+      case 'F':
+      case 'f':
+      {
+        QuantumType
+          quantum_type;
+
+        ssize_t
+          count;
+
+        image->depth=32;
+        quantum_info.format=FloatingPointQuantumFormat;
+        quantum_info.scale=QuantumRange;
+        quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
+        length=(format == 'f' ? 1 : 3)*image->columns*sizeof(float);
+        pixels=(unsigned char *) AcquireMagickMemory(length);
+        if (pixels == (unsigned char *) NULL)
+          ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+        for (y=(long) image->rows-1; y >= 0; y--)
+        {
+          q=SetImagePixels(image,0,y,image->columns,1);
+          if (q == (PixelPacket *) NULL)
+            break;
+          count=ReadBlob(image,length,pixels);
+          if ((size_t) count != length)
+            break;
+          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          if (SyncImagePixels(image) == MagickFalse)
+            break;
+          if (image->previous == (Image *) NULL)
+            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                (QuantumTick(y,image->rows) != MagickFalse))
+              {
+                status=image->progress_monitor(LoadImageTag,y,image->rows,
+                  image->client_data);
+                if (status == MagickFalse)
+                  break;
+              }
+        }
+        pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+        if (EOFBlob(image) != MagickFalse)
+          (void) ThrowMagickException(exception,GetMagickModule(),
+            CorruptImageError,"UnexpectedEndOfFile","`%s'",image->filename);
+        break;
+      }
       default:
         ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     }
@@ -978,6 +1070,12 @@ ModuleExport void RegisterPNMImage(void)
   entry->description=ConstantString("Portable bitmap format (black and white)");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
+  entry=SetMagickInfo("PFM");
+  entry->decoder=(DecoderHandler *) ReadPNMImage;
+  entry->encoder=(EncoderHandler *) WritePNMImage;
+  entry->description=ConstantString("Portable float format");
+  entry->module=ConstantString("PFM");
+  (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PGM");
   entry->decoder=(DecoderHandler *) ReadPNMImage;
   entry->encoder=(EncoderHandler *) WritePNMImage;
@@ -1051,25 +1149,36 @@ ModuleExport void UnregisterPNMImage(void)
 %
 %    o image:  The image.
 %
-%
 */
-static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
+
+static inline void PopCharPixel(const unsigned char pixel,
+  unsigned char **pixels)
 {
-#define PopCharPixel(pixel,p) \
-{ \
-  *(q)=(unsigned char) pixel; \
-  (q)++; \
-}
-#define PopShortPixel(pixel,p) \
-{ \
-  *(q)=(unsigned char) (pixel >> 8); \
-  (q)++; \
-  *(q)=(unsigned char) pixel; \
-  (q)++; \
+  *(*pixels)++=(unsigned char) (pixel);
 }
 
+static inline void PopShortPixel(const unsigned short pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static inline void PopLongPixel(const unsigned long pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 24);
+  *(*pixels)++=(unsigned char) ((pixel) >> 16);
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
+{
   char
-    buffer[MaxTextExtent];
+    buffer[MaxTextExtent],
+    format,
+    magick[MaxTextExtent];
 
   const char
     *value;
@@ -1077,9 +1186,6 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
   IndexPacket
     index;
 
-  int
-    format;
-
   long
     y;
 
@@ -1090,6 +1196,9 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
   MagickOffsetType
     scene;
 
+  QuantumInfo
+    quantum_info;
+
   register const PixelPacket
     *p;
 
@@ -1100,15 +1209,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     i,
     x;
 
-  register unsigned char
-    *q;
-
   size_t
     length,
     packet_size;
 
   unsigned char
-    *pixels;
+    *pixels,
+    *q;
 
   unsigned long
     depth;
@@ -1131,30 +1238,69 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     /*
       Write PNM file header.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     grayscale=IsGrayImage(image,&image->exception);
     depth=image->depth;
-    format=6;
-    if (LocaleCompare(image_info->magick,"PAM") == 0)
-      format=7;
-    else
-      if (LocaleCompare(image_info->magick,"PGM") == 0)
-        format=5;
-      else
-        if (LocaleCompare(image_info->magick,"PBM") == 0)
-          format=4;
-        else
-          if ((LocaleCompare(image_info->magick,"PNM") == 0) &&
-              (image_info->type != TrueColorType) && (grayscale != MagickFalse))
-            {
-              format=5;
-              if (IsMonochromeImage(image,&image->exception) != MagickFalse)
-                format=4;
-            }
-    if ((image->compression == NoCompression) && (format != 7))
-      format-=3;
-    (void) FormatMagickString(buffer,MaxTextExtent,"P%d\n",format);
+    (void) CopyMagickString(magick,image_info->magick,MaxTextExtent);
+    switch (magick[1])
+    {
+      case 'A':
+      case 'a':
+      {
+        format='7';
+        break;
+      }
+      case 'B':
+      case 'b':
+      {
+        format='4';
+        if (image->compression == NoCompression)
+          format='1';
+        break;
+      }
+      case 'F':
+      case 'f':
+      {
+        format='F';
+        if (IsGrayImage(image,&image->exception) != MagickFalse)
+          format='f';
+        break;
+      }
+      case 'G':
+      case 'g':
+      {
+        format='5';
+        if (image->compression == NoCompression)
+          format='2';
+        break;
+      }
+      case 'N':
+      case 'n':
+      {
+        if ((image_info->type != TrueColorType) && (grayscale != MagickFalse))
+          {
+            format='5';
+            if (image->compression == NoCompression)
+              format='2';
+            if (IsMonochromeImage(image,&image->exception) != MagickFalse)
+              {
+                format='4';
+                if (image->compression == NoCompression)
+                  format='1';
+              }
+          }
+      }
+      default:
+      {
+        format='6';
+        if (image->compression == NoCompression)
+          format='3';
+        break;
+      }
+    }
+    (void) FormatMagickString(buffer,MaxTextExtent,"P%c\n",format);
     (void) WriteBlobString(image,buffer);
     value=GetImageProperty(image,"Comment");
     if (value != (const char *) NULL)
@@ -1176,7 +1322,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         }
         (void) WriteBlobByte(image,'\n');
       }
-    if (format != 7)
+    if (format != '7')
       {
         (void) FormatMagickString(buffer,MaxTextExtent,"%lu %lu\n",
           image->columns,image->rows);
@@ -1225,7 +1371,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     */
     switch (format)
     {
-      case 1:
+      case '1':
       {
         /*
           Convert image to a PBM image.
@@ -1241,7 +1387,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           for (x=0; x < (long) image->columns; x++)
           {
             (void) FormatMagickString(buffer,MaxTextExtent,"%u ",
-              PixelIntensity(p) < (QuantumRange/2.0) ? 0x01 : 0x00);
+              PixelIntensity(p) < ((MagickRealType) QuantumRange/2.0) ?
+              0x01 : 0x00);
             (void) WriteBlobString(image,buffer);
             i++;
             if (i == 36)
@@ -1265,7 +1412,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           (void) WriteBlobByte(image,'\n');
         break;
       }
-      case 2:
+      case '2':
       {
         /*
           Convert image to a PGM image.
@@ -1312,7 +1459,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           (void) WriteBlobByte(image,'\n');
         break;
       }
-      case 3:
+      case '3':
       {
         /*
           Convert image to a PNM image.
@@ -1360,7 +1507,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           (void) WriteBlobByte(image,'\n');
         break;
       }
-      case 4:
+      case '4':
       {
         unsigned long
           bit,
@@ -1381,7 +1528,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           for (x=0; x < (long) image->columns; x++)
           {
             byte<<=1;
-            if (PixelIntensity(p) < (QuantumRange/2.0))
+            if (PixelIntensity(p) < ((MagickRealType) QuantumRange/2.0))
               byte|=0x01;
             bit++;
             if (bit == 8)
@@ -1406,7 +1553,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         }
         break;
       }
-      case 5:
+      case '5':
       {
         /*
           Convert image to a PGM image.
@@ -1423,15 +1570,15 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           if (image->depth <= 8)
             for (x=0; x < (long) image->columns; x++)
             {
-              (void) WriteBlobByte(image,
-                ScaleQuantumToChar(PixelIntensityToQuantum(p)));
+              (void) WriteBlobByte(image,ScaleQuantumToChar(
+                PixelIntensityToQuantum(p)));
               p++;
             }
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              (void) WriteBlobMSBShort(image,
-                ScaleQuantumToShort(PixelIntensityToQuantum(p)));
+              (void) WriteBlobMSBShort(image,ScaleQuantumToShort(
+                PixelIntensityToQuantum(p)));
               p++;
             }
           if (image->previous == (Image *) NULL)
@@ -1446,7 +1593,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         }
         break;
       }
-      case 6:
+      case '6':
       {
         /*
           Allocate memory for pixels.
@@ -1502,11 +1649,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         pixels=(unsigned char *) RelinquishMagickMemory(pixels);
         break;
       }
-      case 7:
+      case '7':
       {
-        unsigned long
-          pixel;
-
         /*
           Convert image to a PAM.
         */
@@ -1532,28 +1676,34 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
               if (depth <= 8)
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                    (1UL << depth)-1);
-                  PopCharPixel(pixel,q);
+                  unsigned char
+                    pixel;
+
+                  pixel=(unsigned char) ScaleQuantumToAny(
+                    PixelIntensityToQuantum(p),depth);
+                  PopCharPixel(pixel,&q);
                   if (image->matte != MagickFalse)
                     {
-                      pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                        p->opacity),(1UL << depth)-1UL);
-                      PopCharPixel(pixel,q);
+                      pixel=(unsigned char) ScaleQuantumToAny((Quantum)
+                        (QuantumRange-p->opacity),depth);
+                      PopCharPixel(pixel,&q);
                     }
                   p++;
                 }
               else
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                    (1UL << depth)-1);
-                  PopShortPixel(pixel,q);
+                  unsigned short
+                    pixel;
+
+                  pixel=(unsigned short) ScaleQuantumToAny(
+                    PixelIntensityToQuantum(p),depth);
+                  PopShortPixel(pixel,&q);
                   if (image->matte != MagickFalse)
                     {
-                      pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                        p->opacity),(1UL << depth)-1UL);
-                      PopShortPixel(pixel,q);
+                      pixel=(unsigned short) ScaleQuantumToAny((Quantum)
+                        (QuantumRange-p->opacity),depth);
+                      PopShortPixel(pixel,&q);
                     }
                   p++;
                 }
@@ -1562,34 +1712,40 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
             if (depth <= 8)
               for (x=0; x < (long) image->columns; x++)
               {
-                pixel=ScaleQuantumToAny(p->red,(1UL << depth)-1);
-                PopCharPixel(pixel,q);
-                pixel=ScaleQuantumToAny(p->green,(1UL << depth)-1);
-                PopCharPixel(pixel,q);
-                pixel=ScaleQuantumToAny(p->blue,(1UL << depth)-1);
-                PopCharPixel(pixel,q);
+                unsigned char
+                  pixel;
+
+                pixel=(unsigned char) ScaleQuantumToAny(p->red,depth);
+                PopCharPixel(pixel,&q);
+                pixel=(unsigned char) ScaleQuantumToAny(p->green,depth);
+                PopCharPixel(pixel,&q);
+                pixel=(unsigned char) ScaleQuantumToAny(p->blue,depth);
+                PopCharPixel(pixel,&q);
                 if (image->matte != MagickFalse)
                   {
-                    pixel=ScaleQuantumToAny((Quantum) (QuantumRange-p->opacity),
-                      (1UL << depth)-1UL);
-                    PopCharPixel(pixel,q);
+                    pixel=(unsigned char) ScaleQuantumToAny((Quantum)
+                      (QuantumRange-p->opacity),depth);
+                    PopCharPixel(pixel,&q);
                   }
                 p++;
               }
             else
               for (x=0; x < (long) image->columns; x++)
               {
-                pixel=ScaleQuantumToAny(p->red,(1UL << depth)-1);
-                PopShortPixel(pixel,q);
-                pixel=ScaleQuantumToAny(p->green,(1UL << depth)-1);
-                PopShortPixel(pixel,q);
-                pixel=ScaleQuantumToAny(p->blue,(1UL << depth)-1);
-                PopShortPixel(pixel,q);
+                unsigned short
+                  pixel;
+
+                pixel=(unsigned short) ScaleQuantumToAny(p->red,depth);
+                PopShortPixel(pixel,&q);
+                pixel=(unsigned short) ScaleQuantumToAny(p->green,depth);
+                PopShortPixel(pixel,&q);
+                pixel=(unsigned short) ScaleQuantumToAny(p->blue,depth);
+                PopShortPixel(pixel,&q);
                 if (image->matte != MagickFalse)
                   {
-                    pixel=ScaleQuantumToAny((Quantum) (QuantumRange-p->opacity),
-                      (1UL << depth)-1UL);
-                    PopShortPixel(pixel,q);
+                    pixel=(unsigned short) ScaleQuantumToAny((Quantum)
+                      (QuantumRange-p->opacity),depth);
+                    PopShortPixel(pixel,&q);
                   }
                 p++;
               }
@@ -1607,6 +1763,42 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         pixels=(unsigned char *) RelinquishMagickMemory(pixels);
         break;
       }
+      case 'F':
+      case 'f':
+      {
+        QuantumType
+          quantum_type;
+
+        (void) WriteBlobString(image,image->endian != LSBEndian ?
+          "1.0\n" : "-1.0\n");
+        image->depth=32;
+        quantum_info.format=FloatingPointQuantumFormat;
+        quantum_info.scale=1.0/QuantumRange;
+        quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
+        length=(format == 'f' ? 1 : 3)*image->columns*sizeof(float);
+        pixels=(unsigned char *) AcquireMagickMemory(length);
+        if (pixels == (unsigned char *) NULL)
+          ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+        for (y=(long) image->rows-1; y >= 0; y--)
+        {
+          p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+          if (p == (const PixelPacket *) NULL)
+            break;
+          (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          (void) WriteBlob(image,length,pixels);
+          if (image->previous == (Image *) NULL)
+            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                (QuantumTick(y,image->rows) != MagickFalse))
+              {
+                status=image->progress_monitor(SaveImageTag,y,image->rows,
+                  image->client_data);
+                if (status == MagickFalse)
+                  break;
+              }
+        }
+        pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+        break;
+      }
     }
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
