@@ -57,6 +57,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/resource_.h"
 #include "magick/property.h"
@@ -296,6 +297,9 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     postscript_filename[MaxTextExtent],
     translate_geometry[MaxTextExtent];
 
+  const char
+    *option;
+
   const DelegateInfo
     *delegate_info;
 
@@ -348,7 +352,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   StringInfo
-    *option,
     *profile;
 
   unsigned long
@@ -487,9 +490,9 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         profile=AcquireStringInfo(65536);
         for (i=0; (c=ProfileInteger(image,hex_digits)) != EOF; i++)
         {
-          SetStringInfoLength(profile,i+1);
+          SetStringInfoLength(profile,(size_t) i+1);
           datum=GetStringInfoDatum(profile);
-          datum[i]=c;
+          datum[i]=(unsigned char) c;
         }
         (void) SetImageProfile(image,"icc",profile);
         profile=DestroyStringInfo(profile);
@@ -592,8 +595,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         &bounds.y2)+2;
     if (count != 4)
       continue;
-    if (((unsigned long) (bounds.x2-bounds.x1+0.5) > page.width) ||
-        ((unsigned long) (bounds.y2-bounds.y1+0.5) > page.height))
+    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
       {
         /*
           Set Postscript render geometry.
@@ -674,8 +676,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   option=GetImageOption(image_info,"ps:use-cropbox");
   if ((option != (const char *) NULL) && (IsMagickTrue(option) != MagickFalse))
     (void) ConcatenateMagickString(options,"-dEPSCrop ",MaxTextExtent);
-  if (cmyk != MagickFalse)
-    (void) ConcatenateMagickString(options,"-dUseCIEColor ",MaxTextExtent);
   (void) CopyMagickString(filename,read_info->filename,MaxTextExtent);
   (void) AcquireUniqueFilename(read_info->filename);
   (void) FormatMagickString(command,MaxTextExtent,
@@ -1466,7 +1466,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               for (x=0; x < (long) preview_image->columns; x++)
               {
                 byte<<=1;
-                if (PixelIntensity(p) >= (QuantumRange/2.0))
+                if (PixelIntensity(p) >= ((MagickRealType) QuantumRange/2.0))
                   byte|=0x01;
                 bit++;
                 if (bit == 8)
@@ -1574,7 +1574,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
     pixel.opacity=TransparentOpacity;
     i=0;
-    index=0;
+    index=(IndexPacket) 0;
     x=0;
     type=GetImageType(image,&image->exception);
     if ((image_info->type != TrueColorType) &&
@@ -1642,7 +1642,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               for (x=0; x < (long) image->columns; x++)
               {
                 byte<<=1;
-                if (PixelIntensity(p) >= (QuantumRange/2.0))
+                if (PixelIntensity(p) >= ((MagickRealType) QuantumRange/2.0))
                   byte|=0x01;
                 bit++;
                 if (bit == 8)
