@@ -189,15 +189,15 @@ ModuleExport void UnregisterPS3Image(void)
 static MagickBooleanType SerializeImage(const ImageInfo *image_info,
   Image *image,unsigned char **pixels,size_t *length)
 {
-  IndexPacket
-    *indexes;
-
   long
     y;
 
   MagickBooleanType
     status;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
@@ -214,7 +214,7 @@ static MagickBooleanType SerializeImage(const ImageInfo *image_info,
   status=MagickTrue;
   *length=(image->colorspace == CMYKColorspace ? 4 : 3)*
     (size_t) image->columns*image->rows;
-  *pixels=(unsigned char *) AcquireMagickMemory(*length);
+  *pixels=(unsigned char *) AcquireMagickMemory(*length*sizeof(**pixels));
   if (*pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   q=(*pixels);
@@ -223,7 +223,7 @@ static MagickBooleanType SerializeImage(const ImageInfo *image_info,
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=AcquireIndexes(image);
     if (image->colorspace != CMYKColorspace)
       for (x=0; x < (long) image->columns; x++)
       {
@@ -288,7 +288,7 @@ static MagickBooleanType SerializeImageChannel(const ImageInfo *image_info,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=MagickTrue;
   pack=(unsigned long) (IsMonochromeImage(image,&image->exception) !=
-    MagickFalse ? 8 : 1);
+    MagickFalse ? 1 : 8);
   padded_columns=((image->columns+pack-1)/pack)*pack;
   *length=(size_t) padded_columns*image->rows/pack;
   *pixels=(unsigned char *) AcquireMagickMemory(*length);
@@ -313,8 +313,8 @@ static MagickBooleanType SerializeImageChannel(const ImageInfo *image_info,
         {
           bit=(unsigned char) 0x00;
           if (x < (long) image->columns)
-            bit=(unsigned char)
-              (PixelIntensityToQuantum(p) == TransparentOpacity ? 0x01 : 0x00);
+            bit=(unsigned char) (PixelIntensityToQuantum(p) ==
+              TransparentOpacity ? 0x01 : 0x00);
           code=(code << 1)+bit;
           if (((x+1) % pack) == 0)
             {
@@ -348,12 +348,12 @@ static MagickBooleanType SerializeImageIndexes(const ImageInfo *image_info,
   MagickBooleanType
     status;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     x;
 
@@ -375,7 +375,7 @@ static MagickBooleanType SerializeImageIndexes(const ImageInfo *image_info,
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=AcquireIndexes(image);
     for (x=0; x < (long) image->columns; x++)
       *q++=(unsigned char) indexes[x];
     if (image->previous == (Image *) NULL)
@@ -442,6 +442,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
   switch (compression)
   {
     case NoCompression:
+    default:
     {
       (void) FormatMagickString(buffer,MaxTextExtent,
         "currentfile %lu %lu "PS3_NoCompression" ByteStreamDecodeFilter\n",
@@ -450,11 +451,10 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
     }
     case FaxCompression:
     case Group4Compression:
-    default:
     {
       (void) FormatMagickString(buffer,MaxTextExtent,
         "currentfile %lu %lu "PS3_FaxCompression" ByteStreamDecodeFilter\n",
-        image->columns, image->rows);
+        image->columns,image->rows);
       break;
     }
     case JPEGCompression:
@@ -759,8 +759,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       "  currentfile buffer readline pop",
       "  token pop /compression exch def pop",
       "  % Clip and render.",
-      "  /pixel_stream currentfile columns rows compression",
-      "    ByteStreamDecodeFilter def",
+      "  /pixel_stream currentfile columns rows compression ByteStreamDecodeFilter def",
       "  clipped { ClipImage } if",
       "  alpha stencil not and",
       "  { MaskedImageDict mask_stream resetfile }",
