@@ -439,26 +439,40 @@ static char *ModeToString( PSDImageType inType )
   }
 }
 
+static inline unsigned char PushCharPixel(const unsigned char **pixels)
+{
+  unsigned char
+    pixel;
+
+  pixel=(unsigned char) *(*pixels)++;
+  return(pixel);
+}
+
+static inline unsigned long PushLongPixel(const unsigned char **pixels)
+{
+  unsigned long
+    pixel;
+
+  pixel=(unsigned long) (*(*pixels)++ << 24);
+  pixel|=(unsigned long) (*(*pixels)++ << 16);
+  pixel|=(unsigned long) (*(*pixels)++ << 8);
+  pixel|=(unsigned long) (*(*pixels)++);
+  return(pixel);
+}
+
+static inline unsigned short PushShortPixel(const unsigned char **pixels)
+{
+  unsigned short
+    pixel;
+
+  pixel=(unsigned short) (*(*pixels)++ << 8);
+  pixel|=(unsigned short) (*(*pixels)++);
+  return(pixel);
+}
+
 static MagickBooleanType ParseImageResourceBlocks(Image *image,
   const unsigned char *blocks,size_t length)
 {
-#define PushCharPixel(pixel,p) \
-{ \
-  pixel=(unsigned long) (*(p)); \
-  (p)++; \
-}
-#define PushLongPixel(pixel,p) \
-{ \
-  pixel=(unsigned long) \
-    ((*(p) << 24) | (*((p)+1) << 16) | (*((p)+2) << 8) | *((p)+3)); \
-  (p)+=4; \
-}
-#define PushShortPixel(pixel,p) \
-{ \
-  pixel=(unsigned long) ((*(p) << 8) | *((p)+1)); \
-  (p)+=2; \
-}
-
   const unsigned char
     *p;
 
@@ -480,10 +494,10 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
   {
     if (LocaleNCompare((char *) p,"8BIM",4) != 0)
       break;
-    PushLongPixel(sans,p);
-    PushShortPixel(id,p);
-    PushShortPixel(sans,p);
-    PushLongPixel(count,p);
+    sans=PushLongPixel(&p);
+    id=PushShortPixel(&p);
+    sans=PushShortPixel(&p);
+    count=PushLongPixel(&p);
     switch (id)
     {
       case 0x03ed:
@@ -494,16 +508,16 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
         /*
           Resolution info.
         */
-        PushShortPixel(resolution,p);
+        resolution=PushShortPixel(&p);
         image->x_resolution=(double) resolution;
-        PushShortPixel(sans,p);
-        PushShortPixel(sans,p);
-        PushShortPixel(sans,p);
-        PushShortPixel(resolution,p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
+        resolution=PushShortPixel(&p);
         image->y_resolution=(double) resolution;
-        PushShortPixel(sans,p);
-        PushShortPixel(sans,p);
-        PushShortPixel(sans,p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
         break;
       }
       default:
@@ -1136,10 +1150,10 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (long) layer_info[i].image->columns; x++)
                 {
                   if (packet_size == 1)
-                    pixel=ScaleCharToQuantum((unsigned char)
+                    pixel=(unsigned long) ScaleCharToQuantum((unsigned char)
                       ReadBlobByte(layer_info[i].image));
                   else
-                    pixel=ScaleShortToQuantum(ReadBlobMSBShort(
+                    pixel=(unsigned long) ScaleShortToQuantum(ReadBlobMSBShort(
                       layer_info[i].image));
                   switch (layer_info[i].channel_info[j].type)
                   {
@@ -1214,8 +1228,8 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   indexes=GetIndexes(layer_info[i].image);
                   for (x=0; x < (long) layer_info[i].image->columns; x++)
                   {
-                    q->opacity=QuantumRange-(Quantum) (QuantumScale*(q->opacity*
-                      layer_info[i].opacity));
+                    q->opacity=QuantumRange-(Quantum)
+                      (QuantumScale*(q->opacity*layer_info[i].opacity));
                     q++;
                   }
                   if (SyncImagePixels(layer_info[i].image) == MagickFalse)
@@ -1335,9 +1349,11 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           for (x=0; x < (long) image->columns; x++)
           {
             if (packet_size == 1)
-              pixel=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
+              pixel=(unsigned long) ScaleCharToQuantum((unsigned char)
+                ReadBlobByte(image));
             else
-              pixel=ScaleShortToQuantum(ReadBlobMSBShort(image));
+              pixel=(unsigned long) ScaleShortToQuantum(
+                ReadBlobMSBShort(image));
             switch (image->matte ? i-1 : i)
             {
               case -1:
@@ -1508,11 +1524,10 @@ static void WriteOneChannel(const ImageInfo *image_info,Image *image,
   size_t
     packet_size;
 
-
   if (tmp_image->depth > 8)
     tmp_image->depth=16;
   GetQuantumInfo(image_info,&quantum_info);
-  packet_size =tmp_image->depth > 8UL ? 2UL : 1UL;
+  packet_size=tmp_image->depth > 8UL ? 2UL : 1UL;
   for (y=0; y < (long) tmp_image->rows; y++)
   {
     p=AcquireImagePixels(tmp_image,0,y,tmp_image->columns,1,&image->exception);
@@ -1523,12 +1538,28 @@ static void WriteOneChannel(const ImageInfo *image_info,Image *image,
   }
 }
 
-static void WriteImageChannels(const ImageInfo *image_info,Image *image,
-  Image *tmp_image,unsigned char *pixels)
+static MagickBooleanType WriteImageChannels(const ImageInfo *image_info,
+  Image *image,Image *tmp_image)
 {
+  size_t
+    channels,
+    packet_size;
+
+  unsigned char
+    *pixels;
+
   /*
     Write uncompressed pixel data as separate planes.
   */
+  channels=1;
+  if ((tmp_image->storage_class == PseudoClass) &&
+      (tmp_image->matte == MagickFalse))
+    channels++;
+  packet_size=tmp_image->depth > 8UL ? 2UL : 1UL;
+  pixels=(unsigned char *) AcquireMagickMemory(channels*packet_size*
+    tmp_image->columns*sizeof(*pixels));
+  if (pixels == (unsigned char *) NULL)
+    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   (void) WriteBlobMSBShort(image,0);  /* compression */
   if (tmp_image->storage_class == PseudoClass)
     {
@@ -1552,6 +1583,8 @@ static void WriteImageChannels(const ImageInfo *image_info,Image *image,
           (void) NegateImage(image,MagickFalse);
         }
     }
+  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+  return(MagickTrue);
 }
 
 /* Write white background, RLE-compressed */
@@ -1658,7 +1691,6 @@ static MagickBooleanType WritePSDImage(const ImageInfo *image_info,Image *image)
     packet_size;
 
   unsigned char
-    *pixels,
     layer_name[4];
 
   unsigned long
@@ -1687,10 +1719,6 @@ static MagickBooleanType WritePSDImage(const ImageInfo *image_info,Image *image)
   packet_size=(size_t) (image->depth > 8 ? 6 : 3);
   if (image->matte != MagickFalse)
     packet_size+=image->depth > 8 ? 2 : 1;
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->columns*sizeof(PixelPacket));
-  if (pixels == (unsigned char *) NULL)
-    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   (void) WriteBlob(image,4,(unsigned char *) "8BPS");
   (void) WriteBlobMSBShort(image,1);  /* version */
   for ( i=1; i<=6; i++)
@@ -1889,7 +1917,7 @@ compute_layer_info:
      /* now the image data! */
     tmp_image = base_image;
     while ( tmp_image != NULL ) {
-      WriteImageChannels(image_info,image,tmp_image,pixels );
+      status=WriteImageChannels(image_info,image,tmp_image);
 
       /* add in the pad! */
        if ( rounded_layer_info_size != layer_info_size )
@@ -1907,9 +1935,8 @@ compute_layer_info:
    if (force_white_background  != MagickFalse)
      WriteWhiteBackground(image);
    else
-  WriteImageChannels(image_info,image,image,pixels);
+  status=WriteImageChannels(image_info,image,image);
 
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   CloseBlob(image);
-  return(MagickTrue);
+  return(status);
 }
