@@ -500,7 +500,7 @@ static Image *ReadRLEImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               indexes=GetIndexes(image);
               for (x=0; x < (long) image->columns; x++)
-                indexes[x]=(*p++);
+                indexes[x]=(IndexPacket) (*p++);
               if (SyncImagePixels(image) == MagickFalse)
                 break;
               if (image->previous == (Image *) NULL)
