@@ -359,8 +359,8 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->rows=iris_info.rows;
     image->depth=(unsigned long) MagickMin(iris_info.depth,QuantumDepth);
     if (iris_info.pixel_format == 0)
-      image->depth=(unsigned long) MagickMin(8*iris_info.bytes_per_pixel,
-        QuantumDepth);
+      image->depth=(unsigned long) MagickMin((size_t) 8*
+        iris_info.bytes_per_pixel,QuantumDepth);
     if (iris_info.depth < 3)
       {
         image->storage_class=PseudoClass;
@@ -477,7 +477,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (offset != offsets[y+z*iris_info.rows])
                   {
                     offset=offsets[y+z*iris_info.rows];
-                    offset=SeekBlob(image,(long) offset,SEEK_SET);
+                    offset=(ssize_t) SeekBlob(image,(long) offset,SEEK_SET);
                   }
                 count=ReadBlob(image,(size_t) runlength[y+z*iris_info.rows],
                   packets);
@@ -507,7 +507,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (offset != offsets[y+z*iris_info.rows])
                   {
                     offset=offsets[y+z*iris_info.rows];
-                    offset=SeekBlob(image,(long) offset,SEEK_SET);
+                    offset=(ssize_t) SeekBlob(image,(long) offset,SEEK_SET);
                   }
                 count=ReadBlob(image,(size_t) runlength[y+z*iris_info.rows],
                   packets);
@@ -522,7 +522,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
               p+=(iris_info.columns*4*bytes_per_pixel);
             }
-            offset=SeekBlob(image,position,SEEK_SET);
+            offset=(ssize_t) SeekBlob(image,position,SEEK_SET);
           }
         runlength=(unsigned long *) RelinquishMagickMemory(runlength);
         packets=(unsigned char *) RelinquishMagickMemory(packets);
@@ -940,7 +940,8 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       }
     iris_info.minimum_value=0;
     iris_info.maximum_value=(unsigned long) (image->depth <= 8 ?
-      ScaleQuantumToChar(QuantumRange) : ScaleQuantumToShort(QuantumRange));
+      1UL*ScaleQuantumToChar(QuantumRange) :
+      1UL*ScaleQuantumToShort(QuantumRange));
     /*
       Write SGI header.
     */
