@@ -253,6 +253,9 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register unsigned char
     *p;
 
+  size_t
+    length;
+
   ssize_t
     count;
 
@@ -307,6 +310,8 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
     sun_info.maplength=ReadBlobMSBLong(image);
     image->columns=sun_info.width;
     image->rows=sun_info.height;
+    if ((sun_info.depth == 0) || (sun_info.depth > 32))
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     image->depth=sun_info.depth <= 8 ? 8UL : QuantumDepth;
     if (sun_info.depth < 24)
       {
@@ -398,6 +403,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((count == 0) && (sun_info.type != RT_ENCODED))
       ThrowReaderException(CorruptImageError,"UnableToReadImageData");
     sun_pixels=sun_data;
+    bytes_per_line=0;
     if (sun_info.type == RT_ENCODED)
       {
         unsigned long
@@ -408,8 +414,8 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         height=sun_info.height;
         bytes_per_line=sun_info.width*sun_info.depth;
-        if (!height || !sun_info.width || !sun_info.depth ||
-            bytes_per_line/sun_info.depth != sun_info.width)
+        if ((height == 0) || (sun_info.width == 0) || (sun_info.depth == 0) ||
+            ((bytes_per_line/sun_info.depth) != sun_info.width))
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         if (((~0UL)-bytes_per_line) < 15)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -468,71 +474,86 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     else
       if (image->storage_class == PseudoClass)
-        for (y=0; y < (long) image->rows; y++)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
-          if (q == (PixelPacket *) NULL)
-            break;
-          indexes=GetIndexes(image);
-          for (x=0; x < (long) image->columns; x++)
-            indexes[x]=(*p++);
-          if ((image->columns % 2) != 0)
-            p++;
-          if (SyncImagePixels(image) == MagickFalse)
-            break;
-          if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+          length=image->rows*(image->columns+image->columns % 2);
+          if (((sun_info.type == RT_ENCODED) &&
+               (length > (bytes_per_line*image->rows))) ||
+              ((sun_info.type != RT_ENCODED) && (length > sun_info.length)))
+            ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+          for (y=0; y < (long) image->rows; y++)
+          {
+            q=SetImagePixels(image,0,y,image->columns,1);
+            if (q == (PixelPacket *) NULL)
+              break;
+            indexes=GetIndexes(image);
+            for (x=0; x < (long) image->columns; x++)
+              indexes[x]=(IndexPacket) (*p++);
+            if ((image->columns % 2) != 0)
+              p++;
+            if (SyncImagePixels(image) == MagickFalse)
+              break;
+            if (image->previous == (Image *) NULL)
+              if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                  (QuantumTick(y,image->rows) != MagickFalse))
+                {
+                  status=image->progress_monitor(LoadImageTag,y,image->rows,
+                    image->client_data);
+                  if (status == MagickFalse)
+                    break;
+                }
+          }
         }
       else
-        for (y=0; y < (long) image->rows; y++)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
-          if (q == (PixelPacket *) NULL)
-            break;
-          for (x=0; x < (long) image->columns; x++)
+          length=image->rows*((image->columns*(image->matte != MagickFalse ? 4 :
+            3))+image->columns % 2);
+          if (((sun_info.type == RT_ENCODED) &&
+               (length > (bytes_per_line*image->rows))) ||
+              ((sun_info.type != RT_ENCODED) && (length > sun_info.length)))
+            ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+          for (y=0; y < (long) image->rows; y++)
           {
-            if (image->matte != MagickFalse)
-              q->opacity=(Quantum) (QuantumRange-ScaleCharToQuantum(*p++));
-            if (sun_info.type == RT_STANDARD)
-              {
-                q->blue=ScaleCharToQuantum(*p++);
-                q->green=ScaleCharToQuantum(*p++);
-                q->red=ScaleCharToQuantum(*p++);
-              }
-            else
-              {
-                q->red=ScaleCharToQuantum(*p++);
-                q->green=ScaleCharToQuantum(*p++);
-                q->blue=ScaleCharToQuantum(*p++);
-              }
-            if (image->colors != 0)
-              {
-                q->red=image->colormap[(long) q->red].red;
-                q->green=image->colormap[(long) q->green].green;
-                q->blue=image->colormap[(long) q->blue].blue;
-              }
-            q++;
+            q=SetImagePixels(image,0,y,image->columns,1);
+            if (q == (PixelPacket *) NULL)
+              break;
+            for (x=0; x < (long) image->columns; x++)
+            {
+              if (image->matte != MagickFalse)
+                q->opacity=(Quantum) (QuantumRange-ScaleCharToQuantum(*p++));
+              if (sun_info.type == RT_STANDARD)
+                {
+                  q->blue=ScaleCharToQuantum(*p++);
+                  q->green=ScaleCharToQuantum(*p++);
+                  q->red=ScaleCharToQuantum(*p++);
+                }
+              else
+                {
+                  q->red=ScaleCharToQuantum(*p++);
+                  q->green=ScaleCharToQuantum(*p++);
+                  q->blue=ScaleCharToQuantum(*p++);
+                }
+              if (image->colors != 0)
+                {
+                  q->red=image->colormap[(long) q->red].red;
+                  q->green=image->colormap[(long) q->green].green;
+                  q->blue=image->colormap[(long) q->blue].blue;
+                }
+              q++;
+            }
+            if ((image->columns % 2) != 0)
+              p++;
+            if (SyncImagePixels(image) == MagickFalse)
+              break;
+            if (image->previous == (Image *) NULL)
+              if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                  (QuantumTick(y,image->rows) != MagickFalse))
+                {
+                  status=image->progress_monitor(LoadImageTag,y,image->rows,
+                    image->client_data);
+                  if (status == MagickFalse)
+                    break;
+                }
           }
-          if ((image->columns % 2) != 0)
-            p++;
-          if (SyncImagePixels(image) == MagickFalse)
-            break;
-          if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
         }
     if (image->storage_class == PseudoClass)
       (void) SyncImage(image);
