@@ -243,8 +243,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
     tga_info.colormap_size=(unsigned char) ReadBlobByte(image);
     tga_info.x_origin=ReadBlobLSBShort(image);
     tga_info.y_origin=ReadBlobLSBShort(image);
-    tga_info.width=ReadBlobLSBShort(image);
-    tga_info.height=ReadBlobLSBShort(image);
+    tga_info.width=(unsigned short) ReadBlobLSBShort(image);
+    tga_info.height=(unsigned short) ReadBlobLSBShort(image);
     tga_info.bits_per_pixel=(unsigned char) ReadBlobByte(image);
     tga_info.attributes=(unsigned char) ReadBlobByte(image);
     /*
@@ -333,10 +333,10 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               */
               j=(unsigned char) ReadBlobByte(image);
               k=(unsigned char) ReadBlobByte(image);
-              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,31);
+              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,5);
               pixel.green=ScaleAnyToQuantum((1UL*(k & 0x03) << 3)+
-                (1UL*(j & 0xe0) >> 5),31);
-              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),31);
+                (1UL*(j & 0xe0) >> 5),5);
+              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),5);
               break;
             }
             case 24:
@@ -367,7 +367,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
     flag=0;
     skip=MagickFalse;
     real=0;
-    index=0;
+    index=(IndexPacket) 0;
     runlength=0;
     offset=0;
     for (y=0; y < (long) image->rows; y++)
@@ -413,7 +413,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               */
               index=(IndexPacket) ReadBlobByte(image);
               if (tga_info.colormap_type != 0)
-                pixel=image->colormap[(long) ConstrainColormapIndex(image,index)];
+                pixel=image->colormap[(long) ConstrainColormapIndex(image,
+                  1UL*index)];
               else
                 {
                   pixel.red=ScaleCharToQuantum((unsigned char) index);
@@ -430,10 +431,10 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               */
               j=(unsigned char) ReadBlobByte(image);
               k=(unsigned char) ReadBlobByte(image);
-              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,31);
+              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,5);
               pixel.green=ScaleAnyToQuantum((1UL*(k & 0x03) << 3)+
-                (1UL*(j & 0xe0) >> 5),31);
-              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),31);
+                (1UL*(j & 0xe0) >> 5),5);
+              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),5);
               if (image->matte != MagickFalse)
                 pixel.opacity=(k & 0x80) != 0? OpaqueOpacity :
                   TransparentOpacity; 
@@ -861,8 +862,8 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
               *q++=ScaleQuantumToChar(p->green);
               *q++=ScaleQuantumToChar(p->red);
               if (image->matte != MagickFalse)
-                *q++=(unsigned char) ScaleQuantumToChar(QuantumRange-
-                  p->opacity);
+                *q++=(unsigned char) ScaleQuantumToChar((Quantum)
+                  (QuantumRange-p->opacity));
               if (image->colorspace == CMYKColorspace)
                 *q++=ScaleQuantumToChar(indexes[x]);
             }
