@@ -128,6 +128,14 @@ static MagickBooleanType IsTIFF(const unsigned char *magick,const size_t length)
     return(MagickTrue);
   if (memcmp(magick,"\111\111\052\000",4) == 0)
     return(MagickTrue);
+#if defined(TIFF_VERSION_BIG)
+  if (length < 8)
+    return(MagickFalse);
+  if (memcmp(magick,"\115\115\000\053\000\010\000\000",8) == 0)
+    return(MagickTrue);
+  if (memcmp(magick,"\111\111\053\000\010\000\000\000",8) == 0)
+    return(MagickTrue);
+#endif
   return(MagickFalse);
 }
 
@@ -548,6 +556,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
       image->endian=LSBEndian;
     if (photometric == PHOTOMETRIC_SEPARATED)
       image->colorspace=CMYKColorspace;
+    if (photometric == PHOTOMETRIC_CIELAB)
+      image->colorspace=LABColorspace;
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_SAMPLESPERPIXEL,
       &samples_per_pixel);
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_RESOLUTIONUNIT,&units);
@@ -722,7 +732,14 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         break;
     method=ReadGenericMethod;
     if (TIFFGetField(tiff,TIFFTAG_ROWSPERSTRIP,&rows_per_strip) != 0)
-      method=ReadStripMethod;
+      {
+        char
+          value[MaxTextExtent];
+
+        method=ReadStripMethod;
+        (void) FormatMagickString(value,MaxTextExtent,"%u",rows_per_strip);
+        (void) SetImageProperty(image,"tiff:rows-per-strip",value);
+      }
     if ((samples_per_pixel >= 2) && (interlace == PLANARCONFIG_CONTIG))
       method=ReadRGBAMethod;
     if ((samples_per_pixel >= 2) && (interlace == PLANARCONFIG_SEPARATE))
@@ -762,8 +779,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         (void) ResetMagickMemory(scanline,0,length);
         if (image->storage_class == PseudoClass)
           {
-            long
-              range;
+            unsigned long
+              depth;
 
             uint16
               *blue_colormap,
@@ -775,22 +792,20 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             */
             (void) TIFFGetField(tiff,TIFFTAG_COLORMAP,&red_colormap,
               &green_colormap,&blue_colormap);
-            range=256L;  /* might be old style 8-bit colormap */
+            depth=8;  /* might be old style 8-bit colormap */
             for (i=0; i < (long) image->colors; i++)
               if ((red_colormap[i] >= 256) || (green_colormap[i] >= 256) ||
                   (blue_colormap[i] >= 256))
                 {
-                  range=65535L;
+                  depth=16;
                   break;
                 }
             for (i=0; i < (long) image->colors; i++)
             {
-              image->colormap[i].red=ScaleAnyToQuantum(red_colormap[i],
-                (unsigned long) range);
+              image->colormap[i].red=ScaleAnyToQuantum(red_colormap[i],depth);
               image->colormap[i].green=ScaleAnyToQuantum(green_colormap[i],
-                (unsigned long) range);
-              image->colormap[i].blue=ScaleAnyToQuantum(blue_colormap[i],
-                (unsigned long) range);
+                depth);
+              image->colormap[i].blue=ScaleAnyToQuantum(blue_colormap[i],depth);
             }
           }
         quantum_type=IndexQuantum;
@@ -1307,6 +1322,7 @@ ModuleExport void RegisterTIFFImage(void)
     version[i]='\0';
   }
 #endif
+
   entry=SetMagickInfo("PTIF");
 #if defined(HasTIFF)
   entry->decoder=(DecoderHandler *) ReadTIFFImage;
@@ -1347,6 +1363,20 @@ ModuleExport void RegisterTIFFImage(void)
     entry->version=ConstantString(version);
   entry->module=ConstantString("TIFF");
   (void) RegisterMagickInfo(entry);
+  entry=SetMagickInfo("TIFF64");
+#if defined(TIFF_VERSION_BIG)
+  entry->decoder=(DecoderHandler *) ReadTIFFImage;
+  entry->encoder=(EncoderHandler *) WritePTIFImage;
+#endif
+  entry->adjoin=MagickFalse;
+  entry->endian_support=MagickTrue;
+  entry->seekable_stream=MagickTrue;
+  entry->thread_support=NoThreadSupport;
+  entry->description=ConstantString("Tagged Image File Format (64-bit)");
+  if (*version != '\0')
+    entry->version=ConstantString(version);
+  entry->module=ConstantString("TIFF");
+  (void) RegisterMagickInfo(entry);
 }
 
 /*
@@ -1373,6 +1403,7 @@ ModuleExport void UnregisterTIFFImage(void)
   (void) UnregisterMagickInfo("PTIF");
   (void) UnregisterMagickInfo("TIF");
   (void) UnregisterMagickInfo("TIFF");
+  (void) UnregisterMagickInfo("TIFF64");
 }
 
 #if defined(HasTIFF)
@@ -1655,7 +1686,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  status=OpenBlob(image_info,image,IOBinaryBlobMode,&image->exception);
+  status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
   tiff_exception=(&image->exception);
@@ -1667,6 +1698,15 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
     case MSBEndian: mode="wb"; break;
     default: mode="w"; break;
   }
+#if defined(TIFF_VERSION_BIG)
+  if (LocaleCompare(image_info->magick,"TIFF64") == 0)
+    switch (image_info->endian)
+    {
+      case LSBEndian: mode="wl8"; break;
+      case MSBEndian: mode="wb8"; break;
+      default: mode="w8"; break;
+    }
+#endif
   tiff=TIFFClientOpen(image->filename,mode,(thandle_t) image,TIFFReadBlob,
     TIFFWriteBlob,TIFFSeekBlob,TIFFCloseBlob,TIFFGetBlobSize,TIFFMapBlob,
     TIFFUnmapBlob);
