@@ -109,7 +109,7 @@ static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 
   unsigned long
     columns,
-    max_value,
+    depth,
     rows;
 
   if (length < 40)
@@ -117,7 +117,7 @@ static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
   if (LocaleNCompare((char *) magick,MagickID,strlen(MagickID)) != 0)
     return(MagickFalse);
   count=(ssize_t) sscanf((char *) magick+32,"%lu,%lu,%lu,%s",&columns,&rows,
-    &max_value,format);
+    &depth,format);
   if (count != 4)
     return(MagickFalse);
   return(MagickTrue);
@@ -364,7 +364,6 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -395,7 +394,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   unsigned long
-    max_value;
+    depth;
 
   /*
     Open image file.
@@ -418,7 +417,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (LocaleNCompare((char *) text,MagickID,strlen(MagickID)) != 0)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   count=(ssize_t) sscanf(text+32,"%lu,%lu,%lu,%s",&image->columns,
-    &image->rows,&max_value,format);
+    &image->rows,&depth,format);
   if (count != 4)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   if (LocaleNCompare(format,"CMYK",4) == 0)
@@ -446,17 +445,16 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     q=SetImagePixels(image,x,y,1,1);
     if (q == (PixelPacket *) NULL)
       continue;
-    q->red=ScaleAnyToQuantum(pixel.red,max_value);
-    q->green=ScaleAnyToQuantum(pixel.green,max_value);
-    q->blue=ScaleAnyToQuantum(pixel.blue,max_value);
+    q->red=ScaleAnyToQuantum(pixel.red,depth);
+    q->green=ScaleAnyToQuantum(pixel.green,depth);
+    q->blue=ScaleAnyToQuantum(pixel.blue,depth);
     if (image->colorspace == CMYKColorspace)
       {
         indexes=GetIndexes(image);
-        *indexes=ScaleAnyToQuantum(pixel.index,max_value);
+        *indexes=ScaleAnyToQuantum(pixel.index,depth);
       }
     if (image->matte != MagickFalse)
-      q->opacity=QuantumRange-
-        ScaleAnyToQuantum(pixel.opacity,max_value);
+      q->opacity=QuantumRange-ScaleAnyToQuantum(pixel.opacity,depth);
     (void) SyncImagePixels(image);
   }
   return(GetFirstImageInList(image));
@@ -584,9 +582,6 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
   register long
     x;
 
-  unsigned long
-    quantum_range;
-
   /*
     Open output image file.
   */
@@ -606,12 +601,9 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
   if (image->matte != MagickFalse)
     (void) ConcatenateMagickString(format,"A",MaxTextExtent);
   image->depth=GetImageQuantumDepth(image,MagickTrue);
-  quantum_range=(1UL << image->depth)-1;
-  if (image->depth == 32)
-     quantum_range=4294967295UL;
   (void) FormatMagickString(buffer,MaxTextExtent,
     "# ImageMagick pixel enumeration: %lu,%lu,%lu,%s\n",image->columns,
-    image->rows,quantum_range,format);
+    image->rows,image->depth,format);
   (void) WriteBlobString(image,buffer);
   scene=0;
   do
