@@ -317,8 +317,8 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
     else
       (void) FormatMagickString(buffer,MaxTextExtent,
         "    color('%s',%s) = '%s'",name,
-        PixelIntensityToQuantum(image->colormap+i) < (QuantumRange/2) ?
-        "background" : "foreground",symbol);
+        PixelIntensityToQuantum(image->colormap+i) <
+        (QuantumRange/2) ? "background" : "foreground",symbol);
     (void) WriteBlobString(image,buffer);
     (void) FormatMagickString(buffer,MaxTextExtent,"%s",
       (i == (long) (colors-1) ? ");\n" : ",\n"));
