@@ -399,7 +399,7 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
     byte=0;
     for (x=0; x < (long) image->columns; x++)
     {
-      if (PixelIntensity(p) >= (QuantumRange/2.0))
+      if (PixelIntensity(p) >= ((MagickRealType) QuantumRange/2.0))
         byte|=0x1 << (7-bit);
       bit++;
       if (bit == 8)
