@@ -292,7 +292,7 @@ static void InsertRow(unsigned char *p,long y,Image *image, int bpp)
               {
                 index=((*p) & (0x80 >> bit) ? 0x01 : 0x00);
                 indexes[x+bit]=index;
-                *q++=image->colormap[index];
+                *q++=image->colormap[(int) index];
               }
             p++;
           }
@@ -302,7 +302,7 @@ static void InsertRow(unsigned char *p,long y,Image *image, int bpp)
               {
                 index=((*p) & (0x80 >> bit) ? 0x01 : 0x00);
                 indexes[x+bit]=index;
-                *q++=image->colormap[index];
+                *q++=image->colormap[(int) index];
               }
             p++;
           }
@@ -968,9 +968,9 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
   if (Header.EncryptKey!=0)
     ThrowReaderException(CoderError,"EncryptedWPGImageFileNotSupported");
 
-  BitmapHeader2.RotAngle=0;
   image->colors = 0;
   bpp=0;
+  BitmapHeader2.RotAngle=0;
 
   switch(Header.FileType)
     {
@@ -1102,7 +1102,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                     {  /* fix crippled monochrome palette */
                       image->colormap[1].red =
                         image->colormap[1].green =
-                        image->colormap[1].blue = MaxRGB;
+                        image->colormap[1].blue = QuantumRange;
                     }
                 }      
 
@@ -1113,37 +1113,37 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                   ThrowReaderException(CoderError,"UnableToDecompressImage");
                     }
 
-              if(Rec.RecType==0x14 && BitmapHeader2.RotAngle!=0)
-              {  
-		   // flop command                
-		 if(BitmapHeader2.RotAngle & 0x8000)
-                 {
-                   rotated_image = FlopImage(image, exception);
-		   rotated_image->blob = image->blob;
-		   image->blob = NULL;
-		   RemoveLastImageFromList(&image);
-		   AppendImageToList(&image,rotated_image);
-	         }
-		   // flip command
-		 if(BitmapHeader2.RotAngle & 0x2000)
-		 {
-	           rotated_image = FlipImage(image, exception);
-		   rotated_image->blob = image->blob;
-		   image->blob = NULL;
-		   RemoveLastImageFromList(&image);
-		   AppendImageToList(&image,rotated_image);		
-		 }
+              if(Rec.RecType==0x14 && BitmapHeader2.RotAngle!=0 && !image_info->ping)
+                {  
+                  // flop command                
+                  if(BitmapHeader2.RotAngle & 0x8000)
+                    {
+                      rotated_image = FlopImage(image, exception);
+                      rotated_image->blob = image->blob;
+                      image->blob = NULL;
+                      RemoveLastImageFromList(&image);
+                      AppendImageToList(&image,rotated_image);
+                    }
+                  // flip command
+                  if(BitmapHeader2.RotAngle & 0x2000)
+                    {
+                      rotated_image = FlipImage(image, exception);
+                      rotated_image->blob = image->blob;
+                      image->blob = NULL;
+                      RemoveLastImageFromList(&image);
+                      AppendImageToList(&image,rotated_image);		
+                    }
 		
 		  // rotate command
-                 if(BitmapHeader2.RotAngle & 0x0FFF)
-		 {
-	           rotated_image = RotateImage(image, (BitmapHeader2.RotAngle & 0x0FFF), exception);
-		   rotated_image->blob = image->blob;
-		   image->blob = NULL;
-		   RemoveLastImageFromList(&image);
-		   AppendImageToList(&image,rotated_image);		
-		 }                
-              }
+                  if(BitmapHeader2.RotAngle & 0x0FFF)
+                    {
+                      rotated_image = RotateImage(image, (BitmapHeader2.RotAngle & 0x0FFF), exception);
+                      rotated_image->blob = image->blob;
+                      image->blob = NULL;
+                      RemoveLastImageFromList(&image);
+                      AppendImageToList(&image,rotated_image);		
+                    }                
+                }
 
               /* Allocate next image structure. */
               AllocateNextImage(image_info,image);
@@ -1287,33 +1287,32 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                   }   
                 }
 
-
-		if(CTM[0][0]<0)
+              if(CTM[0][0]<0 && !image_info->ping)
 		{		/*?? RotAngle=360-RotAngle;*/
 		  rotated_image = FlopImage(image, exception);
 		  rotated_image->blob = image->blob;
 		  image->blob = NULL;
 		  RemoveLastImageFromList(&image);
 		  AppendImageToList(&image,rotated_image);
-			/* Try to change CTM according to Flip - I am not sure, must be checked.		  
-		  Tx(0,0)=-1;      Tx(1,0)=0;   Tx(2,0)=0;
-		  Tx(0,1)= 0;      Tx(1,1)=1;   Tx(2,1)=0;
-		  Tx(0,2)=(WPG._2Rect.X_ur+WPG._2Rect.X_ll);
-		                   Tx(1,2)=0;   Tx(2,2)=1; */                  
+                  /* Try to change CTM according to Flip - I am not sure, must be checked.		  
+                     Tx(0,0)=-1;      Tx(1,0)=0;   Tx(2,0)=0;
+                     Tx(0,1)= 0;      Tx(1,1)=1;   Tx(2,1)=0;
+                     Tx(0,2)=(WPG._2Rect.X_ur+WPG._2Rect.X_ll);
+                     Tx(1,2)=0;   Tx(2,2)=1; */                  
                 }
-		if(CTM[1][1]<0)
+              if(CTM[1][1]<0 && !image_info->ping)
 		{		/*?? RotAngle=360-RotAngle;*/
 		  rotated_image = FlipImage(image, exception);
 		  rotated_image->blob = image->blob;
 		  image->blob = NULL;
 		  RemoveLastImageFromList(&image);
 		  AppendImageToList(&image,rotated_image);
-			  /* Try to change CTM according to Flip - I am not sure, must be checked.
-		  float_matrix Tx(3,3);
-		  Tx(0,0)= 1;   Tx(1,0)= 0;   Tx(2,0)=0;
-		  Tx(0,1)= 0;   Tx(1,1)=-1;   Tx(2,1)=0;
-		  Tx(0,2)= 0;   Tx(1,2)=(WPG._2Rect.Y_ur+WPG._2Rect.Y_ll);
-					      Tx(2,2)=1; */		  
+                  /* Try to change CTM according to Flip - I am not sure, must be checked.
+                     float_matrix Tx(3,3);
+                     Tx(0,0)= 1;   Tx(1,0)= 0;   Tx(2,0)=0;
+                     Tx(0,1)= 0;   Tx(1,1)=-1;   Tx(2,1)=0;
+                     Tx(0,2)= 0;   Tx(1,2)=(WPG._2Rect.Y_ur+WPG._2Rect.Y_ll);
+                     Tx(2,2)=1; */		  
 		}		
 		
 
@@ -1363,17 +1362,18 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
       Rewind list, removing any empty images while rewinding.
     */
     p=image;
+    image=NULL;
     while (p != (Image *) NULL)
-    {
-      if ((p->rows == 0) || (p->columns == 0))
       {
-        DeleteImageFromList(&p);
-        image=p;
-        continue;
+        Image *tmp=p;
+        if ((p->rows == 0) || (p->columns == 0)) {
+          p=p->previous;
+          DeleteImageFromList(&tmp);
+        } else {
+          image=p;
+          p=p->previous;
+        }
       }
-      image=p;
-      p=p->previous;
-    }
     /*
       Fix scene numbers.
     */
