@@ -144,6 +144,9 @@ static MagickBooleanType IsXWD(const unsigned char *magick,const size_t length)
 
 static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
+#define CheckOverflowException(length,width,height) \
+   (((height) != 0) && ((length)/((size_t) height) != ((size_t) width)))
+
   char
     *comment;
 
@@ -267,6 +270,11 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ximage->red_mask=header.red_mask;
   ximage->green_mask=header.green_mask;
   ximage->blue_mask=header.blue_mask;
+  if ((ximage->depth < 0) || (ximage->width < 0) || (ximage->height < 0) ||
+      (ximage->bitmap_pad < 0) || (ximage->bytes_per_line < 0))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  if ((ximage->bits_per_pixel > 32) || (ximage->bitmap_unit > 32))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   x_status=XInitImage(ximage);
   if (x_status == 0)
     ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
@@ -312,11 +320,20 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Allocate the pixel buffer.
   */
-  if (ximage->format == ZPixmap)
-    length=(size_t) ximage->bytes_per_line*ximage->height;
-  else
-    length=(size_t) ximage->bytes_per_line*ximage->height*ximage->depth;
-  ximage->data=(char *) AcquireMagickMemory(24*length*sizeof(*ximage->data));
+  length=ximage->bytes_per_line*ximage->height;
+  if (CheckOverflowException(length,ximage->bytes_per_line,ximage->height))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  if (ximage->format != ZPixmap)
+    {
+      size_t
+        extent;
+
+      extent=length;
+      length*=ximage->depth;
+      if (CheckOverflowException(length,extent,ximage->depth))
+        ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+    }
+  ximage->data=(char *) AcquireMagickMemory(length*sizeof(*ximage->data));
   if (ximage->data == (char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   count=ReadBlob(image,length,(unsigned char *) ximage->data);
