@@ -238,11 +238,11 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           for (x=0; x < (long) image->columns; x+=2)
           {
-            chroma_pixels->red=0;
+            chroma_pixels->red=(Quantum) 0;
             chroma_pixels->green=ScaleCharToQuantum(*p++);
             q->red=ScaleCharToQuantum(*p++);
-            q->green=0;
-            q->blue=0;
+            q->green=(Quantum) 0;
+            q->blue=(Quantum) 0;
             q++;
             q->green=0;
             q->blue=0;
@@ -304,9 +304,9 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           for (x=0; x < (long) chroma_image->columns; x++)
           {
-            q->red=0;
+            q->red=(Quantum) 0;
             q->green=ScaleCharToQuantum(*p++);
-            q->blue=0;
+            q->blue=(Quantum) 0;
             q++;
           }
           if (SyncImagePixels(chroma_image) == MagickFalse)
