@@ -1978,7 +1978,6 @@ static MagickBooleanType RenderPostscript(Image *image,
 %
 %    o metrics: bounding box of text.
 %
-%
 */
 #if defined(HasX11)
 static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
@@ -2102,11 +2101,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
     (int) strlen(draw_info->text));
   annotate_info.height=(unsigned int) font_info->ascent+font_info->descent;
   metrics->pixels_per_em.x=(double) font_info->max_bounds.width;
-  metrics->pixels_per_em.y=(double) font_info->max_bounds.width;
-  metrics->ascent=(double) font_info->ascent;
+  metrics->pixels_per_em.y=(double) font_info->ascent+font_info->descent;
+  metrics->ascent=(double) font_info->ascent+4;
   metrics->descent=(double) (-font_info->descent);
   metrics->width=annotate_info.width/ExpandAffine(&draw_info->affine);
-  metrics->height=metrics->pixels_per_em.x+4;
+  metrics->height=font_info->ascent+font_info->descent;
   metrics->max_advance=(double) font_info->max_bounds.width;
   metrics->bounds.x1=0.0;
   metrics->bounds.y1=metrics->descent;
