@@ -31,8 +31,7 @@ typedef enum
   ReadBlobMode,
   ReadBinaryBlobMode,
   WriteBlobMode,
-  WriteBinaryBlobMode,
-  IOBinaryBlobMode
+  WriteBinaryBlobMode
 } BlobMode;
 
 typedef int
