@@ -60,11 +60,17 @@
 */
 struct _ViewInfo
 {
+  unsigned long
+    id;
+
   Image
     *image;
 
-  unsigned long
-    id;
+  VirtualPixelMethod
+    virtual_pixel_method;
+
+  MagickBooleanType
+    debug;
 
   unsigned long
     signature;
@@ -111,11 +117,11 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
-  pixels=AcquireCacheNexus(view_info->image,x,y,columns,rows,view_info->id,
-    exception);
+  pixels=AcquireCacheNexus(view_info->image,view_info->virtual_pixel_method,x,y,
+    columns,rows,view_info->id,exception);
   return(pixels);
 }
 
@@ -124,6 +130,41 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   A c q u i r e C a c h e V i e w I n d e x e s                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireCacheViewIndexes() returns the indexes associated with the specified
+%  view.
+%
+%  The format of the AcquireCacheViewIndexes method is:
+%
+%      const IndexPacket *AcquireCacheViewIndexes(const ViewInfo *view_info)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+*/
+MagickExport const IndexPacket *AcquireCacheViewIndexes(
+  const ViewInfo *view_info)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(AcquireNexusIndexes(view_info->image->cache,view_info->id));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   A c q u i r e O n e C a c h e V i e w P i x e l                           %
 %                                                                             %
 %                                                                             %
@@ -154,7 +195,7 @@ MagickExport PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(AcquireOnePixel(view_info->image,x,y,exception));
@@ -165,6 +206,51 @@ MagickExport PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C l o n e C a c h e V i e w                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  CloneCacheView()  makes an exact copy of the specified cache view.
+%
+%  The format of the CloneCacheView method is:
+%
+%      ViewInfo *CloneCacheView(const ViewInfo *view_info)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The cache view.
+%
+*/
+MagickExport ViewInfo *CloneCacheView(const ViewInfo *view_info)
+{
+  ViewInfo
+    *clone_view;
+
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  if (view_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  clone_view=(ViewInfo *) AcquireMagickMemory(sizeof(ViewInfo));
+  if (clone_view == (ViewInfo *) NULL)
+    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+      view_info->image->filename);
+  (void) ResetMagickMemory(clone_view,0,sizeof(*clone_view));
+  clone_view->image=ReferenceImage(view_info->image);
+  clone_view->id=GetNexus(clone_view->image->cache);
+  clone_view->virtual_pixel_method=view_info->virtual_pixel_method;
+  clone_view->debug=view_info->debug;
+  clone_view->signature=MagickSignature;
+  return(clone_view);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   C l o s e C a c h e V i e w                                               %
 %                                                                             %
 %                                                                             %
@@ -188,7 +274,7 @@ MagickExport ViewInfo *CloseCacheView(ViewInfo *view_info)
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   if (view_info->id != 0)
@@ -236,7 +322,7 @@ MagickExport PixelPacket *GetCacheView(ViewInfo *view_info,const long x,
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(GetCacheNexus(view_info->image,x,y,columns,rows,view_info->id));
@@ -270,7 +356,7 @@ MagickExport ColorspaceType GetCacheViewColorspace(const ViewInfo *view_info)
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(view_info->image->colorspace);
@@ -304,7 +390,7 @@ MagickExport ExceptionInfo *GetCacheViewException(const ViewInfo *view_info)
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(&view_info->image->exception);
@@ -338,7 +424,7 @@ MagickExport IndexPacket *GetCacheViewIndexes(const ViewInfo *view_info)
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(GetNexusIndexes(view_info->image->cache,view_info->id));
@@ -371,7 +457,7 @@ MagickExport PixelPacket *GetCacheViewPixels(const ViewInfo *view_info)
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(GetNexusPixels(view_info->image->cache,view_info->id));
@@ -405,7 +491,7 @@ MagickExport ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(view_info->image->storage_class);
@@ -443,7 +529,7 @@ MagickExport PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(GetOnePixel(view_info->image,x,y));
@@ -487,6 +573,8 @@ MagickExport ViewInfo *OpenCacheView(const Image *image)
   (void) ResetMagickMemory(view_info,0,sizeof(*view_info));
   view_info->image=ReferenceImage((Image *) image);
   view_info->id=GetNexus(view_info->image->cache);
+  view_info->virtual_pixel_method=GetImageVirtualPixelMethod(image);
+  view_info->debug=IsEventLogging();
   view_info->signature=MagickSignature;
   return(view_info);
 }
@@ -496,6 +584,44 @@ MagickExport ViewInfo *OpenCacheView(const Image *image)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   O p e n V i r t u a l C a c h e V i e w                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  OpenVirtualCacheView() opens a view into the pixel cache.
+%
+%  The format of the OpenCacheView method is:
+%
+%      ViewInfo *OpenVirtualCacheView(const Image *image,
+%        const VirtualPixelMethod virtual_pixel_method)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o virtual_pixel_method: The virtual pixel method.
+%
+*/
+MagickExport ViewInfo *OpenVirtualCacheView(const Image *image,
+  const VirtualPixelMethod virtual_pixel_method)
+{
+  ViewInfo
+    *view_info;
+
+  view_info=OpenCacheView(image);
+  if (view_info == (ViewInfo *) NULL)
+    return(view_info);
+  view_info->virtual_pixel_method=virtual_pixel_method;
+  return(view_info);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S e t C a c h e V i e w                                                   %
 %                                                                             %
 %                                                                             %
@@ -525,7 +651,7 @@ MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(SetCacheNexus(view_info->image,x,y,columns,rows,view_info->id));
@@ -563,7 +689,7 @@ MagickExport MagickBooleanType SetCacheViewStorageClass(ViewInfo *view_info,
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(SetImageStorageClass(view_info->image,storage_class));
@@ -598,7 +724,7 @@ MagickExport MagickBooleanType SyncCacheView(ViewInfo *view_info)
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
   assert(view_info->image != (Image *) NULL);
-  if (view_info->image->debug != MagickFalse)
+  if (view_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
   return(SyncCacheNexus(view_info->image,view_info->id));
