@@ -35,6 +35,9 @@ extern MagickExport ClassType
 extern MagickExport ColorspaceType
   GetCacheViewColorspace(const ViewInfo *);
 
+extern MagickExport const IndexPacket
+  *AcquireCacheViewIndexes(const ViewInfo *);
+
 extern MagickExport ExceptionInfo
   *GetCacheViewException(const ViewInfo *);
 
@@ -57,7 +60,9 @@ extern MagickExport PixelPacket
 
 extern MagickExport ViewInfo
   *CloseCacheView(ViewInfo *),
-  *OpenCacheView(const Image *);
+  *CloneCacheView(const ViewInfo *),
+  *OpenCacheView(const Image *),
+  *OpenVirtualCacheView(const Image *,const VirtualPixelMethod);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
