@@ -64,8 +64,6 @@ static inline MagickBooleanType IsGray(const PixelPacket *pixel)
 static inline MagickBooleanType IsMagickColorEqual(const MagickPixelPacket *p,
   const MagickPixelPacket *q)
 {
-  if (p->colorspace != q->colorspace)
-    return(MagickFalse);
   if ((p->matte != MagickFalse) && (q->matte == MagickFalse) &&
       (p->opacity != OpaqueOpacity))
     return(MagickFalse);
@@ -114,7 +112,11 @@ static inline MagickRealType MagickPixelIntensity(
 static inline Quantum MagickPixelIntensityToQuantum(
   const MagickPixelPacket *pixel)
 {
+#if !defined(UseHDRI)
   return((Quantum) (0.299*pixel->red+0.587*pixel->green+0.114*pixel->blue+0.5));
+#else
+  return((Quantum) (0.299*pixel->red+0.587*pixel->green+0.114*pixel->blue));
+#endif
 }
 
 static inline MagickRealType MagickPixelLuminance(
@@ -132,13 +134,18 @@ static inline MagickRealType PixelIntensity(const PixelPacket *pixel)
   MagickRealType
     intensity;
 
-  intensity=0.299*pixel->red+0.587*pixel->green+0.114*pixel->blue;
+  intensity=(MagickRealType) (0.299*pixel->red+0.587*pixel->green+0.114*
+    pixel->blue);
   return(intensity);
 }
 
 static inline Quantum PixelIntensityToQuantum(const PixelPacket *pixel)
 {
+#if !defined(UseHDRI)
   return((Quantum) (0.299*pixel->red+0.587*pixel->green+0.114*pixel->blue+0.5));
+#else
+  return((Quantum) (0.299*pixel->red+0.587*pixel->green+0.114*pixel->blue));
+#endif
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
