@@ -92,6 +92,8 @@ extern MagickExport unsigned long
   GetNumberColors(const Image *,FILE *,ExceptionInfo *);
 
 extern MagickExport void
+  ConcatenateColorComponent(const MagickPixelPacket *,const ChannelType,
+    const ComplianceType,char *),
   DestroyColorList(void),
   GetColorTuple(const MagickPixelPacket *,const MagickBooleanType,char *),
   GetMagickPixelPacket(const Image *,MagickPixelPacket *);
