@@ -97,7 +97,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 MagickExport Image *CompareImages(Image *image,const Image *reconstruct_image,
@@ -130,14 +129,16 @@ MagickExport Image *CompareImageChannels(Image *image,
   MagickStatusType
     difference;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
 
   register IndexPacket
-    *difference_indexes,
-    *indexes,
-    *reconstruct_indexes;
+    *difference_indexes;
 
   register long
     x;
@@ -201,8 +202,8 @@ MagickExport Image *CompareImageChannels(Image *image,
     if ((p == (const PixelPacket *) NULL) ||
         (q == (const PixelPacket *) NULL) || (r == (PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     difference_indexes=GetCacheViewIndexes(difference_view);
     for (x=0; x < (long) image->columns; x++)
     {
@@ -297,10 +298,6 @@ MagickExport MagickBooleanType GetImageDistortion(Image *image,
 static MagickRealType GetAbsoluteError(const Image *image,
   const Image *reconstruct_image,ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -311,6 +308,10 @@ static MagickRealType GetAbsoluteError(const Image *image,
   MagickRealType
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -337,8 +338,8 @@ static MagickRealType GetAbsoluteError(const Image *image,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       SetMagickPixelPacket(image,p,indexes+x,&image_pixel);
@@ -359,10 +360,6 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -370,6 +367,10 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
     area,
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -392,8 +393,8 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -431,14 +432,114 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   return(distortion/area);
 }
 
+static MagickRealType GetMeanErrorPerPixel(Image *image,
+  const Image *reconstruct_image,const ChannelType channel,
+  ExceptionInfo *exception)
+{
+  double
+    alpha,
+    area,
+    beta,
+    distance,
+    maximum_error,
+    mean_error,
+    mean_error_per_pixel;
+
+  long
+    y;
+
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
+  register const PixelPacket
+    *p,
+    *q;
+
+  register long
+    x;
+
+  ViewInfo
+    *image_view,
+    *reconstruct_view;
+
+  alpha=1.0;
+  beta=1.0;
+  area=0.0;
+  maximum_error=0.0;
+  mean_error_per_pixel=0.0;
+  mean_error=0.0;
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+      exception);
+    if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
+      break;
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
+    for (x=0; x < (long) image->columns; x++)
+    {
+      if (image->matte != MagickFalse)
+        {
+          alpha=QuantumScale*(QuantumRange-(double) p->opacity);
+          beta=QuantumScale*(QuantumRange-(double) q->opacity);
+        }
+      if ((channel & RedChannel) != 0)
+        {
+          distance=fabs(alpha*p->red-beta*q->red);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      if ((channel & GreenChannel) != 0)
+        {
+          distance=fabs(alpha*p->green-beta*q->green);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      if ((channel & BlueChannel) != 0)
+        {
+          distance=fabs(alpha*p->blue-beta*q->blue);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        {
+          distance=fabs(alpha*indexes[x]-beta*reconstruct_indexes[x]);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      p++;
+      q++;
+    }
+  }
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
+  image->error.mean_error_per_pixel=mean_error_per_pixel/area;
+  image->error.normalized_mean_error=QuantumScale*QuantumScale*mean_error/area;
+  image->error.normalized_maximum_error=QuantumScale*maximum_error;
+  return((MagickRealType) image->error.mean_error_per_pixel);
+}
+
 static MagickRealType GetMeanSquaredError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -447,6 +548,10 @@ static MagickRealType GetMeanSquaredError(const Image *image,
     distance,
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -469,8 +574,8 @@ static MagickRealType GetMeanSquaredError(const Image *image,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -517,10 +622,6 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -528,6 +629,10 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
     distance,
     distortion;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -549,8 +654,8 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -652,6 +757,12 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
         exception);
       break;
     }
+    case MeanErrorPerPixelMetric:
+    {
+      *distortion=(double) GetMeanErrorPerPixel(image,reconstruct_image,channel,
+        exception);
+      break;
+    }
     case MeanSquaredErrorMetric:
     {
       *distortion=(double) GetMeanSquaredError(image,reconstruct_image,channel,
@@ -731,10 +842,6 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
 MagickExport MagickBooleanType IsImagesEqual(Image *image,
   const Image *reconstruct_image)
 {
-  IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
   long
     y;
 
@@ -748,6 +855,10 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
     mean_error,
     mean_error_per_pixel;
 
+  register const IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
   register const PixelPacket
     *p,
     *q;
@@ -783,8 +894,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       &image->exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
-    indexes=GetCacheViewIndexes(image_view);
-    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    indexes=AcquireCacheViewIndexes(image_view);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
       distance=fabs(p->red-(double) q->red);
@@ -830,8 +941,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   reconstruct_view=CloseCacheView(reconstruct_view);
   image_view=CloseCacheView(image_view);
   image->error.mean_error_per_pixel=(double) (mean_error_per_pixel/area);
-  image->error.normalized_mean_error=(double)
-    (QuantumScale*QuantumScale*mean_error/area);
+  image->error.normalized_mean_error=(double) (QuantumScale*QuantumScale*
+    mean_error/area);
   image->error.normalized_maximum_error=(double) (QuantumScale*maximum_error);
   status=image->error.mean_error_per_pixel == 0.0 ? MagickTrue : MagickFalse;
   return(status);
