@@ -45,6 +45,7 @@
 #include "magick/client.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
+#include "magick/colorspace.h"
 #include "magick/composite.h"
 #include "magick/composite-private.h"
 #include "magick/constitute.h"
@@ -437,12 +438,13 @@ static void CompositeHSB(const MagickRealType red,const MagickRealType green,
     min=blue;
   *hue=0.0;
   *saturation=0.0;
-  if (max != 0.0)
-    *saturation=(double) ((max-min)/max);
   *brightness=(double) (QuantumScale*max);
-  if (*saturation == 0.0)
+  if (max == 0.0)
     return;
+  *saturation=(double) (1.0-min/max);
   delta=max-min;
+  if (delta == 0.0)
+    return;
   if (red == max)
     *hue=(double) ((green-blue)/delta);
   else
@@ -454,9 +456,6 @@ static void CompositeHSB(const MagickRealType red,const MagickRealType green,
   *hue/=6.0;
   if (*hue < 0.0)
     *hue+=1.0;
-  else
-    if (*hue > 1.0)
-      *hue-=1.0;
 }
 
 static inline MagickRealType In(const MagickRealType p,
@@ -522,6 +521,29 @@ static inline void CompositeLighten(const MagickPixelPacket *p,
     composite->index=gamma*Lighten(p->index,alpha,q->index,beta);
 }
 
+static inline MagickRealType LinearLight(const MagickRealType p,
+  const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
+{ 
+  return((1.0-QuantumScale*beta)*q+2.0*(1.0-QuantumScale*alpha)*p-1.0);
+}
+
+static inline void CompositeLinearLight(const MagickPixelPacket *p,
+  const MagickRealType alpha,const MagickPixelPacket *q,
+  const MagickRealType beta,MagickPixelPacket *composite)
+{
+  MagickRealType
+    gamma;
+
+  gamma=RoundToUnity((1.0-QuantumScale*beta)+2.0*(1.0-QuantumScale*alpha)-1.0);
+  composite->opacity=(MagickRealType) QuantumRange*(1.0-gamma);
+  gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
+  composite->red=gamma*LinearLight(p->red,alpha,q->red,beta);
+  composite->green=gamma*LinearLight(p->green,alpha,q->green,beta);
+  composite->blue=gamma*LinearLight(p->blue,alpha,q->blue,beta);
+  if (q->colorspace == CMYKColorspace)
+    composite->index=gamma*LinearLight(p->index,alpha,q->index,beta);
+}   
+
 static inline MagickRealType Minus(const MagickRealType p,
   const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
 {
@@ -871,10 +893,8 @@ static void HSBComposite(const double hue,const double saturation,
       *blue=(*red);
       return;
     }
-  h=6.0*hue;
-  if (h == 6.0)
-    h=0.0;
-  f=h-(int) h;
+  h=6.0*(hue-floor(hue));
+  f=h-floor((double) h);
   p=brightness*(1.0-saturation);
   q=brightness*(1.0-saturation*f);
   t=brightness*(1.0-saturation*(1.0-f));
@@ -981,6 +1001,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     midpoint,
     percent_brightness,
     percent_saturation,
+    quantum_sans,
     source_dissolve,
     threshold;
 
@@ -1023,9 +1044,6 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   threshold=0.05f;
   switch (compose)
   {
-    /*
-      These operators modify destination outside the overlaid region.
-    */
     case ClearCompositeOp:
     case SrcCompositeOp:
     case SrcInCompositeOp:
@@ -1035,16 +1053,19 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     case DstInCompositeOp:
     case DstAtopCompositeOp:
     {
+      /*
+        Modify destination outside the overlaid region.
+      */
       modify_outside_overlay=MagickTrue;
       break;
     }
-    /*
-      These operators modify destination outside the overlaid region.
-      and require an alpha channel to exist, to add transparency.
-    */
     case CopyOpacityCompositeOp:
     case ChangeMaskCompositeOp:
     {
+      /*
+        Modify destination outside the overlaid region and require an alpha
+        channel to exist, to add transparency.
+      */
       if (image->matte == MagickFalse)
         (void) SetImageOpacity(image,OpaqueOpacity);
       modify_outside_overlay=MagickTrue;
@@ -1492,6 +1513,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             destination.opacity,&composite);
           break;
         }
+        case LinearLightCompositeOp:
+        {
+          CompositeLinearLight(&source,source.opacity,&destination,
+            destination.opacity,&composite);
+          break;
+        }
         case ColorDodgeCompositeOp:
         {
           CompositeColorDodge(&source,source.opacity,&destination,
@@ -1599,8 +1626,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
           CompositeHSB(destination.red,destination.green,destination.blue,&hue,
             &saturation,&brightness);
           CompositeHSB(source.red,source.green,source.blue,&hue,&sans,&sans);
-          HSBComposite(hue,saturation,brightness,&composite.red,
-            &composite.green,&composite.blue);
+          HSBComposite(hue,saturation,brightness,&composite.red,&quantum_sans,
+            &quantum_sans);
           if (source.opacity < destination.opacity)
             composite.opacity=source.opacity;
           break;
@@ -1618,8 +1645,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             &saturation,&brightness);
           CompositeHSB(source.red,source.green,source.blue,&sans,&saturation,
             &sans);
-          HSBComposite(hue,saturation,brightness,&composite.red,
-            &composite.green,&composite.blue);
+          HSBComposite(hue,saturation,brightness,&quantum_sans,&composite.green,
+            &quantum_sans);
           if (source.opacity < destination.opacity)
             composite.opacity=source.opacity;
           break;
@@ -1637,8 +1664,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             &saturation,&brightness);
           CompositeHSB(source.red,source.green,source.blue,&sans,&sans,
             &brightness);
-          HSBComposite(hue,saturation,brightness,&composite.red,
-            &composite.green,&composite.blue);
+          HSBComposite(hue,saturation,brightness,&quantum_sans,&quantum_sans,
+            &composite.blue);
           if (source.opacity < destination.opacity)
             composite.opacity=source.opacity;
           break;
@@ -1694,17 +1721,23 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         }
         case CopyOpacityCompositeOp:  /* deprecated */
         {
-          if (source.matte != MagickFalse)
+          if (source.matte == MagickFalse)
             {
-              composite.opacity=source.opacity;
+              composite.opacity=(MagickRealType) (QuantumRange-
+                MagickPixelIntensityToQuantum(&source));
               break;
             }
-          composite.opacity=(MagickRealType) (QuantumRange-
-            MagickPixelIntensityToQuantum(&source));
+          composite.opacity=source.opacity;
           break;
         }
-        case CopyBlackCompositeOp:  /* deprecated */
+        case CopyBlackCompositeOp:
         {
+          if (source.colorspace != CMYKColorspace)
+            {
+              composite.index=(MagickRealType) (QuantumRange-
+                MagickPixelIntensityToQuantum(&source));
+              break;
+            }
           composite.index=source.index;
           break;
         }
