@@ -52,6 +52,7 @@
 #include "magick/list.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/option.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
 #if defined(HasTIFF)
@@ -987,14 +988,16 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   write_info=CloneImageInfo(image_info);
   SetImageInfoFile(write_info,file);
   write_info->compression=Group4Compression;
+  (void) SetImageOption(write_info,"quantum:polarity","min-is-white");
   status=WriteImage(write_info,huffman_image);
   write_info=DestroyImageInfo(write_info);
-  (void) fclose(file);
   if (status == MagickFalse)
     return(MagickFalse);
   tiff=TIFFOpen(filename,"rb");
   if (tiff == (TIFF *) NULL)
     {
+      huffman_image=DestroyImage(huffman_image);
+      (void) fclose(file);
       (void) RelinquishUniqueFileResource(filename);
       ThrowFileException(&image->exception,FileOpenError,"UnableToOpenFile",
         image_info->filename);
@@ -1013,6 +1016,8 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   if (buffer == (unsigned char *) NULL)
     {
       TIFFClose(tiff);
+      huffman_image=DestroyImage(huffman_image);
+      (void) fclose(file);
       (void) RelinquishUniqueFileResource(filename);
       ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
         image_info->filename);
@@ -1034,6 +1039,7 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   buffer=(unsigned char *) RelinquishMagickMemory(buffer);
   TIFFClose(tiff);
   huffman_image=DestroyImage(huffman_image);
+  (void) fclose(file);
   (void) RelinquishUniqueFileResource(filename);
   return(MagickTrue);
 }
