@@ -502,23 +502,28 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
     }
   for (next=image; next != (Image *) NULL; next=GetNextImageInList(next))
   {
+    const StringInfo
+      *profile;
+
     next->taint=MagickFalse;
+    if (next->magick_columns == 0)
+      next->magick_columns=next->columns;
+    if (next->magick_rows == 0)
+      next->magick_rows=next->rows;
     (void) CopyMagickString(next->magick,magick,MaxTextExtent);
     (void) CopyMagickString(next->magick_filename,magick_filename,
       MaxTextExtent);
     if (IsBlobTemporary(image) != MagickFalse)
       (void) CopyMagickString(next->filename,filename,MaxTextExtent);
-    if (next->magick_columns == 0)
-      next->magick_columns=next->columns;
-    if (next->magick_rows == 0)
-      next->magick_rows=next->rows;
     value=GetImageProperty(next,"EXIF:Orientation");
     if (value != (char *) NULL)
       {
         next->orientation=(OrientationType) atol(value);
         (void) DeleteImageProperty(next,"EXIF:Orientation");
       }
-    value=GetImageProperty(next,"EXIF:XResolution");
+    value=GetImageProperty(next,"TIFF:XResolution");
+    if (value == (char *) NULL)
+      value=GetImageProperty(next,"EXIF:XResolution");
     if (value != (char *) NULL)
       {
         geometry_info.rho=next->x_resolution;
@@ -527,8 +532,11 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         if (geometry_info.sigma != 0)
           next->x_resolution=geometry_info.rho/geometry_info.sigma;
         (void) DeleteImageProperty(next,"EXIF:XResolution");
+        (void) DeleteImageProperty(next,"TIFF:XResolution");
       }
-    value=GetImageProperty(next,"EXIF:YResolution");
+    value=GetImageProperty(next,"TIFF:YResolution");
+    if (value == (char *) NULL)
+      value=GetImageProperty(next,"EXIF:YResolution");
     if (value != (char *) NULL)
       {
         geometry_info.rho=next->y_resolution;
@@ -537,12 +545,16 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
         if (geometry_info.sigma != 0)
           next->y_resolution=geometry_info.rho/geometry_info.sigma;
         (void) DeleteImageProperty(next,"EXIF:YResolution");
+        (void) DeleteImageProperty(next,"TIFF:YResolution");
       }
-    value=GetImageProperty(next,"EXIF:ResolutionUnit");
+    value=GetImageProperty(next,"TIFF:ResolutionUnit");
+    if (value == (char *) NULL)
+      value=GetImageProperty(next,"EXIF:YResolution");
     if (value != (char *) NULL)
       {
         next->units=(ResolutionType) (atoi(value)-1);
         (void) DeleteImageProperty(next,"EXIF:ResolutionUnit");
+        (void) DeleteImageProperty(next,"TIFF:ResolutionUnit");
       }
     if (next->page.width == 0)
       next->page.width=next->columns;
@@ -602,6 +614,22 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
                 }
           }
       }
+    profile=GetImageProfile(next,"icc");
+    if (profile == (const StringInfo *) NULL)
+      profile=GetImageProfile(next,"icm");
+    if (profile != (const StringInfo *) NULL)
+      {
+        image->color_profile.length=GetStringInfoLength(profile);
+        image->color_profile.info=GetStringInfoDatum(profile);
+      }
+    profile=GetImageProfile(next,"iptc");
+    if (profile == (const StringInfo *) NULL)
+      profile=GetImageProfile(next,"8bim");
+    if (profile != (const StringInfo *) NULL)
+      {
+        image->iptc_profile.length=GetStringInfoLength(profile);
+        image->iptc_profile.info=GetStringInfoDatum(profile);
+      }
     if (read_info->verbose != MagickFalse)
       (void) IdentifyImage(next,stdout,MagickFalse);
     image=next;
@@ -804,6 +832,9 @@ static void SyncImageInfo(const ImageInfo *image_info,Image *image,
     (void) ParseAbsoluteGeometry(image_info->extract,&image->extract_info);
   if (image_info->depth != 0)
     (void) SetImageDepth(image,image_info->depth);
+  else
+    if (image->taint != MagickFalse)
+      image->depth=QuantumDepth;
   if (image_info->compression != UndefinedCompression)
     image->compression=image_info->compression;
   if (image_info->quality != UndefinedCompressionQuality)
@@ -833,7 +864,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
     *magick_info;
 
   ExceptionInfo
-    sans_exception;
+    *sans_exception;
 
   ImageInfo
     *write_info;
@@ -852,12 +883,12 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       image_info->filename);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  GetExceptionInfo(&sans_exception);
+  sans_exception=AcquireExceptionInfo();
   write_info=CloneImageInfo(image_info);
   (void) CopyMagickString(write_info->filename,image->filename,MaxTextExtent);
   if (*write_info->magick == '\0')
     (void) CopyMagickString(write_info->magick,image->magick,MaxTextExtent);
-  (void) SetImageInfo(write_info,MagickTrue,&sans_exception);
+  (void) SetImageInfo(write_info,MagickTrue,sans_exception);
   if (LocaleCompare(write_info->magick,"clipmask") == 0)
     {
       if (image->clip_mask == (Image *) NULL)
@@ -867,10 +898,10 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
           return(MagickFalse);
         }
       image=image->clip_mask;
-      (void) SetImageInfo(write_info,MagickTrue,&sans_exception);
+      (void) SetImageInfo(write_info,MagickTrue,sans_exception);
     }
   (void) CopyMagickString(filename,image->filename,MaxTextExtent);
-  SyncImageInfo(write_info,image,&sans_exception);
+  SyncImageInfo(write_info,image,sans_exception);
   (void) SyncImageProfiles(image);
   if ((GetPreviousImageInList(image) == (Image *) NULL) &&
       (GetNextImageInList(image) == (Image *) NULL) &&
@@ -892,13 +923,13 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
             write_info->magick,&image->exception);
           write_info=DestroyImageInfo(write_info);
           (void) CopyMagickString(image->filename,filename,MaxTextExtent);
-          (void) DestroyExceptionInfo(&sans_exception);
+          sans_exception=DestroyExceptionInfo(sans_exception);
           return(status);
         }
     }
   status=MagickFalse;
   temporary=MagickFalse;
-  magick_info=GetMagickInfo(write_info->magick,&sans_exception);
+  magick_info=GetMagickInfo(write_info->magick,sans_exception);
   if ((magick_info != (const MagickInfo *) NULL) &&
       (GetMagickSeekableStream(magick_info) != MagickFalse))
     {
@@ -906,7 +937,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
         filename[MaxTextExtent];
 
       (void) CopyMagickString(filename,image->filename,MaxTextExtent);
-      status=OpenBlob(image_info,image,IOBinaryBlobMode,&image->exception);
+      status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
       (void) CopyMagickString(image->filename,filename,MaxTextExtent);
       if (status != MagickFalse)
         {
@@ -955,7 +986,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
         }
       else
         {
-          magick_info=GetMagickInfo(write_info->magick,&sans_exception);
+          magick_info=GetMagickInfo(write_info->magick,sans_exception);
           if ((write_info->affirm == MagickFalse) &&
               (magick_info == (const MagickInfo *) NULL))
             {
@@ -1009,7 +1040,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       (write_info->verbose != MagickFalse))
     (void) IdentifyImage(image,stdout,MagickFalse);
   write_info=DestroyImageInfo(write_info);
-  (void) DestroyExceptionInfo(&sans_exception);
+  sans_exception=DestroyExceptionInfo(sans_exception);
   return(status);
 }
 
@@ -1041,11 +1072,13 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
   Image *images,const char *filename,ExceptionInfo *exception)
 {
+  ExceptionInfo
+    *sans_exception;
+
   ImageInfo
     *write_info;
 
@@ -1073,7 +1106,9 @@ MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
   (void) CopyMagickString(write_info->filename,images->filename,MaxTextExtent);
   if (*write_info->magick == '\0')
     (void) CopyMagickString(write_info->magick,images->magick,MaxTextExtent);
-  (void) SetImageInfo(write_info,MagickTrue,exception);
+  sans_exception=AcquireExceptionInfo();
+  (void) SetImageInfo(write_info,MagickTrue,sans_exception);
+  sans_exception=DestroyExceptionInfo(sans_exception);
   p=images;
   for ( ; GetNextImageInList(p) != (Image *) NULL; p=GetNextImageInList(p))
     if (p->scene >= GetNextImageInList(p)->scene)
