@@ -243,20 +243,20 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
   SetMagickPixelPacket(frame_image,&image->border_color,(IndexPacket *) NULL,
     &border);
   GetMagickPixelPacket(frame_image,&accentuate);
-  accentuate.red=QuantumScale*((QuantumRange-AccentuateModulate)*matte.red+
-    (QuantumRange*AccentuateModulate));
-  accentuate.green=QuantumScale*((QuantumRange-AccentuateModulate)*matte.green+
-    (QuantumRange*AccentuateModulate));
-  accentuate.blue=QuantumScale*((QuantumRange-AccentuateModulate)*matte.blue+
-    (QuantumRange*AccentuateModulate));
+  accentuate.red=(MagickRealType) (QuantumScale*((QuantumRange-
+    AccentuateModulate)*matte.red+(QuantumRange*AccentuateModulate)));
+  accentuate.green=(MagickRealType) (QuantumScale*((QuantumRange-
+    AccentuateModulate)*matte.green+(QuantumRange*AccentuateModulate)));
+  accentuate.blue=(MagickRealType) (QuantumScale*((QuantumRange-
+    AccentuateModulate)*matte.blue+(QuantumRange*AccentuateModulate)));
   accentuate.opacity=matte.opacity;
   GetMagickPixelPacket(frame_image,&highlight);
-  highlight.red=QuantumScale*((QuantumRange-HighlightModulate)*matte.red+
-    (QuantumRange*HighlightModulate));
-  highlight.green=QuantumScale*((QuantumRange-HighlightModulate)*matte.green+
-    (QuantumRange*HighlightModulate));
-  highlight.blue=QuantumScale*((QuantumRange-HighlightModulate)*matte.blue+
-    (QuantumRange*HighlightModulate));
+  highlight.red=(MagickRealType) (QuantumScale*((QuantumRange-
+    HighlightModulate)*matte.red+(QuantumRange*HighlightModulate)));
+  highlight.green=(MagickRealType) (QuantumScale*((QuantumRange-
+    HighlightModulate)*matte.green+(QuantumRange*HighlightModulate)));
+  highlight.blue=(MagickRealType) (QuantumScale*((QuantumRange-
+    HighlightModulate)*matte.blue+(QuantumRange*HighlightModulate)));
   highlight.opacity=matte.opacity;
   GetMagickPixelPacket(frame_image,&shadow);
   shadow.red=QuantumScale*matte.red*ShadowModulate;
@@ -612,12 +612,12 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       (image->rows <= (raise_info->height << 1)))
     ThrowBinaryException(OptionError,"ImageSizeMustExceedBevelWidth",
       image->filename);
-  foreground=(Quantum) QuantumRange;
+  foreground=QuantumRange;
   background=(Quantum) 0;
   if (raise == MagickFalse)
     {
       foreground=(Quantum) 0;
-      background=(Quantum) QuantumRange;
+      background=QuantumRange;
     }
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
@@ -628,37 +628,38 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       break;
     for (x=0; x < y; x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*
+        HighlightFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*
+        HighlightFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
+        HighlightFactor)));
       q++;
     }
     for ( ; x < (long) (image->columns-y); x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*AccentuateFactor+
-        (MagickRealType) foreground*(QuantumRange-AccentuateFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*
         AccentuateFactor+(MagickRealType) foreground*(QuantumRange-
-        AccentuateFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*
+        AccentuateFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
         AccentuateFactor+(MagickRealType) foreground*(QuantumRange-
-        AccentuateFactor))+0.5);
+        AccentuateFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
+        AccentuateFactor+(MagickRealType) foreground*(QuantumRange-
+        AccentuateFactor)));
       q++;
     }
     for ( ; x < (long) image->columns; x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*ShadowFactor+
+        (MagickRealType) background*(QuantumRange-ShadowFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
+        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
+        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -679,27 +680,27 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       break;
     for (x=0; x < (long) raise_info->width; x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*
+        HighlightFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*
+        HighlightFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
+        HighlightFactor)));
       q++;
     }
     for ( ; x < (long) (image->columns-raise_info->width); x++)
       q++;
     for ( ; x < (long) image->columns; x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*ShadowFactor+
+        (MagickRealType) background*(QuantumRange-ShadowFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
+        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
+        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -720,35 +721,35 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       break;
     for (x=0; x < (long) (image->rows-y); x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*
+        HighlightFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*
+        HighlightFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
         HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor))+0.5);
+        HighlightFactor)));
       q++;
     }
     for ( ; x < (long) (image->columns-(image->rows-y)); x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*TroughFactor+
-        (MagickRealType) background*(QuantumRange-TroughFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*TroughFactor+
-        (MagickRealType) background*(QuantumRange-TroughFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*TroughFactor+
-        (MagickRealType) background*(QuantumRange-TroughFactor))+0.5);
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*TroughFactor+
+        (MagickRealType) background*(QuantumRange-TroughFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
+        TroughFactor+(MagickRealType) background*(QuantumRange-TroughFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
+        TroughFactor+(MagickRealType) background*(QuantumRange-TroughFactor)));
       q++;
     }
     for ( ; x < (long) image->columns; x++)
     {
-      q->red=(Quantum) (QuantumScale*((MagickRealType) q->red*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
-      q->green=(Quantum) (QuantumScale*((MagickRealType) q->green*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
-      q->blue=(Quantum) (QuantumScale*((MagickRealType) q->blue*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor))+0.5);
+      q->red=RoundToQuantum(QuantumScale*((MagickRealType) q->red*ShadowFactor+
+        (MagickRealType) background*(QuantumRange-ShadowFactor)));
+      q->green=RoundToQuantum(QuantumScale*((MagickRealType) q->green*
+        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
+      q->blue=RoundToQuantum(QuantumScale*((MagickRealType) q->blue*
+        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
