@@ -239,7 +239,6 @@ MagickExport void DestroyDelegateList(void)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
   const char *decode,const char *encode,ExceptionInfo *exception)
@@ -346,7 +345,6 @@ MagickExport const char *GetDelegateCommands(const DelegateInfo *delegate_info)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport const DelegateInfo *GetDelegateInfo(const char *decode,
   const char *encode,ExceptionInfo *exception)
@@ -785,11 +783,11 @@ static void CopyDelegateFile(const char *source,const char *destination)
     }
   for (length=0; ; )
   {
-    count=read(source_file,buffer,quantum);
+    count=(ssize_t) read(source_file,buffer,quantum);
     if (count <= 0)
       break;
     length=(size_t) count;
-    count=write(destination_file,buffer,length);
+    count=(ssize_t) write(destination_file,buffer,length);
     if ((size_t) count != length)
       break;
   }
@@ -1036,7 +1034,6 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
   ExceptionInfo *exception)
@@ -1310,7 +1307,6 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 static MagickBooleanType LoadDelegateLists(const char *filename,
   ExceptionInfo *exception)
