@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -22,10 +22,15 @@
 extern "C" {
 #endif
 
+#if !defined(ExcludeMagickDeprecated)
+
 #include <stdarg.h>
 #include "magick/blob.h"
+#include "magick/draw.h"
 #include "magick/constitute.h"
+#include "magick/magick-config.h"
 #include "magick/quantum.h"
+#include "magick/registry.h"
 #include "magick/semaphore.h"
 
 #if !defined(magick_attribute)
@@ -79,12 +84,33 @@ typedef MagickBooleanType
   (*MonitorHandler)(const char *,const MagickOffsetType,const MagickSizeType,
     ExceptionInfo *);
 
+typedef struct _ImageAttribute
+{
+  char
+    *key,
+    *value;
+                                                                                
+  MagickBooleanType
+    compression;
+                                                                                
+  struct _ImageAttribute
+    *previous,
+    *next;  /* deprecated */
+} ImageAttribute;
+
 extern MagickExport char
   *AllocateString(const char *),
+  *InterpretImageAttributes(const ImageInfo *,Image *,const char *),
   *PostscriptGeometry(const char *),
   *TranslateText(const ImageInfo *,Image *,const char *);
 
+extern MagickExport const ImageAttribute
+  *GetImageAttribute(const Image *,const char *),
+  *GetImageClippingPathAttribute(Image *),
+  *GetNextImageAttribute(const Image *);
+
 extern MagickExport Image
+  *GetImageFromMagickRegistry(const char *,long *id,ExceptionInfo *),
   *GetImageList(const Image *,const long,ExceptionInfo *),
   *GetNextImage(const Image *),
   *GetPreviousImage(const Image *),
@@ -93,9 +119,6 @@ extern MagickExport Image
   *SpliceImageList(Image *,const long,const unsigned long,const Image *,
     ExceptionInfo *);
 
-extern MagickExport long
-  GetImageListIndex(const Image *);
-
 extern MagickExport IndexPacket
   ValidateColormapIndex(Image *,const unsigned long);
 
@@ -104,16 +127,33 @@ extern MagickExport int
   ParseImageGeometry(const char *,long *,long *,unsigned long *,
     unsigned long *);
 
+extern MagickExport long
+  GetImageListIndex(const Image *),
+  SetMagickRegistry(const RegistryType,const void *,const size_t,
+    ExceptionInfo *);
+
 extern MagickExport MagickBooleanType
+  CloneImageAttributes(Image *,const Image *),
+  ColorFloodfillImage(Image *,const DrawInfo *,const PixelPacket,const long,
+    const long,const PaintMethod),
+  DeleteImageAttribute(Image *,const char *),
+  DeleteMagickRegistry(const long),
   DescribeImage(Image *,FILE *,const MagickBooleanType),
+  FormatImageAttribute(Image *,const char *,const char *,...)
+    magick_attribute((format (printf,3,4))),
+  FormatImageAttributeList(Image *,const char *,const char *,va_list)
+    magick_attribute((format (printf,3,0))),
   FuzzyColorCompare(const Image *,const PixelPacket *,const PixelPacket *),
   FuzzyOpacityCompare(const Image *,const PixelPacket *,const PixelPacket *),
   MagickMonitor(const char *,const MagickOffsetType,const MagickSizeType,
     void *),
+  MatteFloodfillImage(Image *,const PixelPacket,const Quantum,const long,
+    const long,const PaintMethod),
   OpaqueImage(Image *,const PixelPacket,const PixelPacket),
   PopImagePixels(Image *,const QuantumType,unsigned char *),
   PushImagePixels(Image *,const QuantumType,const unsigned char *),
   SetExceptionInfo(ExceptionInfo *,ExceptionType),
+  SetImageAttribute(Image *,const char *,const char *),
   TransparentImage(Image *,const PixelPacket,const Quantum);
 
 extern MagickExport MonitorHandler
@@ -148,19 +188,26 @@ extern MagickExport unsigned long
 extern MagickExport void
   *AcquireMemory(const size_t),
   *CloneMemory(void *,const void *,const size_t),
+  DestroyImageAttributes(Image *),
   DestroyImages(Image *),
+  DestroyMagick(void),
+  DestroyMagickRegistry(void),
   *GetConfigureBlob(const char *,char *,size_t *,ExceptionInfo *),
+  *GetMagickRegistry(const long,RegistryType *,size_t *,ExceptionInfo *),
   IdentityAffine(AffineMatrix *),
   LiberateMemory(void **),
   LiberateSemaphoreInfo(SemaphoreInfo **),
   FormatString(char *,const char *,...) magick_attribute((format (printf,2,3))),
   FormatStringList(char *,const char *,va_list)
     magick_attribute((format (printf,2,0))),
+  InitializeMagick(const char *),
   ReacquireMemory(void **,const size_t),
+  ResetImageAttributeIterator(const Image *),
   SetCacheThreshold(const unsigned long),
   SetImage(Image *,const Quantum),
   Strip(char *),
   TemporaryFilename(char *);
+#endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
