@@ -82,7 +82,6 @@
 %
 %    o sharpen: Increase or decrease image contrast.
 %
-%
 */
 MagickExport MagickBooleanType ContrastImage(Image *image,
   const MagickBooleanType sharpen)
@@ -444,7 +443,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.red != white.red)
               normalize_map[i].red=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.red)/(white.red-black.red)));
+                (MagickRealType) (MaxMap*(i-black.red)/(white.red-black.red)));
           }
     if ((channel & GreenChannel) != 0)
       {
@@ -456,7 +455,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.green != white.green)
               normalize_map[i].green=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.green)/(white.green-
+                (MagickRealType) (MaxMap*(i-black.green)/(white.green-
                 black.green)));
       }
     if ((channel & BlueChannel) != 0)
@@ -469,7 +468,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.blue != white.blue)
               normalize_map[i].blue=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.blue)/(white.blue-
+                (MagickRealType) (MaxMap*(i-black.blue)/(white.blue-
                 black.blue)));
       }
     if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
@@ -482,7 +481,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.opacity != white.opacity)
               normalize_map[i].opacity=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.opacity)/(white.opacity-
+                (MagickRealType) (MaxMap*(i-black.opacity)/(white.opacity-
                 black.opacity)));
       }
     if (((channel & IndexChannel) != 0) &&
@@ -496,7 +495,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.index != white.index)
               normalize_map[i].index=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.index)/(white.index-
+                (MagickRealType) (MaxMap*(i-black.index)/(white.index-
                 black.index)));
       }
   }
@@ -623,7 +622,6 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
 {
@@ -643,7 +641,8 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
   distance=(MagickRealType) r->opacity-(MagickRealType) pixel.opacity; \
   distance_squared+=QuantumScale*(3.0*((MagickRealType) \
     QuantumRange+1.0)-1.0-mean)*distance*distance; \
-  if (distance_squared < ((MagickRealType) QuantumRange*QuantumRange/25.0)) \
+  if (distance_squared < ((MagickRealType) QuantumRange*(MagickRealType) \
+      QuantumRange/25.0f)) \
     { \
       aggregate.red+=(weight)*r->red; \
       aggregate.green+=(weight)*r->green; \
@@ -823,10 +822,9 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  histogram=(MagickPixelPacket *)
-    AcquireMagickMemory((MaxMap+1)*sizeof(*histogram));
-  map=(MagickPixelPacket *)
-    AcquireMagickMemory((MaxMap+1)*sizeof(*map));
+  histogram=(MagickPixelPacket *) AcquireMagickMemory((MaxMap+1)*
+    sizeof(*histogram));
+  map=(MagickPixelPacket *) AcquireMagickMemory((MaxMap+1)*sizeof(*map));
   equalize_map=(PixelPacket *)
     AcquireMagickMemory((MaxMap+1)*sizeof(*equalize_map));
   if ((histogram == (MagickPixelPacket *) NULL) ||
@@ -865,22 +863,22 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
     map[i]=intensity;
   }
   black=map[0];
-  white=map[MaxMap];
+  white=map[(int) MaxMap];
   (void) ResetMagickMemory(equalize_map,0,(MaxMap+1)*sizeof(*equalize_map));
   for (i=0; i <= (long) MaxMap; i++)
   {
     if (white.red != black.red)
-      equalize_map[i].red=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].red-black.red))/(white.red-black.red)));
+      equalize_map[i].red=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].red-black.red))/(white.red-black.red)));
     if (white.green != black.green)
-      equalize_map[i].green=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].green-black.green))/(white.green-black.green)));
+      equalize_map[i].green=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].green-black.green))/(white.green-black.green)));
     if (white.blue != black.blue)
-      equalize_map[i].blue=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].blue-black.blue))/(white.blue-black.blue)));
+      equalize_map[i].blue=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].blue-black.blue))/(white.blue-black.blue)));
     if (white.opacity != black.opacity)
-      equalize_map[i].opacity=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].opacity-black.opacity))/(white.opacity-black.opacity)));
+      equalize_map[i].opacity=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].opacity-black.opacity))/(white.opacity-black.opacity)));
   }
   histogram=(MagickPixelPacket *) RelinquishMagickMemory(histogram);
   map=(MagickPixelPacket *) RelinquishMagickMemory(map);
@@ -892,14 +890,14 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
       for (i=0; i < (long) image->colors; i++)
       {
         if (black.red != white.red)
-          image->colormap[i].red=
-            equalize_map[ScaleQuantumToMap(image->colormap[i].red)].red;
+          image->colormap[i].red=equalize_map[ScaleQuantumToMap(
+            image->colormap[i].red)].red;
         if (black.green != white.green)
-          image->colormap[i].green=
-            equalize_map[ScaleQuantumToMap(image->colormap[i].green)].green;
+          image->colormap[i].green=equalize_map[ScaleQuantumToMap(
+            image->colormap[i].green)].green;
         if (black.blue != white.blue)
-          image->colormap[i].blue=
-            equalize_map[ScaleQuantumToMap(image->colormap[i].blue)].blue;
+          image->colormap[i].blue=equalize_map[ScaleQuantumToMap(
+            image->colormap[i].blue)].blue;
       }
     }
   /*
@@ -1048,8 +1046,8 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
   (void) ResetMagickMemory(gamma_map,0,(MaxMap+1)*sizeof(*gamma_map));
   if (gamma != 0.0)
     for (i=0; i <= (long) MaxMap; i++)
-      gamma_map[i]=(MagickRealType) ScaleMapToQuantum((unsigned long)
-        (MaxMap*pow((double) i/MaxMap,1.0/gamma)+0.5));
+      gamma_map[i]=(MagickRealType) ScaleMapToQuantum((MagickRealType)
+        (MaxMap*pow((double) i/MaxMap,1.0/gamma)));
   if (image->storage_class == PseudoClass)
     {
       /*
@@ -1106,9 +1104,9 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
           break;
       }
   }
+  gamma_map=(MagickRealType *) RelinquishMagickMemory(gamma_map);
   if (image->gamma != 0.0)
     image->gamma*=gamma;
-  gamma_map=(MagickRealType *) RelinquishMagickMemory(gamma_map);
   return(MagickTrue);
 }
 
@@ -1239,8 +1237,8 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   if (levels_map == (MagickRealType *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
-  black=ScaleQuantumToMap((Quantum) (black_point+0.5));
-  white=ScaleQuantumToMap((Quantum) (white_point+0.5));
+  black=ScaleQuantumToMap(RoundToQuantum(black_point));
+  white=ScaleQuantumToMap(RoundToQuantum(white_point));
   for (i=0; i < (long) black; i++)
     levels_map[i]=0.0;
   if (gamma == 1.0)
@@ -1263,14 +1261,14 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
       for (i=0; i < (long) image->colors; i++)
       {
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=ScaleMapToQuantum((unsigned long)
-            levels_map[ScaleQuantumToMap(image->colormap[i].red)]);
+          image->colormap[i].red=ScaleMapToQuantum(levels_map[
+            ScaleQuantumToMap(image->colormap[i].red)]);
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=ScaleMapToQuantum((unsigned long)
-            levels_map[ScaleQuantumToMap(image->colormap[i].green)]);
+          image->colormap[i].green=ScaleMapToQuantum(levels_map[
+            ScaleQuantumToMap(image->colormap[i].green)]);
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=ScaleMapToQuantum((unsigned long)
-            levels_map[ScaleQuantumToMap(image->colormap[i].blue)]);
+          image->colormap[i].blue=ScaleMapToQuantum(levels_map[
+            ScaleQuantumToMap(image->colormap[i].blue)]);
       }
     }
   /*
@@ -1285,22 +1283,17 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->red)]);
+        q->red=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->red)]);
       if ((channel & GreenChannel) != 0)
-        q->green=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->green)]);
+        q->green=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->green)]);
       if ((channel & BlueChannel) != 0)
-        q->blue=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->blue)]);
+        q->blue=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->blue)]);
       if (((channel & OpacityChannel) != 0) & (image->matte != MagickFalse))
-        q->opacity=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->opacity)]);
+        q->opacity=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->opacity)]);
       if (((channel & IndexChannel) != 0) &&
           ((image->storage_class == PseudoClass) ||
            (image->colorspace == CMYKColorspace)))
-        indexes[x]=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(indexes[x])]);
+        indexes[x]=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(indexes[x])]);
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1449,7 +1442,6 @@ MagickExport MagickBooleanType LinearStretchImage(Image *image,
 %    o modulate: Define the percent change in brightness, saturation, and
 %      hue.
 %
-%
 */
 MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
 {
@@ -1657,12 +1649,12 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               (image->colormap[i].green != image->colormap[i].blue))
             continue;
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=(Quantum) QuantumRange-image->colormap[i].red;
+          image->colormap[i].red=QuantumRange-image->colormap[i].red;
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=(Quantum) QuantumRange-
+          image->colormap[i].green=QuantumRange-
             image->colormap[i].green;
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=(Quantum) QuantumRange-
+          image->colormap[i].blue=QuantumRange-
             image->colormap[i].blue;
       }
     }
@@ -1685,14 +1677,14 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               continue;
             }
           if ((channel & RedChannel) != 0)
-            q->red=(Quantum) QuantumRange-q->red;
+            q->red=QuantumRange-q->red;
           if ((channel & GreenChannel) != 0)
-            q->green=(Quantum) QuantumRange-q->green;
+            q->green=QuantumRange-q->green;
           if ((channel & BlueChannel) != 0)
-            q->blue=(Quantum) QuantumRange-q->blue;
+            q->blue=QuantumRange-q->blue;
           if (((channel & OpacityChannel) != 0) &&
               (image->matte != MagickFalse))
-            q->opacity=(Quantum) QuantumRange-q->opacity;
+            q->opacity=QuantumRange-q->opacity;
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
             indexes[x]=(IndexPacket) QuantumRange-indexes[x];
@@ -1723,13 +1715,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=(Quantum) QuantumRange-q->red;
+        q->red=QuantumRange-q->red;
       if ((channel & GreenChannel) != 0)
-        q->green=(Quantum) QuantumRange-q->green;
+        q->green=QuantumRange-q->green;
       if ((channel & BlueChannel) != 0)
-        q->blue=(Quantum) QuantumRange-q->blue;
+        q->blue=QuantumRange-q->blue;
       if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-        q->opacity=(Quantum) QuantumRange-q->opacity;
+        q->opacity=QuantumRange-q->opacity;
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         indexes[x]=(IndexPacket) QuantumRange-indexes[x];
@@ -1904,7 +1896,7 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
   {
     if (sharpen != MagickFalse)
       {
-        sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((unsigned long)
+        sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((MagickRealType)
           (MaxMap*((1.0/(1.0+exp(contrast*(midpoint/(double) QuantumRange-
           (double) i/MaxMap))))-(1.0/(1.0+exp(contrast*(midpoint/
           (double) QuantumRange)))))/((1.0/(1.0+exp(contrast*(midpoint/
@@ -1912,7 +1904,7 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
           (double) QuantumRange)))))+0.5));
         continue;
       }
-    sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((unsigned long)
+    sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((MagickRealType)
       (MaxMap*(QuantumScale*midpoint-log((1.0-(1.0/(1.0+exp(midpoint/
       (double) QuantumRange*contrast))+((double) i/MaxMap)*((1.0/
       (1.0+exp(contrast*(midpoint/(double) QuantumRange-1.0))))-(1.0/
@@ -1930,17 +1922,17 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
       for (i=0; i < (long) image->colors; i++)
       {
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=(Quantum)
-            (sigmoidal_map[ScaleQuantumToMap(image->colormap[i].red)]+0.5);
+          image->colormap[i].red=RoundToQuantum(sigmoidal_map[
+            ScaleQuantumToMap(image->colormap[i].red)]);
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=(Quantum)
-            (sigmoidal_map[ScaleQuantumToMap(image->colormap[i].green)]+0.5);
+          image->colormap[i].green=RoundToQuantum(sigmoidal_map[
+            ScaleQuantumToMap(image->colormap[i].green)]);
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=(Quantum)
-            (sigmoidal_map[ScaleQuantumToMap(image->colormap[i].blue)]+0.5);
+          image->colormap[i].blue=RoundToQuantum(sigmoidal_map[
+            ScaleQuantumToMap(image->colormap[i].blue)]);
         if ((channel & OpacityChannel) != 0)
-          image->colormap[i].opacity=(Quantum)
-            (sigmoidal_map[ScaleQuantumToMap(image->colormap[i].opacity)]+0.5);
+          image->colormap[i].opacity=RoundToQuantum(sigmoidal_map[
+            ScaleQuantumToMap(image->colormap[i].opacity)]);
       }
     }
   /*
@@ -1955,17 +1947,17 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=(Quantum) (sigmoidal_map[ScaleQuantumToMap(q->red)]+0.5);
+        q->red=RoundToQuantum(sigmoidal_map[ScaleQuantumToMap(q->red)]);
       if ((channel & GreenChannel) != 0)
-        q->green=(Quantum) (sigmoidal_map[ScaleQuantumToMap(q->green)]+0.5);
+        q->green=RoundToQuantum(sigmoidal_map[ScaleQuantumToMap(q->green)]);
       if ((channel & BlueChannel) != 0)
-        q->blue=(Quantum) (sigmoidal_map[ScaleQuantumToMap(q->blue)]+0.5);
+        q->blue=RoundToQuantum(sigmoidal_map[ScaleQuantumToMap(q->blue)]);
       if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-        q->opacity=(Quantum) (sigmoidal_map[ScaleQuantumToMap(q->opacity)]+0.5);
+        q->opacity=RoundToQuantum(sigmoidal_map[ScaleQuantumToMap(q->opacity)]);
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
-        indexes[x]=(IndexPacket)
-          (sigmoidal_map[ScaleQuantumToMap(indexes[x])]+0.5);
+        indexes[x]=(IndexPacket) RoundToQuantum(sigmoidal_map[
+          ScaleQuantumToMap(indexes[x])]);
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
