@@ -677,7 +677,52 @@ static inline double MagickMax(const double x,const double y)
   return(y);
 }
 
-static MagickRealType CubicWeightingFunction(const MagickRealType x)
+static void BicubicInterpolate(const MagickPixelPacket *pixels,const double dx,
+  MagickPixelPacket *pixel)
+{
+  MagickRealType
+    dx2,
+    p,
+    q,
+    r,
+    s;
+
+  dx2=dx*dx;
+  p=(pixels[3].red-pixels[2].red)-(pixels[0].red-pixels[1].red);
+  q=(pixels[0].red-pixels[1].red)-p;
+  r=pixels[2].red-pixels[0].red;
+  s=pixels[1].red;
+  pixel->red=(dx*dx2*p)+(dx2*q)+(dx*r)+s;
+  p=(pixels[3].green-pixels[2].green)-(pixels[0].green-pixels[1].green);
+  q=(pixels[0].green-pixels[1].green)-p;
+  r=pixels[2].green-pixels[0].green;
+  s=pixels[1].green;
+  pixel->green=(dx*dx2*p)+(dx2*q)+(dx*r)+s;
+  p=(pixels[3].blue-pixels[2].blue)-(pixels[0].blue-pixels[1].blue);
+  q=(pixels[0].blue-pixels[1].blue)-p;
+  r=pixels[2].blue-pixels[0].blue;
+  s=pixels[1].blue;
+  pixel->blue=(dx*dx2*p)+(dx2*q)+(dx*r)+s;
+  if (pixel->matte != MagickFalse)
+    {
+      p=(pixels[3].opacity-pixels[2].opacity)-(pixels[0].opacity-
+        pixels[1].opacity);
+      q=(pixels[0].opacity-pixels[1].opacity)-p;
+      r=pixels[2].opacity-pixels[0].opacity;
+      s=pixels[1].opacity;
+      pixel->opacity=(dx*dx2*p)+(dx2*q)+(dx*r)+s;
+    }
+  if (pixel->colorspace == CMYKColorspace)
+    {
+      p=(pixels[3].index-pixels[2].index)-(pixels[0].index-pixels[1].index);
+      q=(pixels[0].index-pixels[1].index)-p;
+      r=pixels[2].index-pixels[0].index;
+      s=pixels[1].index;
+      pixel->index=(dx*dx2*p)+(dx2*q)+(dx*r)+s;
+    }
+}
+
+static inline MagickRealType CubicWeightingFunction(const MagickRealType x)
 {
   MagickRealType
     alpha,
@@ -694,7 +739,7 @@ static MagickRealType CubicWeightingFunction(const MagickRealType x)
   return(gamma/6.0);
 }
 
-static double MeshInterpolate(const PointInfo *delta,const double p,
+static inline double MeshInterpolate(const PointInfo *delta,const double p,
   const double x,const double y)
 {
   return(delta->x*x+delta->y*y+(1.0-delta->x-delta->y)*p);
@@ -708,7 +753,7 @@ static inline long NearestNeighbor(MagickRealType x)
 }
 
 MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
-  ViewInfo *image_view,InterpolatePixelMethod method,const double x,
+  ViewInfo *image_view,const InterpolatePixelMethod method,const double x,
   const double y,ExceptionInfo *exception)
 {
   MagickPixelPacket
@@ -722,12 +767,12 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
   PointInfo
     delta;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i;
 
@@ -743,7 +788,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         4,4,exception);
       if (p == (const PixelPacket *) NULL)
         return(pixel);
-      indexes=GetCacheViewIndexes(image_view);
+      indexes=AcquireCacheViewIndexes(image_view);
       for (i=0; i < 16L; i++)
       {
         GetMagickPixelPacket(image,pixels+i);
@@ -773,55 +818,35 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
     }
     case BicubicInterpolatePixel:
     {
-      long
-        n;
-
-      MagickRealType
-        dx,
-        dy;
-
-      register long
-        j;
+      MagickPixelPacket
+        u[4];
 
       p=AcquireCacheView(image_view,(long) floor(x)-1,(long) floor(y)-1,
         4,4,exception);
       if (p == (const PixelPacket *) NULL)
         return(pixel);
-      indexes=GetCacheViewIndexes(image_view);
-      n=0;
-      delta.x=x-floor(x);
-      delta.y=y-floor(y);
-      for (i=(-1); i < 3L; i++)
+      indexes=AcquireCacheViewIndexes(image_view);
+      for (i=0; i < 16L; i++)
       {
-        dy=CubicWeightingFunction((MagickRealType) i-delta.y);
-        for (j=(-1); j < 3L; j++)
-        {
-          GetMagickPixelPacket(image,pixels+n);
-          SetMagickPixelPacket(image,p,indexes+n,pixels+n);
-          alpha[n]=1.0;
-          if (image->matte != MagickFalse)
-            {
-              alpha[n]=QuantumScale*((MagickRealType) QuantumRange-p->opacity);
-              pixels[n].red*=alpha[n];
-              pixels[n].green*=alpha[n];
-              pixels[n].blue*=alpha[n];
-              if (image->colorspace == CMYKColorspace)
-                pixels[n].index*=alpha[n];
-            }
-          dx=CubicWeightingFunction(delta.x-(MagickRealType) j);
-          gamma=alpha[n];
-          gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-          pixel.red+=gamma*dx*dy*pixels[n].red;
-          pixel.green+=gamma*dx*dy*pixels[n].green;
-          pixel.blue+=gamma*dx*dy*pixels[n].blue;
-          if (image->matte != MagickFalse)
-            pixel.opacity+=dx*dy*pixels[n].opacity;
-          if (image->colorspace == CMYKColorspace)
-            pixel.index+=gamma*dx*dy*pixels[n].index;
-          n++;
-          p++;
-        }
+        GetMagickPixelPacket(image,pixels+i);
+        SetMagickPixelPacket(image,p,indexes+i,pixels+i);
+        alpha[i]=1.0;
+        if (image->matte != MagickFalse)
+          {
+            alpha[i]=QuantumScale*((MagickRealType) QuantumRange-p->opacity);
+            pixels[i].red*=alpha[i];
+            pixels[i].green*=alpha[i];
+            pixels[i].blue*=alpha[i];
+            if (image->colorspace == CMYKColorspace)
+              pixels[i].index*=alpha[i];
+          }
+        p++;
       }
+      delta.x=x-floor(x);
+      for (i=0; i < 4L; i++)
+        BicubicInterpolate(pixels+4*i,delta.x,u+i);
+      delta.y=y-floor(y);
+      BicubicInterpolate(u,delta.y,&pixel);
       break;
     }
     case BilinearInterpolatePixel:
@@ -831,7 +856,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         exception);
       if (p == (const PixelPacket *) NULL)
         return(pixel);
-      indexes=GetCacheViewIndexes(image_view);
+      indexes=AcquireCacheViewIndexes(image_view);
       for (i=0; i < 4L; i++)
       {
         GetMagickPixelPacket(image,pixels+i);
@@ -910,7 +935,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         exception);
       if (p == (const PixelPacket *) NULL)
         return(pixel);
-      indexes=GetCacheViewIndexes(image_view);
+      indexes=AcquireCacheViewIndexes(image_view);
       GetMagickPixelPacket(image,pixels);
       SetMagickPixelPacket(image,p,indexes,&pixel);
       break;
@@ -924,7 +949,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         2,2,exception);
       if (p == (const PixelPacket *) NULL)
         return(pixel);
-      indexes=GetCacheViewIndexes(image_view);
+      indexes=AcquireCacheViewIndexes(image_view);
       for (i=0; i < 4L; i++)
       {
         GetMagickPixelPacket(image,pixels+i);
@@ -1049,11 +1074,64 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         exception);
       if (p == (const PixelPacket *) NULL)
         return(pixel);
-      indexes=GetCacheViewIndexes(image_view);
+      indexes=AcquireCacheViewIndexes(image_view);
       GetMagickPixelPacket(image,pixels);
       SetMagickPixelPacket(image,p,indexes,&pixel);
       break;
     }
+    case SplineInterpolatePixel:
+    {
+      long
+        n;
+
+      MagickRealType
+        dx,
+        dy;
+
+      register long
+        j;
+
+      p=AcquireCacheView(image_view,(long) floor(x)-1,(long) floor(y)-1,
+        4,4,exception);
+      if (p == (const PixelPacket *) NULL)
+        return(pixel);
+      indexes=AcquireCacheViewIndexes(image_view);
+      n=0;
+      delta.x=x-floor(x);
+      delta.y=y-floor(y);
+      for (i=(-1); i < 3L; i++)
+      {
+        dy=CubicWeightingFunction((MagickRealType) i-delta.y);
+        for (j=(-1); j < 3L; j++)
+        {
+          GetMagickPixelPacket(image,pixels+n);
+          SetMagickPixelPacket(image,p,indexes+n,pixels+n);
+          alpha[n]=1.0;
+          if (image->matte != MagickFalse)
+            {
+              alpha[n]=QuantumScale*((MagickRealType) QuantumRange-p->opacity);
+              pixels[n].red*=alpha[n];
+              pixels[n].green*=alpha[n];
+              pixels[n].blue*=alpha[n];
+              if (image->colorspace == CMYKColorspace)
+                pixels[n].index*=alpha[n];
+            }
+          dx=CubicWeightingFunction(delta.x-(MagickRealType) j);
+          gamma=alpha[n];
+          gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
+          pixel.red+=gamma*dx*dy*pixels[n].red;
+          pixel.green+=gamma*dx*dy*pixels[n].green;
+          pixel.blue+=gamma*dx*dy*pixels[n].blue;
+          if (image->matte != MagickFalse)
+            pixel.opacity+=dx*dy*pixels[n].opacity;
+          if (image->colorspace == CMYKColorspace)
+            pixel.index+=gamma*dx*dy*pixels[n].index;
+          n++;
+          p++;
+        }
+      }
+      break;
+    }
   }
   return(pixel);
 }
