@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -28,6 +28,10 @@ extern "C" {
 extern MagickExport double
   ExpandAffine(const AffineMatrix *);
 
+extern MagickExport MagickPixelPacket
+  InterpolatePixelColor(const Image *,ViewInfo *,const InterpolatePixelMethod,
+    const double,const double,ExceptionInfo *);
+
 extern MagickExport unsigned long
   GetOptimalKernelWidth(const double,const double),
   GetOptimalKernelWidth1D(const double,const double),
