@@ -86,6 +86,13 @@
 #include "magick/timer.h"
 #include "magick/utility.h"
 #include "magick/version.h"
+#if defined(HasLCMS)
+#if defined(HAVE_LCMS_LCMS_H)
+#include <lcms/lcms.h>
+#else
+#include "lcms.h"
+#endif
+#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -286,6 +293,8 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
       ChannelStatistics
         *channel_statistics;
 
+      (void) fprintf(file,"  Depth: %lu-bit\n",GetImageDepth(image,
+        &image->exception));
       channel_statistics=GetImageChannelStatistics(image,&image->exception);
       (void) fprintf(file,"  Channel depth:\n");
       switch (colorspace)
@@ -742,6 +751,27 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           continue;
         (void) fprintf(file,"  Profile-%s: %lu bytes\n",name,(unsigned long)
           GetStringInfoLength(profile));
+#if defined(HasLCMS)
+        if ((LocaleCompare(name,"icc") == 0) ||
+            (LocaleCompare(name,"icm") == 0))
+          {
+            cmsHPROFILE
+              icc_profile;
+
+            icc_profile=cmsOpenProfileFromMem(GetStringInfoDatum(profile),
+              (DWORD) GetStringInfoLength(profile));
+            if (icc_profile != (cmsHPROFILE *) NULL)
+              {
+                const char
+                  *name;
+
+                name=cmsTakeProductName(icc_profile);
+                if (name != (const char *) NULL)
+                  (void) fprintf(file,"    %s\n",name);
+                (void) cmsCloseProfile(icc_profile);
+              }
+          }
+#endif
         if (LocaleCompare(name,"iptc") == 0)
           {
             char
