@@ -25,7 +25,7 @@ extern "C" {
 #include <magick/color.h>
 
 #define OpaqueOpacity  ((Quantum) 0UL)
-#define TransparentOpacity  ((Quantum) QuantumRange)
+#define TransparentOpacity  (QuantumRange)
 
 typedef enum
 {
@@ -36,6 +36,9 @@ typedef enum
   ImageTransmitType
 } TransmitType;
 
+extern MagickExport const IndexPacket
+  *AcquireIndexes(const Image *);
+
 extern MagickExport const PixelPacket
   *AcquireImagePixels(const Image *,const long,const long,const unsigned long,
     const unsigned long,ExceptionInfo *);
@@ -82,6 +85,7 @@ extern MagickExport MagickBooleanType
   IsMagickConflict(const char *),
   IsImageObject(const Image *),
   ListMagickInfo(FILE *,ExceptionInfo *),
+  ModifyImage(Image **,ExceptionInfo *),
   PlasmaImage(Image *,const SegmentInfo *,unsigned long,unsigned long),
   ResetImagePage(Image *,const char *),
   SeparateImageChannel(Image *,const ChannelType),
@@ -99,8 +103,13 @@ extern MagickExport MagickBooleanType
   SyncImagePixels(Image *),
   TextureImage(Image *,const Image *);
 
+extern MagickExport MagickPixelPacket
+  AcquireOneMagickPixel(const Image *,const long,const long,ExceptionInfo *);
+
 extern MagickExport PixelPacket
   AcquireOnePixel(const Image *,const long,const long,ExceptionInfo *),
+  AcquireOneVirtualPixel(const Image *,const VirtualPixelMethod,const long,
+    const long,ExceptionInfo *),
   *GetImagePixels(Image *,const long,const long,const unsigned long,
     const unsigned long),
   GetOnePixel(Image *,const long,const long),
@@ -114,7 +123,6 @@ extern MagickExport void
   DisassociateImageStream(Image *),
   GetImageException(Image *,ExceptionInfo *),
   GetImageInfo(ImageInfo *),
-  ModifyImage(Image **,ExceptionInfo *),
   SetImageInfoBlob(ImageInfo *,const void *,const size_t),
   SetImageInfoFile(ImageInfo *,FILE *);
 
