@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -31,17 +31,29 @@ typedef enum
   CompareOverlayLayer,
   DisposeLayer,
   OptimizeLayer,
-  OptimizePlusLayer
+  OptimizeImageLayer,
+  OptimizePlusLayer,
+  OptimizeTransLayer,
+  RemoveDupsLayer,
+  RemoveZeroLayer,
+  CompositeLayer
 } MagickLayerMethod;
 
 extern MagickExport Image
-  *CoalesceImages(Image *,ExceptionInfo *),
-  *DisposeImages(Image *,ExceptionInfo *),
+  *CoalesceImages(const Image *,ExceptionInfo *),
+  *DisposeImages(const Image *,ExceptionInfo *),
   *CompareImageLayers(const Image *,const MagickLayerMethod,ExceptionInfo *),
   *DeconstructImages(const Image *,ExceptionInfo *),
   *OptimizeImageLayers(const Image *,ExceptionInfo *),
   *OptimizePlusImageLayers(const Image *,ExceptionInfo *);
 
+extern MagickExport void
+  OptimizeImageTransparency(const Image *,ExceptionInfo *),
+  RemoveDuplicateLayers(Image **,ExceptionInfo *),
+  RemoveZeroDelayLayers(Image **,ExceptionInfo *),
+  CompositeLayers(Image *,const CompositeOperator,Image *,const long,
+    const long,ExceptionInfo *);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
