@@ -211,7 +211,6 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
     *image;
 
   long
-    length,
     first,
     last,
     step;
@@ -219,6 +218,9 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
   register long
     i;
 
+  size_t
+    length;
+
   assert(images != (const Image *) NULL);
   assert(images->signature == MagickSignature);
   assert(scenes != (char *) NULL);
@@ -234,7 +236,8 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
     while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
       p++;
     first=strtol(p,&p,10);
-    if (first < 0) first+=length;
+    if (first < 0)
+      first+=(long) length;
     last=first;
     while (isspace((int) ((unsigned char) *p)) != 0)
       p++;
@@ -242,7 +245,7 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
       {
         last=strtol(p+1,&p,10);
         if (last < 0)
-          last+=length;
+          last+=(long) length;
       }
     for (step=first > last ? -1 : 1; first != (last+step); first+=step)
     {
@@ -343,8 +346,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
 
   long
     first,
-    last,
-    length;
+    last;
 
   MagickBooleanType
     *delete_list;
@@ -352,6 +354,9 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
   register long
     i;
 
+  size_t
+    length;
+
   assert(images != (Image **) NULL);
   assert((*images)->signature == MagickSignature);
   assert(scenes != (char *) NULL);
@@ -371,7 +376,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
       return;
     }
   image=(*images);
-  for (i=0; i < length; i++)
+  for (i=0; i < (long) length; i++)
     delete_list[i]=MagickFalse;
   /*
     Note which images will be deleted, avoid duplicate deleted
@@ -382,7 +387,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
       p++;
     first=strtol(p,&p,10);
     if (first < 0)
-      first+=length;
+      first+=(long) length;
     last=first;
     while (isspace((int) ((unsigned char) *p)) != 0)
       p++;
@@ -390,19 +395,19 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
       {
         last=strtol(p+1,&p,10);
         if (last < 0)
-          last+=length;
+          last+=(long) length;
       }
     if (first > last)
       continue;
     for (i=first; i <= last; i++)
-      if ((i >= 0) && (i < length))
+      if ((i >= 0) && (i < (long) length))
         delete_list[i]=MagickTrue;
   }
   /*
     Delete images marked for deletion, once only
   */
   image=(*images);
-  for (i=0; i < length; i++)
+  for (i=0; i < (long) length; i++)
   {
     *images=image;
     image=GetNextImageInList(image);
@@ -743,16 +748,15 @@ MagickExport Image **ImageListToArray(const Image *images,
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
-  group=(Image **) AcquireMagickMemory((size_t)
-    (GetImageListLength(images)+1)*sizeof(*group));
+  group=(Image **) AcquireMagickMemory((size_t) (GetImageListLength(images)+1)*
+    sizeof(*group));
   if (group == (Image **) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",images->filename);
       return((Image **) NULL);
     }
-  while (images->previous != (Image *) NULL)
-    images=images->previous;
+  images=GetFirstImageInList(images);
   for (i=0; images != (Image *) NULL; images=images->next)
     group[i++]=(Image *) images;
   group[i]=(Image *) NULL;
