@@ -880,26 +880,22 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
     {
       case 'c':
       {
-        (void) CopyMagickString(q,GetClientName(),extent);
-        q+=strlen(GetClientName());
+        q+=CopyMagickString(q,GetClientName(),extent);
         break;
       }
       case 'd':
       {
-        (void) CopyMagickString(q,domain,extent);
-        q+=strlen(domain);
+        q+=CopyMagickString(q,domain,extent);
         break;
       }
       case 'e':
       {
-        (void) CopyMagickString(q,event,extent);
-        q+=strlen(event);
+        q+=CopyMagickString(q,event,extent);
         break;
       }
       case 'f':
       {
-        (void) CopyMagickString(q,function,extent);
-        q+=strlen(function);
+        q+=CopyMagickString(q,function,extent);
         break;
       }
       case 'g':
@@ -930,14 +926,12 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
               p++;
               break;
             }
-        (void) CopyMagickString(q,p,extent);
-        q+=strlen(p);
+        q+=CopyMagickString(q,p,extent);
         break;
       }
       case 'n':
       {
-        (void) CopyMagickString(q,GetLogName(),extent);
-        q+=strlen(GetLogName());
+        q+=CopyMagickString(q,GetLogName(),extent);
         break;
       }
       case 'p':
@@ -963,8 +957,7 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
       }
       case 'v':
       {
-        (void) CopyMagickString(q,MagickLibVersionText,extent);
-        q+=strlen(MagickLibVersionText);
+        q+=CopyMagickString(q,MagickLibVersionText,extent);
         break;
       }
       case '%':
@@ -1038,8 +1031,7 @@ static char *TranslateFilename(const LogInfo *log_info)
     {
       case 'c':
       {
-        (void) CopyMagickString(q,GetClientName(),extent);
-        q+=strlen(GetClientName());
+        q+=CopyMagickString(q,GetClientName(),extent);
         break;
       }
       case 'g':
@@ -1056,8 +1048,7 @@ static char *TranslateFilename(const LogInfo *log_info)
       }
       case 'n':
       {
-        (void) CopyMagickString(q,GetLogName(),extent);
-        q+=strlen(GetLogName());
+        q+=CopyMagickString(q,GetLogName(),extent);
         break;
       }
       case 'p':
@@ -1067,8 +1058,7 @@ static char *TranslateFilename(const LogInfo *log_info)
       }
       case 'v':
       {
-        (void) CopyMagickString(q,MagickLibVersionText,extent);
-        q+=strlen(MagickLibVersionText);
+        q+=CopyMagickString(q,MagickLibVersionText,extent);
         break;
       }
       case '%':
@@ -1136,8 +1126,8 @@ MagickBooleanType LogMagickEventList(const LogEventType type,const char *module,
     }
   if ((log_info->handler_mask & ConsoleHandler) != 0)
     {
-      (void) fprintf(stdout,"%s\n",text);
-      (void) fflush(stdout);
+      (void) fprintf(stderr,"%s\n",text);
+      (void) fflush(stderr);
     }
   if ((log_info->handler_mask & DebugHandler) != 0)
     {
@@ -1262,9 +1252,11 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
 {
   char
     keyword[MaxTextExtent],
-    *q,
     *token;
 
+  const char
+    *q;
+
   LogInfo
     *log_info = (LogInfo *) NULL;
 
@@ -1379,7 +1371,7 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
             ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
         log_info=(LogInfo *) NULL;
       }
-    GetMagickToken(q,(char **) NULL,token);
+    GetMagickToken(q,(const char **) NULL,token);
     if (*token != '=')
       continue;
     GetMagickToken(q,&q,token);
