@@ -121,50 +121,6 @@ static MagickBooleanType
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   D e s t r o y M a g i c k                                                 %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  DestroyMagick() destroys the ImageMagick environment.
-%
-%  The format of the DestroyMagick function is:
-%
-%      DestroyMagick(void)
-%
-*/
-MagickExport void DestroyMagick(void)
-{
-#if defined(HasX11)
-  DestroyXResources();
-#endif
-  DestroyConstitute();
-  DestroyMimeList();
-  DestroyConfigureList();
-  DestroyTypeList();
-  DestroyColorList();
-#if defined(__WINDOWS__)
-  NTGhostscriptUnLoadDLL();
-#endif
-  DestroyMagicList();
-  DestroyDelegateList();
-  DestroyMagickList();
-  DestroyCoderList();
-  DestroyMagickResources();
-  DestroyMagickRegistry();
-  DestroyCacheResources();
-  DestroyRandomReservoir();
-  DestroyLocaleList();
-  DestroyLogList();
-  instantiate_magick=MagickFalse;
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 +   D e s t r o y M a g i c k L i s t                                         %
 %                                                                             %
 %                                                                             %
@@ -223,16 +179,16 @@ MagickExport const char *GetImageMagick(const unsigned char *magick,
   const size_t length)
 {
   ExceptionInfo
-    exception;
+    *exception;
 
   register const MagickInfo
     *p;
 
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(magick != (const unsigned char *) NULL);
-  GetExceptionInfo(&exception);
-  p=GetMagickInfo("*",&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  p=GetMagickInfo("*",exception);
+  exception=DestroyExceptionInfo(exception);
   if (p == (const MagickInfo *) NULL)
     return((const char *) NULL);
   AcquireSemaphoreInfo(&magick_semaphore);
@@ -764,206 +720,6 @@ MagickExport MagickStatusType GetMagickThreadSupport(
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   I n i t i a l i z e M a g i c k                                           %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  InitializeMagick() initializes the ImageMagick environment.
-%
-%  The format of the InitializeMagick function is:
-%
-%      InitializeMagick(const char *path)
-%
-%  A description of each parameter follows:
-%
-%    o path: The execution path of the current ImageMagick client.
-%
-*/
-
-static SignalHandler *SetMagickSignalHandler(int signal_number,
-  SignalHandler *handler)
-{
-#if defined(HAVE_SIGACTION) && defined(HAVE_SIGEMPTYSET)
-  int
-    status;
-
-  sigset_t
-    mask;
-
-  struct sigaction
-    action,
-    previous_action;
-
-  sigemptyset(&mask);
-  sigaddset(&mask,signal_number);
-  sigprocmask(SIG_BLOCK,&mask,NULL);
-  action.sa_mask=mask;
-  action.sa_handler=handler;
-  action.sa_flags=0;
-#if defined(SA_INTERRUPT)
-  action.sa_flags|=SA_INTERRUPT;
-#endif
-  status=sigaction(signal_number,&action,&previous_action);
-  if (status < 0)
-    return(SIG_ERR);
-  sigprocmask(SIG_UNBLOCK,&mask,NULL);
-  return(previous_action.sa_handler);
-#else
-  return(signal(signal_number,handler));
-#endif
-}
-
-static void MagickSignalHandler(int signal_number)
-{
-#if !defined(HAVE_SIGACTION)
-  (void) signal(signal_number,SIG_IGN);
-#endif
-  AsynchronousDestroyMagickResources();
-  instantiate_magick=MagickFalse;
-  (void) SetMagickSignalHandler(signal_number,signal_handlers[signal_number]);
-#if defined(HAVE_RAISE)
-  if (signal_handlers[signal_number] != MagickSignalHandler)
-    raise(signal_number);
-#endif
-#if !defined(HAVE__EXIT)
-  exit(signal_number);
-#else
-#if defined(SIGHUP)
-  if (signal_number == SIGHUP)
-    exit(signal_number);
-#endif
-#if defined(SIGINT) && !defined(__WINDOWS__)
-  if (signal_number == SIGINT)
-    exit(signal_number);
-#endif
-#if defined(SIGTERM)
-  if (signal_number == SIGTERM)
-    exit(signal_number);
-#endif
-  _exit(signal_number);
-#endif
-}
-
-static SignalHandler *RegisterMagickSignalHandler(int signal_number)
-{
-  SignalHandler
-    *handler;
-
-  handler=SetMagickSignalHandler(signal_number,MagickSignalHandler);
-  if (handler == SIG_ERR)
-    return(handler);
-  if (handler != SIG_DFL)
-    handler=SetMagickSignalHandler(signal_number,handler);
-  else
-    (void) LogMagickEvent(ConfigureEvent,GetMagickModule(),
-      "Register handler for signal: %d",signal_number);
-  return(handler);
-}
-
-MagickExport void InitializeMagick(const char *path)
-{
-  char
-    *events,
-    execution_path[MaxTextExtent],
-    filename[MaxTextExtent];
-
-  ExceptionInfo
-    *exception;
-
-  time_t
-    seconds;
-
-  /*
-    Initialize the Magick environment.
-  */
-  seconds=time((time_t *) NULL);
-  srand((unsigned int) (seconds+getpid()));
-  InitializeSemaphore();
-  events=GetEnvironmentValue("MAGICK_DEBUG");
-  if (events != (char *) NULL)
-    {
-      (void) SetLogEventMask(events);
-      events=DestroyString(events);
-    }
-#if defined(__WINDOWS__)
-#if defined(_DEBUG) && !defined(__BORLANDC__)
-  if (IsEventLogging() != MagickFalse)
-    {
-      int
-        debug;
-
-      debug=_CrtSetDbgFlag(_CRTDBG_REPORT_FLAG);
-      debug|=_CRTDBG_CHECK_ALWAYS_DF |_CRTDBG_DELAY_FREE_MEM_DF |
-        _CRTDBG_LEAK_CHECK_DF;
-      if (0)
-        {
-          debug=_CrtSetDbgFlag(debug);
-          _ASSERTE(_CrtCheckMemory());
-        }
-    }
-#endif
-#endif
-  /*
-    Set client name and execution path.
-  */
-  (void) GetExecutionPath(execution_path);
-  if ((path != (const char *) NULL) && (*path != '\0'))
-    (void) CopyMagickString(execution_path,path,MaxTextExtent);
-  GetPathComponent(execution_path,TailPath,filename);
-  (void) SetClientName(filename);
-  GetPathComponent(execution_path,HeadPath,execution_path);
-  (void) SetClientPath(execution_path);
-  /*
-    Set signal handlers.
-  */
-#if defined(SIGABRT)
-  if (signal_handlers[SIGABRT] == (SignalHandler *) NULL)
-    signal_handlers[SIGABRT]=RegisterMagickSignalHandler(SIGABRT);
-#endif
-#if defined(SIGFPE)
-  if (signal_handlers[SIGFPE] == (SignalHandler *) NULL)
-    signal_handlers[SIGFPE]=RegisterMagickSignalHandler(SIGFPE);
-#endif
-#if defined(SIGHUP)
-  if (signal_handlers[SIGHUP] == (SignalHandler *) NULL)
-    signal_handlers[SIGHUP]=RegisterMagickSignalHandler(SIGHUP);
-#endif
-#if defined(SIGINT) && !defined(__WINDOWS__)
-  if (signal_handlers[SIGINT] == (SignalHandler *) NULL)
-    signal_handlers[SIGINT]=RegisterMagickSignalHandler(SIGINT);
-#endif
-#if defined(SIGQUIT)
-  if (signal_handlers[SIGQUIT] == (SignalHandler *) NULL)
-    signal_handlers[SIGQUIT]=RegisterMagickSignalHandler(SIGQUIT);
-#endif
-#if defined(SIGTERM)
-  if (signal_handlers[SIGTERM] == (SignalHandler *) NULL)
-    signal_handlers[SIGTERM]=RegisterMagickSignalHandler(SIGTERM);
-#endif
-#if defined(SIGXCPU)
-  if (signal_handlers[SIGXCPU] == (SignalHandler *) NULL)
-    signal_handlers[SIGXCPU]=RegisterMagickSignalHandler(SIGXCPU);
-#endif
-#if defined(SIGXFSZ)
-  if (signal_handlers[SIGXFSZ] == (SignalHandler *) NULL)
-    signal_handlers[SIGXFSZ]=RegisterMagickSignalHandler(SIGXFSZ);
-#endif
-  /*
-    Initialize magick resources.
-  */
-  InitializeMagickResources();
-  exception=AcquireExceptionInfo();
-  (void) GetMagickInfo((char *) NULL,exception);
-  exception=DestroyExceptionInfo(exception);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 +   I n i t i a l i z e M a g i c k L i s t                                   %
 %                                                                             %
 %                                                                             %
@@ -1017,7 +773,7 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
             *magick_info;
 
           magick_list=NewSplayTree(CompareSplayTreeString,
-            RelinquishMagickMemory,DestroyMagickNode);
+            (void *(*)(void *)) NULL,DestroyMagickNode);
           if (magick_list == (SplayTreeInfo *) NULL)
             {
               char
@@ -1030,8 +786,7 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
             }
           magick_info=SetMagickInfo("tmp");
           magick_info->stealth=MagickTrue;
-          status=AddValueToSplayTree(magick_list,ConstantString(
-            magick_info->name),magick_info);
+          status=AddValueToSplayTree(magick_list,magick_info->name,magick_info);
           if (status == MagickFalse)
             {
               char
@@ -1044,8 +799,7 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
             }
           magick_info=SetMagickInfo("clipmask");
           magick_info->stealth=MagickTrue;
-          status=AddValueToSplayTree(magick_list,ConstantString(
-            magick_info->name),magick_info);
+          status=AddValueToSplayTree(magick_list,magick_info->name,magick_info);
           if (status == MagickFalse)
             {
               char
@@ -1080,8 +834,8 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsMagickConflict() returns true if the image format is not a valid image
-%  format or conflicts with a logical drive (.e.g. X:).
+%  IsMagickConflict() returns MagickTrue if the image format is not a valid
+%  image format or conflicts with a logical drive (.e.g. X:).
 %
 %  The format of the IsMagickConflict method is:
 %
@@ -1101,15 +855,15 @@ MagickExport MagickBooleanType IsMagickConflict(const char *magick)
     *magick_info;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   assert(magick != (char *) NULL);
-  GetExceptionInfo(&exception);
-  magick_info=GetMagickInfo(magick,&exception);
-  delegate_info=GetDelegateInfo(magick,(char *) NULL,&exception);
+  exception=AcquireExceptionInfo();
+  magick_info=GetMagickInfo(magick,exception);
+  delegate_info=GetDelegateInfo(magick,(char *) NULL,exception);
   if (delegate_info == (const DelegateInfo *) NULL)
-    delegate_info=GetDelegateInfo((char *) NULL,magick,&exception);
-  (void) DestroyExceptionInfo(&exception);
+    delegate_info=GetDelegateInfo((char *) NULL,magick,exception);
+  exception=DestroyExceptionInfo(exception);
   if ((magick_info == (const MagickInfo *) NULL) &&
       (delegate_info == (const DelegateInfo *) NULL))
     return(MagickTrue);
@@ -1241,7 +995,7 @@ MagickExport MagickBooleanType ListMagickInfo(FILE *file,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  IsMagickInstantiated() returns MagickTrue if the ImageMagick environment
-%  is currently instantiated:  InitializeMagick() has been called but
+%  is currently instantiated:  MagickCoreGenesis() has been called but
 %  MagickDestroy() has not.
 %
 %  The format of the IsMagickInstantiated method is:
@@ -1259,6 +1013,258 @@ MagickExport MagickBooleanType IsMagickInstantiated(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k C o r e G e n e s i s                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickCoreGenesis() initializes the MagickCore environment.
+%
+%  The format of the InitializeMagick function is:
+%
+%      MagickCoreGenesis(const char *path,
+%        const MagickBooleanType establish_signal_handlers)
+%
+%  A description of each parameter follows:
+%
+%    o path: The execution path of the current ImageMagick client.
+%
+%    o establish_signal_handlers: set to MagickTrue to use MagickCore's own
+%      signal handlers for common signals.
+%
+*/
+
+static SignalHandler *SetMagickSignalHandler(int signal_number,
+  SignalHandler *handler)
+{
+#if defined(HAVE_SIGACTION) && defined(HAVE_SIGEMPTYSET)
+  int
+    status;
+
+  sigset_t
+    mask;
+
+  struct sigaction
+    action,
+    previous_action;
+
+  sigemptyset(&mask);
+  sigaddset(&mask,signal_number);
+  sigprocmask(SIG_BLOCK,&mask,NULL);
+  action.sa_mask=mask;
+  action.sa_handler=handler;
+  action.sa_flags=0;
+#if defined(SA_INTERRUPT)
+  action.sa_flags|=SA_INTERRUPT;
+#endif
+  status=sigaction(signal_number,&action,&previous_action);
+  if (status < 0)
+    return(SIG_ERR);
+  sigprocmask(SIG_UNBLOCK,&mask,NULL);
+  return(previous_action.sa_handler);
+#else
+  return(signal(signal_number,handler));
+#endif
+}
+
+static void MagickSignalHandler(int signal_number)
+{
+#if !defined(HAVE_SIGACTION)
+  (void) signal(signal_number,SIG_IGN);
+#endif
+  AsynchronousDestroyMagickResources();
+  instantiate_magick=MagickFalse;
+  (void) SetMagickSignalHandler(signal_number,signal_handlers[signal_number]);
+#if defined(HAVE_RAISE)
+  if (signal_handlers[signal_number] != MagickSignalHandler)
+    raise(signal_number);
+#endif
+#if !defined(HAVE__EXIT)
+  exit(signal_number);
+#else
+#if defined(SIGHUP)
+  if (signal_number == SIGHUP)
+    exit(signal_number);
+#endif
+#if defined(SIGINT) && !defined(__WINDOWS__)
+  if (signal_number == SIGINT)
+    exit(signal_number);
+#endif
+#if defined(SIGTERM)
+  if (signal_number == SIGTERM)
+    exit(signal_number);
+#endif
+  _exit(signal_number);
+#endif
+}
+
+static SignalHandler *RegisterMagickSignalHandler(int signal_number)
+{
+  SignalHandler
+    *handler;
+
+  handler=SetMagickSignalHandler(signal_number,MagickSignalHandler);
+  if (handler == SIG_ERR)
+    return(handler);
+  if (handler != SIG_DFL)
+    handler=SetMagickSignalHandler(signal_number,handler);
+  else
+    (void) LogMagickEvent(ConfigureEvent,GetMagickModule(),
+      "Register handler for signal: %d",signal_number);
+  return(handler);
+}
+
+MagickExport void MagickCoreGenesis(const char *path,
+  const MagickBooleanType establish_signal_handlers)
+{
+  char
+    *events,
+    execution_path[MaxTextExtent],
+    filename[MaxTextExtent];
+
+  ExceptionInfo
+    *exception;
+
+  time_t
+    seconds;
+
+  /*
+    Initialize the Magick environment.
+  */
+  seconds=time((time_t *) NULL);
+  srand((unsigned int) (seconds+getpid()));
+  InitializeSemaphore();
+  events=GetEnvironmentValue("MAGICK_DEBUG");
+  if (events != (char *) NULL)
+    {
+      (void) SetLogEventMask(events);
+      events=DestroyString(events);
+    }
+#if defined(__WINDOWS__)
+#if defined(_DEBUG) && !defined(__BORLANDC__)
+  if (IsEventLogging() != MagickFalse)
+    {
+      int
+        debug;
+
+      debug=_CrtSetDbgFlag(_CRTDBG_REPORT_FLAG);
+      debug|=_CRTDBG_CHECK_ALWAYS_DF |_CRTDBG_DELAY_FREE_MEM_DF |
+        _CRTDBG_LEAK_CHECK_DF;
+      if (0)
+        {
+          debug=_CrtSetDbgFlag(debug);
+          _ASSERTE(_CrtCheckMemory());
+        }
+    }
+#endif
+#endif
+  /*
+    Set client name and execution path.
+  */
+  (void) GetExecutionPath(execution_path);
+  if ((path != (const char *) NULL) && (*path != '\0'))
+    (void) CopyMagickString(execution_path,path,MaxTextExtent);
+  GetPathComponent(execution_path,TailPath,filename);
+  (void) SetClientName(filename);
+  GetPathComponent(execution_path,HeadPath,execution_path);
+  (void) SetClientPath(execution_path);
+  if (establish_signal_handlers != MagickFalse)
+    {
+      /*
+        Set signal handlers.
+      */
+#if defined(SIGABRT)
+      if (signal_handlers[SIGABRT] == (SignalHandler *) NULL)
+        signal_handlers[SIGABRT]=RegisterMagickSignalHandler(SIGABRT);
+#endif
+#if defined(SIGFPE)
+      if (signal_handlers[SIGFPE] == (SignalHandler *) NULL)
+        signal_handlers[SIGFPE]=RegisterMagickSignalHandler(SIGFPE);
+#endif
+#if defined(SIGHUP)
+      if (signal_handlers[SIGHUP] == (SignalHandler *) NULL)
+        signal_handlers[SIGHUP]=RegisterMagickSignalHandler(SIGHUP);
+#endif
+#if defined(SIGINT) && !defined(__WINDOWS__)
+      if (signal_handlers[SIGINT] == (SignalHandler *) NULL)
+        signal_handlers[SIGINT]=RegisterMagickSignalHandler(SIGINT);
+#endif
+#if defined(SIGQUIT)
+      if (signal_handlers[SIGQUIT] == (SignalHandler *) NULL)
+        signal_handlers[SIGQUIT]=RegisterMagickSignalHandler(SIGQUIT);
+#endif
+#if defined(SIGTERM)
+      if (signal_handlers[SIGTERM] == (SignalHandler *) NULL)
+        signal_handlers[SIGTERM]=RegisterMagickSignalHandler(SIGTERM);
+#endif
+#if defined(SIGXCPU)
+      if (signal_handlers[SIGXCPU] == (SignalHandler *) NULL)
+        signal_handlers[SIGXCPU]=RegisterMagickSignalHandler(SIGXCPU);
+#endif
+#if defined(SIGXFSZ)
+      if (signal_handlers[SIGXFSZ] == (SignalHandler *) NULL)
+        signal_handlers[SIGXFSZ]=RegisterMagickSignalHandler(SIGXFSZ);
+#endif
+    }
+  /*
+    Initialize magick resources.
+  */
+  InitializeMagickResources();
+  exception=AcquireExceptionInfo();
+  (void) GetMagickInfo((char *) NULL,exception);
+  exception=DestroyExceptionInfo(exception);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   M a g i c k C o r e T e r m i n u s                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickCoreTerminus() destroys the MagickCore environment.
+%
+%  The format of the DestroyMagick function is:
+%
+%      MagickCoreTerminus(void)
+%
+*/
+MagickExport void MagickCoreTerminus(void)
+{
+#if defined(HasX11)
+  DestroyXResources();
+#endif
+  DestroyConstitute();
+  DestroyMimeList();
+  DestroyConfigureList();
+  DestroyTypeList();
+  DestroyColorList();
+#if defined(__WINDOWS__)
+  NTGhostscriptUnLoadDLL();
+#endif
+  DestroyMagicList();
+  DestroyDelegateList();
+  DestroyMagickList();
+  DestroyCoderList();
+  DestroyMagickResources();
+  DestroyImageRegistry();
+  DestroyCacheResources();
+  DestroyRandomReservoir();
+  DestroyLocaleList();
+  DestroyLogList();
+  instantiate_magick=MagickFalse;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   R e g i s t e r M a g i c k I n f o                                       %
 %                                                                             %
 %                                                                             %
@@ -1293,8 +1299,7 @@ MagickExport MagickInfo *RegisterMagickInfo(MagickInfo *magick_info)
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",magick_info->name);
   if (magick_list == (SplayTreeInfo *) NULL)
     return((MagickInfo *) NULL);
-  status=AddValueToSplayTree(magick_list,ConstantString(magick_info->name),
-    magick_info);
+  status=AddValueToSplayTree(magick_list,magick_info->name,magick_info);
   if (status == MagickFalse)
     ThrowMagickFatalException(ResourceLimitFatalError,
       "UnableToAllocateMagickInfo",magick_info->name);
@@ -1397,5 +1402,5 @@ MagickExport MagickBooleanType UnregisterMagickInfo(const char *name)
     p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
   }
   RelinquishSemaphoreInfo(magick_semaphore);
-  return(RemoveNodeByValueFromSplayTree(magick_list,p));
+  return(DeleteNodeByValueFromSplayTree(magick_list,p));
 }
