@@ -48,7 +48,9 @@ extern "C" {
 #define AcquireMagickResource  PrependMagickMethod(AcquireMagickResource)
 #define AcquireMemory  PrependMagickMethod(AcquireMemory)
 #define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
+#define AcquireOneMagickPixel  PrependMagickMethod(AcquireOneMagickPixel)
 #define AcquireOnePixel  PrependMagickMethod(AcquireOnePixel)
+#define AcquireOneVirtualPixel  PrependMagickMethod(AcquireOneVirtualPixel)
 #define AcquireQuantizeInfo  PrependMagickMethod(AcquireQuantizeInfo)
 #define AcquireQuantumInfo  PrependMagickMethod(AcquireQuantumInfo)
 #define AcquireSemaphoreInfo  PrependMagickMethod(AcquireSemaphoreInfo)
@@ -76,6 +78,7 @@ extern "C" {
 #define AllocateNextImage  PrependMagickMethod(AllocateNextImage)
 #define AllocateSemaphoreInfo  PrependMagickMethod(AllocateSemaphoreInfo)
 #define AllocateString  PrependMagickMethod(AllocateString)
+#define AnalyzeImage  PrependMagickMethod(AnalyzeImage)
 #define AnimateImages  PrependMagickMethod(AnimateImages)
 #define AnnotateImage  PrependMagickMethod(AnnotateImage)
 #define AppendImageFormat  PrependMagickMethod(AppendImageFormat)
@@ -128,6 +131,7 @@ extern "C" {
 #define CloneString  PrependMagickMethod(CloneString)
 #define CloseBlob  PrependMagickMethod(CloseBlob)
 #define CloseCacheView  PrependMagickMethod(CloseCacheView)
+#define CloseMagickLog  PrependMagickMethod(CloseMagickLog)
 #define CoalesceImages  PrependMagickMethod(CoalesceImages)
 #define ColorFloodfillImage  PrependMagickMethod(ColorFloodfillImage)
 #define ColorizeImage  PrependMagickMethod(ColorizeImage)
@@ -142,6 +146,7 @@ extern "C" {
 #define CompareStringInfo  PrependMagickMethod(CompareStringInfo)
 #define CompositeImageChannel  PrependMagickMethod(CompositeImageChannel)
 #define CompositeImage  PrependMagickMethod(CompositeImage)
+#define CompositeLayers  PrependMagickMethod(CompositeLayers)
 #define CompressImageColormap  PrependMagickMethod(CompressImageColormap)
 #define ConcatenateMagickString  PrependMagickMethod(ConcatenateMagickString)
 #define ConcatenateStringInfo  PrependMagickMethod(ConcatenateStringInfo)
@@ -159,7 +164,6 @@ extern "C" {
 #define ConvolveImage  PrependMagickMethod(ConvolveImage)
 #define CopyMagickMemory  PrependMagickMethod(CopyMagickMemory)
 #define CopyMagickString  PrependMagickMethod(CopyMagickString)
-#define CreatesRGBImageProfile  PrependMagickMethod(CreatesRGBImageProfile)
 #define CropImage  PrependMagickMethod(CropImage)
 #define CycleColormapImage  PrependMagickMethod(CycleColormapImage)
 #define DeconstructImages  PrependMagickMethod(DeconstructImages)
@@ -167,6 +171,7 @@ extern "C" {
 #define DefineImageProperty  PrependMagickMethod(DefineImageProperty)
 #define DeleteImageAttribute  PrependMagickMethod(DeleteImageAttribute)
 #define DeleteImageFromList  PrependMagickMethod(DeleteImageFromList)
+#define DeleteImageList  PrependMagickMethod(DeleteImageList)
 #define DeleteImageOption  PrependMagickMethod(DeleteImageOption)
 #define DeleteImageProperty  PrependMagickMethod(DeleteImageProperty)
 #define DeleteImages  PrependMagickMethod(DeleteImages)
@@ -225,6 +230,7 @@ extern "C" {
 #define DestroyXResources  PrependMagickMethod(DestroyXResources)
 #define DestroyXWidget  PrependMagickMethod(DestroyXWidget)
 #define DetachBlob  PrependMagickMethod(DetachBlob)
+#define DisassociateImageStream  PrependMagickMethod(DisassociateImageStream)
 #define DispatchImage  PrependMagickMethod(DispatchImage)
 #define DisplayImages  PrependMagickMethod(DisplayImages)
 #define DisposeImages  PrependMagickMethod(DisposeImages)
@@ -251,6 +257,7 @@ extern "C" {
 #define ExportQuantumPixels  PrependMagickMethod(ExportQuantumPixels)
 #define ExtentImage  PrependMagickMethod(ExtentImage)
 #define FileToBlob  PrependMagickMethod(FileToBlob)
+#define FileToImage  PrependMagickMethod(FileToImage)
 #define FileToStringInfo  PrependMagickMethod(FileToStringInfo)
 #define FileToString  PrependMagickMethod(FileToString)
 #define FinalizeSignature  PrependMagickMethod(FinalizeSignature)
@@ -335,6 +342,7 @@ extern "C" {
 #define GetImageChannelDistortion  PrependMagickMethod(GetImageChannelDistortion)
 #define GetImageChannelExtrema  PrependMagickMethod(GetImageChannelExtrema)
 #define GetImageChannelMean  PrependMagickMethod(GetImageChannelMean)
+#define GetImageChannelRange  PrependMagickMethod(GetImageChannelRange)
 #define GetImageChannelStatistics  PrependMagickMethod(GetImageChannelStatistics)
 #define GetImageClipMask  PrependMagickMethod(GetImageClipMask)
 #define GetImageClippingPathAttribute  PrependMagickMethod(GetImageClippingPathAttribute)
@@ -362,6 +370,7 @@ extern "C" {
 #define GetImageProperty  PrependMagickMethod(GetImageProperty)
 #define GetImageQuantizeError  PrependMagickMethod(GetImageQuantizeError)
 #define GetImageQuantumDepth  PrependMagickMethod(GetImageQuantumDepth)
+#define GetImageRange  PrependMagickMethod(GetImageRange)
 #define GetImageTotalInkDensity  PrependMagickMethod(GetImageTotalInkDensity)
 #define GetImageType  PrependMagickMethod(GetImageType)
 #define GetImageVirtualPixelMethod  PrependMagickMethod(GetImageVirtualPixelMethod)
@@ -373,7 +382,9 @@ extern "C" {
 #define GetLocaleInfo_  PrependMagickMethod(GetLocaleInfo_)
 #define GetLocaleList  PrependMagickMethod(GetLocaleList)
 #define GetLocaleMessage  PrependMagickMethod(GetLocaleMessage)
+#define GetLocaleMonitorMessage  PrependMagickMethod(GetLocaleMonitorMessage)
 #define GetLocaleOptions  PrependMagickMethod(GetLocaleOptions)
+#define GetLocaleValue  PrependMagickMethod(GetLocaleValue)
 #define GetLogInfoList  PrependMagickMethod(GetLogInfoList)
 #define GetLogInfo  PrependMagickMethod(GetLogInfo)
 #define GetLogList  PrependMagickMethod(GetLogList)
@@ -452,6 +463,11 @@ extern "C" {
 #define GetRandomKey  PrependMagickMethod(GetRandomKey)
 #define GetRandomValue  PrependMagickMethod(GetRandomValue)
 #define GetSignatureInfo  PrependMagickMethod(GetSignatureInfo)
+#define GetStreamInfoClientData  PrependMagickMethod(GetStreamInfoClientData)
+#define GetStringInfoDatum  PrependMagickMethod(GetStringInfoDatum)
+#define GetStringInfoLength  PrependMagickMethod(GetStringInfoLength)
+#define GetStringInfoPath  PrependMagickMethod(GetStringInfoPath)
+#define GetThresholdMapFile  PrependMagickMethod(GetThresholdMapFile)
 #define GetThresholdMap  PrependMagickMethod(GetThresholdMap)
 #define GetTimerInfo  PrependMagickMethod(GetTimerInfo)
 #define GetTypeInfoByFamily  PrependMagickMethod(GetTypeInfoByFamily)
@@ -473,6 +489,7 @@ extern "C" {
 #define GetXMLTreeTag  PrependMagickMethod(GetXMLTreeTag)
 #define GlobExpression  PrependMagickMethod(GlobExpression)
 #define GradientImage  PrependMagickMethod(GradientImage)
+#define GravityAdjustGeometry  PrependMagickMethod(GravityAdjustGeometry)
 #define HashPointerType  PrependMagickMethod(HashPointerType)
 #define HashStringInfoType  PrependMagickMethod(HashStringInfoType)
 #define HashStringType  PrependMagickMethod(HashStringType)
@@ -516,6 +533,7 @@ extern "C" {
 #define IsGlob  PrependMagickMethod(IsGlob)
 #define IsGrayImage  PrependMagickMethod(IsGrayImage)
 #define IsHashmapEmpty  PrependMagickMethod(IsHashmapEmpty)
+#define IsImageObject  PrependMagickMethod(IsImageObject)
 #define IsImagesEqual  PrependMagickMethod(IsImagesEqual)
 #define IsImageSimilar  PrependMagickMethod(IsImageSimilar)
 #define IsLinkedListEmpty  PrependMagickMethod(IsLinkedListEmpty)
@@ -550,8 +568,10 @@ extern "C" {
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
 #define ListMimeInfo  PrependMagickMethod(ListMimeInfo)
 #define ListModuleInfo  PrependMagickMethod(ListModuleInfo)
+#define ListThresholdMapFile  PrependMagickMethod(ListThresholdMapFile)
 #define ListThresholdMaps  PrependMagickMethod(ListThresholdMaps)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
+#define LoadFontConfigFonts  PrependMagickMethod(LoadFontConfigFonts)
 #define LoadMimeLists  PrependMagickMethod(LoadMimeLists)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
@@ -561,8 +581,11 @@ extern "C" {
 #define LogMagickEventList  PrependMagickMethod(LogMagickEventList)
 #define LogMagickEvent  PrependMagickMethod(LogMagickEvent)
 #define LZWEncodeImage  PrependMagickMethod(LZWEncodeImage)
+#define MagickCoreGenesis  PrependMagickMethod(MagickCoreGenesis)
+#define MagickCoreTerminus  PrependMagickMethod(MagickCoreTerminus)
 #define MagickError  PrependMagickMethod(MagickError)
 #define MagickFatalError  PrependMagickMethod(MagickFatalError)
+#define MagickIncarnate  PrependMagickMethod(MagickIncarnate)
 #define MagickMonitor  PrependMagickMethod(MagickMonitor)
 #define MagickOpenStream  PrependMagickMethod(MagickOpenStream)
 #define MagickOptionToMnemonic  PrependMagickMethod(MagickOptionToMnemonic)
@@ -604,19 +627,23 @@ extern "C" {
 #define OpenBlob  PrependMagickMethod(OpenBlob)
 #define OpenCacheView  PrependMagickMethod(OpenCacheView)
 #define OpenStream  PrependMagickMethod(OpenStream)
+#define OpenVirtualCacheView  PrependMagickMethod(OpenVirtualCacheView)
 #define OptimizeImageLayers  PrependMagickMethod(OptimizeImageLayers)
+#define OptimizeImageTransparency  PrependMagickMethod(OptimizeImageTransparency)
 #define OptimizePlusImageLayers  PrependMagickMethod(OptimizePlusImageLayers)
 #define OrderedDitherImageChannel  PrependMagickMethod(OrderedDitherImageChannel)
 #define OrderedDitherImage  PrependMagickMethod(OrderedDitherImage)
 #define OrderedPosterizeImageChannel  PrependMagickMethod(OrderedPosterizeImageChannel)
 #define OrderedPosterizeImage  PrependMagickMethod(OrderedPosterizeImage)
 #define PackbitsEncodeImage  PrependMagickMethod(PackbitsEncodeImage)
+#define PaintFloodfillImage  PrependMagickMethod(PaintFloodfillImage)
 #define PaintOpaqueImageChannel  PrependMagickMethod(PaintOpaqueImageChannel)
 #define PaintOpaqueImage  PrependMagickMethod(PaintOpaqueImage)
 #define PaintTransparentImage  PrependMagickMethod(PaintTransparentImage)
 #define ParseAbsoluteGeometry  PrependMagickMethod(ParseAbsoluteGeometry)
 #define ParseAffineGeometry  PrependMagickMethod(ParseAffineGeometry)
 #define ParseChannelOption  PrependMagickMethod(ParseChannelOption)
+#define ParseCharacterContent  PrependMagickMethod(ParseCharacterContent)
 #define ParseGeometry  PrependMagickMethod(ParseGeometry)
 #define ParseGravityGeometry  PrependMagickMethod(ParseGravityGeometry)
 #define ParseImageGeometry  PrependMagickMethod(ParseImageGeometry)
@@ -637,6 +664,7 @@ extern "C" {
 #define PreviewImage  PrependMagickMethod(PreviewImage)
 #define PrintStringInfo  PrependMagickMethod(PrintStringInfo)
 #define ProfileImage  PrependMagickMethod(ProfileImage)
+#define PruneTagFromXMLTree  PrependMagickMethod(PruneTagFromXMLTree)
 #define PushImageList  PrependMagickMethod(PushImageList)
 #define PushImagePixels  PrependMagickMethod(PushImagePixels)
 #define PutEntryInHashmap  PrependMagickMethod(PutEntryInHashmap)
@@ -655,6 +683,7 @@ extern "C" {
 #define RandomThresholdImage  PrependMagickMethod(RandomThresholdImage)
 #define ReacquireMemory  PrependMagickMethod(ReacquireMemory)
 #define ReadBlobByte  PrependMagickMethod(ReadBlobByte)
+#define ReadBlobFloat  PrependMagickMethod(ReadBlobFloat)
 #define ReadBlobLong  PrependMagickMethod(ReadBlobLong)
 #define ReadBlobLSBLong  PrependMagickMethod(ReadBlobLSBLong)
 #define ReadBlobLSBShort  PrependMagickMethod(ReadBlobLSBShort)
@@ -662,7 +691,6 @@ extern "C" {
 #define ReadBlobMSBShort  PrependMagickMethod(ReadBlobMSBShort)
 #define ReadBlob  PrependMagickMethod(ReadBlob)
 #define ReadBlobShort  PrependMagickMethod(ReadBlobShort)
-#define ReadBlobStream  PrependMagickMethod(ReadBlobStream)
 #define ReadBlobString  PrependMagickMethod(ReadBlobString)
 #define ReadImage  PrependMagickMethod(ReadImage)
 #define ReadInlineImage  PrependMagickMethod(ReadInlineImage)
@@ -684,9 +712,11 @@ extern "C" {
 #define RegisterCUTImage  PrependMagickMethod(RegisterCUTImage)
 #define RegisterDCMImage  PrependMagickMethod(RegisterDCMImage)
 #define RegisterDIBImage  PrependMagickMethod(RegisterDIBImage)
+#define RegisterDOTImage  PrependMagickMethod(RegisterDOTImage)
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
 #define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
+#define RegisterEXRImage  PrependMagickMethod(RegisterEXRImage)
 #define RegisterFAXImage  PrependMagickMethod(RegisterFAXImage)
 #define RegisterFITSImage  PrependMagickMethod(RegisterFITSImage)
 #define RegisterGIFImage  PrependMagickMethod(RegisterGIFImage)
@@ -696,6 +726,7 @@ extern "C" {
 #define RegisterHTMLImage  PrependMagickMethod(RegisterHTMLImage)
 #define RegisterICONImage  PrependMagickMethod(RegisterICONImage)
 #define RegisterINFOImage  PrependMagickMethod(RegisterINFOImage)
+#define RegisterJP2Image  PrependMagickMethod(RegisterJP2Image)
 #define RegisterJPEGImage  PrependMagickMethod(RegisterJPEGImage)
 #define RegisterLABELImage  PrependMagickMethod(RegisterLABELImage)
 #define RegisterMAGICKImage  PrependMagickMethod(RegisterMAGICKImage)
@@ -773,6 +804,7 @@ extern "C" {
 #define RelinquishSemaphoreInfo  PrependMagickMethod(RelinquishSemaphoreInfo)
 #define RelinquishUniqueFileResource  PrependMagickMethod(RelinquishUniqueFileResource)
 #define RemoteDisplayCommand  PrependMagickMethod(RemoteDisplayCommand)
+#define RemoveDuplicateLayers  PrependMagickMethod(RemoveDuplicateLayers)
 #define RemoveElementByValueFromLinkedList  PrependMagickMethod(RemoveElementByValueFromLinkedList)
 #define RemoveElementFromLinkedList  PrependMagickMethod(RemoveElementFromLinkedList)
 #define RemoveEntryFromHashmap  PrependMagickMethod(RemoveEntryFromHashmap)
@@ -785,10 +817,12 @@ extern "C" {
 #define RemoveLastImageFromList  PrependMagickMethod(RemoveLastImageFromList)
 #define RemoveNodeByValueFromSplayTree  PrependMagickMethod(RemoveNodeByValueFromSplayTree)
 #define RemoveNodeFromSplayTree  PrependMagickMethod(RemoveNodeFromSplayTree)
+#define RemoveZeroDelayLayers  PrependMagickMethod(RemoveZeroDelayLayers)
 #define ReplaceImageInList  PrependMagickMethod(ReplaceImageInList)
 #define ResetHashmapIterator  PrependMagickMethod(ResetHashmapIterator)
 #define ResetImageAttributeIterator  PrependMagickMethod(ResetImageAttributeIterator)
 #define ResetImageOptionIterator  PrependMagickMethod(ResetImageOptionIterator)
+#define ResetImagePage  PrependMagickMethod(ResetImagePage)
 #define ResetImageProfileIterator  PrependMagickMethod(ResetImageProfileIterator)
 #define ResetImagePropertyIterator  PrependMagickMethod(ResetImagePropertyIterator)
 #define ResetLinkedListIterator  PrependMagickMethod(ResetLinkedListIterator)
@@ -804,6 +838,7 @@ extern "C" {
 #define RotateImage  PrependMagickMethod(RotateImage)
 #define SampleImage  PrependMagickMethod(SampleImage)
 #define ScaleImage  PrependMagickMethod(ScaleImage)
+#define SeedRandomReservoir  PrependMagickMethod(SeedRandomReservoir)
 #define SeekBlob  PrependMagickMethod(SeekBlob)
 #define SegmentImage  PrependMagickMethod(SegmentImage)
 #define SeparateImageChannel  PrependMagickMethod(SeparateImageChannel)
@@ -852,10 +887,12 @@ extern "C" {
 #define SetMagickRegistry  PrependMagickMethod(SetMagickRegistry)
 #define SetMagickResourceLimit  PrependMagickMethod(SetMagickResourceLimit)
 #define SetMonitorHandler  PrependMagickMethod(SetMonitorHandler)
+#define SetStreamInfoClientData  PrependMagickMethod(SetStreamInfoClientData)
 #define SetStreamInfoMap  PrependMagickMethod(SetStreamInfoMap)
 #define SetStreamInfoStorageType  PrependMagickMethod(SetStreamInfoStorageType)
 #define SetStringInfoDatum  PrependMagickMethod(SetStringInfoDatum)
 #define SetStringInfoLength  PrependMagickMethod(SetStringInfoLength)
+#define SetStringInfoPath  PrependMagickMethod(SetStringInfoPath)
 #define SetStringInfo  PrependMagickMethod(SetStringInfo)
 #define SetWarningHandler  PrependMagickMethod(SetWarningHandler)
 #define SetXMLTreeAttribute  PrependMagickMethod(SetXMLTreeAttribute)
@@ -943,9 +980,11 @@ extern "C" {
 #define UnregisterCUTImage  PrependMagickMethod(UnregisterCUTImage)
 #define UnregisterDCMImage  PrependMagickMethod(UnregisterDCMImage)
 #define UnregisterDIBImage  PrependMagickMethod(UnregisterDIBImage)
+#define UnregisterDOTImage  PrependMagickMethod(UnregisterDOTImage)
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
 #define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
+#define UnregisterEXRImage  PrependMagickMethod(UnregisterEXRImage)
 #define UnregisterFAXImage  PrependMagickMethod(UnregisterFAXImage)
 #define UnregisterFITSImage  PrependMagickMethod(UnregisterFITSImage)
 #define UnregisterGIFImage  PrependMagickMethod(UnregisterGIFImage)
@@ -955,6 +994,7 @@ extern "C" {
 #define UnregisterHTMLImage  PrependMagickMethod(UnregisterHTMLImage)
 #define UnregisterICONImage  PrependMagickMethod(UnregisterICONImage)
 #define UnregisterINFOImage  PrependMagickMethod(UnregisterINFOImage)
+#define UnregisterJP2Image  PrependMagickMethod(UnregisterJP2Image)
 #define UnregisterJPEGImage  PrependMagickMethod(UnregisterJPEGImage)
 #define UnregisterLABELImage  PrependMagickMethod(UnregisterLABELImage)
 #define UnregisterMAGICKImage  PrependMagickMethod(UnregisterMAGICKImage)
@@ -1036,6 +1076,7 @@ extern "C" {
 #define WaveImage  PrependMagickMethod(WaveImage)
 #define WhiteThresholdImage  PrependMagickMethod(WhiteThresholdImage)
 #define WriteBlobByte  PrependMagickMethod(WriteBlobByte)
+#define WriteBlobFloat  PrependMagickMethod(WriteBlobFloat)
 #define WriteBlobLong  PrependMagickMethod(WriteBlobLong)
 #define WriteBlobLSBLong  PrependMagickMethod(WriteBlobLSBLong)
 #define WriteBlobLSBShort  PrependMagickMethod(WriteBlobLSBShort)
