@@ -844,20 +844,20 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
 static void *DestroyModuleNode(void *module_info)
 {
   ExceptionInfo
-    exception;
+    *exception;
 
   register ModuleInfo
     *p;
 
-  GetExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
   p=(ModuleInfo *) module_info;
-  if (UnregisterModule(p,&exception) == MagickFalse)
-    CatchException(&exception);
+  if (UnregisterModule(p,exception) == MagickFalse)
+    CatchException(exception);
   if (p->tag != (char *) NULL)
     p->tag=DestroyString(p->tag);
   if (p->path != (char *) NULL)
     p->path=DestroyString(p->path);
-  (void) DestroyExceptionInfo(&exception);
+  exception=DestroyExceptionInfo(exception);
   return(RelinquishMagickMemory(p));
 }
 
@@ -878,7 +878,7 @@ static MagickBooleanType InitializeModuleList(
             *module_info;
 
           module_list=NewSplayTree(CompareSplayTreeString,
-            RelinquishMagickMemory,DestroyModuleNode);
+            (void *(*)(void *)) NULL,DestroyModuleNode);
           if (module_list == (SplayTreeInfo *) NULL)
             {
               char
@@ -905,8 +905,7 @@ static MagickBooleanType InitializeModuleList(
           module_info->stealth=MagickTrue;
           (void) time(&module_info->load_time);
           module_info->signature=MagickSignature;
-          status=AddValueToSplayTree(module_list,
-            ConstantString(module_info->tag),module_info);
+          status=AddValueToSplayTree(module_list,module_info->tag,module_info);
           if (status == MagickFalse)
             {
               char
@@ -1232,8 +1231,7 @@ static const ModuleInfo *RegisterModule(const ModuleInfo *module_info,
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",module_info->tag);
   if (module_list == (SplayTreeInfo *) NULL)
     return((const ModuleInfo *) NULL);
-  status=AddValueToSplayTree(module_list,ConstantString(module_info->tag),
-    module_info);
+  status=AddValueToSplayTree(module_list,module_info->tag,module_info);
   if (status == MagickFalse)
     (void) ThrowMagickException(exception,GetMagickModule(),ResourceLimitError,
       "MemoryAllocationFailed","`%s'",module_info->tag);
