@@ -176,8 +176,8 @@ MagickExport MontageInfo *DestroyMontageInfo(MontageInfo *montage_info)
   if (montage_info->frame != (char *) NULL)
     montage_info->frame=DestroyString(montage_info->frame);
   if (montage_info->texture != (char *) NULL)
-    montage_info->texture=(char *)
-      RelinquishMagickMemory(montage_info->texture);
+    montage_info->texture=(char *) RelinquishMagickMemory(
+      montage_info->texture);
   if (montage_info->font != (char *) NULL)
     montage_info->font=DestroyString(montage_info->font);
   montage_info->signature=(~MagickSignature);
