@@ -45,6 +45,7 @@
 #include "magick/color.h"
 #include "magick/compare.h"
 #include "magick/constitute.h"
+#include "magick/distort.h"
 #include "magick/draw.h"
 #include "magick/effect.h"
 #include "magick/exception.h"
@@ -242,6 +243,8 @@ static const OptionInfo
     { "-dispose", 1L },
     { "+dissolve", 0L },
     { "-dissolve", 1L },
+    { "+distort", 0L },
+    { "-distort", 2L },
     { "+dither", 0L },
     { "-dither", 0L },
     { "+draw", 0L },
@@ -632,6 +635,7 @@ static const OptionInfo
     { "Hue", (long) HueCompositeOp },
     { "In", (long) InCompositeOp },
     { "Lighten", (long) LightenCompositeOp },
+    { "LinearLight", (long) LinearLightCompositeOp },
     { "Luminize", (long) LuminizeCompositeOp },
     { "Minus", (long) MinusCompositeOp },
     { "Modulate", (long) ModulateCompositeOp },
@@ -729,6 +733,17 @@ static const OptionInfo
     { "3", (long) PreviousDispose },
     { (char *) NULL, (long) UndefinedDispose }
   },
+  DistortOptions[] =
+  {
+    { "Undefined", (long) UndefinedDistortion },
+    { "Affine", (long) AffineDistortion },
+    { "AffineProjection", (long) AffineProjectionDistortion },
+    { "Bilinear", (long) BilinearDistortion },
+    { "Perspective", (long) PerspectiveDistortion },
+    { "ScaleRotateTranslate", (long) ScaleRotateTranslateDistortion },
+    { "SRT", (long) ScaleRotateTranslateDistortion },
+    { (char *) NULL, (long) UndefinedDistortion }
+  },
   EndianOptions[] =
   {
     { "Undefined", (long) UndefinedEndian },
@@ -844,6 +859,7 @@ static const OptionInfo
     { "Integer", (long) IntegerInterpolatePixel },
     { "Mesh", (long) MeshInterpolatePixel },
     { "NearestNeighbor", (long) NearestNeighborInterpolatePixel },
+    { "Spline", (long) SplineInterpolatePixel },
     { (char *) NULL, (long) UndefinedInterpolatePixel }
   },
   LayersOptions[] =
@@ -894,6 +910,7 @@ static const OptionInfo
     { "DataType",      MagickDataTypeOptions },
     { "Decoration",    MagickDecorationOptions },
     { "Dispose",       MagickDisposeOptions },
+    { "Distort",       MagickDistortOptions },
     { "Endian",        MagickEndianOptions },
     { "Evaluate",      MagickEvaluateOptions },
     { "FillRule",      MagickFillRuleOptions },
@@ -1025,6 +1042,7 @@ static const OptionInfo
     { "Laplacian", (long) LaplacianNoise },
     { "Multiplicative", (long) MultiplicativeGaussianNoise },
     { "Poisson", (long) PoissonNoise },
+    { "Random", (long) RandomNoise },
     { "Uniform", (long) UniformNoise },
     { (char *) NULL, (long) UndefinedNoise }
   },
@@ -1422,6 +1440,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption value)
     case MagickDataTypeOptions: return(DataTypeOptions);
     case MagickDecorationOptions: return(DecorationOptions);
     case MagickDisposeOptions: return(DisposeOptions);
+    case MagickDistortOptions: return(DistortOptions);
     case MagickEndianOptions: return(EndianOptions);
     case MagickEvaluateOptions: return(EvaluateOptions);
     case MagickFillRuleOptions: return(FillRuleOptions);
