@@ -41,6 +41,7 @@
 #include "magick/studio.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
+#include "magick/colorspace-private.h"
 #include "magick/composite.h"
 #include "magick/composite-private.h"
 #include "magick/draw.h"
@@ -53,8 +54,55 @@
 #include "magick/string_.h"
 
 /*
-  Define declarations.
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   P a i n t F l o o d f i l l I m a g e                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  PaintFloodfill() changes the color value of any pixel that matches
+%  target and is an immediate neighbor.  If the method FillToBorderMethod is
+%  specified, the color value is changed for any neighbor pixel that does not
+%  match the bordercolor member of image.
+%
+%  By default target must match a particular pixel color exactly.
+%  However, in many cases two colors may differ by a small amount.  The
+%  fuzz member of image defines how much tolerance is acceptable to
+%  consider two colors as the same.  For example, set fuzz to 10 and the
+%  color red at intensities of 100 and 102 respectively are now
+%  interpreted as the same color for the purposes of the floodfill.
+%
+%  The format of the PaintFloodfillImage method is:
+%
+%      MagickBooleanType PaintFloodfillImage(Image *image,
+%        const ChannelType channel,const MagickPixelPacket target,
+%        const long x_offset,const long y_offset,const DrawInfo *draw_info,
+%        const PaintMethod method)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o channel: The channel(s).
+%
+%    o target: The RGB value of the target color.
+%
+%    o x_offset,y_offset: The starting location of the operation.
+%
+%    o draw_info: The draw info.
+%
+%    o method: Choose either FloodfillMethod or FillToBorderMethod.
+%
 */
+MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
+  const ChannelType channel,const MagickPixelPacket *target,
+  const long x_offset,const long y_offset,const DrawInfo *draw_info,
+  const PaintMethod method)
+{
 #define MaxStacksize  (1 << 15)
 #define PushSegmentStack(up,left,right,delta) \
 { \
@@ -72,53 +120,7 @@
         } \
     } \
 }
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   C o l o r F l o o d f i l l I m a g e                                     %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  ColorFloodfill() changes the color value of any pixel that matches
-%  target and is an immediate neighbor.  If the method FillToBorderMethod is
-%  specified, the color value is changed for any neighbor pixel that does not
-%  match the bordercolor member of image.
-%
-%  By default target must match a particular pixel color exactly.
-%  However, in many cases two colors may differ by a small amount.  The
-%  fuzz member of image defines how much tolerance is acceptable to
-%  consider two colors as the same.  For example, set fuzz to 10 and the
-%  color red at intensities of 100 and 102 respectively are now
-%  interpreted as the same color for the purposes of the floodfill.
-%
-%  The format of the ColorFloodfillImage method is:
-%
-%      MagickBooleanType ColorFloodfillImage(Image *image,
-%        const DrawInfo *draw_info,const PixelPacket target,
-%        const long x_offset,const long y_offset,const PaintMethod method)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-%    o draw_info: The draw info.
-%
-%    o target: The RGB value of the target color.
-%
-%    o x,y: The starting location of the operation.
-%
-%    o method: Choose either FloodfillMethod or FillToBorderMethod.
-%
-*/
-MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
-  const DrawInfo *draw_info,const PixelPacket target,const long x_offset,
-  const long y_offset,const PaintMethod method)
-{
+
   Image
     *floodplane_image;
 
@@ -132,12 +134,19 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
   MagickBooleanType
     skip;
 
+  MagickPixelPacket
+    fill,
+    pixel;
+
   PixelPacket
     fill_color;
 
   register const PixelPacket
     *p;
 
+  register IndexPacket
+    *indexes;
+
   register long
     x;
 
@@ -167,14 +176,14 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
     return(MagickFalse);
   if (image->matte == MagickFalse)
     (void) SetImageOpacity(image,OpaqueOpacity);
+  /*
+    Set floodfill state.
+  */
   floodplane_image=CloneImage(image,image->columns,image->rows,MagickTrue,
     &image->exception);
   if (floodplane_image == (Image *) NULL)
     return(MagickFalse);
   (void) SetImageOpacity(floodplane_image,OpaqueOpacity);
-  /*
-    Set floodfill color.
-  */
   segment_stack=(SegmentInfo *) AcquireMagickMemory(MaxStacksize*
     sizeof(*segment_stack));
   if (segment_stack == (SegmentInfo *) NULL)
@@ -192,6 +201,8 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
   s=segment_stack;
   PushSegmentStack(y,x,x,1);
   PushSegmentStack(y+1,x,x,-1);
+  GetMagickPixelPacket(image,&fill);
+  GetMagickPixelPacket(image,&pixel);
   while (s > segment_stack)
   {
     /*
@@ -209,19 +220,21 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
     q=GetImagePixels(floodplane_image,0,y,(unsigned long) (x1+1),1);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
       break;
+    indexes=GetIndexes(image);
     p+=x1;
     q+=x1;
     for (x=x1; x >= 0; x--)
     {
       if (q->opacity == TransparentOpacity)
         break;
+      SetMagickPixelPacket(image,p,indexes+x,&pixel);
       if (method == FloodfillMethod)
         {
-          if (IsColorSimilar(image,p,&target) == MagickFalse)
+          if (IsMagickColorSimilar(&pixel,target) == MagickFalse)
             break;
         }
       else
-        if (IsColorSimilar(image,p,&target) != MagickFalse)
+        if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
           break;
       q->opacity=TransparentOpacity;
       p--;
@@ -249,17 +262,19 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
               if ((p == (const PixelPacket *) NULL) ||
                   (q == (PixelPacket *) NULL))
                 break;
+              indexes=GetIndexes(image);
               for ( ; x < (long) image->columns; x++)
               {
                 if (q->opacity == TransparentOpacity)
                   break;
+                SetMagickPixelPacket(image,p,indexes+x,&pixel);
                 if (method == FloodfillMethod)
                   {
-                    if (IsColorSimilar(image,p,&target) == MagickFalse)
+                    if (IsMagickColorSimilar(&pixel,target) == MagickFalse)
                       break;
                   }
                 else
-                  if (IsColorSimilar(image,p,&target) != MagickFalse)
+                  if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
                     break;
                 q->opacity=TransparentOpacity;
                 p++;
@@ -281,17 +296,19 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
           q=GetImagePixels(floodplane_image,x,y,(unsigned long) (x2-x+1),1);
           if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
             break;
+          indexes=GetIndexes(image);
           for ( ; x <= x2; x++)
           {
             if (q->opacity == TransparentOpacity)
               break;
+            SetMagickPixelPacket(image,p,indexes+x,&pixel);
             if (method == FloodfillMethod)
               {
-                if (IsColorSimilar(image,p,&target) != MagickFalse)
+                if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
                   break;
               }
             else
-              if (IsColorSimilar(image,p,&target) == MagickFalse)
+              if (IsMagickColorSimilar(&pixel,target) == MagickFalse)
                 break;
             p++;
             q++;
@@ -310,13 +327,27 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
     q=GetImagePixels(image,0,y,image->columns,1);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
       break;
+    indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
       if (p->opacity != OpaqueOpacity)
         {
           fill_color=GetFillColor(draw_info,x,y);
-          MagickCompositeOver(&fill_color,(MagickRealType) fill_color.opacity,q,
-            (MagickRealType) q->opacity,q);
+          SetMagickPixelPacket(image,&fill_color,(IndexPacket *) NULL,&fill);
+          if (image->colorspace == CMYKColorspace)
+            RGBtoCMYK(&fill);
+          if ((channel & RedChannel) != 0)
+            q->red=RoundToQuantum(fill.red);
+          if ((channel & GreenChannel) != 0)
+            q->green=RoundToQuantum(fill.green);
+          if ((channel & BlueChannel) != 0)
+            q->blue=RoundToQuantum(fill.blue);
+          if (((channel & OpacityChannel) != 0) &&
+              (image->matte != MagickFalse))
+            q->opacity=RoundToQuantum(fill.opacity);
+          if (((channel & IndexChannel) != 0) &&
+              (image->colorspace == CMYKColorspace))
+            indexes[x]=RoundToQuantum(fill.index);
         }
       p++;
       q++;
@@ -333,255 +364,6 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
-%                                                                             %
-%   M a t t e F l o o d f i l l I m a g e                                     %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  MatteFloodfill() changes the transparency value of any pixel that matches
-%  target and is an immediate neighbor.  If the method FillToBorderMethod
-%  is specified, the transparency value is changed for any neighbor pixel
-%  that does not match the bordercolor member of image.
-%
-%  By default target must match a particular pixel transparency exactly.
-%  However, in many cases two transparency values may differ by a
-%  small amount.  The fuzz member of image defines how much tolerance is
-%  acceptable to consider two transparency values as the same.  For example,
-%  set fuzz to 10 and the opacity values of 100 and 102 respectively are
-%  now interpreted as the same value for the purposes of the floodfill.
-%
-%  The format of the MatteFloodfillImage method is:
-%
-%      MagickBooleanType MatteFloodfillImage(Image *image,
-%        const PixelPacket target,const Quantum opacity,const long x_offset,
-%        const long y_offset,const PaintMethod method)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-%    o target: The RGB value of the target color.
-%
-%    o opacity: The level of transparency: 0 is fully opaque and QuantumRange is
-%      fully transparent.
-%
-%    o x,y: The starting location of the operation.
-%
-%    o method:  Choose either FloodfillMethod or FillToBorderMethod.
-%
-%
-*/
-MagickExport MagickBooleanType MatteFloodfillImage(Image *image,
-  const PixelPacket target,const Quantum opacity,const long x_offset,
-  const long y_offset,const PaintMethod method)
-{
-  Image
-    *floodplane_image;
-
-  long
-    offset,
-    start,
-    x1,
-    x2,
-    y;
-
-  MagickBooleanType
-    skip;
-
-  register const PixelPacket
-    *p;
-
-  register long
-    x;
-
-  register PixelPacket
-    *q;
-
-  register SegmentInfo
-    *s;
-
-  SegmentInfo
-    *segment_stack;
-
-  /*
-    Check boundary conditions.
-  */
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  if ((x_offset < 0) || (x_offset >= (long) image->columns))
-    return(MagickFalse);
-  if ((y_offset < 0) || (y_offset >= (long) image->rows))
-    return(MagickFalse);
-  if (SetImageStorageClass(image,DirectClass) == MagickFalse)
-    return(MagickFalse);
-  if (image->matte == MagickFalse)
-    (void) SetImageOpacity(image,OpaqueOpacity);
-  floodplane_image=CloneImage(image,image->columns,image->rows,MagickTrue,
-    &image->exception);
-  if (floodplane_image == (Image *) NULL)
-    return(MagickFalse);
-  (void) SetImageOpacity(floodplane_image,OpaqueOpacity);
-  /*
-    Set floodfill color.
-  */
-  segment_stack=(SegmentInfo *)
-    AcquireMagickMemory(MaxStacksize*sizeof(*segment_stack));
-  if (segment_stack == (SegmentInfo *) NULL)
-    {
-      floodplane_image=DestroyImage(floodplane_image);
-      ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-        image->filename);
-    }
-  /*
-    Push initial segment on stack.
-  */
-  x=x_offset;
-  y=y_offset;
-  start=0;
-  s=segment_stack;
-  PushSegmentStack(y,x,x,1);
-  PushSegmentStack(y+1,x,x,-1);
-  while (s > segment_stack)
-  {
-    /*
-      Pop segment off stack.
-    */
-    s--;
-    x1=(long) s->x1;
-    x2=(long) s->x2;
-    offset=(long) s->y2;
-    y=(long) s->y1+offset;
-    /*
-      Recolor neighboring pixels.
-    */
-    p=AcquireImagePixels(image,0,y,(unsigned long) (x1+1),1,&image->exception);
-    q=GetImagePixels(floodplane_image,0,y,(unsigned long) (x1+1),1);
-    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-      break;
-    p+=x1;
-    q+=x1;
-    for (x=x1; x >= 0; x--)
-    {
-      if (q->opacity == TransparentOpacity)
-        break;
-      if (method == FloodfillMethod)
-        {
-          if (IsColorSimilar(image,p,&target) == MagickFalse)
-            break;
-        }
-      else
-        if (IsColorSimilar(image,p,&target) != MagickFalse)
-          break;
-      q->opacity=TransparentOpacity;
-      q--;
-      p--;
-    }
-    if (SyncImagePixels(floodplane_image) == MagickFalse)
-      break;
-    skip=x >= x1 ? MagickTrue : MagickFalse;
-    if (skip == MagickFalse)
-      {
-        start=x+1;
-        if (start < x1)
-          PushSegmentStack(y,start,x1-1,-offset);
-        x=x1+1;
-      }
-    do
-    {
-      if (skip == MagickFalse)
-        {
-          if (x < (long) image->columns)
-            {
-              p=AcquireImagePixels(image,x,y,image->columns-x,1,
-                &image->exception);
-              q=GetImagePixels(floodplane_image,x,y,image->columns-x,1);
-              if ((p == (const PixelPacket *) NULL) ||
-                  (q == (PixelPacket *) NULL))
-                break;
-              for ( ; x < (long) image->columns; x++)
-              {
-                if (q->opacity == TransparentOpacity)
-                  break;
-                if (method == FloodfillMethod)
-                  {
-                    if (IsColorSimilar(image,p,&target) == MagickFalse)
-                      break;
-                  }
-                else
-                  if (IsColorSimilar(image,p,&target) != MagickFalse)
-                    break;
-                q->opacity=TransparentOpacity;
-                q++;
-                p++;
-              }
-              if (SyncImagePixels(floodplane_image) == MagickFalse)
-                break;
-            }
-          PushSegmentStack(y,start,x-1,offset);
-          if (x > (x2+1))
-            PushSegmentStack(y,x2+1,x-1,-offset);
-        }
-      skip=MagickFalse;
-      x++;
-      if (x <= x2)
-        {
-          p=AcquireImagePixels(image,x,y,(unsigned long) (x2-x+1),1,
-            &image->exception);
-          q=GetImagePixels(floodplane_image,x,y,(unsigned long) (x2-x+1),1);
-          if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-            break;
-          for ( ; x <= x2; x++)
-          {
-            if (q->opacity == TransparentOpacity)
-              break;
-            if (method == FloodfillMethod)
-              {
-                if (IsColorSimilar(image,p,&target) != MagickFalse)
-                  break;
-              }
-            else
-              if (IsColorSimilar(image,p,&target) == MagickFalse)
-                break;
-            p++;
-            q++;
-          }
-        }
-      start=x;
-    } while (x <= x2);
-  }
-  for (y=0; y < (long) image->rows; y++)
-  {
-    /*
-      Tile fill color onto floodplane.
-    */
-    p=AcquireImagePixels(floodplane_image,0,y,image->columns,1,
-      &image->exception);
-    q=GetImagePixels(image,0,y,image->columns,1);
-    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-      break;
-    for (x=0; x < (long) image->columns; x++)
-    {
-      if (p->opacity != OpaqueOpacity)
-        q->opacity=opacity;
-      p++;
-      q++;
-    }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-  }
-  segment_stack=(SegmentInfo *) RelinquishMagickMemory(segment_stack);
-  floodplane_image=DestroyImage(floodplane_image);
-  return(y == (long) image->rows ? MagickTrue : MagickFalse);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
 %     P a i n t O p a q u e I m a g e                                         %
 %                                                                             %
 %                                                                             %
@@ -608,7 +390,7 @@ MagickExport MagickBooleanType MatteFloodfillImage(Image *image,
 %
 %    o image: The image.
 %
-%    o channel: The channel.
+%    o channel: The channel(s).
 %
 %    o target: The RGB value of the target color.
 %
