@@ -746,7 +746,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
   */
   profile=AcquireStringInfo((size_t) length);
   SetStringInfoDatum(profile,(unsigned char *) datum);
-  if ((LocaleCompare("icc",name) == 0) || (LocaleCompare("icm",name) == 0))
+  if ((LocaleCompare(name,"icc") == 0) || (LocaleCompare(name,"icm") == 0))
     {
       const StringInfo
         *icc_profile;
@@ -833,11 +833,10 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 #else
           (void) cmsErrorAction(LCMS_ERROR_SHOW);
 #endif
-          source_profile=cmsOpenProfileFromMem((unsigned char *)
-            GetStringInfoDatum(icc_profile),(DWORD)
-            GetStringInfoLength(icc_profile));
-          target_profile=cmsOpenProfileFromMem((unsigned char *)
-            GetStringInfoDatum(profile),(DWORD) GetStringInfoLength(profile));
+          source_profile=cmsOpenProfileFromMem(GetStringInfoDatum(icc_profile),
+            (DWORD) GetStringInfoLength(icc_profile));
+          target_profile=cmsOpenProfileFromMem(GetStringInfoDatum(profile),
+            (DWORD) GetStringInfoLength(profile));
           if ((source_profile == (cmsHPROFILE) NULL) ||
               (target_profile == (cmsHPROFILE) NULL))
             ThrowBinaryException(ResourceLimitError,"UnableToManageColor",name);
@@ -1189,7 +1188,8 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
   const StringInfo *profile)
 {
   char
-    key[MaxTextExtent];
+    key[MaxTextExtent],
+    property[MaxTextExtent];
 
   MagickBooleanType
     status;
@@ -1214,11 +1214,10 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
         Continue to support deprecated color profile member.
       */
       icc_profile=GetImageProfile(image,name);
-      if (icc_profile != (StringInfo *) NULL)
+      if (icc_profile != (const StringInfo *) NULL)
         {
           image->color_profile.length=GetStringInfoLength(icc_profile);
-          image->color_profile.info=(unsigned char *)
-            GetStringInfoDatum(icc_profile);
+          image->color_profile.info=GetStringInfoDatum(icc_profile);
         }
     }
   if ((status != MagickFalse) &&
@@ -1231,13 +1230,17 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
         Continue to support deprecated IPTC profile member.
       */
       iptc_profile=GetImageProfile(image,name);
-      if (iptc_profile != (StringInfo *) NULL)
+      if (iptc_profile != (const StringInfo *) NULL)
         {
           image->iptc_profile.length=GetStringInfoLength(iptc_profile);
-          image->iptc_profile.info=(unsigned char *)
-            GetStringInfoDatum(iptc_profile);
+          image->iptc_profile.info=GetStringInfoDatum(iptc_profile);
         }
     }
+  /*
+    Inject profile into image properties.
+  */
+  (void) FormatMagickString(property,MaxTextExtent,"%s:sans",name);
+  (void) GetImageProperty(image,property);
   return(status);
 }
 
