@@ -32,12 +32,15 @@ extern MagickExport const StringInfo
 
 extern MagickExport MagickBooleanType
   CloneImageProfiles(Image *,const Image *),
+  DeleteImageProfile(Image *,const char *),
   ProfileImage(Image *,const char *,const void *,const size_t,
     const MagickBooleanType),
-  RemoveImageProfile(Image *,const char *),
   SetImageProfile(Image *,const char *,const StringInfo *),
   SyncImageProfiles(Image *);
 
+extern MagickExport StringInfo
+  *RemoveImageProfile(Image *,const char *);
+
 extern MagickExport void
   DestroyImageProfiles(Image *),
   ResetImageProfileIterator(const Image *);
