@@ -71,6 +71,7 @@
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#include "magick/xml-tree.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -233,7 +234,7 @@ MagickExport MagickBooleanType DefineImageProperty(Image *image,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DeleteImageProperty() deletes an key from the image map.
+%  DeleteImageProperty() deletes an image property.
 %
 %  The format of the DeleteImageProperty method is:
 %
@@ -385,9 +386,9 @@ MagickExport MagickBooleanType FormatImageProperty(Image *image,
 */
 
 static char
-  *TracePSClippath(unsigned char *,size_t,const unsigned long,
+  *TracePSClippath(const unsigned char *,size_t,const unsigned long,
     const unsigned long),
-  *TraceSVGClippath(unsigned char *,size_t,const unsigned long,
+  *TraceSVGClippath(const unsigned char *,size_t,const unsigned long,
     const unsigned long);
 
 static MagickBooleanType GetIPTCProperty(const Image *image,const char *key)
@@ -460,7 +461,7 @@ static inline long MagickMax(const long x,const long y)
   return(y);
 }
 
-static inline int ReadPropertyByte(unsigned char **p,size_t *length)
+static inline int ReadPropertyByte(const unsigned char **p,size_t *length)
 {
   int
     c;
@@ -472,7 +473,7 @@ static inline int ReadPropertyByte(unsigned char **p,size_t *length)
   return(c);
 }
 
-static inline unsigned long ReadPropertyMSBLong(unsigned char **p,
+static inline unsigned long ReadPropertyMSBLong(const unsigned char **p,
   size_t *length)
 {
   int
@@ -502,7 +503,7 @@ static inline unsigned long ReadPropertyMSBLong(unsigned char **p,
   return(value & 0xffffffff);
 }
 
-static inline unsigned short ReadPropertyMSBShort(unsigned char **p,
+static inline unsigned short ReadPropertyMSBShort(const unsigned char **p,
   size_t *length)
 {
   int
@@ -541,6 +542,9 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
   const StringInfo
     *profile;
 
+  const unsigned char
+    *info;
+
   long
     id,
     start,
@@ -559,9 +563,6 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
   size_t
     length;
 
-  unsigned char
-    *info;
-
   /*
     There's no newlines in path names, so it's safe as terminator.
   */
@@ -672,7 +673,7 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
 }
 
 static inline unsigned short ReadPropertyShort(const EndianType endian,
-  unsigned char *buffer)
+  const unsigned char *buffer)
 {
   unsigned short
     value;
@@ -688,7 +689,7 @@ static inline unsigned short ReadPropertyShort(const EndianType endian,
 }
 
 static inline unsigned long ReadPropertyLong(const EndianType endian,
-  unsigned char *buffer)
+  const unsigned char *buffer)
 {
   unsigned long
     value;
@@ -727,7 +728,7 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
 
   typedef struct _DirectoryInfo
   {
-    unsigned char
+    const unsigned char
       *directory;
 
     unsigned long
@@ -992,6 +993,10 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
   const StringInfo
     *profile;
 
+  const unsigned char
+    *directory,
+    *exif;
+
   DirectoryInfo
     directory_stack[MaxDirectoryStack];
 
@@ -1016,10 +1021,6 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
   static int
     tag_bytes[] = {0, 1, 1, 2, 4, 8, 1, 1, 2, 4, 8, 4, 8};
 
-  unsigned char
-    *directory,
-    *exif;
-
   unsigned long
     entry,
     number_entries,
@@ -1379,7 +1380,52 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
   return(MagickTrue);
 }
 
-static char *TracePSClippath(unsigned char *blob,size_t length,
+static MagickBooleanType GetXMPProperty(const Image *image,
+  const char *property)
+{
+  const StringInfo
+    *profile;
+
+  ExceptionInfo
+    *exception;
+
+  register long
+    i;
+
+  register unsigned char
+    *p;
+
+  XMLTreeInfo
+    *xmp;
+
+  profile=GetImageProfile(image,"xmp");
+  if (profile == (StringInfo *) NULL)
+    return(MagickFalse);
+  if ((property == (const char *) NULL) || (*property == '\0'))
+    return(MagickFalse);
+  p=GetStringInfoDatum(profile);
+  for (i=0; (i < (long) GetStringInfoLength(profile)) && (*p != '\0'); i++)
+    p++;
+  if (i == (long) GetStringInfoLength(profile))
+    return(MagickFalse);
+  exception=AcquireExceptionInfo();
+  xmp=NewXMLTree((char *) ++p,exception);
+  exception=DestroyExceptionInfo(exception);
+  if (xmp == (XMLTreeInfo *) NULL)
+    return(MagickFalse);
+  xmp=GetXMLTreeChild(xmp,"rdf:RDF");
+  if (xmp == (XMLTreeInfo *) NULL)
+    return(MagickFalse);
+  xmp=GetXMLTreeChild(xmp,"rdf:Description");
+  if (xmp == (XMLTreeInfo *) NULL)
+    return(MagickFalse);
+  if (image->properties == (void *) NULL)
+    ((Image *) image)->properties=NewSplayTree(CompareSplayTreeString,
+      RelinquishMagickMemory,RelinquishMagickMemory);
+  return(GetXMLTreeAttributes(xmp,(SplayTreeInfo *) image->properties));
+}
+
+static char *TracePSClippath(const unsigned char *blob,size_t length,
   const unsigned long magick_unused(columns),
   const unsigned long magick_unused(rows))
 {
@@ -1575,7 +1621,7 @@ static char *TracePSClippath(unsigned char *blob,size_t length,
   return(path);
 }
 
-static char *TraceSVGClippath(unsigned char *blob,size_t length,
+static char *TraceSVGClippath(const unsigned char *blob,size_t length,
   const unsigned long columns,const unsigned long rows)
 {
   char
@@ -1854,25 +1900,25 @@ MagickExport const char *GetImageProperty(const Image *image,
 
           GetMagickPixelPacket(image,&pixel);
           fx_info=AcquireFxInfo(image,property+6);
-          status=FxEvaluateChannelExpression(fx_info,RedChannel,&alpha,
+          status=FxEvaluateChannelExpression(fx_info,RedChannel,0,0,&alpha,
             exception);
           pixel.red=(MagickRealType) QuantumRange*alpha;
-          status|=FxEvaluateChannelExpression(fx_info,GreenChannel,&alpha,
+          status|=FxEvaluateChannelExpression(fx_info,GreenChannel,0,0,&alpha,
             exception);
           pixel.green=(MagickRealType) QuantumRange*alpha;
-          status|=FxEvaluateChannelExpression(fx_info,BlueChannel,&alpha,
+          status|=FxEvaluateChannelExpression(fx_info,BlueChannel,0,0,&alpha,
             exception);
           pixel.blue=(MagickRealType) QuantumRange*alpha;
           if (image->matte != MagickFalse)
             {
-              status|=FxEvaluateChannelExpression(fx_info,OpacityChannel,&alpha,
-                exception);
+              status|=FxEvaluateChannelExpression(fx_info,OpacityChannel,0,0,
+                &alpha,exception);
               pixel.opacity=(MagickRealType) QuantumRange*(1.0-alpha);
             }
           if (image->colorspace == CMYKColorspace)
             {
-              status|=FxEvaluateChannelExpression(fx_info,BlackChannel,&alpha,
-                exception);
+              status|=FxEvaluateChannelExpression(fx_info,BlackChannel,0,0,
+                &alpha,exception);
               pixel.index=(MagickRealType) QuantumRange*alpha;
             }
           fx_info=DestroyFxInfo(fx_info);
@@ -1889,6 +1935,20 @@ MagickExport const char *GetImageProperty(const Image *image,
         }
       break;
     }
+    case 'X':
+    case 'x':
+    {
+      if (LocaleNCompare("xmp:",property,4) == 0)
+        {
+          if (GetXMPProperty(image,property) != MagickFalse)
+            {
+              p=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
+                image->properties,property);
+              return(p);
+            }
+        }
+      break;
+    }
   }
   return(p);
 }
@@ -2257,8 +2317,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           length);
         if (length != (MagickSizeType) ((size_t) length))
           (void) FormatMagickSize(length,format);
-        (void) ConcatenateMagickString(q,format,extent);
-        q+=strlen(format);
+        q+=ConcatenateMagickString(q,format,extent);
         break;
       }
       case 'c':
@@ -2301,8 +2360,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Directory.
             */
             GetPathComponent(image->magick_filename,HeadPath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
           case 'e':
@@ -2311,8 +2369,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Filename extension.
             */
             GetPathComponent(image->magick_filename,ExtensionPath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
           case 'f':
@@ -2321,8 +2378,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Filename.
             */
             GetPathComponent(image->magick_filename,TailPath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
           case 't':
@@ -2331,8 +2387,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               Base filename.
             */
             GetPathComponent(image->magick_filename,BasePath,filename);
-            (void) CopyMagickString(q,filename,extent);
-            q+=strlen(filename);
+            q+=CopyMagickString(q,filename,extent);
             break;
           }
         }
@@ -2361,8 +2416,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image filename.
         */
-        (void) CopyMagickString(q,image->filename,extent);
-        q+=strlen(image->filename);
+        q+=CopyMagickString(q,image->filename,extent);
         break;
       }
       case 'k':
@@ -2392,8 +2446,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               break;
             q=interpret_text+strlen(interpret_text);
           }
-        (void) CopyMagickString(q,value,extent);
-        q+=length;
+        q+=CopyMagickString(q,value,extent);
         break;
       }
       case 'm':
@@ -2401,8 +2454,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image format.
         */
-        (void) CopyMagickString(q,image->magick,extent);
-        q+=strlen(image->magick);
+        q+=CopyMagickString(q,image->magick,extent);
         break;
       }
       case 'M':
@@ -2410,8 +2462,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image magick filename.
         */
-        (void) CopyMagickString(q,image->magick_filename,extent);
-        q+=strlen(image->magick_filename);
+        q+=CopyMagickString(q,image->magick_filename,extent);
         break;
       }
       case 'n':
@@ -2428,8 +2479,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         /*
           Image output filename.
         */
-        (void) CopyMagickString(q,text_info->filename,extent);
-        q+=strlen(text_info->filename);
+        q+=CopyMagickString(q,text_info->filename,extent);
         break;
       }
       case 'p':
@@ -2491,8 +2541,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           Unique filename.
         */
         (void) CopyMagickString(filename,text_info->unique,extent);
-        (void) CopyMagickString(q,filename,extent);
-        q+=strlen(filename);
+        q+=CopyMagickString(q,filename,extent);
         break;
       }
       case 'w':
@@ -2707,8 +2756,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         value=GetImageProperty(image,"Signature");
         if (value == (const char *) NULL)
           break;
-        (void) CopyMagickString(q,value,extent);
-        q+=strlen(value);
+        q+=CopyMagickString(q,value,extent);
         break;
       }
       case '%':
