@@ -171,10 +171,10 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
     if (q == (PixelPacket *) NULL)
       break;
     resize_indexes=GetIndexes(resize_image);
-    offset.y=(MagickRealType) y*image->rows/resize_image->rows;
+    offset.y=(MagickRealType) (y*image->rows/resize_image->rows);
     for (x=0; x < (long) resize_image->columns; x++)
     {
-      offset.x=(MagickRealType) x*image->columns/resize_image->columns;
+      offset.x=(MagickRealType) (x*image->columns/resize_image->columns);
       pixel=InterpolatePixelColor(image,image_view,image->interpolate,
         offset.x-0.5,offset.y-0.5,exception);
       SetPixelPacket(resize_image,&pixel,q,resize_indexes+x);
@@ -228,7 +228,6 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
 %
 %    o x: MagickRealType value.
 %
-%
 */
 
 static MagickRealType J1(MagickRealType x)
@@ -399,7 +398,6 @@ static MagickRealType BesselOrderOne(MagickRealType x)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *MagnifyImage(const Image *image,ExceptionInfo *exception)
 {
@@ -441,7 +439,6 @@ MagickExport Image *MagnifyImage(const Image *image,ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *MinifyImage(const Image *image,ExceptionInfo *exception)
 {
@@ -505,7 +502,6 @@ MagickExport Image *MinifyImage(const Image *image,ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickRealType Bessel(const MagickRealType x,
@@ -693,8 +689,8 @@ static MagickRealType Triangle(const MagickRealType x,
   return(0.0);
 }
 
-static MagickBooleanType HorizontalFilter(const Image *source,
-  Image *destination,const MagickRealType x_factor,
+static MagickBooleanType HorizontalFilter(const Image *image,
+  Image *resize,const MagickRealType x_factor,
   const FilterInfo *filter_info,const MagickRealType blur,
   ContributionInfo *contribution,const MagickSizeType span,
   MagickOffsetType *quantum,ExceptionInfo *exception)
@@ -706,7 +702,7 @@ static MagickBooleanType HorizontalFilter(const Image *source,
     n,
     start,
     stop,
-    y;
+    x;
 
   MagickBooleanType
     status;
@@ -723,31 +719,33 @@ static MagickBooleanType HorizontalFilter(const Image *source,
     scale,
     support;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
-    *p;
+    *pixels;
 
   register IndexPacket
-    *indexes,
-    *source_indexes;
+    *resize_indexes;
 
   register long
     i,
-    x;
+    y;
 
   register PixelPacket
-    *q;
+    *resize_pixels;
 
   /*
-    Apply filter to resize horizontally from source to destination.
+    Apply filter to resize horizontally from image to resize.
   */
   scale=blur*MagickMax(1.0/x_factor,1.0);
   support=scale*filter_info->support;
-  destination->storage_class=source->storage_class;
+  resize->storage_class=image->storage_class;
   if (support > 0.5)
     {
-      if (SetImageStorageClass(destination,DirectClass) == MagickFalse)
+      if (SetImageStorageClass(resize,DirectClass) == MagickFalse)
         {
-          InheritException(exception,&destination->exception);
+          InheritException(exception,&resize->exception);
           return(MagickFalse);
         }
     }
@@ -761,17 +759,17 @@ static MagickBooleanType HorizontalFilter(const Image *source,
     }
   scale=1.0/scale;
   (void) ResetMagickMemory(&zero,0,sizeof(zero));
-  for (x=0; x < (long) destination->columns; x++)
+  for (x=0; x < (long) resize->columns; x++)
   {
     center=(MagickRealType) (x+0.5)/x_factor;
     start=(long) (MagickMax(center-support,0.0)+0.5);
-    stop=(long) (MagickMin(center+support,(double) source->columns)+0.5);
+    stop=(long) (MagickMin(center+support,(double) image->columns)+0.5);
     density=0.0;
     for (n=0; n < (stop-start); n++)
     {
       contribution[n].pixel=start+n;
-      contribution[n].weight=filter_info->function(scale*
-        ((MagickRealType) (start+n)-center+0.5),filter_info->support);
+      contribution[n].weight=filter_info->function(scale*((MagickRealType)
+        (start+n)-center+0.5),filter_info->support);
       density+=contribution[n].weight;
     }
     if ((density != 0.0) && (density != 1.0))
@@ -783,30 +781,32 @@ static MagickBooleanType HorizontalFilter(const Image *source,
         for (i=0; i < n; i++)
           contribution[i].weight*=density;
       }
-    p=AcquireImagePixels(source,contribution[0].pixel,0,(unsigned long)
-      (contribution[n-1].pixel-contribution[0].pixel+1),source->rows,exception);
-    q=SetImagePixels(destination,x,0,1,destination->rows);
-    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+    pixels=AcquireImagePixels(image,contribution[0].pixel,0,(unsigned long)
+      (contribution[n-1].pixel-contribution[0].pixel+1),image->rows,exception);
+    resize_pixels=SetImagePixels(resize,x,0,1,resize->rows);
+    if ((pixels == (const PixelPacket *) NULL) ||
+        (resize_pixels == (PixelPacket *) NULL))
       break;
-    source_indexes=GetIndexes(source);
-    indexes=GetIndexes(destination);
-    for (y=0; y < (long) destination->rows; y++)
+    indexes=AcquireIndexes(image);
+    resize_indexes=GetIndexes(resize);
+    #pragma omp parallel for private(alpha, gamma, i, j, pixel)
+    for (y=0; y < (long) resize->rows; y++)
     {
       pixel=zero;
-      if (source->matte == MagickFalse)
+      if (image->matte == MagickFalse)
         {
           for (i=0; i < n; i++)
           {
             j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
               (contribution[i].pixel-contribution[0].pixel);
             alpha=contribution[i].weight;
-            pixel.red+=alpha*(p+j)->red;
-            pixel.green+=alpha*(p+j)->green;
-            pixel.blue+=alpha*(p+j)->blue;
+            pixel.red+=alpha*(pixels+j)->red;
+            pixel.green+=alpha*(pixels+j)->green;
+            pixel.blue+=alpha*(pixels+j)->blue;
           }
-          q->red=RoundToQuantum(pixel.red);
-          q->green=RoundToQuantum(pixel.green);
-          q->blue=RoundToQuantum(pixel.blue);
+          resize_pixels[y].red=RoundToQuantum(pixel.red);
+          resize_pixels[y].green=RoundToQuantum(pixel.green);
+          resize_pixels[y].blue=RoundToQuantum(pixel.blue);
         }
       else
         {
@@ -816,40 +816,40 @@ static MagickBooleanType HorizontalFilter(const Image *source,
             j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
               (contribution[i].pixel-contribution[0].pixel);
             alpha=contribution[i].weight*QuantumScale*((MagickRealType)
-              QuantumRange-(p+j)->opacity);
-            pixel.red+=alpha*(p+j)->red;
-            pixel.green+=alpha*(p+j)->green;
-            pixel.blue+=alpha*(p+j)->blue;
+              QuantumRange-(pixels+j)->opacity);
+            pixel.red+=alpha*(pixels+j)->red;
+            pixel.green+=alpha*(pixels+j)->green;
+            pixel.blue+=alpha*(pixels+j)->blue;
             gamma+=alpha;
           }
           gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-          q->red=RoundToQuantum(gamma*pixel.red);
-          q->green=RoundToQuantum(gamma*pixel.green);
-          q->blue=RoundToQuantum(gamma*pixel.blue);
+          resize_pixels[y].red=RoundToQuantum(gamma*pixel.red);
+          resize_pixels[y].green=RoundToQuantum(gamma*pixel.green);
+          resize_pixels[y].blue=RoundToQuantum(gamma*pixel.blue);
         }
-      if ((source->matte != MagickFalse) && (destination->matte != MagickFalse))
+      if ((image->matte != MagickFalse) && (resize->matte != MagickFalse))
         {
           for (i=0; i < n; i++)
           {
             j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
               (contribution[i].pixel-contribution[0].pixel);
-            pixel.opacity+=contribution[i].weight*(p+j)->opacity;
+            pixel.opacity+=contribution[i].weight*(pixels+j)->opacity;
           }
-          q->opacity=RoundToQuantum(pixel.opacity);
+          resize_pixels[y].opacity=RoundToQuantum(pixel.opacity);
         }
-      if ((source->colorspace == CMYKColorspace) &&
-          (destination->colorspace == CMYKColorspace))
+      if ((image->colorspace == CMYKColorspace) &&
+          (resize->colorspace == CMYKColorspace))
         {
-          if (source->matte == MagickFalse)
+          if (image->matte == MagickFalse)
             {
               for (i=0; i < n; i++)
               {
                 j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
                   (contribution[i].pixel-contribution[0].pixel);
                 alpha=contribution[i].weight;
-                pixel.index+=alpha*source_indexes[j];
+                pixel.index+=alpha*indexes[j];
               }
-              indexes[y]=(IndexPacket) RoundToQuantum(pixel.index);
+              resize_indexes[y]=(IndexPacket) RoundToQuantum(pixel.index);
             }
           else
             {
@@ -859,41 +859,40 @@ static MagickBooleanType HorizontalFilter(const Image *source,
                 j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
                   (contribution[i].pixel-contribution[0].pixel);
                 alpha=contribution[i].weight*QuantumScale*((MagickRealType)
-                  QuantumRange-(p+j)->opacity);
-                pixel.index+=alpha*source_indexes[j];
+                  QuantumRange-(pixels+j)->opacity);
+                pixel.index+=alpha*indexes[j];
                 gamma+=alpha;
               }
               gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-              indexes[y]=(IndexPacket) RoundToQuantum(gamma*pixel.index);
+              resize_indexes[y]=(IndexPacket) RoundToQuantum(gamma*pixel.index);
             }
         }
-      if ((destination->storage_class == PseudoClass) &&
-          (source->storage_class == PseudoClass))
+      if ((resize->storage_class == PseudoClass) &&
+          (image->storage_class == PseudoClass))
         {
           i=(long) (MagickMin(MagickMax(center,(double) start),(double) stop-
             1.0)+0.5);
           j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
             (contribution[i-start].pixel-contribution[0].pixel);
-          indexes[y]=source_indexes[j];
+          resize_indexes[y]=indexes[j];
         }
-      q++;
     }
-    if (SyncImagePixels(destination) == MagickFalse)
+    if (SyncImagePixels(resize) == MagickFalse)
       break;
-    if ((source->progress_monitor != (MagickProgressMonitor) NULL) &&
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
         (QuantumTick(*quantum,span) != MagickFalse))
       {
-        status=source->progress_monitor(ResizeImageTag,(MagickOffsetType)
-          *quantum,span,source->client_data);
+        status=image->progress_monitor(ResizeImageTag,(MagickOffsetType)
+          *quantum,span,image->client_data);
         if (status == MagickFalse)
           break;
       }
     (*quantum)++;
   }
-  return(x == (long) destination->columns ? MagickTrue : MagickFalse);
+  return(x == (long) resize->columns ? MagickTrue : MagickFalse);
 }
 
-static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
+static MagickBooleanType VerticalFilter(const Image *image,Image *resize,
   const MagickRealType y_factor,const FilterInfo *filter_info,
   const MagickRealType blur,ContributionInfo *contribution,
   const MagickSizeType span,MagickOffsetType *quantum,ExceptionInfo *exception)
@@ -903,7 +902,7 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
     n,
     start,
     stop,
-    x;
+    y;
 
   MagickBooleanType
     status;
@@ -920,31 +919,33 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
     scale,
     support;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
-    *p;
+    *pixels;
 
   register IndexPacket
-    *indexes,
-    *source_indexes;
+    *resize_indexes;
 
   register long
     i,
-    y;
+    x;
 
   register PixelPacket
-    *q;
+    *resize_pixels;
 
   /*
-    Apply filter to resize vertically from source to destination.
+    Apply filter to resize vertically from image to resize.
   */
   scale=blur*MagickMax(1.0/y_factor,1.0);
   support=scale*filter_info->support;
-  destination->storage_class=source->storage_class;
+  resize->storage_class=image->storage_class;
   if (support > 0.5)
     {
-      if (SetImageStorageClass(destination,DirectClass) == MagickFalse)
+      if (SetImageStorageClass(resize,DirectClass) == MagickFalse)
         {
-          InheritException(exception,&destination->exception);
+          InheritException(exception,&resize->exception);
           return(MagickFalse);
         }
     }
@@ -958,11 +959,11 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
     }
   scale=1.0/scale;
   (void) ResetMagickMemory(&zero,0,sizeof(zero));
-  for (y=0; y < (long) destination->rows; y++)
+  for (y=0; y < (long) resize->rows; y++)
   {
     center=(MagickRealType) (y+0.5)/y_factor;
     start=(long) (MagickMax(center-support,0.0)+0.5);
-    stop=(long) (MagickMin(center+support,(double) source->rows)+0.5);
+    stop=(long) (MagickMin(center+support,(double) image->rows)+0.5);
     density=0.0;
     for (n=0; n < (stop-start); n++)
     {
@@ -980,115 +981,116 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
         for (i=0; i < n; i++)
           contribution[i].weight*=density;
       }
-    p=AcquireImagePixels(source,0,contribution[0].pixel,source->columns,
+    pixels=AcquireImagePixels(image,0,contribution[0].pixel,image->columns,
       (unsigned long) (contribution[n-1].pixel-contribution[0].pixel+1),
       exception);
-    q=SetImagePixels(destination,0,y,destination->columns,1);
-    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+    resize_pixels=SetImagePixels(resize,0,y,resize->columns,1);
+    if ((pixels == (const PixelPacket *) NULL) ||
+        (resize_pixels == (PixelPacket *) NULL))
       break;
-    source_indexes=GetIndexes(source);
-    indexes=GetIndexes(destination);
-    for (x=0; x < (long) destination->columns; x++)
+    indexes=AcquireIndexes(image);
+    resize_indexes=GetIndexes(resize);
+    #pragma omp parallel for private(alpha, gamma, i, j, pixel)
+    for (x=0; x < (long) resize->columns; x++)
     {
       gamma=0.0;
       pixel=zero;
-      if (source->matte == MagickFalse)
+      if (image->matte == MagickFalse)
         {
           for (i=0; i < n; i++)
           {
             j=(long) ((contribution[i].pixel-contribution[0].pixel)*
-              source->columns+x);
+              image->columns+x);
             alpha=contribution[i].weight;
-            pixel.red+=alpha*(p+j)->red;
-            pixel.green+=alpha*(p+j)->green;
-            pixel.blue+=alpha*(p+j)->blue;
+            pixel.red+=alpha*(pixels+j)->red;
+            pixel.green+=alpha*(pixels+j)->green;
+            pixel.blue+=alpha*(pixels+j)->blue;
           }
-          q->red=RoundToQuantum(pixel.red);
-          q->green=RoundToQuantum(pixel.green);
-          q->blue=RoundToQuantum(pixel.blue);
+          resize_pixels[x].red=RoundToQuantum(pixel.red);
+          resize_pixels[x].green=RoundToQuantum(pixel.green);
+          resize_pixels[x].blue=RoundToQuantum(pixel.blue);
         }
       else
         {
           for (i=0; i < n; i++)
           {
             j=(long) ((contribution[i].pixel-contribution[0].pixel)*
-              source->columns+x);
+              image->columns+x);
             alpha=contribution[i].weight*QuantumScale*((MagickRealType)
-              QuantumRange-(p+j)->opacity);
-            pixel.red+=alpha*(p+j)->red;
-            pixel.green+=alpha*(p+j)->green;
-            pixel.blue+=alpha*(p+j)->blue;
+              QuantumRange-(pixels+j)->opacity);
+            pixel.red+=alpha*(pixels+j)->red;
+            pixel.green+=alpha*(pixels+j)->green;
+            pixel.blue+=alpha*(pixels+j)->blue;
             gamma+=alpha;
           }
           gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-          q->red=RoundToQuantum(gamma*pixel.red);
-          q->green=RoundToQuantum(gamma*pixel.green);
-          q->blue=RoundToQuantum(gamma*pixel.blue);
+          resize_pixels[x].red=RoundToQuantum(gamma*pixel.red);
+          resize_pixels[x].green=RoundToQuantum(gamma*pixel.green);
+          resize_pixels[x].blue=RoundToQuantum(gamma*pixel.blue);
         }
-      if ((source->matte != MagickFalse) && (destination->matte != MagickFalse))
+      if ((image->matte != MagickFalse) && (resize->matte != MagickFalse))
         {
           for (i=0; i < n; i++)
           {
             j=(long) ((contribution[i].pixel-contribution[0].pixel)*
-              source->columns+x);
-            pixel.opacity+=contribution[i].weight*(p+j)->opacity;
+              image->columns+x);
+            pixel.opacity+=contribution[i].weight*(pixels+j)->opacity;
           }
-          q->opacity=RoundToQuantum(pixel.opacity);
+          resize_pixels[x].opacity=RoundToQuantum(pixel.opacity);
         }
-      if ((source->colorspace == CMYKColorspace) &&
-          (destination->colorspace == CMYKColorspace))
+      if ((image->colorspace == CMYKColorspace) &&
+          (resize->colorspace == CMYKColorspace))
         {
           gamma=0.0;
-          if (source->matte == MagickFalse)
+          if (image->matte == MagickFalse)
             {
               for (i=0; i < n; i++)
               {
                 j=(long) ((contribution[i].pixel-contribution[0].pixel)*
-                  source->columns+x);
+                  image->columns+x);
                 alpha=contribution[i].weight;
-                pixel.index+=alpha*source_indexes[j];
+                pixel.index+=alpha*indexes[j];
               }
-              indexes[x]=(IndexPacket) RoundToQuantum(pixel.index);
+              resize_indexes[x]=(IndexPacket) RoundToQuantum(pixel.index);
             }
           else
             {
               for (i=0; i < n; i++)
               {
                 j=(long) ((contribution[i].pixel-contribution[0].pixel)*
-                  source->columns+x);
+                  image->columns+x);
                 alpha=contribution[i].weight*QuantumScale*((MagickRealType)
-                  QuantumRange-(p+j)->opacity);
-                pixel.index+=alpha*source_indexes[j];
+                  QuantumRange-(pixels+j)->opacity);
+                pixel.index+=alpha*indexes[j];
                 gamma+=alpha;
               }
               gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-              indexes[x]=(IndexPacket) RoundToQuantum(gamma*pixel.index);
+              resize_indexes[x]=(IndexPacket) RoundToQuantum(gamma*pixel.index);
             }
         }
-      if ((destination->storage_class == PseudoClass) &&
-          (source->storage_class == PseudoClass))
+      if ((resize->storage_class == PseudoClass) &&
+          (image->storage_class == PseudoClass))
         {
           i=(long) (MagickMin(MagickMax(center,(double) start),(double) stop-
             1.0)+0.5);
           j=(long) ((contribution[i-start].pixel-contribution[0].pixel)*
-            source->columns+x);
-          indexes[x]=source_indexes[j];
+            image->columns+x);
+          resize_indexes[x]=indexes[j];
         }
-      q++;
     }
-    if (SyncImagePixels(destination) == MagickFalse)
+    if (SyncImagePixels(resize) == MagickFalse)
       break;
-    if ((source->progress_monitor != (MagickProgressMonitor) NULL) &&
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
         (QuantumTick(*quantum,span) != MagickFalse))
       {
-        status=source->progress_monitor(ResizeImageTag,(MagickOffsetType)
-          *quantum,span,source->client_data);
+        status=image->progress_monitor(ResizeImageTag,(MagickOffsetType)
+          *quantum,span,image->client_data);
         if (status == MagickFalse)
           break;
       }
     (*quantum)++;
   }
-  return(y == (long) destination->rows ? MagickTrue : MagickFalse);
+  return(y == (long) resize->rows ? MagickTrue : MagickFalse);
 }
 
 MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
@@ -1099,7 +1101,7 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
     *contribution;
 
   Image
-    *source_image,
+    *image_image,
     *resize_image;
 
   MagickRealType
@@ -1182,7 +1184,7 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
   if (support < filters[i].support)
     support=filters[i].support;
   contribution=(ContributionInfo *) AcquireMagickMemory((size_t)
-    (2.0*MagickMax(support,0.5)+3)*sizeof(*contribution));
+    (2.0*MagickMax(support,0.5)+3.0)*sizeof(*contribution));
   if (contribution == (ContributionInfo *) NULL)
     {
       resize_image=DestroyImage(resize_image);
@@ -1195,41 +1197,41 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
   if ((columns*((MagickSizeType) image->rows+rows)) >
       (rows*((MagickSizeType) image->columns+columns)))
     {
-      source_image=CloneImage(image,columns,image->rows,MagickTrue,exception);
-      if (source_image == (Image *) NULL)
+      image_image=CloneImage(image,columns,image->rows,MagickTrue,exception);
+      if (image_image == (Image *) NULL)
         {
           contribution=(ContributionInfo *) RelinquishMagickMemory(
             contribution);
           resize_image=DestroyImage(resize_image);
           return((Image *) NULL);
         }
-      span=(MagickSizeType) (source_image->columns+resize_image->rows);
-      status=HorizontalFilter(image,source_image,x_factor,&filters[i],blur,
+      span=(MagickSizeType) (image_image->columns+resize_image->rows);
+      status=HorizontalFilter(image,image_image,x_factor,&filters[i],blur,
+        contribution,span,&quantum,exception);
+      status|=VerticalFilter(image_image,resize_image,y_factor,&filters[i],blur,
         contribution,span,&quantum,exception);
-      status|=VerticalFilter(source_image,resize_image,y_factor,&filters[i],
-        blur,contribution,span,&quantum,exception);
     }
   else
     {
-      source_image=CloneImage(image,image->columns,rows,MagickTrue,exception);
-      if (source_image == (Image *) NULL)
+      image_image=CloneImage(image,image->columns,rows,MagickTrue,exception);
+      if (image_image == (Image *) NULL)
         {
           contribution=(ContributionInfo *) RelinquishMagickMemory(
-             contribution);
+            contribution);
           resize_image=DestroyImage(resize_image);
           return((Image *) NULL);
         }
-      span=(MagickSizeType) (resize_image->columns+source_image->rows);
-      status=VerticalFilter(image,source_image,y_factor,&filters[i],blur,
+      span=(MagickSizeType) (resize_image->columns+image_image->rows);
+      status=VerticalFilter(image,image_image,y_factor,&filters[i],blur,
         contribution,span,&quantum,exception);
-      status|=HorizontalFilter(source_image,resize_image,x_factor,&filters[i],
+      status|=HorizontalFilter(image_image,resize_image,x_factor,&filters[i],
         blur,contribution,span,&quantum,exception);
     }
   /*
     Free allocated memory.
   */
   contribution=(ContributionInfo *) RelinquishMagickMemory(contribution);
-  source_image=DestroyImage(source_image);
+  image_image=DestroyImage(image_image);
   if (status == MagickFalse)
     {
       resize_image=DestroyImage(resize_image);
@@ -1274,7 +1276,6 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
 {
 #define SampleImageTag  "Sample/Image"
 
-
   Image
     *sample_image;
 
@@ -1287,21 +1288,20 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
   MagickBooleanType
     status;
 
-  PixelPacket
-    *pixels;
+  register const IndexPacket
+    *indexes;
 
   register const PixelPacket
-    *p;
+    *pixels;
 
   register IndexPacket
-    *indexes,
     *sample_indexes;
 
   register long
     x;
 
   register PixelPacket
-    *q;
+    *sample_pixels;
   /*
     Initialize sampled image attributes.
   */
@@ -1321,14 +1321,11 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
   /*
     Allocate scan line buffer and column offset buffers.
   */
-  pixels=(PixelPacket *) AcquireMagickMemory((size_t) image->columns*
-    sizeof(*pixels));
   x_offset=(long *) AcquireMagickMemory((size_t) sample_image->columns*
     sizeof(*x_offset));
   y_offset=(long *) AcquireMagickMemory((size_t) sample_image->rows*
     sizeof(*y_offset));
-  if ((pixels == (PixelPacket *) NULL) || (x_offset == (long *) NULL) ||
-      (y_offset == (long *) NULL))
+  if ((x_offset == (long *) NULL) || (y_offset == (long *) NULL))
     {
       sample_image=DestroyImage(sample_image);
       ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1346,12 +1343,12 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
     Sample each row.
   */
   j=(-1);
-  p=AcquireImagePixels(image,0,0,image->columns,1,exception);
-  indexes=GetIndexes(image);
+  pixels=AcquireImagePixels(image,0,0,image->columns,1,exception);
+  indexes=AcquireIndexes(image);
   for (y=0; y < (long) sample_image->rows; y++)
   {
-    q=SetImagePixels(sample_image,0,y,sample_image->columns,1);
-    if (q == (PixelPacket *) NULL)
+    sample_pixels=SetImagePixels(sample_image,0,y,sample_image->columns,1);
+    if (sample_pixels == (PixelPacket *) NULL)
       break;
     sample_indexes=GetIndexes(sample_image);
     if (j != y_offset[y])
@@ -1360,19 +1357,18 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
           Read a scan line.
         */
         j=y_offset[y];
-        p=AcquireImagePixels(image,0,j,image->columns,1,exception);
-        if (p == (const PixelPacket *) NULL)
+        pixels=AcquireImagePixels(image,0,j,image->columns,1,exception);
+        if (pixels == (const PixelPacket *) NULL)
           break;
-        indexes=GetIndexes(image);
-        (void) CopyMagickMemory(pixels,p,(size_t)
-          image->columns*sizeof(*pixels));
+        indexes=AcquireIndexes(image);
       }
     /*
       Sample each column.
     */
     for (x=0; x < (long) sample_image->columns; x++)
-      *q++=pixels[x_offset[x]];
-    if (sample_indexes != (IndexPacket *) NULL)
+      sample_pixels[x]=pixels[x_offset[x]];
+    if ((image->storage_class == PseudoClass) ||
+        (image->colorspace == CMYKColorspace))
       for (x=0; x < (long) sample_image->columns; x++)
         sample_indexes[x]=indexes[x_offset[x]];
     if (SyncImagePixels(sample_image) == MagickFalse)
@@ -1388,7 +1384,6 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
   }
   y_offset=(long *) RelinquishMagickMemory(y_offset);
   x_offset=(long *) RelinquishMagickMemory(x_offset);
-  pixels=(PixelPacket *) RelinquishMagickMemory(pixels);
   return(sample_image);
 }
 
@@ -1420,7 +1415,6 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
   const unsigned long rows,ExceptionInfo *exception)
@@ -1451,11 +1445,13 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
     scale,
     span;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
   register IndexPacket
-    *indexes,
     *scale_indexes;
 
   register long
@@ -1538,7 +1534,7 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
         p=AcquireImagePixels(image,0,i++,image->columns,1,exception);
         if (p == (const PixelPacket *) NULL)
           break;
-        indexes=GetIndexes(image);
+        indexes=AcquireIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
           x_vector[x].red=(MagickRealType) p->red;
@@ -1566,7 +1562,7 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
               p=AcquireImagePixels(image,0,i++,image->columns,1,exception);
               if (p == (const PixelPacket *) NULL)
                 break;
-              indexes=GetIndexes(image);
+              indexes=AcquireIndexes(image);
               for (x=0; x < (long) image->columns; x++)
               {
                 x_vector[x].red=(MagickRealType) p->red;
@@ -1602,7 +1598,7 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
             p=AcquireImagePixels(image,0,i++,image->columns,1,exception);
             if (p == (const PixelPacket *) NULL)
               break;
-            indexes=GetIndexes(image);
+            indexes=AcquireIndexes(image);
             for (x=0; x < (long) image->columns; x++)
             {
               x_vector[x].red=(MagickRealType) p->red;
@@ -1812,7 +1808,6 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ThumbnailImage(const Image *image,
   const unsigned long columns,const unsigned long rows,ExceptionInfo *exception)
