@@ -101,7 +101,6 @@
 */
 #define MaxDimension  3
 #define DeltaTau  0.5f
-#define FastClassify  1
 #if defined(FastClassify)
 #define WeightingExponent  2.0
 #define SegmentPower(ratio) (ratio)
@@ -204,8 +203,8 @@ static void
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Classify() defines on ore more classes.  Each pixel is thresholded to
-%  determine which class it belongs to.  If not class is identified it is
+%  Classify() defines one or more classes.  Each pixel is thresholded to
+%  determine which class it belongs to.  If the class is not identified it is
 %  assigned to the closest class based on the fuzzy c-Means technique.
 %
 %  The format of the Classify method is:
@@ -232,12 +231,10 @@ static void
 %    o verbose:  A value greater than zero prints detailed information about
 %      the identified classes.
 %
-%
 */
 static MagickBooleanType Classify(Image *image,short **extrema,
   const MagickRealType cluster_threshold,
-  const MagickRealType magick_unused(weighting_exponent),
-  const MagickBooleanType verbose)
+  const MagickRealType weighting_exponent,const MagickBooleanType verbose)
 {
 #define SegmentImageTag  "Segment/Image"
 
@@ -312,8 +309,8 @@ static MagickBooleanType Classify(Image *image,short **extrema,
         */
         if (head != (Cluster *) NULL)
           {
-            cluster->next=(Cluster *)
-              AcquireMagickMemory(sizeof(*cluster->next));
+            cluster->next=(Cluster *) AcquireMagickMemory(
+              sizeof(*cluster->next));
             cluster=cluster->next;
           }
         else
@@ -383,12 +380,10 @@ static MagickBooleanType Classify(Image *image,short **extrema,
               Count this pixel.
             */
             count++;
-            cluster->red.center+=(MagickRealType)
-              ScaleQuantumToChar(p->red);
+            cluster->red.center+=(MagickRealType) ScaleQuantumToChar(p->red);
             cluster->green.center+=(MagickRealType)
               ScaleQuantumToChar(p->green);
-            cluster->blue.center+=(MagickRealType)
-              ScaleQuantumToChar(p->blue);
+            cluster->blue.center+=(MagickRealType) ScaleQuantumToChar(p->blue);
             cluster->count++;
             break;
           }
@@ -510,7 +505,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
     cluster=cluster->next;
   }
   /*
-    Do course grain storage_class.
+    Do course grain classes.
   */
   for (y=0; y < (long) image->rows; y++)
   {
@@ -520,7 +515,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
     indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      index=0;
+      index=(IndexPacket) 0;
       cluster=head;
       for (i=0; i < (long) number_clusters; i++)
       {
@@ -639,7 +634,6 @@ static MagickBooleanType Classify(Image *image,short **extrema,
 %    o number_crossings: This unsigned long specifies the number of elements
 %      in the zero_crossing array.
 %
-%
 */
 
 static inline long MagickAbsoluteValue(const long x)
@@ -779,7 +773,6 @@ static void ConsolidateCrossings(ZeroCrossing *zero_crossing,
 %    o extents:  This pointer to an ExtentPacket represent the extends
 %      of a particular peak or valley of a color component.
 %
-%
 */
 static long DefineRegion(const short *extrema,ExtentPacket *extents)
 {
@@ -836,7 +829,6 @@ static long DefineRegion(const short *extrema,ExtentPacket *extents)
 %      DerivativeHistogram to the derivative of the histogram using central
 %      differencing.
 %
-%
 */
 static void DerivativeHistogram(const MagickRealType *histogram,
   MagickRealType *derivative)
@@ -892,7 +884,6 @@ static void DerivativeHistogram(const MagickRealType *histogram,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickPixelPacket GetImageDynamicThreshold(const Image *image,
   const double cluster_threshold,const double smooth_threshold,
@@ -990,8 +981,8 @@ MagickExport MagickPixelPacket GetImageDynamicThreshold(const Image *image,
         */
         if (head != (Cluster *) NULL)
           {
-            cluster->next=(Cluster *)
-              AcquireMagickMemory(sizeof(*cluster->next));
+            cluster->next=(Cluster *) AcquireMagickMemory(
+              sizeof(*cluster->next));
             cluster=cluster->next;
           }
         else
@@ -1189,7 +1180,6 @@ MagickExport MagickPixelPacket GetImageDynamicThreshold(const Image *image,
 %    o histogram: Specifies an array of integers representing the number
 %      of pixels for each intensity of a particular color component.
 %
-%
 */
 static void InitializeHistogram(const Image *image,long **histogram,
   ExceptionInfo *exception)
@@ -1254,7 +1244,6 @@ static void InitializeHistogram(const Image *image,long **histogram,
 %    o number_crossings: This unsigned long specifies the number of elements
 %      in the zero_crossing array.
 %
-%
 */
 
 static void InitializeList(IntervalTree **list,long *number_nodes,
@@ -1364,14 +1353,14 @@ static IntervalTree *InitializeIntervalTree(const ZeroCrossing *zero_crossing,
           {
             if (node == head)
               {
-                node->child=(IntervalTree *)
-                  AcquireMagickMemory(sizeof(*node->child));
+                node->child=(IntervalTree *) AcquireMagickMemory(
+                  sizeof(*node->child));
                 node=node->child;
               }
             else
               {
-                node->sibling=(IntervalTree *)
-                  AcquireMagickMemory(sizeof(*node->sibling));
+                node->sibling=(IntervalTree *) AcquireMagickMemory(
+                  sizeof(*node->sibling));
                 node=node->sibling;
               }
             node->tau=zero_crossing[i+1].tau;
@@ -1384,8 +1373,8 @@ static IntervalTree *InitializeIntervalTree(const ZeroCrossing *zero_crossing,
         }
       if (left != head->left)
         {
-          node->sibling=(IntervalTree *)
-            AcquireMagickMemory(sizeof(*node->sibling));
+          node->sibling=(IntervalTree *) AcquireMagickMemory(
+            sizeof(*node->sibling));
           node=node->sibling;
           node->tau=zero_crossing[i+1].tau;
           node->child=(IntervalTree *) NULL;
@@ -1432,7 +1421,6 @@ static IntervalTree *InitializeIntervalTree(const ZeroCrossing *zero_crossing,
 %      represent the peaks and valleys of the histogram for each color
 %      component.
 %
-%
 */
 
 static void ActiveNodes(IntervalTree **list,long *number_nodes,
@@ -1507,8 +1495,8 @@ static MagickRealType OptimalTau(const long *histogram,const double max_tau,
     Allocate zero crossing list.
   */
   count=(unsigned long) ((max_tau-min_tau)/delta_tau)+2;
-  zero_crossing=(ZeroCrossing *)
-    AcquireMagickMemory((size_t) count*sizeof(*zero_crossing));
+  zero_crossing=(ZeroCrossing *) AcquireMagickMemory((size_t) count*
+    sizeof(*zero_crossing));
   if (zero_crossing == (ZeroCrossing *) NULL)
     return(0.0);
   for (i=0; i < (long) count; i++)
@@ -1517,8 +1505,8 @@ static MagickRealType OptimalTau(const long *histogram,const double max_tau,
     Initialize zero crossing list.
   */
   derivative=(MagickRealType *) AcquireMagickMemory(256*sizeof(*derivative));
-  second_derivative=(MagickRealType *)
-    AcquireMagickMemory(256*sizeof(*second_derivative));
+  second_derivative=(MagickRealType *) AcquireMagickMemory(256*
+    sizeof(*second_derivative));
   if ((derivative == (MagickRealType *) NULL) ||
       (second_derivative == (MagickRealType *) NULL))
     ThrowMagickFatalException(ResourceLimitFatalError,
@@ -1663,9 +1651,8 @@ static MagickRealType OptimalTau(const long *histogram,const double max_tau,
 %
 %  A description of each parameter follows.
 %
-%    o histogram: Specifies an array of MagickRealTypes representing the number of
-%      pixels for each intensity of a particular color component.
-%
+%    o histogram: Specifies an array of MagickRealTypes representing the number
+%      of pixels for each intensity of a particular color component.
 %
 */
 
@@ -1841,7 +1828,6 @@ MagickExport MagickBooleanType SegmentImage(Image *image,
 %      -1, 0, or 1 representing the slope of the first derivative of the
 %      of a particular color component.
 %
-%
 */
 static void ZeroCrossHistogram(MagickRealType *second_derivative,
   const MagickRealType smooth_threshold,short *crossings)
