@@ -23,7 +23,7 @@
 %                               December 2002                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -90,9 +90,6 @@ struct _SplayTreeInfo
     *(*relinquish_key)(void *),
     *(*relinquish_value)(void *);
 
-  unsigned long
-    depth;
-
   MagickBooleanType
     balance;
 
@@ -171,15 +168,15 @@ MagickExport MagickBooleanType AddValueToSplayTree(SplayTreeInfo *splay_info,
           ((splay_info->root->key < key) ? -1 : 0);
       if (compare == 0)
         {
-          if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-              (splay_info->root->value != (void *) NULL))
-            splay_info->root->value=splay_info->relinquish_value(
-              splay_info->root->value);
           if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
               (splay_info->root->key != (void *) NULL))
             splay_info->root->key=splay_info->relinquish_key(
               splay_info->root->key);
           splay_info->root->key=(void *) key;
+          if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+              (splay_info->root->value != (void *) NULL))
+            splay_info->root->value=splay_info->relinquish_value(
+              splay_info->root->value);
           splay_info->root->value=(void *) value;
           RelinquishSemaphoreInfo(splay_info->semaphore);
           return(MagickTrue);
@@ -240,8 +237,8 @@ MagickExport MagickBooleanType AddValueToSplayTree(SplayTreeInfo *splay_info,
 %
 */
 
-static NodeInfo *LinkSplayTreeNodes(NodeInfo **nodes,unsigned long low,
-  unsigned long high)
+static NodeInfo *LinkSplayTreeNodes(NodeInfo **nodes,const unsigned long low,
+  const unsigned long high)
 {
   register NodeInfo
     *node;
@@ -382,6 +379,215 @@ MagickExport int CompareSplayTreeStringInfo(const void *target,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   D e l e t e N o d e B y V a l u e F r o m S p l a y T r e e               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DeleteNodeByValueFromSplayTree() deletes a node by value from the
+%  splay-tree.
+%
+%  The format of the DeleteNodeByValueFromSplayTree method is:
+%
+%      MagickBooleanType DeleteNodeByValueFromSplayTree(
+%        SplayTreeInfo *splay_info,const void *value)
+%
+%  A description of each parameter follows:
+%
+%    o splay_info: The splay-tree info.
+%
+%    o value: The value.
+%
+*/
+
+static void *GetFirstSplayTreeNode(SplayTreeInfo *splay_info)
+{
+  register NodeInfo
+    *node;
+
+  node=splay_info->root;
+  if (splay_info->root == (NodeInfo *) NULL)
+    return((NodeInfo *) NULL);
+  while (node->left != (NodeInfo *) NULL)
+    node=node->left;
+  return(node->key);
+}
+
+MagickExport MagickBooleanType DeleteNodeByValueFromSplayTree(
+  SplayTreeInfo *splay_info,const void *value)
+{
+  register NodeInfo
+    *next,
+    *node;
+
+  assert(splay_info != (SplayTreeInfo *) NULL);
+  assert(splay_info->signature == MagickSignature);
+  if (splay_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  if (splay_info->root == (NodeInfo *) NULL)
+    return(MagickFalse);
+  AcquireSemaphoreInfo(&splay_info->semaphore);
+  next=(NodeInfo *) GetFirstSplayTreeNode(splay_info);
+  while (next != (NodeInfo *) NULL)
+  {
+    SplaySplayTree(splay_info,next);
+    next=(NodeInfo *) NULL;
+    node=splay_info->root->right;
+    if (node != (NodeInfo *) NULL)
+      {
+        while (node->left != (NodeInfo *) NULL)
+          node=node->left;
+        next=(NodeInfo *) node->key;
+      }
+    if (splay_info->root->value == value)
+      {
+        int
+          compare;
+
+        register NodeInfo
+          *left,
+          *right;
+
+        void
+          *key;
+
+        /*
+          We found the node that matches the value; now delete it.
+        */
+        key=splay_info->root->key;
+        SplaySplayTree(splay_info,key);
+        splay_info->key=(void *) NULL;
+        if (splay_info->compare != (int (*)(const void *,const void *)) NULL)
+          compare=splay_info->compare(splay_info->root->key,key);
+        else
+          compare=(splay_info->root->key > key) ? 1 :
+            ((splay_info->root->key < key) ? -1 : 0);
+        if (compare != 0)
+          {
+            RelinquishSemaphoreInfo(splay_info->semaphore);
+            return(MagickFalse);
+          }
+        left=splay_info->root->left;
+        right=splay_info->root->right;
+        if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
+            (splay_info->root->key != (void *) NULL))
+          splay_info->root->key=splay_info->relinquish_key(
+            splay_info->root->key);
+        if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+            (splay_info->root->value != (void *) NULL))
+          splay_info->root->value=splay_info->relinquish_value(
+            splay_info->root->value);
+        splay_info->root=(NodeInfo *) RelinquishMagickMemory(splay_info->root);
+        splay_info->nodes--;
+        if (left == (NodeInfo *) NULL)
+          {
+            splay_info->root=right;
+            RelinquishSemaphoreInfo(splay_info->semaphore);
+            return(MagickTrue);
+          }
+        splay_info->root=left;
+        if (right != (NodeInfo *) NULL)
+          {
+            while (left->right != (NodeInfo *) NULL)
+              left=left->right;
+            left->right=right;
+          }
+        RelinquishSemaphoreInfo(splay_info->semaphore);
+        return(MagickTrue);
+      }
+  }
+  RelinquishSemaphoreInfo(splay_info->semaphore);
+  return(MagickFalse);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   D e l e t e N o d e F r o m S p l a y T r e e                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DeleteNodeFromSplayTree() deletes a node from the splay-tree.
+%
+%  The format of the DeleteNodeFromSplayTree method is:
+%
+%      MagickBooleanType DeleteNodeFromSplayTree(SplayTreeInfo *splay_info,
+%        const void *key)
+%
+%  A description of each parameter follows:
+%
+%    o splay_info: The splay-tree info.
+%
+%    o key: The key.
+%
+*/
+MagickExport MagickBooleanType DeleteNodeFromSplayTree(
+  SplayTreeInfo *splay_info,const void *key)
+{
+  int
+    compare;
+
+  register NodeInfo
+    *left,
+    *right;
+
+  assert(splay_info != (SplayTreeInfo *) NULL);
+  assert(splay_info->signature == MagickSignature);
+  if (splay_info->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  if (splay_info->root == (NodeInfo *) NULL)
+    return(MagickFalse);
+  AcquireSemaphoreInfo(&splay_info->semaphore);
+  SplaySplayTree(splay_info,key);
+  splay_info->key=(void *) NULL;
+  if (splay_info->compare != (int (*)(const void *,const void *)) NULL)
+    compare=splay_info->compare(splay_info->root->key,key);
+  else
+    compare=(splay_info->root->key > key) ? 1 :
+      ((splay_info->root->key < key) ? -1 : 0);
+  if (compare != 0)
+    {
+      RelinquishSemaphoreInfo(splay_info->semaphore);
+      return(MagickFalse);
+    }
+  left=splay_info->root->left;
+  right=splay_info->root->right;
+  if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+      (splay_info->root->value != (void *) NULL))
+    splay_info->root->value=splay_info->relinquish_value(
+      splay_info->root->value);
+  if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
+      (splay_info->root->key != (void *) NULL))
+    splay_info->root->key=splay_info->relinquish_key(splay_info->root->key);
+  splay_info->root=(NodeInfo *) RelinquishMagickMemory(splay_info->root);
+  splay_info->nodes--;
+  if (left == (NodeInfo *) NULL)
+    {
+      splay_info->root=right;
+      RelinquishSemaphoreInfo(splay_info->semaphore);
+      return(MagickTrue);
+    }
+  splay_info->root=left;
+  if (right != (NodeInfo *) NULL)
+    {
+      while (left->right != (NodeInfo *) NULL)
+        left=left->right;
+      left->right=right;
+    }
+  RelinquishSemaphoreInfo(splay_info->semaphore);
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y S p l a y T r e e                                           %
 %                                                                             %
 %                                                                             %
@@ -411,14 +617,14 @@ MagickExport SplayTreeInfo *DestroySplayTree(SplayTreeInfo *splay_info)
   AcquireSemaphoreInfo(&splay_info->semaphore);
   if (splay_info->root != (NodeInfo *) NULL)
     {
-      if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-          (splay_info->root->value != (void *) NULL))
-        splay_info->root->value=splay_info->relinquish_value(
-          splay_info->root->value);
       if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
           (splay_info->root->key != (void *) NULL))
         splay_info->root->key=splay_info->relinquish_key(splay_info->root->key);
       splay_info->root->key=(void *) NULL;
+      if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+          (splay_info->root->value != (void *) NULL))
+        splay_info->root->value=splay_info->relinquish_value(
+          splay_info->root->value);
       for (pend=splay_info->root; pend != (NodeInfo *) NULL; )
       {
         active=pend;
@@ -426,27 +632,27 @@ MagickExport SplayTreeInfo *DestroySplayTree(SplayTreeInfo *splay_info)
         {
           if (active->left != (NodeInfo *) NULL)
             {
-              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-                  (active->left->value != (void *) NULL))
-                active->left->value=splay_info->relinquish_value(
-                  active->left->value);
               if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
                   (active->left->key != (void *) NULL))
                 active->left->key=splay_info->relinquish_key(active->left->key);
               active->left->key=(void *) pend;
+              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+                  (active->left->value != (void *) NULL))
+                active->left->value=splay_info->relinquish_value(
+                  active->left->value);
               pend=active->left;
             }
           if (active->right != (NodeInfo *) NULL)
             {
-              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-                  (active->right->value != (void *) NULL))
-                active->right->value=splay_info->relinquish_value(
-                  active->right->value);
               if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
                   (active->right->key != (void *) NULL))
                 active->right->key=splay_info->relinquish_key(
                   active->right->key);
               active->right->key=(void *) pend;
+              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+                  (active->right->value != (void *) NULL))
+                active->right->value=splay_info->relinquish_value(
+                  active->right->value);
               pend=active->right;
             }
           node=active;
@@ -845,7 +1051,6 @@ MagickExport SplayTreeInfo *NewSplayTree(
   splay_info->compare=compare;
   splay_info->relinquish_key=relinquish_key;
   splay_info->relinquish_value=relinquish_value;
-  splay_info->depth=0;
   splay_info->balance=MagickFalse;
   splay_info->key=(void *) NULL;
   splay_info->next=(void *) NULL;
@@ -867,12 +1072,13 @@ MagickExport SplayTreeInfo *NewSplayTree(
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveNodeByValueFromSplayTree() removes a node by value from the splay-tree.
+%  RemoveNodeByValueFromSplayTree() removes a node by value from the splay-tree
+%  and returns its key.
 %
 %  The format of the RemoveNodeByValueFromSplayTree method is:
 %
-%      MagickBooleanType RemoveNodeByValueFromSplayTree(
-%        SplayTreeInfo *splay_info,const void *value)
+%      void *RemoveNodeByValueFromSplayTree(SplayTreeInfo *splay_info,
+%        const void *value)
 %
 %  A description of each parameter follows:
 %
@@ -881,33 +1087,23 @@ MagickExport SplayTreeInfo *NewSplayTree(
 %    o value: The value.
 %
 */
-
-static void *GetFirstSplayTreeNode(SplayTreeInfo *splay_info)
-{
-  register NodeInfo
-    *node;
-
-  node=splay_info->root;
-  if (splay_info->root == (NodeInfo *) NULL)
-    return((NodeInfo *) NULL);
-  while (node->left != (NodeInfo *) NULL)
-    node=node->left;
-  return(node->key);
-}
-
-MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
-  SplayTreeInfo *splay_info,const void *value)
+MagickExport void *RemoveNodeByValueFromSplayTree(SplayTreeInfo *splay_info,
+  const void *value)
 {
   register NodeInfo
     *next,
     *node;
 
+  void
+    *key;
+
   assert(splay_info != (SplayTreeInfo *) NULL);
   assert(splay_info->signature == MagickSignature);
   if (splay_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  key=(void *) NULL;
   if (splay_info->root == (NodeInfo *) NULL)
-    return(MagickFalse);
+    return(key);
   AcquireSemaphoreInfo(&splay_info->semaphore);
   next=(NodeInfo *) GetFirstSplayTreeNode(splay_info);
   while (next != (NodeInfo *) NULL)
@@ -930,9 +1126,6 @@ MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
           *left,
           *right;
 
-        void
-          *key;
-
         /*
           We found the node that matches the value; now remove it.
         */
@@ -947,7 +1140,7 @@ MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
         if (compare != 0)
           {
             RelinquishSemaphoreInfo(splay_info->semaphore);
-            return(MagickFalse);
+            return(key);
           }
         left=splay_info->root->left;
         right=splay_info->root->right;
@@ -955,17 +1148,13 @@ MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
             (splay_info->root->value != (void *) NULL))
           splay_info->root->value=splay_info->relinquish_value(
             splay_info->root->value);
-        if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
-            (splay_info->root->key != (void *) NULL))
-          splay_info->root->key=splay_info->relinquish_key(
-            splay_info->root->key);
         splay_info->root=(NodeInfo *) RelinquishMagickMemory(splay_info->root);
         splay_info->nodes--;
         if (left == (NodeInfo *) NULL)
           {
             splay_info->root=right;
             RelinquishSemaphoreInfo(splay_info->semaphore);
-            return(MagickTrue);
+            return(key);
           }
         splay_info->root=left;
         if (right != (NodeInfo *) NULL)
@@ -975,11 +1164,11 @@ MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
             left->right=right;
           }
         RelinquishSemaphoreInfo(splay_info->semaphore);
-        return(MagickTrue);
+        return(key);
       }
   }
   RelinquishSemaphoreInfo(splay_info->semaphore);
-  return(MagickFalse);
+  return(key);
 }
 
 /*
@@ -993,12 +1182,12 @@ MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveNodeFromSplayTree() removes a node from the splay-tree.
+%  RemoveNodeFromSplayTree() removes a node from the splay-tree and returns its
+%  value.
 %
 %  The format of the RemoveNodeFromSplayTree method is:
 %
-%      MagickBooleanType RemoveNodeFromSplayTree(SplayTreeInfo *splay_info,
-%        const void *key)
+%      void *RemoveNodeFromSplayTree(SplayTreeInfo *splay_info,const void *key)
 %
 %  A description of each parameter follows:
 %
@@ -1007,8 +1196,8 @@ MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
 %    o key: The key.
 %
 */
-MagickExport MagickBooleanType RemoveNodeFromSplayTree(
-  SplayTreeInfo *splay_info,const void *key)
+MagickExport void *RemoveNodeFromSplayTree(SplayTreeInfo *splay_info,
+  const void *key)
 {
   int
     compare;
@@ -1017,12 +1206,16 @@ MagickExport MagickBooleanType RemoveNodeFromSplayTree(
     *left,
     *right;
 
+  void
+    *value;
+
   assert(splay_info != (SplayTreeInfo *) NULL);
   assert(splay_info->signature == MagickSignature);
   if (splay_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  value=(void *) NULL;
   if (splay_info->root == (NodeInfo *) NULL)
-    return(MagickFalse);
+    return(value);
   AcquireSemaphoreInfo(&splay_info->semaphore);
   SplaySplayTree(splay_info,key);
   splay_info->key=(void *) NULL;
@@ -1034,14 +1227,11 @@ MagickExport MagickBooleanType RemoveNodeFromSplayTree(
   if (compare != 0)
     {
       RelinquishSemaphoreInfo(splay_info->semaphore);
-      return(MagickFalse);
+      return(value);
     }
   left=splay_info->root->left;
   right=splay_info->root->right;
-  if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-      (splay_info->root->value != (void *) NULL))
-    splay_info->root->value=splay_info->relinquish_value(
-      splay_info->root->value);
+  value=splay_info->root->value;
   if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
       (splay_info->root->key != (void *) NULL))
     splay_info->root->key=splay_info->relinquish_key(splay_info->root->key);
@@ -1051,7 +1241,7 @@ MagickExport MagickBooleanType RemoveNodeFromSplayTree(
     {
       splay_info->root=right;
       RelinquishSemaphoreInfo(splay_info->semaphore);
-      return(MagickTrue);
+      return(value);
     }
   splay_info->root=left;
   if (right != (NodeInfo *) NULL)
@@ -1061,7 +1251,7 @@ MagickExport MagickBooleanType RemoveNodeFromSplayTree(
       left->right=right;
     }
   RelinquishSemaphoreInfo(splay_info->semaphore);
-  return(MagickTrue);
+  return(value);
 }
 
 /*
@@ -1131,8 +1321,8 @@ MagickExport void ResetSplayTreeIterator(SplayTreeInfo *splay_info)
 %
 */
 
-static NodeInfo *Splay(SplayTreeInfo *splay_info,const void *key,
-  NodeInfo **node,NodeInfo **parent,NodeInfo **grandparent)
+static NodeInfo *Splay(SplayTreeInfo *splay_info,const unsigned long depth,
+  const void *key,NodeInfo **node,NodeInfo **parent,NodeInfo **grandparent)
 {
   int
     compare;
@@ -1159,15 +1349,13 @@ static NodeInfo *Splay(SplayTreeInfo *splay_info,const void *key,
       next=(&n->right);
   if (next != (NodeInfo **) NULL)
     {
-      if (splay_info->depth >= MaxSplayTreeDepth)
+      if (depth >= MaxSplayTreeDepth)
         {
           splay_info->balance=MagickTrue;
           return(n);
         }
-      splay_info->depth++;
-      n=Splay(splay_info,key,next,node,parent);
-      splay_info->depth--;
-      if ((*node != n) || (splay_info->balance != MagickFalse))
+      n=Splay(splay_info,depth+1,key,next,node,parent);
+      if ((n != *node) || (splay_info->balance != MagickFalse))
         return(n);
     }
   if (parent == (NodeInfo **) NULL)
@@ -1241,14 +1429,12 @@ static void SplaySplayTree(SplayTreeInfo *splay_info,const void *key)
       if (compare == 0)
         return;
     }
-  splay_info->depth=0;
-  (void) Splay(splay_info,key,&splay_info->root,(NodeInfo **) NULL,
+  (void) Splay(splay_info,0UL,key,&splay_info->root,(NodeInfo **) NULL,
     (NodeInfo **) NULL);
   if (splay_info->balance != MagickFalse)
     {
       BalanceSplayTree(splay_info);
-      splay_info->depth=0;
-      (void) Splay(splay_info,key,&splay_info->root,(NodeInfo **) NULL,
+      (void) Splay(splay_info,0UL,key,&splay_info->root,(NodeInfo **) NULL,
         (NodeInfo **) NULL);
       if (splay_info->balance != MagickFalse)
         {
