@@ -161,6 +161,7 @@ MagickExport void RegisterStaticModules(void)
 #if defined(HasTIFF)
   RegisterEPTImage();
 #endif
+  RegisterEXRImage();
   RegisterFAXImage();
   RegisterFITSImage();
 #if defined(HasFPX)
@@ -314,6 +315,7 @@ MagickExport void UnregisterStaticModules(void)
 #if defined(HasTIFF)
   UnregisterEPTImage();
 #endif
+  UnregisterEXRImage();
   UnregisterFAXImage();
   UnregisterFITSImage();
 #if defined(HasFPX)
