@@ -113,7 +113,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   ExceptionInfo *exception)
@@ -235,25 +234,23 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
   MagickStatusType
     status;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     x;
 
   unsigned long
-    depth,
-    scale;
+    depth;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   depth=1;
-  scale=QuantumRange/(QuantumRange >> (QuantumDepth-depth));
   if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
     {
       p=image->colormap;
@@ -261,17 +258,19 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
       {
         status=MagickFalse;
         if ((channel & RedChannel) != 0)
-          status|=((unsigned long) p->red != (scale*(p->red/scale)));
+          status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
+            depth),depth);
         if ((channel & GreenChannel) != 0)
-          status|=((unsigned long) p->green != (scale*(p->green/scale)));
+          status|=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
+            depth),depth);
         if ((channel & BlueChannel) != 0)
-          status|=((unsigned long) p->blue != (scale*(p->blue/scale)));
+          status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
+            depth),depth);
         if (status != MagickFalse)
           {
             depth++;
             if (depth == QuantumDepth)
               return(depth);
-            scale=QuantumRange/(QuantumRange >> (QuantumDepth-depth));
             continue;
           }
         x++;
@@ -284,27 +283,31 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
       p=AcquireImagePixels(image,0,y,image->columns,1,exception);
       if (p == (const PixelPacket *) NULL)
         break;
-      indexes=GetIndexes(image);
+      indexes=AcquireIndexes(image);
       for (x=0; x < (long) image->columns; )
       {
         status=MagickFalse;
         if ((channel & RedChannel) != 0)
-          status|=((unsigned long) p->red != (scale*(p->red/scale)));
+          status|=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
+            depth),depth);
         if ((channel & GreenChannel) != 0)
-          status|=((unsigned long) p->green != (scale*(p->green/scale)));
+          status|=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
+            depth),depth);
         if ((channel & BlueChannel) != 0)
-          status|=((unsigned long) p->blue != (scale*(p->blue/scale)));
+          status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
+            depth),depth);
         if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-          status|=((unsigned long) p->opacity != (scale*(p->opacity/scale)));
+          status|=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,
+            depth),depth);
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace))
-          status|=((unsigned long) indexes[x] != (scale*(indexes[x]/scale)));
+          status|=indexes[x] != ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],
+            depth),depth);
         if (status != MagickFalse)
           {
             depth++;
             if (depth == QuantumDepth)
               return(depth);
-            scale=QuantumRange/(QuantumRange >> (QuantumDepth-depth));
             continue;
           }
         x++;
@@ -319,7 +322,7 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   G e t I m a g e C h a n n e l E x t r e m a                               %
++   G e t I m a g e C h a n n e l E x t r e m a                               %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -357,105 +360,21 @@ MagickExport MagickBooleanType GetImageChannelExtrema(const Image *image,
   const ChannelType channel,unsigned long *minima,unsigned long *maxima,
   ExceptionInfo *exception)
 {
-  long
-    y;
+  double
+    max,
+    min;
 
-  register const PixelPacket
-    *p;
-
-  register IndexPacket
-    *indexes;
-
-  register long
-    x;
+  MagickBooleanType
+    status;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  *maxima=0;
-  *minima=(unsigned long) QuantumRange;
-  y=(long) image->rows;
-  if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
-    {
-      p=image->colormap;
-      for (x=0; x < (long) image->colors; )
-      {
-        if ((channel & RedChannel) != 0)
-          {
-            if ((unsigned long) p->red < *minima)
-              *minima=1UL*p->red;
-            if ((unsigned long) p->red > *maxima)
-              *maxima=1UL*p->red;
-          }
-        if ((channel & GreenChannel) != 0)
-          {
-            if ((unsigned long) p->green < *minima)
-              *minima=1UL*p->green;
-            if ((unsigned long) p->green > *maxima)
-              *maxima=1UL*p->green;
-          }
-        if ((channel & BlueChannel) != 0)
-          {
-            if ((unsigned long) p->blue < *minima)
-              *minima=1UL*p->blue;
-            if ((unsigned long) p->blue > *maxima)
-              *maxima=1UL*p->blue;
-          }
-        x++;
-        p++;
-      }
-    }
-  else
-    for (y=0; y < (long) image->rows; y++)
-    {
-      p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-      if (p == (const PixelPacket *) NULL)
-        break;
-      indexes=GetIndexes(image);
-      for (x=0; x < (long) image->columns; )
-      {
-        if ((channel & RedChannel) != 0)
-          {
-            if ((unsigned long) p->red < *minima)
-              *minima=1UL*p->red;
-            if ((unsigned long) p->red > *maxima)
-              *maxima=1UL*p->red;
-          }
-        if ((channel & GreenChannel) != 0)
-          {
-            if ((unsigned long) p->green < *minima)
-              *minima=1UL*p->green;
-            if ((unsigned long) p->green > *maxima)
-              *maxima=1UL*p->green;
-          }
-        if ((channel & BlueChannel) != 0)
-          {
-            if ((unsigned long) p->blue < *minima)
-              *minima=1UL*p->blue;
-            if ((unsigned long) p->blue > *maxima)
-              *maxima=1UL*p->blue;
-          }
-        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-          {
-            if ((unsigned long) p->opacity < *minima)
-              *minima=1UL*p->opacity;
-            if ((unsigned long) p->opacity > *maxima)
-              *maxima=1UL*p->opacity;
-          }
-        if (((channel & IndexChannel) != 0) &&
-            (image->colorspace == CMYKColorspace))
-          {
-            if ((unsigned long) indexes[x] < *minima)
-              *minima=1UL*indexes[x];
-            if ((unsigned long) indexes[x] > *maxima)
-              *maxima=1UL*indexes[x];
-          }
-        x++;
-        p++;
-      }
-    }
-  return(y == (long) image->rows ? MagickTrue : MagickFalse);
+  status=GetImageChannelRange(image,channel,&min,&max,exception);
+  *minima=(unsigned long) (min+0.5);
+  *maxima=(unsigned long) (max+0.5);
+  return(status);
 }
 
 /*
@@ -490,7 +409,6 @@ MagickExport MagickBooleanType GetImageChannelExtrema(const Image *image,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 MagickExport MagickBooleanType GetImageMean(const Image *image,double *mean,
@@ -516,12 +434,12 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
   long
     y;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     x;
 
@@ -537,7 +455,7 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
     p=AcquireImagePixels(image,0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=AcquireIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -590,6 +508,155 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t I m a g e C h a n n e l R a n g e                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetImageChannelRange() returns the range of one or more image channels.
+%
+%  The format of the GetImageChannelRange method is:
+%
+%      MagickBooleanType GetImageChannelRange(const Image *image,
+%        const ChannelType channel,double *minima,double *maxima,
+%        ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o channel: The channel.
+%
+%    o minima: The minimum value in the channel.
+%
+%    o maxima: The maximum value in the channel.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+
+MagickExport MagickBooleanType GetImageRange(const Image *image,
+  double *minima,double *maxima,ExceptionInfo *exception)
+{
+  return(GetImageChannelRange(image,AllChannels,minima,maxima,exception));
+}
+
+MagickExport MagickBooleanType GetImageChannelRange(const Image *image,
+  const ChannelType channel,double *minima,double *maxima,
+  ExceptionInfo *exception)
+{
+  long
+    y;
+
+  MagickPixelPacket
+    pixel;
+
+  register const IndexPacket
+    *indexes;
+
+  register const PixelPacket
+    *p;
+
+  register long
+    x;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  *maxima=(-1.0E-37);
+  *minima=1.0E+37;
+  GetMagickPixelPacket(image,&pixel);
+  y=(long) image->rows;
+  if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
+    {
+      p=image->colormap;
+      for (x=0; x < (long) image->colors; )
+      {
+        if ((channel & RedChannel) != 0)
+          {
+            if ((double) p->red < *minima)
+              *minima=(double) p->red;
+            if ((double) p->red > *maxima)
+              *maxima=(double) p->red;
+          }
+        if ((channel & GreenChannel) != 0)
+          {
+            if ((double) p->green < *minima)
+              *minima=(double) p->green;
+            if ((double) p->green > *maxima)
+              *maxima=(double) p->green;
+          }
+        if ((channel & BlueChannel) != 0)
+          {
+            if ((double) p->blue < *minima)
+              *minima=(double) p->blue;
+            if ((double) p->blue > *maxima)
+              *maxima=(double) p->blue;
+          }
+        x++;
+        p++;
+      }
+    }
+  else
+    for (y=0; y < (long) image->rows; y++)
+    {
+      p=AcquireImagePixels(image,0,y,image->columns,1,exception);
+      if (p == (const PixelPacket *) NULL)
+        break;
+      indexes=AcquireIndexes(image);
+      for (x=0; x < (long) image->columns; )
+      {
+        SetMagickPixelPacket(image,p,indexes+x,&pixel);
+        if ((channel & RedChannel) != 0)
+          {
+            if (pixel.red < *minima)
+              *minima=(double) pixel.red;
+            if (pixel.red > *maxima)
+              *maxima=(double) pixel.red;
+          }
+        if ((channel & GreenChannel) != 0)
+          {
+            if (pixel.green < *minima)
+              *minima=(double) pixel.green;
+            if (pixel.green > *maxima)
+              *maxima=(double) pixel.green;
+          }
+        if ((channel & BlueChannel) != 0)
+          {
+            if (pixel.blue < *minima)
+              *minima=(double) pixel.blue;
+            if (pixel.blue > *maxima)
+              *maxima=(double) pixel.blue;
+          }
+        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+          {
+            if (pixel.opacity < *minima)
+              *minima=(double) pixel.opacity;
+            if (pixel.opacity > *maxima)
+              *maxima=(double) pixel.opacity;
+          }
+        if (((channel & IndexChannel) != 0) &&
+            (image->colorspace == CMYKColorspace))
+          {
+            if ((double) indexes[x] < *minima)
+              *minima=(double) indexes[x];
+            if ((double) indexes[x] > *maxima)
+              *maxima=(double) indexes[x];
+          }
+        x++;
+        p++;
+      }
+    }
+  return(y == (long) image->rows ? MagickTrue : MagickFalse);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t I m a g e C h a n n e l S t a t i s t i c s                         %
 %                                                                             %
 %                                                                             %
@@ -619,16 +686,14 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
 %
 */
 
-static inline unsigned long MagickMax(const unsigned long x,
-  const unsigned long y)
+static inline double MagickMax(const double x,const double y)
 {
   if (x > y)
     return(x);
   return(y);
 }
 
-static inline unsigned long MagickMin(const unsigned long x,
-  const unsigned long y)
+static inline double MagickMin(const double x,const double y)
 {
   if (x < y)
     return(x);
@@ -647,12 +712,15 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   long
     y;
 
+  MagickStatusType
+    status;
+
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i,
     x;
@@ -662,7 +730,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
 
   unsigned long
     channels,
-    scale;
+    depth;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -677,10 +745,8 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   for (i=0; i <= AllChannels; i++)
   {
     channel_statistics[i].depth=1;
-    channel_statistics[i].scale=(unsigned long)
-      (QuantumRange/(QuantumRange >> (QuantumDepth-1)));
-    channel_statistics[i].maxima=(Quantum) 0;
-    channel_statistics[i].minima=(Quantum) QuantumRange;
+    channel_statistics[i].maxima=(-1.0E-37);
+    channel_statistics[i].minima=1.0E+37;
     channel_statistics[i].mean=0.0;
     channel_statistics[i].standard_deviation=0.0;
   }
@@ -690,42 +756,39 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     p=AcquireImagePixels(image,0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=AcquireIndexes(image);
     for (x=0; x < (long) image->columns; )
     {
       if (channel_statistics[RedChannel].depth != QuantumDepth)
         {
-          scale=channel_statistics[RedChannel].scale;
-          if ((unsigned long) p->red != (scale*(p->red/scale)))
+          depth=channel_statistics[RedChannel].depth;
+          status=p->red != ScaleAnyToQuantum(ScaleQuantumToAny(p->red,
+            depth),depth) ? MagickTrue : MagickFalse;
+          if (status != MagickFalse)
             {
               channel_statistics[RedChannel].depth++;
-              channel_statistics[RedChannel].scale=QuantumRange/
-                (QuantumRange >> (QuantumDepth-
-                channel_statistics[RedChannel].depth));
               continue;
             }
         }
       if (channel_statistics[GreenChannel].depth != QuantumDepth)
         {
-          scale=channel_statistics[GreenChannel].scale;
-          if ((unsigned long) p->green != (scale*(p->green/scale)))
+          depth=channel_statistics[GreenChannel].depth;
+          status=p->green != ScaleAnyToQuantum(ScaleQuantumToAny(p->green,
+            depth),depth) ? MagickTrue : MagickFalse;
+          if (status != MagickFalse)
             {
               channel_statistics[GreenChannel].depth++;
-              channel_statistics[GreenChannel].scale=QuantumRange/
-                (QuantumRange >> (QuantumDepth-
-                channel_statistics[GreenChannel].depth));
               continue;
             }
         }
       if (channel_statistics[BlueChannel].depth != QuantumDepth)
         {
-          scale=channel_statistics[BlueChannel].scale;
-          if ((unsigned long) p->blue != (scale*(p->blue/scale)))
+          depth=channel_statistics[BlueChannel].depth;
+          status=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
+            depth),depth) ? MagickTrue : MagickFalse;
+          if (status != MagickFalse)
             {
               channel_statistics[BlueChannel].depth++;
-              channel_statistics[BlueChannel].scale=QuantumRange/
-                (QuantumRange >> (QuantumDepth-
-                channel_statistics[BlueChannel].depth));
               continue;
             }
         }
@@ -733,13 +796,12 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
         {
           if (channel_statistics[OpacityChannel].depth != QuantumDepth)
             {
-              scale=channel_statistics[OpacityChannel].scale;
-              if ((unsigned long) p->opacity != (scale*(p->opacity/scale)))
+              depth=channel_statistics[OpacityChannel].depth;
+              status=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(
+                p->opacity,depth),depth) ? MagickTrue : MagickFalse;
+              if (status != MagickFalse)
                 {
                   channel_statistics[OpacityChannel].depth++;
-                  channel_statistics[OpacityChannel].scale=QuantumRange/
-                    (QuantumRange >> (QuantumDepth-
-                    channel_statistics[OpacityChannel].depth));
                   continue;
                 }
             }
@@ -748,57 +810,56 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
         {
           if (channel_statistics[BlackChannel].depth != QuantumDepth)
             {
-              scale=channel_statistics[BlackChannel].scale;
-              if ((unsigned long) indexes[x] != (scale*(indexes[x]/scale)))
+              depth=channel_statistics[BlackChannel].depth;
+              status=indexes[x] != ScaleAnyToQuantum(ScaleQuantumToAny(
+                indexes[x],depth),depth) ? MagickTrue : MagickFalse;
+              if (status != MagickFalse)
                 {
                   channel_statistics[BlackChannel].depth++;
-                  channel_statistics[BlackChannel].scale=QuantumRange/
-                    (QuantumRange >> (QuantumDepth-
-                    channel_statistics[BlackChannel].depth));
                   continue;
                 }
             }
         }
-      if (p->red < channel_statistics[RedChannel].minima)
-        channel_statistics[RedChannel].minima=p->red;
-      if (p->red > channel_statistics[RedChannel].maxima)
-        channel_statistics[RedChannel].maxima=p->red;
+      if ((double) p->red < channel_statistics[RedChannel].minima)
+        channel_statistics[RedChannel].minima=(double) p->red;
+      if ((double) p->red > channel_statistics[RedChannel].maxima)
+        channel_statistics[RedChannel].maxima=(double) p->red;
       channel_statistics[RedChannel].mean+=p->red;
-      channel_statistics[RedChannel].standard_deviation+=
-        (double) p->red*p->red;
-      if (p->green < channel_statistics[GreenChannel].minima)
-        channel_statistics[GreenChannel].minima=p->green;
-      if (p->green > channel_statistics[GreenChannel].maxima)
-        channel_statistics[GreenChannel].maxima=p->green;
+      channel_statistics[RedChannel].standard_deviation+=(double)
+        p->red*p->red;
+      if ((double) p->green < channel_statistics[GreenChannel].minima)
+        channel_statistics[GreenChannel].minima=(double) p->green;
+      if ((double) p->green > channel_statistics[GreenChannel].maxima)
+        channel_statistics[GreenChannel].maxima=(double) p->green;
       channel_statistics[GreenChannel].mean+=p->green;
-      channel_statistics[GreenChannel].standard_deviation+=
-        (double) p->green*p->green;
-      if (p->blue < channel_statistics[BlueChannel].minima)
-        channel_statistics[BlueChannel].minima=p->blue;
-      if (p->blue > channel_statistics[BlueChannel].maxima)
-        channel_statistics[BlueChannel].maxima=p->blue;
+      channel_statistics[GreenChannel].standard_deviation+=(double)
+        p->green*p->green;
+      if ((double) p->blue < channel_statistics[BlueChannel].minima)
+        channel_statistics[BlueChannel].minima=(double) p->blue;
+      if ((double) p->blue > channel_statistics[BlueChannel].maxima)
+        channel_statistics[BlueChannel].maxima=(double) p->blue;
       channel_statistics[BlueChannel].mean+=p->blue;
-      channel_statistics[BlueChannel].standard_deviation+=
-        (double) p->blue*p->blue;
+      channel_statistics[BlueChannel].standard_deviation+=(double)
+        p->blue*p->blue;
       if (image->matte != MagickFalse)
         {
-          if (p->opacity < channel_statistics[OpacityChannel].minima)
-            channel_statistics[OpacityChannel].minima=p->opacity;
-          if (p->opacity > channel_statistics[OpacityChannel].maxima)
-            channel_statistics[OpacityChannel].maxima=p->opacity;
+          if ((double) p->opacity < channel_statistics[OpacityChannel].minima)
+            channel_statistics[OpacityChannel].minima=(double) p->opacity;
+          if ((double) p->opacity > channel_statistics[OpacityChannel].maxima)
+            channel_statistics[OpacityChannel].maxima=(double) p->opacity;
           channel_statistics[OpacityChannel].mean+=p->opacity;
-          channel_statistics[OpacityChannel].standard_deviation+=
-            (double) p->opacity*p->opacity;
+          channel_statistics[OpacityChannel].standard_deviation+=(double)
+            p->opacity*p->opacity;
         }
       if (image->colorspace == CMYKColorspace)
         {
-          if (indexes[x] < channel_statistics[BlackChannel].minima)
-            channel_statistics[BlackChannel].minima=indexes[x];
-          if (indexes[x] > channel_statistics[BlackChannel].maxima)
-            channel_statistics[BlackChannel].maxima=indexes[x];
+          if ((double) indexes[x] < channel_statistics[BlackChannel].minima)
+            channel_statistics[BlackChannel].minima=(double) indexes[x];
+          if ((double) indexes[x] > channel_statistics[BlackChannel].maxima)
+            channel_statistics[BlackChannel].maxima=(double) indexes[x];
           channel_statistics[BlackChannel].mean+=indexes[x];
-          channel_statistics[BlackChannel].standard_deviation+=
-            (double) indexes[x]*indexes[x];
+          channel_statistics[BlackChannel].standard_deviation+=(double)
+            indexes[x]*indexes[x];
         }
       x++;
       p++;
@@ -812,12 +873,13 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   }
   for (i=0; i < AllChannels; i++)
   {
-    channel_statistics[AllChannels].depth=MagickMax(1UL*
-      channel_statistics[AllChannels].depth,1UL*channel_statistics[i].depth);
-    channel_statistics[AllChannels].minima=(Quantum) MagickMin(1UL*
-      channel_statistics[AllChannels].minima,1UL*channel_statistics[i].minima);
-    channel_statistics[AllChannels].maxima=(Quantum) MagickMax(1UL*
-      channel_statistics[AllChannels].maxima,1UL*channel_statistics[i].maxima);
+    channel_statistics[AllChannels].depth=(unsigned long) MagickMax((double) 
+      channel_statistics[AllChannels].depth,(double)
+      channel_statistics[i].depth);
+    channel_statistics[AllChannels].minima=MagickMin(
+      channel_statistics[AllChannels].minima,channel_statistics[i].minima);
+    channel_statistics[AllChannels].maxima=MagickMax(
+      channel_statistics[AllChannels].maxima,channel_statistics[i].maxima);
     channel_statistics[AllChannels].mean+=channel_statistics[i].mean;
     channel_statistics[AllChannels].standard_deviation+=
       channel_statistics[i].standard_deviation;
@@ -876,7 +938,7 @@ MagickExport unsigned long GetImageQuantumDepth(const Image *image,
     if (depth <= 16)
       depth=16;
   if (constrain != MagickFalse)
-    depth=MagickMin(depth,QuantumDepth);
+    depth=(unsigned long) MagickMin((double) depth,(double) QuantumDepth);
   return(depth);
 }
 
@@ -920,9 +982,6 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
   long
     y;
 
-  MagickRealType
-    scale;
-
   register IndexPacket
     *indexes;
 
@@ -937,13 +996,12 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(image->signature == MagickSignature);
   y=(long) image->rows;
-  if (GetImageDepth(image,&image->exception) > MagickMin(depth,QuantumDepth))
+  if (GetImageDepth(image,&image->exception) >
+      (unsigned long) MagickMin((double) depth,(double) QuantumDepth))
     {
       /*
         Scale pixels to desired depth.
       */
-      scale=(MagickRealType) QuantumRange/(MagickRealType) (QuantumRange >>
-        (QuantumDepth-MagickMin(depth,QuantumDepth)));
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
@@ -953,17 +1011,19 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
         for (x=0; x < (long) image->columns; x++)
         {
           if ((channel & RedChannel) != 0)
-            q->red=RoundToQuantum(scale*(q->red/scale));
+            q->red=ScaleAnyToQuantum(ScaleQuantumToAny(q->red,depth),depth);
           if ((channel & GreenChannel) != 0)
-            q->green=RoundToQuantum(scale*(q->green/scale));
+            q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,depth),depth);
           if ((channel & BlueChannel) != 0)
-            q->blue=RoundToQuantum(scale*(q->blue/scale));
+            q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth),depth);
           if (((channel & OpacityChannel) != 0) &&
               (image->matte != MagickFalse))
-            q->opacity=RoundToQuantum(scale*(q->opacity/scale));
+            q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth),
+              depth);
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
-            indexes[x]=RoundToQuantum(scale*(indexes[x]/scale));
+            indexes[x]=ScaleAnyToQuantum(ScaleQuantumToAny(indexes[x],depth),
+              depth);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -978,14 +1038,16 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
           for (i=0; i < (long) image->colors; i++)
           {
             if ((channel & RedChannel) != 0)
-              q->red=RoundToQuantum(scale*(q->red/scale));
+              q->red=ScaleAnyToQuantum(ScaleQuantumToAny(q->red,depth),depth);
             if ((channel & GreenChannel) != 0)
-              q->green=RoundToQuantum(scale*(q->green/scale));
+              q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,depth),
+                depth);
             if ((channel & BlueChannel) != 0)
-              q->blue=RoundToQuantum(scale*(q->blue/scale));
+              q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth),depth);
             if (((channel & OpacityChannel) != 0) &&
                 (image->matte != MagickFalse))
-              q->opacity=RoundToQuantum(scale*(q->opacity/scale));
+              q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth),
+                depth);
             q++;
         }
       }
