@@ -111,9 +111,6 @@ static const PixelPacket
   *AcquirePixelStream(const Image *,const VirtualPixelMethod,const long,
     const long,const unsigned long,const unsigned long,ExceptionInfo *);
 
-static IndexPacket
-  *GetIndexesFromStream(const Image *);
-
 static PixelPacket
   AcquireOnePixelFromStream(const Image *,const VirtualPixelMethod,const long,
     const long,ExceptionInfo *),
@@ -140,6 +137,46 @@ static void
 %                                                                             %
 %                                                                             %
 %                                                                             %
++   A c q u i r e I n d e x e s F r o m S t r e a m                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireIndexesFromStream() returns the indexes associated with the last call to
+%  SetPixelStream() or AcquirePixelStream().
+%
+%  The format of the AcquireIndexesFromStream() method is:
+%
+%      const IndexPacket *AcquireIndexesFromStream(const Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o indexes: return the indexes associated with the last call to
+%      SetPixelStream() or AcquirePixelStream().
+%
+%    o image: The image.
+%
+*/
+static const IndexPacket *AcquireIndexesFromStream(const Image *image)
+{
+  CacheInfo
+    *cache_info;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  cache_info=(CacheInfo *) image->cache;
+  assert(cache_info->signature == MagickSignature);
+  return(cache_info->indexes);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +   A c q u i r e O n e P i x e l F r o m S t r e a m                         %
 %                                                                             %
 %                                                                             %
@@ -393,19 +430,23 @@ static void DestroyPixelStream(Image *image)
   CacheInfo
     *cache_info;
 
+  MagickBooleanType
+    destroy;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
   assert(cache_info->signature == MagickSignature);
+  destroy=MagickFalse;
   AcquireSemaphoreInfo(&cache_info->semaphore);
   cache_info->reference_count--;
-  if (cache_info->reference_count > 0)
-    {
-      RelinquishSemaphoreInfo(cache_info->semaphore);
-      return;
-    }
+  if (cache_info->reference_count == 0)
+    destroy=MagickTrue;
+  RelinquishSemaphoreInfo(cache_info->semaphore);
+  if (destroy == MagickFalse)
+    return;
   RelinquishStreamPixels(cache_info);
   if (cache_info->nexus_info != (NexusInfo *) NULL)
     {
@@ -417,8 +458,8 @@ static void DestroyPixelStream(Image *image)
       cache_info->nexus_info=(NexusInfo *) RelinquishMagickMemory(
         cache_info->nexus_info);
     }
-  RelinquishSemaphoreInfo(cache_info->semaphore);
-  cache_info->semaphore=DestroySemaphoreInfo(cache_info->semaphore);
+  if (cache_info->semaphore != (SemaphoreInfo *) NULL)
+    cache_info->semaphore=DestroySemaphoreInfo(cache_info->semaphore);
   cache_info=(CacheInfo *) RelinquishMagickMemory(cache_info);
 }
 
@@ -757,6 +798,7 @@ MagickExport Image *ReadStream(const ImageInfo *image_info,StreamHandler stream,
   (void) GetCacheInfo(&read_info->cache);
   GetCacheMethods(&cache_methods);
   cache_methods.acquire_pixel_handler=AcquirePixelStream;
+  cache_methods.acquire_indexes_from_handler=AcquireIndexesFromStream;
   cache_methods.get_pixel_handler=GetPixelStream;
   cache_methods.set_pixel_handler=SetPixelStream;
   cache_methods.sync_pixel_handler=SyncPixelStream;
