@@ -49,7 +49,6 @@
 #include "magick/memory_.h"
 #include "magick/property.h"
 #include "magick/resource_.h"
-#include "magick/semaphore.h"
 #include "magick/signature.h"
 #include "magick/string_.h"
 
@@ -1665,8 +1664,8 @@ MagickExport void SetStringInfoDatum(StringInfo *string_info,
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
-  assert(source != (const unsigned char *) NULL);
-  (void) CopyMagickMemory(string_info->datum,source,string_info->length);
+  if (string_info->length != 0)
+    (void) CopyMagickMemory(string_info->datum,source,string_info->length);
 }
 
 /*
