@@ -472,9 +472,9 @@ MagickExport MagickBooleanType BlackThresholdImage(Image *image,
       {
         if ((MagickRealType) PixelIntensityToQuantum(q) < pixel.red)
           {
-            q->red=0;
-            q->green=0;
-            q->blue=0;
+            q->red=(Quantum) 0;
+            q->green=(Quantum) 0;
+            q->blue=(Quantum) 0;
           }
         q++;
       }
@@ -482,13 +482,13 @@ MagickExport MagickBooleanType BlackThresholdImage(Image *image,
       for (x=0; x < (long) image->columns; x++)
       {
         if ((MagickRealType) q->red < pixel.red)
-          q->red=0;
+          q->red=(Quantum) 0;
         if ((MagickRealType) q->green < pixel.green)
-          q->green=0;
+          q->green=(Quantum) 0;
         if ((MagickRealType) q->blue < pixel.blue)
-          q->blue=0;
+          q->blue=(Quantum) 0;
         if ((MagickRealType) q->opacity < pixel.opacity)
-          q->opacity=0;
+          q->opacity=(Quantum) 0;
         q++;
       }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1114,23 +1114,23 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
       p=strchr(threshold_map,',');
       p++;
       if ((channel & RedChannel) != 0)
-        levels.red = (Quantum) strtol(p, &p, 10),   (void)(*p == ',' && p++);
+        levels.red = (unsigned long) strtol(p, &p, 10),   (void)(*p == ',' && p++);
       if ((channel & GreenChannel) != 0)
-        levels.green = (Quantum) strtol(p, &p, 10), (void)(*p == ',' && p++);
+        levels.green = (unsigned long) strtol(p, &p, 10), (void)(*p == ',' && p++);
       if ((channel & BlueChannel) != 0)
-        levels.blue = (Quantum) strtol(p, &p, 10),  (void)(*p == ',' && p++);
+        levels.blue = (unsigned long) strtol(p, &p, 10),  (void)(*p == ',' && p++);
       if ((channel & OpacityChannel) != 0)
-        levels.opacity = (Quantum) strtol(p, &p, 10), (void)(*p == ',' && p++);
+        levels.opacity = (unsigned long) strtol(p, &p, 10), (void)(*p == ',' && p++);
       if ((channel & IndexChannel) != 0 && image->colorspace == CMYKColorspace)
-        levels.index=(IndexPacket) strtol(p, &p, 10), (void)(*p == ',' && p++);
+        levels.index=(unsigned long) strtol(p, &p, 10), (void)(*p == ',' && p++);
     }
   }
 #else
-  /* miss-parse level values as a geometry */
+  /* Parse level values as a geometry */
   /* This is difficult!
    * How to map   GeometryInfo structure elements into
    * LongPixelPacket structure elements, but according to channel?
-   * Note channel may skip elements!!!!
+   * Note the channels list may skip elements!!!!
    * EG  -channel BA  -ordered-dither map,2,3
    * will need to map  g.rho -> l.blue, and g.sigma -> l.opacity
    * A simpler way is needed, probably converting geometry to a temporary
@@ -1190,6 +1190,7 @@ printf("DEBUG levels  r=%ld g=%ld b=%ld a=%ld i=%ld\n",
               t = dither threshold level    0..divisor-1  NB: 0 only on last
               Each color_level is of size   QuantumRange / (levels-1)
               NB: All input levels and divisor are already had 1 subtracted
+              Opacity is inverted so 'off' represents transparent.
         */
         if (levels.red) {
           t = (int) (QuantumScale*q->red*(levels.red*d+1));
@@ -1207,9 +1208,9 @@ printf("DEBUG levels  r=%ld g=%ld b=%ld a=%ld i=%ld\n",
           q->blue=(Quantum) ((l+(t >= threshold))*QuantumRange/levels.blue);
         }
         if (levels.opacity) {
-          t = (int) (QuantumScale*q->opacity*(levels.opacity*d+1));
+          t = (int) ((1.0-QuantumScale*q->opacity)*(levels.opacity*d+1));
           l = t/d;  t = t-l*d;
-          q->opacity=(Quantum) ((l+(t >= threshold))*QuantumRange/
+          q->opacity=(Quantum) ((1.0-l-(t >= threshold))*QuantumRange/
             levels.opacity);
         }
         if (levels.index) {
