@@ -159,7 +159,7 @@ MagickExport TokenInfo *DestroyTokenInfo(TokenInfo *token_info)
 %
 %  The format of the GetMagickToken method is:
 %
-%      void GetMagickToken(const char *start,char **end,char *token)
+%      void GetMagickToken(const char *start,const char **end,char *token)
 %
 %  A description of each parameter follows:
 %
@@ -169,9 +169,8 @@ MagickExport TokenInfo *DestroyTokenInfo(TokenInfo *token_info)
 %
 %    o token: copy the token to this buffer.
 %
-%
 */
-MagickExport void GetMagickToken(const char *start,char **end,char *token)
+MagickExport void GetMagickToken(const char *start,const char **end,char *token)
 {
   register const char
     *p;
@@ -283,8 +282,8 @@ MagickExport void GetMagickToken(const char *start,char **end,char *token)
     }
   while (isspace((int) ((unsigned char) *p)) != 0)
     p++;
-  if (end != (char **) NULL)
-    *end=(char *) p;
+  if (end != (const char **) NULL)
+    *end=(const char *) p;
 }
 
 /*
@@ -338,7 +337,7 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
   if ((*p == ']') && (strchr(pattern,'[') != (char *) NULL))
     {
       ExceptionInfo
-        exception;
+        *exception;
 
       ImageInfo
         *image_info;
@@ -348,9 +347,9 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
       */
       image_info=AcquireImageInfo();
       (void) CopyMagickString(image_info->filename,pattern,MaxTextExtent);
-      GetExceptionInfo(&exception);
-      (void) SetImageInfo(image_info,MagickTrue,&exception);
-      (void) DestroyExceptionInfo(&exception);
+      exception=AcquireExceptionInfo();
+      (void) SetImageInfo(image_info,MagickTrue,exception);
+      exception=DestroyExceptionInfo(exception);
       if (LocaleCompare(image_info->filename,pattern) != 0)
         {
           image_info=DestroyImageInfo(image_info);
