@@ -421,12 +421,14 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
     bounding_box,
     page;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
   register IndexPacket
-    *crop_indexes,
-    *indexes;
+    *crop_indexes;
 
   register PixelPacket
     *q;
@@ -461,6 +463,11 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       ((page.x-bounding_box.x) > (long) image->columns) ||
       ((page.y-bounding_box.y) > (long) image->rows))
     {
+      /*
+        Crop missed the image on the virtual canvas
+        Give warnign and return a 'missed image'
+        Special case, for 'background' disposed GIF animation frames.
+      */
       (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
         "GeometryDoesNotContainImage","`%s'",image->filename);
       crop_image=CloneImage(image,1,1,MagickTrue,exception);
@@ -471,6 +478,8 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       crop_image->page=bounding_box;
       crop_image->page.x=(-1);
       crop_image->page.y=(-1);
+      if ( crop_image->dispose == BackgroundDispose )
+        crop_image->dispose = NoneDispose;
       return(crop_image);
     }
   if ((page.x < 0) && (bounding_box.x >= 0))
@@ -538,7 +547,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
       break;
     (void) CopyMagickMemory(q,p,(size_t) crop_image->columns*sizeof(*q));
-    indexes=GetCacheViewIndexes(image_view);
+    indexes=AcquireCacheViewIndexes(image_view);
     crop_indexes=GetCacheViewIndexes(crop_view);
     if ((indexes != (IndexPacket *) NULL) &&
         (crop_indexes != (IndexPacket *) NULL))
