@@ -696,10 +696,6 @@ MagickExport MagickBooleanType ExpandFilenames(int *argc,char ***argv)
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(argc != (int *) NULL);
   assert(argv != (char ***) NULL);
-  for (i=1; i < (long) *argc; i++)
-    if (strlen((*argv)[i]) > (MaxTextExtent/2-1))
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "TokenLengthExceedsLimit",(*argv)[i]);
   vector=(char **) AcquireMagickMemory((*argc+1)*sizeof(*vector));
   if (vector == (char **) NULL)
     return(MagickFalse);
