@@ -23,7 +23,7 @@
 %                               December 2004                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -604,7 +604,7 @@ MagickExport XMLTreeInfo *GetNextXMLTreeTag(XMLTreeInfo *xml_info)
 %
 %  The format of the GetXMLTreeAttribute method is:
 %
-%      XMLTreeInfo *GetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag)
+%      const char *GetXMLTreeAttribute(XMLTreeInfo *xml_info,const char *tag)
 %
 %  A description of each parameter follows:
 %
@@ -660,6 +660,56 @@ MagickExport const char *GetXMLTreeAttribute(XMLTreeInfo *xml_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t X M L T r e e A t t r i b u t e s                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetXMLTreeAttributes() injects all attributes associated with the current
+%  tag in the specified splay-tree.
+%
+%  The format of the GetXMLTreeAttributes method is:
+%
+%      MagickBooleanType GetXMLTreeAttributes(const XMLTreeInfo *xml_info,
+%        SplayTreeInfo *attributes)
+%
+%  A description of each parameter follows:
+%
+%    o xml_info: The xml info.
+%
+%    o attributes: The attribute splay-tree.
+%
+*/
+MagickExport MagickBooleanType GetXMLTreeAttributes(const XMLTreeInfo *xml_info,
+  SplayTreeInfo *attributes)
+{
+  register long
+    i;
+
+  assert(xml_info != (XMLTreeInfo *) NULL);
+  assert((xml_info->signature == MagickSignature) ||
+         (((XMLTreeRoot *) xml_info)->signature == MagickSignature));
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
+  assert(attributes != (SplayTreeInfo *) NULL);
+  if (xml_info->attributes == (char **) NULL)
+    return(MagickTrue);
+  i=0;
+  while (xml_info->attributes[i] != (char *) NULL)
+  {
+     (void) AddValueToSplayTree(attributes,
+       ConstantString(xml_info->attributes[i]),
+       ConstantString(xml_info->attributes[i+1]));
+    i+=2;
+  }
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t X M L T r e e C h i l d                                             %
 %                                                                             %
 %                                                                             %
@@ -1425,9 +1475,12 @@ static void ParseProcessingInstructions(XMLTreeRoot *root,char *xml,
       if (root->processing_instructions[i] == (char **) NULL)
         ThrowMagickFatalException(ResourceLimitFatalError,
           "UnableToAcquireString",xml);
-      root->processing_instructions[i][0]=ConstantString(target);
-      root->processing_instructions[i][1]=(char *) NULL;
       root->processing_instructions[i+1]=(char **) NULL;
+      root->processing_instructions[i][0]=ConstantString(target);
+      root->processing_instructions[i][1]=(char *)
+        root->processing_instructions[i+1];
+      root->processing_instructions[i+1]=(char **) NULL;
+      root->processing_instructions[i][2]=ConstantString("");
     }
   j=1;
   while (root->processing_instructions[i][j] != (char *) NULL)
@@ -1726,14 +1779,14 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
   /*
     Convert xml-string to UTF8.
   */
-  length=strlen(xml);
-  if (length == 0)
+  if ((xml == (const char *) NULL) || (strlen(xml) == 0))
     {
       (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
         "ParseError","root tag missing");
       return((XMLTreeInfo *) NULL);
     }
   root=(XMLTreeRoot *) NewXMLTreeTag((char *) NULL);
+  length=strlen(xml);
   utf8=ConvertUTF16ToUTF8(xml,&length);
   if (utf8 == (char *) NULL)
     {
@@ -2249,12 +2302,13 @@ MagickExport XMLTreeInfo *SetXMLTreeAttribute(XMLTreeInfo *xml_info,
     xml_info->attributes[i]=DestroyString(
       xml_info->attributes[i]);
   (void) CopyMagickMemory(xml_info->attributes+i,xml_info->attributes+i+2,
-    (size_t) (j-i+2)*sizeof(*xml_info->attributes));
+    (size_t) (j-i)*sizeof(*xml_info->attributes));
   xml_info->attributes=(char **) ResizeMagickMemory(xml_info->attributes,
     (size_t) (j+2)*sizeof(*xml_info->attributes));
   if (xml_info->attributes == (char **) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
       tag);
+  j-=2;
   (void) CopyMagickMemory(xml_info->attributes[j+1]+(i/2),
     xml_info->attributes[j+1]+(i/2)+1,(size_t) (j/2)-(i/2)*
     sizeof(*xml_info->attributes));
@@ -2439,7 +2493,8 @@ static char *XMLTreeTagToXML(XMLTreeInfo *xml_info,char **source,size_t *length,
     *length+=FormatMagickString(*source+(*length),*max_length,"\"");
     j+=3;
   }
-  *length+=FormatMagickString(*source+(*length),*max_length,">");
+  *length+=FormatMagickString(*source+(*length),*max_length,*xml_info->content ?
+    ">" : "/>");
   if (xml_info->child != (XMLTreeInfo *) NULL)
     *source=XMLTreeTagToXML(xml_info->child,source,length,max_length,0,
       attributes);
@@ -2453,8 +2508,9 @@ static char *XMLTreeTagToXML(XMLTreeInfo *xml_info,char **source,size_t *length,
       if (*source == (char *) NULL)
         return((char *) NULL);
     }
-  *length+=FormatMagickString(*source+(*length),*max_length,"</%s>",
-    xml_info->tag);
+  if (*xml_info->content != '\0')
+    *length+=FormatMagickString(*source+(*length),*max_length,"</%s>",
+     xml_info->tag);
   while ((content[offset] != '\0') && (offset < xml_info->offset))
     offset++;
   if (xml_info->ordered != (XMLTreeInfo *) NULL)
