@@ -71,7 +71,7 @@ int main(int argc,char **argv)
     *text;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   ImageInfo
     *image_info;
@@ -83,26 +83,28 @@ int main(int argc,char **argv)
   register long
     i;
 
-  InitializeMagick(*argv);
-  GetExceptionInfo(&exception);
+  MagickCoreGenesis(*argv,MagickTrue);
+  exception=AcquireExceptionInfo();
   regard_warnings=MagickFalse;
   for (i=1; i < (long) argc; i++)
   {
     option=argv[i];
     if ((strlen(option) == 1) || ((*option != '-') && (*option != '+')))
       continue;
+    if (LocaleCompare("debug",option+1) == 0)
+      (void) SetLogEventMask(argv[++i]);
     if (LocaleCompare("regard-warnings",option+1) == 0)
       regard_warnings=MagickTrue;
   }
   image_info=AcquireImageInfo();
   text=(char *) NULL;
-  status=IdentifyImageCommand(image_info,argc,argv,&text,&exception);
-  if ((status == MagickFalse) || (exception.severity != UndefinedException))
+  status=IdentifyImageCommand(image_info,argc,argv,&text,exception);
+  if ((status == MagickFalse) || (exception->severity != UndefinedException))
     {
-      if ((exception.severity < ErrorException) &&
+      if ((exception->severity < ErrorException) &&
           (regard_warnings == MagickFalse))
         status=MagickTrue;
-      CatchException(&exception);
+      CatchException(exception);
     }
   if (text != (char *) NULL)
     {
@@ -111,7 +113,7 @@ int main(int argc,char **argv)
       text=DestroyString(text);
     }
   image_info=DestroyImageInfo(image_info);
-  (void) DestroyExceptionInfo(&exception);
-  DestroyMagick();
+  exception=DestroyExceptionInfo(exception);
+  MagickCoreTerminus();
   return(status == MagickFalse ? 1 : 0);
 }
