@@ -783,7 +783,8 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
         case RootMeanSquaredErrorMetric:
         case PeakAbsoluteErrorMetric:
         {
-          (void) fprintf(stderr,"%g (%g)\n",distortion,QuantumScale*distortion);
+          (void) fprintf(stderr,"%g (%g)\n",distortion,(double) (QuantumScale*
+            distortion));
           break;
         }
         case AbsoluteErrorMetric:
