@@ -105,11 +105,11 @@ typedef struct _CompositeOptions
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
-  Image *composite_image,CompositeOptions *option_info,ExceptionInfo *exception)
+  Image *composite_image,CompositeOptions *composite_options,
+  ExceptionInfo *exception)
 {
   MagickStatusType
     status;
@@ -125,30 +125,30 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
   if (composite_image != (Image *) NULL)
     {
       assert(composite_image->signature == MagickSignature);
-      if (option_info->compose == BlendCompositeOp)
+      if (composite_options->compose == BlendCompositeOp)
         (void) CloneString(&composite_image->geometry,
-          option_info->blend_geometry);
-      if (option_info->compose == DisplaceCompositeOp)
+          composite_options->blend_geometry);
+      if (composite_options->compose == DisplaceCompositeOp)
         (void) CloneString(&composite_image->geometry,
-          option_info->displace_geometry);
-      if (option_info->compose == DissolveCompositeOp)
+          composite_options->displace_geometry);
+      if (composite_options->compose == DissolveCompositeOp)
         (void) CloneString(&composite_image->geometry,
-          option_info->dissolve_geometry);
-      if (option_info->compose == ModulateCompositeOp)
+          composite_options->dissolve_geometry);
+      if (composite_options->compose == ModulateCompositeOp)
         (void) CloneString(&composite_image->geometry,
-          option_info->watermark_geometry);
-      if (option_info->compose == ThresholdCompositeOp)
+          composite_options->watermark_geometry);
+      if (composite_options->compose == ThresholdCompositeOp)
         (void) CloneString(&composite_image->geometry,
-          option_info->unsharp_geometry);
+          composite_options->unsharp_geometry);
       /*
         Composite image.
       */
-      if (option_info->stegano != 0)
+      if (composite_options->stegano != 0)
         {
           Image
             *stegano_image;
 
-          (*image)->offset=option_info->stegano-1;
+          (*image)->offset=composite_options->stegano-1;
           stegano_image=SteganoImage(*image,composite_image,exception);
           if (stegano_image != (Image *) NULL)
             {
@@ -157,7 +157,7 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
             }
         }
       else
-        if (option_info->stereo != MagickFalse)
+        if (composite_options->stereo != MagickFalse)
           {
             Image
               *stereo_image;
@@ -170,7 +170,7 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
               }
           }
         else
-          if (option_info->tile != MagickFalse)
+          if (composite_options->tile != MagickFalse)
             {
               long
                 x,
@@ -187,8 +187,9 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
               columns=composite_image->columns;
               for (y=0; y < (long) (*image)->rows; y+=composite_image->rows)
                 for (x=0; x < (long) (*image)->columns; x+=columns)
-                  status&=CompositeImageChannel(*image,option_info->channel,
-                    option_info->compose,composite_image,x,y);
+                  status&=CompositeImageChannel(*image,
+                    composite_options->channel,composite_options->compose,
+                    composite_image,x,y);
               GetImageException(*image,exception);
             }
           else
@@ -203,14 +204,16 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
                 Digitally composite image.
               */
               SetGeometry(*image,&geometry);
-              (void) ParseAbsoluteGeometry(option_info->geometry,&geometry);
+              (void) ParseAbsoluteGeometry(composite_options->geometry,
+                &geometry);
               (void) FormatMagickString(composite_geometry,MaxTextExtent,
                 "%lux%lu%+ld%+ld",composite_image->columns,
                 composite_image->rows,geometry.x,geometry.y);
-              (*image)->gravity=(GravityType) option_info->gravity;
+              (*image)->gravity=(GravityType) composite_options->gravity;
               (void) ParseGravityGeometry(*image,composite_geometry,&geometry);
-              status&=CompositeImageChannel(*image,option_info->channel,
-                option_info->compose,composite_image,geometry.x,geometry.y);
+              status&=CompositeImageChannel(*image,composite_options->channel,
+                composite_options->compose,composite_image,geometry.x,
+                geometry.y);
               GetImageException(*image,exception);
             }
     }
@@ -293,6 +296,7 @@ static void CompositeUsage(void)
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-size geometry       width and height of image",
       "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-transparent-color color",
@@ -330,26 +334,33 @@ static void CompositeUsage(void)
   exit(0);
 }
 
-static void RelinquishCompositeOptions(CompositeOptions *option_info)
+static void GetCompositeOptions(CompositeOptions *composite_options)
 {
-  if (option_info->blend_geometry != (char *) NULL)
-    option_info->blend_geometry=(char *)
-      RelinquishMagickMemory(option_info->blend_geometry);
-  if (option_info->displace_geometry != (char *) NULL)
-    option_info->displace_geometry=(char *)
-      RelinquishMagickMemory(option_info->displace_geometry);
-  if (option_info->dissolve_geometry != (char *) NULL)
-    option_info->dissolve_geometry=(char *)
-      RelinquishMagickMemory(option_info->dissolve_geometry);
-  if (option_info->geometry != (char *) NULL)
-    option_info->geometry=(char *)
-      RelinquishMagickMemory(option_info->geometry);
-  if (option_info->unsharp_geometry != (char *) NULL)
-    option_info->unsharp_geometry=(char *)
-      RelinquishMagickMemory(option_info->unsharp_geometry);
-  if (option_info->watermark_geometry != (char *) NULL)
-    option_info->watermark_geometry=(char *)
-      RelinquishMagickMemory(option_info->watermark_geometry);
+  (void) ResetMagickMemory(composite_options,0,sizeof(*composite_options));
+  composite_options->channel=DefaultChannels;
+  composite_options->compose=OverCompositeOp;
+}
+
+static void RelinquishCompositeOptions(CompositeOptions *composite_options)
+{
+  if (composite_options->blend_geometry != (char *) NULL)
+    composite_options->blend_geometry=(char *)
+      RelinquishMagickMemory(composite_options->blend_geometry);
+  if (composite_options->displace_geometry != (char *) NULL)
+    composite_options->displace_geometry=(char *)
+      RelinquishMagickMemory(composite_options->displace_geometry);
+  if (composite_options->dissolve_geometry != (char *) NULL)
+    composite_options->dissolve_geometry=(char *)
+      RelinquishMagickMemory(composite_options->dissolve_geometry);
+  if (composite_options->geometry != (char *) NULL)
+    composite_options->geometry=(char *)
+      RelinquishMagickMemory(composite_options->geometry);
+  if (composite_options->unsharp_geometry != (char *) NULL)
+    composite_options->unsharp_geometry=(char *)
+      RelinquishMagickMemory(composite_options->unsharp_geometry);
+  if (composite_options->watermark_geometry != (char *) NULL)
+    composite_options->watermark_geometry=(char *)
+      RelinquishMagickMemory(composite_options->watermark_geometry);
 }
 
 WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
@@ -358,7 +369,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
 #define NotInitialized  (unsigned int) (~0)
 #define DestroyComposite() \
 { \
-  RelinquishCompositeOptions(&option_info); \
+  RelinquishCompositeOptions(&composite_options); \
   for ( ; k >= 0; k--) \
     image_stack[k]=DestroyImageList(image_stack[k]); \
   for (i=0; i < (long) argc; i++) \
@@ -385,7 +396,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
     *option;
 
   CompositeOptions
-    option_info;
+    composite_options;
 
   const char
     *format;
@@ -432,8 +443,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
     }
   if (argc < 4)
     CompositeUsage();
-  (void) ResetMagickMemory(&option_info,0,sizeof(CompositeOptions));
-  option_info.compose=OverCompositeOp;
+  GetCompositeOptions(&composite_options);
   filename=(char *) NULL;
   format="%w,%h,%m";
   j=1;
@@ -546,7 +556,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("blend",option+1) == 0)
           {
-            (void) CloneString(&option_info.blend_geometry,(char *) NULL);
+            (void) CloneString(&composite_options.blend_geometry,(char *) NULL);
             if (*option == '+')
               break;
             i++;
@@ -554,8 +564,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            (void) CloneString(&option_info.blend_geometry,argv[i]);
-            option_info.compose=BlendCompositeOp;
+            (void) CloneString(&composite_options.blend_geometry,argv[i]);
+            composite_options.compose=BlendCompositeOp;
             break;
           }
         if (LocaleCompare("blue-primary",option+1) == 0)
@@ -591,7 +601,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
 
             if (*option == '+')
               {
-                option_info.channel=DefaultChannels;
+                composite_options.channel=DefaultChannels;
                 break;
               }
             i++;
@@ -601,7 +611,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             if (channel < 0)
               ThrowCompositeException(OptionError,"UnrecognizedChannelType",
                 argv[i]);
-            option_info.channel=(ChannelType) channel;
+            composite_options.channel=(ChannelType) channel;
             break;
           }
         if (LocaleCompare("colors",option+1) == 0)
@@ -646,7 +656,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             long
               compose;
 
-            option_info.compose=UndefinedCompositeOp;
+            composite_options.compose=UndefinedCompositeOp;
             if (*option == '+')
               break;
             i++;
@@ -657,7 +667,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             if (compose < 0)
               ThrowCompositeException(OptionError,
                 "UnrecognizedComposeOperator",argv[i]);
-            option_info.compose=(CompositeOperator) compose;
+            composite_options.compose=(CompositeOperator) compose;
             break;
           }
         if (LocaleCompare("compress",option+1) == 0)
@@ -739,7 +749,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("displace",option+1) == 0)
           {
-            (void) CloneString(&option_info.displace_geometry,(char *) NULL);
+            (void) CloneString(&composite_options.displace_geometry,
+              (char *) NULL);
             if (*option == '+')
               break;
             i++;
@@ -747,8 +758,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            (void) CloneString(&option_info.displace_geometry,argv[i]);
-            option_info.compose=DisplaceCompositeOp;
+            (void) CloneString(&composite_options.displace_geometry,argv[i]);
+            composite_options.compose=DisplaceCompositeOp;
             break;
           }
         if (LocaleCompare("display",option+1) == 0)
@@ -778,7 +789,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("dissolve",option+1) == 0)
           {
-            (void) CloneString(&option_info.dissolve_geometry,(char *) NULL);
+            (void) CloneString(&composite_options.dissolve_geometry,
+              (char *) NULL);
             if (*option == '+')
               break;
             i++;
@@ -786,8 +798,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            (void) CloneString(&option_info.dissolve_geometry,argv[i]);
-            option_info.compose=DissolveCompositeOp;
+            (void) CloneString(&composite_options.dissolve_geometry,argv[i]);
+            composite_options.compose=DissolveCompositeOp;
             break;
           }
         if (LocaleCompare("dither",option+1) == 0)
@@ -879,7 +891,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("geometry",option+1) == 0)
           {
-            (void) CloneString(&option_info.geometry,(char *) NULL);
+            (void) CloneString(&composite_options.geometry,(char *) NULL);
             if (*option == '+')
               break;
             i++;
@@ -887,7 +899,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            (void) CloneString(&option_info.geometry,argv[i]);
+            (void) CloneString(&composite_options.geometry,argv[i]);
             break;
           }
         if (LocaleCompare("gravity",option+1) == 0)
@@ -895,7 +907,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             long
               gravity;
 
-            option_info.gravity=UndefinedGravity;
+            composite_options.gravity=UndefinedGravity;
             if (*option == '+')
               break;
             i++;
@@ -906,7 +918,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             if (gravity < 0)
               ThrowCompositeException(OptionError,"UnrecognizedGravityType",
                 argv[i]);
-            option_info.gravity=(GravityType) gravity;
+            composite_options.gravity=(GravityType) gravity;
             break;
           }
         if (LocaleCompare("green-primary",option+1) == 0)
@@ -1169,6 +1181,26 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowCompositeInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("sharpen",option+1) == 0)
           {
             i++;
@@ -1191,7 +1223,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("stegano",option+1) == 0)
           {
-            option_info.stegano=0;
+            composite_options.stegano=0;
             if (*option == '+')
               break;
             i++;
@@ -1199,12 +1231,13 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            option_info.stegano=atol(argv[i])+1;
+            composite_options.stegano=atol(argv[i])+1;
             break;
           }
         if (LocaleCompare("stereo",option+1) == 0)
           {
-            option_info.stereo=(*option == '-') ? MagickTrue : MagickFalse;
+            composite_options.stereo=(*option == '-') ? MagickTrue :
+              MagickFalse;
             break;
           }
         if (LocaleCompare("strip",option+1) == 0)
@@ -1237,7 +1270,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("tile",option+1) == 0)
           {
-            option_info.tile=(*option == '-') ? MagickTrue : MagickFalse;
+            composite_options.tile=(*option == '-') ? MagickTrue : MagickFalse;
             (void) CopyMagickString(argv[i]+1,"sans0",MaxTextExtent);
             break;
           }
@@ -1302,7 +1335,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("unsharp",option+1) == 0)
           {
-            (void) CloneString(&option_info.unsharp_geometry,(char *) NULL);
+            (void) CloneString(&composite_options.unsharp_geometry,
+              (char *) NULL);
             if (*option == '+')
               break;
             i++;
@@ -1310,8 +1344,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            (void) CloneString(&option_info.unsharp_geometry,argv[i]);
-            option_info.compose=ThresholdCompositeOp;
+            (void) CloneString(&composite_options.unsharp_geometry,argv[i]);
+            composite_options.compose=ThresholdCompositeOp;
             break;
           }
         ThrowCompositeException(OptionError,"UnrecognizedOption",option)
@@ -1351,7 +1385,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("watermark",option+1) == 0)
           {
-            (void) CloneString(&option_info.watermark_geometry,(char *) NULL);
+            (void) CloneString(&composite_options.watermark_geometry,
+              (char *) NULL);
             if (*option == '+')
               break;
             i++;
@@ -1359,8 +1394,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
-            (void) CloneString(&option_info.watermark_geometry,argv[i]);
-            option_info.compose=ModulateCompositeOp;
+            (void) CloneString(&composite_options.watermark_geometry,argv[i]);
+            composite_options.compose=ModulateCompositeOp;
             break;
           }
         if (LocaleCompare("white-point",option+1) == 0)
@@ -1414,8 +1449,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       image->mask=mask_image;
       (void) NegateImage(image->mask,MagickFalse);
     }
-  status&=CompositeImageList(image_info,&image,composite_image,&option_info,
-    exception);
+  status&=CompositeImageList(image_info,&image,composite_image,
+    &composite_options,exception);
   composite_image=DestroyImage(composite_image);
   /*
     Write composite images.
@@ -1442,7 +1477,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       text=DestroyString(text);
     }
   image=DestroyImage(image);
-  RelinquishCompositeOptions(&option_info);
+  RelinquishCompositeOptions(&composite_options);
   DestroyComposite();
   return(status != 0 ? MagickTrue : MagickFalse);
 }
