@@ -144,7 +144,8 @@ static void ConvertUsage(void)
       "-adaptive-blur geometry",
       "                     adaptively blur pixels; decrease effect near edges",
       "-adaptive-resize geometry",
-      "                     adaptively resize image with data dependent triangulation",
+      "                     adaptively resize image with data dependent",
+      "                     triangulation",
       "-adaptive-sharpen geometry",
       "                     adaptively sharpen pixels; increase effect near edges",
       "-annotate geometry text",
@@ -167,13 +168,16 @@ static void ConvertUsage(void)
       "                     apply a convolution kernel to the image",
       "-cycle amount        cycle the image colormap",
       "-despeckle           reduce the speckles within an image",
+      "-distort type coefficients",
+      "                     distort the image",
       "-draw string         annotate the image with a graphic primitive",
       "-edge radius         apply a filter to detect edges in the image",
       "-emboss radius       emboss an image",
       "-enhance             apply a digital filter to enhance a noisy image",
       "-equalize            perform histogram equalization to an image",
       "-evaluate operator value",
-      "                     evaluate an arithmetic, relational, or logical expression",
+      "                     evaluate an arithmetic, relational, or logical",
+      "                     expression",
       "-extent geometry     set the image size",
       "-extract geometry    extract area from image",
       "-flip                flip image vertically",
@@ -203,7 +207,8 @@ static void ConvertUsage(void)
       "-normalize           transform image to span the full range of colors",
       "-opaque color        change this color to the fill color",
       "-ordered-dither NxN",
-      "                     add a noise pattern to the image with specific amplitudes",
+      "                     add a noise pattern to the image with specific",
+      "                     amplitudes",
       "-paint radius        simulate an oil painting",
       "-polaroid angle      simulate a Polaroid picture",
       "-posterize levels    reduce the image to a limited number of color levels",
@@ -234,7 +239,8 @@ static void ConvertUsage(void)
       "-shave geometry      shave pixels from the image edges",
       "-shear geometry      slide one edge of the image along the X or Y axis",
       "-sigmoidal-contrast geometry",
-      "                     lightness rescaling using sigmoidal contrast enhancement",
+      "                     lightness rescaling using sigmoidal contrast",
+      "                     enhancement",
       "-sketch geometry     simulate a pencil sketch",
       "-solarize threshold  negate all pixels above the threshold level",
       "-splice geometry     splice the background color into the image",
@@ -286,6 +292,7 @@ static void ConvertUsage(void)
       "-affine matrix       affine transform matrix",
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
+      "-attenuate value     lessen (or intensify) when adding noise to an image",
       "-background color    background color",
       "-bias value          add bias when convolving an image",
       "-black-point-compensation",
@@ -1066,6 +1073,27 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 argv[i]);
             break;
           }
+        if (LocaleCompare("distort",option+1) == 0)
+          {
+            long
+              op;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            op=ParseMagickOption(MagickDistortOptions,MagickFalse,argv[i]);
+            if (op < 0)
+              ThrowConvertException(OptionError,"UnrecognizedDistortType",
+                argv[i]);
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("dither",option+1) == 0)
           break;
         if (LocaleCompare("draw",option+1) == 0)
@@ -1145,8 +1173,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             op=ParseMagickOption(MagickEvaluateOptions,MagickFalse,argv[i]);
             if (op < 0)
-              ThrowConvertException(OptionError,
-                "UnrecognizedEvaluateOperator",argv[i]);
+              ThrowConvertException(OptionError,"UnrecognizedEvaluateOperator",
+                argv[i]);
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
