@@ -197,25 +197,6 @@ extern WandExport void
   DrawSkewY(DrawingWand *,const double),
   DrawTranslate(DrawingWand *,const double,const double);
 
-/*
-  Deprecated.
-*/
-typedef struct _DrawingWand
-  *DrawContext;
-
-extern WandExport double
-  DrawGetFillAlpha(const DrawingWand *),
-  DrawGetStrokeAlpha(const DrawingWand *);
-
-extern WandExport DrawInfo
-  *DrawPeekGraphicWand(const DrawingWand *);
-
-extern WandExport void
-  DrawPopGraphicContext(DrawingWand *),
-  DrawPushGraphicContext(DrawingWand *),
-  DrawSetFillAlpha(DrawingWand *,const double),
-  DrawSetStrokeAlpha(DrawingWand *,const double);
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
