@@ -381,7 +381,7 @@ int main ( int argc, char **argv )
   int rows, columns = 0;
   char size[MaxTextExtent];
   ImageInfo *image_info;
-  ExceptionInfo exception;
+  ExceptionInfo *exception;
 
   if ( argc != 2 )
     {
@@ -392,23 +392,23 @@ int main ( int argc, char **argv )
   (void) CopyMagickString( outfile, argv[1], MaxTextExtent );
 
   if (LocaleNCompare("drawtest",argv[0],7) == 0)
-    InitializeMagick((char *) NULL);
+    MagickCoreGenesis((char *) NULL,MagickTrue);
   else
-    InitializeMagick(*argv);
+    MagickCoreGenesis(*argv,MagickTrue);
 
   /*
    * Create canvas image
    */
   columns=596;
   rows=842;
-  image_info=CloneImageInfo((ImageInfo*)NULL);
-  GetExceptionInfo( &exception );
+  image_info=CloneImageInfo((ImageInfo*) NULL);
+  exception=AcquireExceptionInfo();
   (void) FormatMagickString(size, MaxTextExtent, "%dx%d", columns, rows);
   (void) CloneString(&image_info->size,size);
   (void) CopyMagickString(image_info->filename,"xc:white",MaxTextExtent);
-  canvas=ReadImage ( image_info, &exception );
-  if (exception.severity >= ErrorException)
-    CatchException(&exception);
+  canvas=ReadImage(image_info,exception );
+  if (exception->severity >= ErrorException)
+    CatchException(exception);
   if ( canvas == (Image *)NULL )
     {
       (void) printf ( "Failed to read canvas image %s\n",image_info->filename);
@@ -423,13 +423,12 @@ int main ( int argc, char **argv )
   /*
    * Save image to file
    */
-  (void) CopyMagickString(canvas->filename,outfile,
-    sizeof(image_info->filename));
+  (void) CopyMagickString(canvas->filename,outfile,MaxTextExtent);
   (void) WriteImage ( image_info, canvas );
 
-  (void) DestroyExceptionInfo( &exception );
+  exception=DestroyExceptionInfo(exception);
    canvas =DestroyImage( canvas );
    image_info =DestroyImageInfo( image_info );
-  DestroyMagick();
+  MagickCoreTerminus();
   return 0;
 }
