@@ -82,7 +82,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static void IdentifyUsage(void)
@@ -96,6 +95,7 @@ static void IdentifyUsage(void)
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
       "-channel type        apply option to select image channels",
+      "-colorspace type     alternate image colorspace",
       "-crop geometry       cut out a rectangular region of the image",
       "-debug events        display copious debugging information",
       "-define format:option",
@@ -119,6 +119,7 @@ static void IdentifyUsage(void)
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-set attribute value set an image attribute",
       "-size geometry       width and height of image",
       "-strip               strip image of all profiles and comments",
@@ -372,6 +373,23 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
                 argv[i]);
             break;
           }
+        if (LocaleCompare("colorspace",option+1) == 0)
+          {
+            long
+              colorspace;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            colorspace=ParseMagickOption(MagickColorspaceOptions,
+              MagickFalse,argv[i]);
+            if (colorspace < 0)
+              ThrowIdentifyException(OptionError,"UnrecognizedColorspace",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("crop",option+1) == 0)
           {
             if (*option == '+')
@@ -404,7 +422,6 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
                 argv[i]);
             (void) SetLogEventMask(argv[i]);
             break;
-            break;
           }
         if (LocaleCompare("define",option+1) == 0)
           {
@@ -613,6 +630,26 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
               ThrowIdentifyInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowIdentifyInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("set",option+1) == 0)
           {
             i++;
