@@ -164,6 +164,7 @@ static void ImportUsage(void)
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
       "-screen              select image from root window",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-set property value  set an image property",
       "-silent              operate silently, i.e. don't ring any bells ",
       "-snaps value         number of screen snapshots",
@@ -1072,6 +1073,26 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             ximage_info.screen=(*option == '-') ? MagickTrue : MagickFalse;
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowImportException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowImportInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("silent",option+1) == 0)
           {
             ximage_info.silent=(*option == '-') ? MagickTrue : MagickFalse;
