@@ -91,8 +91,6 @@ extern WandExport MagickBooleanType
     const long,const long),
   MagickClipImage(MagickWand *),
   MagickClipPathImage(MagickWand *,const char *,const MagickBooleanType),
-  MagickColorFloodfillImage(MagickWand *,const PixelWand *,const double,
-    const PixelWand *,const long,const long),
   MagickColorizeImage(MagickWand *,const PixelWand *,const PixelWand *),
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
@@ -110,9 +108,12 @@ extern WandExport MagickBooleanType
   MagickCropImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickCycleColormapImage(MagickWand *,const long),
+  MagickDeleteImageProperty(MagickWand *,const char *),
   MagickDespeckleImage(MagickWand *),
   MagickDisplayImage(MagickWand *,const char *),
   MagickDisplayImages(MagickWand *,const char *),
+  MagickDistortImage(MagickWand *,const DistortImageMethod,const unsigned long,
+    const double *),
   MagickDrawImage(MagickWand *,const DrawingWand *),
   MagickEdgeImage(MagickWand *,const double),
   MagickEmbossImage(MagickWand *,const double,const double),
@@ -139,11 +140,9 @@ extern WandExport MagickBooleanType
     const ChannelType, const MetricType,double *),
   MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
     double *),
-  MagickGetImageChannelExtrema(MagickWand *,const ChannelType,unsigned long *,
-    unsigned long *),
   MagickGetImageChannelMean(MagickWand *,const ChannelType,double *,double *),
+  MagickGetImageChannelRange(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageColormapColor(MagickWand *,const unsigned long,PixelWand *),
-  MagickGetImageExtrema(MagickWand *,unsigned long *,unsigned long *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatte(MagickWand *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
@@ -153,6 +152,7 @@ extern WandExport MagickBooleanType
   MagickGetImagePixelColor(MagickWand *,const long,const long,PixelWand *),
   MagickGetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,void *),
+  MagickGetImageRange(MagickWand *,double *,double *),
   MagickGetImageRedPrimary(MagickWand *,double *,double *),
   MagickGetImageResolution(MagickWand *,double *,double *),
   MagickGetImageWhitePoint(MagickWand *,double *,double *),
@@ -166,8 +166,6 @@ extern WandExport MagickBooleanType
   MagickLinearStretchImage(MagickWand *,const double,const double),
   MagickMagnifyImage(MagickWand *),
   MagickMapImage(MagickWand *,const MagickWand *,const MagickBooleanType),
-  MagickMatteFloodfillImage(MagickWand *,const double,const double,
-    const PixelWand *,const long,const long),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
   MagickModulateImage(MagickWand *,const double,const double,const double),
@@ -184,6 +182,8 @@ extern WandExport MagickBooleanType
   MagickOrderedPosterizeImage(MagickWand *,const char *),
   MagickOrderedPosterizeImageChannel(MagickWand *,const ChannelType,
     const char *),
+  MagickPaintFloodfillImage(MagickWand *,const ChannelType,const PixelWand *,
+    const double,const PixelWand *,const long,const long),
   MagickPaintOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
     const double),
   MagickPaintOpaqueImageChannel(MagickWand *,const ChannelType,
@@ -268,7 +268,7 @@ extern WandExport MagickBooleanType
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
   MagickSetImageScene(MagickWand *,const unsigned long),
-  MagickSetImageTicksPerSecond(MagickWand *,const unsigned long),
+  MagickSetImageTicksPerSecond(MagickWand *,const long),
   MagickSetImageType(MagickWand *,const ImageType),
   MagickSetImageUnits(MagickWand *,const ResolutionType),
   MagickSetImageWhitePoint(MagickWand *,const double,const double),
@@ -381,38 +381,6 @@ extern WandExport unsigned long
 extern WandExport VirtualPixelMethod
   MagickGetImageVirtualPixelMethod(MagickWand *);
 
-/*
-  Deprecated methods.
-*/
-extern WandExport char
-  *MagickDescribeImage(MagickWand *),
-  *MagickGetImageAttribute(MagickWand *,const char *);
-
-extern WandExport long
-  MagickGetImageIndex(MagickWand *);
-
-extern WandExport MagickBooleanType
-  MagickOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
-    const double),
-  MagickSetImageAttribute(MagickWand *,const char *,const char *),
-  MagickSetImageIndex(MagickWand *,const long),
-  MagickSetImageOption(MagickWand *,const char *,const char *,const char *),
-  MagickTransparentImage(MagickWand *,const PixelWand *,const double,
-    const double);
-
-extern WandExport MagickWand
-  *MagickRegionOfInterestImage(MagickWand *,const unsigned long,
-    const unsigned long,const long,const long);
-
-extern WandExport MagickSizeType
-  MagickGetImageSize(MagickWand *);
-
-extern WandExport unsigned char
-  *MagickWriteImageBlob(MagickWand *,size_t *);
-
-extern WandExport VirtualPixelMethod
-  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod);
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
