@@ -23,7 +23,7 @@
 %                                 August 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -56,7 +56,7 @@
 */
 #define ThrowWandException(severity,tag,context) \
 { \
-  (void) ThrowMagickException(&wand->exception,GetMagickModule(),severity, \
+  (void) ThrowMagickException(wand->exception,GetMagickModule(),severity, \
     tag,"`%s'",context); \
   return(MagickFalse); \
 }
@@ -66,6 +66,41 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k D e l e t e O p t i o n                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickDeleteOption() deletes a wand option.
+%
+%  The format of the MagickDeleteOption method is:
+%
+%      MagickBooleanType MagickDeleteOption(MagickWand *wand,
+%        const char *option)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o option: The image option.
+%
+*/
+WandExport MagickBooleanType MagickDeleteOption(MagickWand *wand,
+  const char *option)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(DeleteImageOption(wand->image_info,option));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t A n t i a l i a s                                       %
 %                                                                             %
 %                                                                             %
@@ -98,13 +133,49 @@ WandExport MagickBooleanType MagickGetAntialias(const MagickWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t B a c k g r o u n d C o l o r                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetBackgroundColor() returns the wand background color.
+%
+%  The format of the MagickGetBackgroundColor method is:
+%
+%      PixelWand *MagickGetBackgroundColor(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport PixelWand *MagickGetBackgroundColor(MagickWand *wand)
+{
+  PixelWand
+    *background_color;
+
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  background_color=NewPixelWand();
+  PixelSetQuantumColor(background_color,&wand->image_info->background_color);
+  return(background_color);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t C o m p r e s s i o n                                   %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  MagickGetCompression() gets the wand compression.
+%  MagickGetCompression() gets the wand compression type.
 %
 %  The format of the MagickGetCompression method is:
 %
@@ -214,23 +285,23 @@ WandExport char *MagickGetException(MagickWand *wand,ExceptionType *severity)
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
   assert(severity != (ExceptionType *) NULL);
-  *severity=wand->exception.severity;
+  *severity=wand->exception->severity;
   description=(char *) AcquireMagickMemory(2*MaxTextExtent);
   if (description == (char *) NULL)
     {
-      (void) ThrowMagickException(&wand->exception,GetMagickModule(),WandError,
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
         "MemoryAllocationFailed","`%s'",wand->name);
       return((char *) NULL);
     }
   *description='\0';
-  if (wand->exception.reason != (char *) NULL)
+  if (wand->exception->reason != (char *) NULL)
     (void) CopyMagickString(description,GetLocaleExceptionMessage(
-      wand->exception.severity,wand->exception.reason),MaxTextExtent);
-  if (wand->exception.description != (char *) NULL)
+      wand->exception->severity,wand->exception->reason),MaxTextExtent);
+  if (wand->exception->description != (char *) NULL)
     {
       (void) ConcatenateMagickString(description," (",MaxTextExtent);
       (void) ConcatenateMagickString(description,GetLocaleExceptionMessage(
-        wand->exception.severity,wand->exception.description),MaxTextExtent);
+        wand->exception->severity,wand->exception->description),MaxTextExtent);
       (void) ConcatenateMagickString(description,")",MaxTextExtent);
     }
   return(description);
@@ -327,6 +398,37 @@ WandExport char *MagickGetHomeURL(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t T y p e                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetType() returns the wand type.
+%
+%  The format of the MagickGetType method is:
+%
+%      ImageType MagickGetType(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport ImageType MagickGetType(MagickWand *wand)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(wand->image_info->type);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t I n t e r l a c e S c h e m e                           %
 %                                                                             %
 %                                                                             %
@@ -439,6 +541,37 @@ WandExport char *MagickGetOption(MagickWand *wand,const char *key)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t O r i e n t a t i o n                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetOrientation() gets the wand orientation type.
+%
+%  The format of the MagickGetOrientation method is:
+%
+%      OrientationType MagickGetOrientation(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport OrientationType MagickGetOrientation(MagickWand *wand)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(wand->image_info->orientation);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t P a c k a g e N a m e                                   %
 %                                                                             %
 %                                                                             %
@@ -1086,10 +1219,10 @@ WandExport MagickBooleanType MagickSetFormat(MagickWand *wand,
       *wand->image_info->magick='\0';
       return(MagickTrue);
     }
-  magick_info=GetMagickInfo(format,&wand->exception);
+  magick_info=GetMagickInfo(format,wand->exception);
   if (magick_info == (const MagickInfo *) NULL)
     return(MagickFalse);
-  ClearMagickException(&wand->exception);
+  ClearMagickException(wand->exception);
   (void) CopyMagickString(wand->image_info->magick,format,MaxTextExtent);
   return(MagickTrue);
 }
@@ -1214,6 +1347,42 @@ WandExport MagickBooleanType MagickSetOption(MagickWand *wand,const char *key,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k S e t O r i e n t a t i o n                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickSetOrientation() sets the wand orientation type.
+%
+%  The format of the MagickSetOrientation method is:
+%
+%      MagickBooleanType MagickSetOrientation(MagickWand *wand,
+%        const OrientationType orientation)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o orientation: The wand orientation.
+%
+*/
+WandExport MagickBooleanType MagickSetOrientation(MagickWand *wand,
+  const OrientationType orientation)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  wand->image_info->orientation=orientation;
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k S e t P a g e                                                 %
 %                                                                             %
 %                                                                             %
@@ -1508,7 +1677,6 @@ WandExport MagickBooleanType MagickSetSamplingFactors(MagickWand *wand,
 %
 %    o rows: The rows in pixels.
 %
-%
 */
 WandExport MagickBooleanType MagickSetSize(MagickWand *wand,
   const unsigned long columns,const unsigned long rows)
@@ -1605,8 +1773,6 @@ WandExport MagickBooleanType MagickSetType(MagickWand *wand,
   assert(wand->signature == WandSignature);
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
-  if (wand->images == (Image *) NULL)
-    ThrowWandException(WandError,"ContainsNoImages",wand->name);
   wand->image_info->type=image_type;
   return(MagickTrue);
 }
