@@ -24,6 +24,7 @@ extern "C" {
 
 #define DegreesToRadians(x)  (MagickPI*(x)/180.0)
 #define MagickPI  3.14159265358979323846264338327950288419716939937510
+#define MagickWandId  "MagickWand"
 #define QuantumScale  ((MagickRealType) 1.0/(MagickRealType) QuantumRange)
 #define QuantumTick(i,span) ((MagickBooleanType) ((((i) & ((i)-1)) == 0) || \
    (((i) & 0xfff) == 0) || \
@@ -39,7 +40,7 @@ struct _MagickWand
     name[MaxTextExtent];
 
   ExceptionInfo
-    exception;
+    *exception;
 
   ImageInfo
     *image_info;
