@@ -56,11 +56,10 @@
 */
 #define ThrowWandException(severity,tag,context) \
 { \
-  (void) ThrowMagickException(&wand->exception,GetMagickModule(),severity, \
+  (void) ThrowMagickException(wand->exception,GetMagickModule(),severity, \
     tag,"`%s'",context); \
   return(MagickFalse); \
 }
-#define MagickWandId  "MagickWand"
 
 /*
   Global declarations.
@@ -100,10 +99,9 @@ WandExport void ClearMagickWand(MagickWand *wand)
   wand->quantize_info=DestroyQuantizeInfo(wand->quantize_info);
   wand->image_info=DestroyImageInfo(wand->image_info);
   wand->images=DestroyImageList(wand->images);
-  (void) DestroyExceptionInfo(&wand->exception);
   wand->quantize_info=CloneQuantizeInfo((QuantizeInfo *) NULL);
   wand->image_info=AcquireImageInfo();
-  GetExceptionInfo(&wand->exception);
+  ClearMagickException(wand->exception);
   wand->debug=IsEventLogging();
 }
 
@@ -128,7 +126,6 @@ WandExport void ClearMagickWand(MagickWand *wand)
 %
 %    o wand: The magick wand.
 %
-%
 */
 WandExport MagickWand *CloneMagickWand(const MagickWand *wand)
 {
@@ -152,13 +149,13 @@ WandExport MagickWand *CloneMagickWand(const MagickWand *wand)
     }
   (void) ResetMagickMemory(clone_wand,0,sizeof(*clone_wand));
   clone_wand->id=AcquireWandId();
-  (void) FormatMagickString(clone_wand->name,MaxTextExtent,"MagickWand-%lu",
-    clone_wand->id);
-  GetExceptionInfo(&clone_wand->exception);
-  InheritException(&clone_wand->exception,&wand->exception);
+  (void) FormatMagickString(clone_wand->name,MaxTextExtent,"%s-%lu",
+    MagickWandId,clone_wand->id);
+  clone_wand->exception=AcquireExceptionInfo();
+  InheritException(clone_wand->exception,wand->exception);
   clone_wand->image_info=CloneImageInfo(wand->image_info);
   clone_wand->quantize_info=CloneQuantizeInfo(wand->quantize_info);
-  clone_wand->images=CloneImageList(wand->images,&clone_wand->exception);
+  clone_wand->images=CloneImageList(wand->images,clone_wand->exception);
   clone_wand->debug=IsEventLogging();
   if (clone_wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",clone_wand->name);
@@ -198,7 +195,7 @@ WandExport MagickWand *DestroyMagickWand(MagickWand *wand)
   wand->quantize_info=DestroyQuantizeInfo(wand->quantize_info);
   wand->image_info=DestroyImageInfo(wand->image_info);
   wand->images=DestroyImageList(wand->images);
-  (void) DestroyExceptionInfo(&wand->exception);
+  wand->exception=DestroyExceptionInfo(wand->exception);
   RelinquishWandId(wand->id);
   wand->signature=(~WandSignature);
   wand=(MagickWand *) RelinquishMagickMemory(wand);
@@ -266,7 +263,7 @@ WandExport MagickBooleanType MagickClearException(MagickWand *wand)
   assert(wand->signature == WandSignature);
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
-  ClearMagickException(&wand->exception);
+  ClearMagickException(wand->exception);
   return(MagickTrue);
 }
 
@@ -301,7 +298,7 @@ WandExport long MagickGetIteratorIndex(MagickWand *wand)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
   if (wand->images == (Image *) NULL)
     {
-      (void) ThrowMagickException(&wand->exception,GetMagickModule(),WandError,
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
         "ContainsNoIterators","`%s'",wand->name);
       return(-1);
     }
@@ -340,14 +337,14 @@ WandExport char *MagickQueryConfigureOption(const char *option)
     **configure_info;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   unsigned long
     number_options;
 
-  GetExceptionInfo(&exception);
-  configure_info=GetConfigureInfoList(option,&number_options,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  configure_info=GetConfigureInfoList(option,&number_options,exception);
+  exception=DestroyExceptionInfo(exception);
   if (configure_info == (const ConfigureInfo **) NULL)
     return((char *) NULL);
   value=AcquireString(configure_info[0]->value);
@@ -391,11 +388,11 @@ WandExport char **MagickQueryConfigureOptions(const char *pattern,
     **options;
 
   ExceptionInfo
-    exception;
+    *exception;
 
-  GetExceptionInfo(&exception);
-  options=GetConfigureList(pattern,number_options,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  options=GetConfigureList(pattern,number_options,exception);
+  exception=DestroyExceptionInfo(exception);
   return(options);
 }
 
@@ -465,7 +462,7 @@ WandExport double *MagickQueryFontMetrics(MagickWand *wand,
   assert(drawing_wand != (const DrawingWand *) NULL);
   if (wand->images == (Image *) NULL)
     {
-      (void) ThrowMagickException(&wand->exception,GetMagickModule(),WandError,
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
         "ContainsNoImages","`%s'",wand->name);
       return((double *) NULL);
     }
@@ -484,7 +481,7 @@ WandExport double *MagickQueryFontMetrics(MagickWand *wand,
   draw_info=DestroyDrawInfo(draw_info);
   if (status == MagickFalse)
     {
-      InheritException(&wand->exception,&wand->images->exception);
+      InheritException(wand->exception,&wand->images->exception);
       font_metrics=(double *) RelinquishMagickMemory(font_metrics);
       return((double *) NULL);
     }
@@ -573,11 +570,11 @@ WandExport double *MagickQueryMultilineFontMetrics(MagickWand *wand,
   assert(drawing_wand != (const DrawingWand *) NULL);
   if (wand->images == (Image *) NULL)
     {
-      (void) ThrowMagickException(&wand->exception,GetMagickModule(),WandError,
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
         "ContainsNoImages","`%s'",wand->name);
       return((double *) NULL);
     }
-  font_metrics=(double *) AcquireMagickMemory(7*sizeof(*font_metrics));
+  font_metrics=(double *) AcquireMagickMemory(13*sizeof(*font_metrics));
   if (font_metrics == (double *) NULL)
     return((double *) NULL);
   draw_info=PeekDrawingWand(drawing_wand);
@@ -592,7 +589,7 @@ WandExport double *MagickQueryMultilineFontMetrics(MagickWand *wand,
   draw_info=DestroyDrawInfo(draw_info);
   if (status == MagickFalse)
     {
-      InheritException(&wand->exception,&wand->images->exception);
+      InheritException(wand->exception,&wand->images->exception);
       font_metrics=(double *) RelinquishMagickMemory(font_metrics);
       return((double *) NULL);
     }
@@ -645,11 +642,11 @@ WandExport char **MagickQueryFonts(const char *pattern,
     **fonts;
 
   ExceptionInfo
-    exception;
+    *exception;
 
-  GetExceptionInfo(&exception);
-  fonts=GetTypeList(pattern,number_fonts,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  fonts=GetTypeList(pattern,number_fonts,exception);
+  exception=DestroyExceptionInfo(exception);
   return(fonts);
 }
 
@@ -679,7 +676,6 @@ WandExport char **MagickQueryFonts(const char *pattern,
 %    o number_formats:  This integer returns the number of image formats in the
 %      list.
 %
-%
 */
 WandExport char **MagickQueryFormats(const char *pattern,
   unsigned long *number_formats)
@@ -688,11 +684,11 @@ WandExport char **MagickQueryFormats(const char *pattern,
     **formats;
 
   ExceptionInfo
-    exception;
+    *exception;
 
-  GetExceptionInfo(&exception);
-  formats=GetMagickList(pattern,number_formats,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  formats=GetMagickList(pattern,number_formats,exception);
+  exception=DestroyExceptionInfo(exception);
   return(formats);
 }
 
@@ -835,7 +831,7 @@ WandExport MagickBooleanType MagickSetIteratorIndex(MagickWand *wand,
   image=GetImageFromList(wand->images,index);
   if (image == (Image *) NULL)
     {
-      InheritException(&wand->exception,&wand->images->exception);
+      InheritException(wand->exception,&wand->images->exception);
       return(MagickFalse);
     }
   wand->active=MagickTrue;
@@ -970,7 +966,7 @@ WandExport MagickWand *NewMagickWand(void)
   wand->id=AcquireWandId();
   (void) FormatMagickString(wand->name,MaxTextExtent,"%s-%lu",MagickWandId,
     wand->id);
-  GetExceptionInfo(&wand->exception);
+  wand->exception=AcquireExceptionInfo();
   wand->image_info=AcquireImageInfo();
   wand->quantize_info=CloneQuantizeInfo((QuantizeInfo *) NULL);
   wand->images=NewImageList();
@@ -1009,6 +1005,6 @@ WandExport MagickWand *NewMagickWandFromImage(const Image *image)
     *wand;
 
   wand=NewMagickWand();
-  wand->images=CloneImage(image,0,0,MagickTrue,&wand->exception);
+  wand->images=CloneImage(image,0,0,MagickTrue,wand->exception);
   return(wand);
 }
