@@ -76,7 +76,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static void MontageUsage(void)
@@ -165,6 +164,7 @@ static void MontageUsage(void)
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-set attribute value set an image attribute",
       "-shadow              add a shadow beneath a tile to simulate depth",
       "-size geometry       width and height of image",
@@ -1262,6 +1262,26 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowMontageInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("scenes",option+1) == 0)
           {
             first_scene=0;
@@ -1392,6 +1412,17 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             (void) CloneString(&montage_info->tile,argv[i]);
             break;
           }
+        if (LocaleCompare("tile-offset",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowMontageInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("tint",option+1) == 0)
           {
             if (*option == '+')
