@@ -70,7 +70,7 @@ struct _PixelIterator
     name[MaxTextExtent];
 
   ExceptionInfo
-    exception;
+    *exception;
 
   ViewInfo
     *view;
@@ -85,7 +85,7 @@ struct _PixelIterator
     y;
 
   PixelWand
-    **pixel_wand;
+    **pixel_wands;
 
   MagickBooleanType
     debug;
@@ -122,11 +122,10 @@ WandExport void ClearPixelIterator(PixelIterator *iterator)
   assert(iterator->signature == WandSignature);
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
-  iterator->pixel_wand=DestroyPixelWands(iterator->pixel_wand,
+  iterator->pixel_wands=DestroyPixelWands(iterator->pixel_wands,
     iterator->region.width);
-  (void) DestroyExceptionInfo(&iterator->exception);
-  GetExceptionInfo(&iterator->exception);
-  iterator->pixel_wand=NewPixelWands(iterator->region.width);
+  ClearMagickException(iterator->exception);
+  iterator->pixel_wands=NewPixelWands(iterator->region.width);
   iterator->active=MagickFalse;
   iterator->y=0;
   iterator->debug=IsEventLogging();
@@ -137,6 +136,68 @@ WandExport void ClearPixelIterator(PixelIterator *iterator)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C l o n e P i x e l I t e r a t o r                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ClonePixelIterator() makes an exact copy of the specified iterator.
+%
+%  The format of the ClonePixelIterator method is:
+%
+%      PixelIterator *ClonePixelIterator(const PixelIterator *iterator)
+%
+%  A description of each parameter follows:
+%
+%    o iterator: The magick iterator.
+%
+*/
+WandExport PixelIterator *ClonePixelIterator(const PixelIterator *iterator)
+{
+  PixelIterator
+    *clone_iterator;
+
+  assert(iterator != (PixelIterator *) NULL);
+  assert(iterator->signature == WandSignature);
+  if (iterator->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
+  clone_iterator=(PixelIterator *) AcquireMagickMemory(sizeof(*clone_iterator));
+  if (clone_iterator == (PixelIterator *) NULL)
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=DestroyString(message);
+    }
+  (void) ResetMagickMemory(clone_iterator,0,sizeof(*clone_iterator));
+  clone_iterator->id=AcquireWandId();
+  (void) FormatMagickString(clone_iterator->name,MaxTextExtent,"%s-%lu",
+    PixelIteratorId,clone_iterator->id);
+  clone_iterator->exception=AcquireExceptionInfo();
+  InheritException(clone_iterator->exception,iterator->exception);
+  clone_iterator->view=CloneCacheView(iterator->view);
+  clone_iterator->region=iterator->region;
+  clone_iterator->active=iterator->active;
+  clone_iterator->y=iterator->y;
+  clone_iterator->pixel_wands=ClonePixelWands((const PixelWand **)
+    iterator->pixel_wands,iterator->region.width);
+  clone_iterator->debug=iterator->debug;
+  if (clone_iterator->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",
+      clone_iterator->name);
+  clone_iterator->signature=WandSignature;
+  return(clone_iterator);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y P i x e l I t e r a t o r                                   %
 %                                                                             %
 %                                                                             %
@@ -161,9 +222,9 @@ WandExport PixelIterator *DestroyPixelIterator(PixelIterator *iterator)
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
   iterator->view=CloseCacheView(iterator->view);
-  iterator->pixel_wand=DestroyPixelWands(iterator->pixel_wand,
+  iterator->pixel_wands=DestroyPixelWands(iterator->pixel_wands,
     iterator->region.width);
-  (void) DestroyExceptionInfo(&iterator->exception);
+  iterator->exception=DestroyExceptionInfo(iterator->exception);
   iterator->signature=(~WandSignature);
   RelinquishWandId(iterator->id);
   iterator=(PixelIterator *) RelinquishMagickMemory(iterator);
@@ -273,14 +334,14 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
   iterator->id=AcquireWandId();
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
     PixelIteratorId,iterator->id);
-  GetExceptionInfo(&iterator->exception);
+  iterator->exception=AcquireExceptionInfo();
   iterator->view=view;
   SetGeometry(image,&iterator->region);
   iterator->region.width=image->columns;
   iterator->region.height=image->rows;
   iterator->region.x=0;
   iterator->region.y=0;
-  iterator->pixel_wand=NewPixelWands(iterator->region.width);
+  iterator->pixel_wands=NewPixelWands(iterator->region.width);
   iterator->y=0;
   iterator->debug=IsEventLogging();
   if (iterator->debug != MagickFalse)
@@ -319,7 +380,7 @@ WandExport MagickBooleanType PixelClearIteratorException(
   assert(iterator->signature == WandSignature);
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
-  ClearMagickException(&iterator->exception);
+  ClearMagickException(iterator->exception);
   return(MagickTrue);
 }
 
@@ -396,14 +457,14 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
   iterator->id=AcquireWandId();
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
     PixelIteratorId,iterator->id);
-  GetExceptionInfo(&iterator->exception);
+  iterator->exception=AcquireExceptionInfo();
   iterator->view=view;
   SetGeometry(image,&iterator->region);
   iterator->region.width=columns;
   iterator->region.height=rows;
   iterator->region.x=x;
   iterator->region.y=y;
-  iterator->pixel_wand=NewPixelWands(iterator->region.width);
+  iterator->pixel_wands=NewPixelWands(iterator->region.width);
   iterator->y=0;
   iterator->debug=IsEventLogging();
   if (iterator->debug != MagickFalse)
@@ -441,7 +502,7 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
 WandExport PixelWand **PixelGetCurrentIteratorRow(PixelIterator *iterator,
   unsigned long *number_wands)
 {
-  IndexPacket
+  register const IndexPacket
     *indexes;
 
   register const PixelPacket
@@ -457,22 +518,22 @@ WandExport PixelWand **PixelGetCurrentIteratorRow(PixelIterator *iterator,
   *number_wands=0;
   iterator->active=MagickTrue;
   p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
-    iterator->y,iterator->region.width,1,&iterator->exception);
+    iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
-  indexes=GetCacheViewIndexes(iterator->view);
+  indexes=AcquireCacheViewIndexes(iterator->view);
   for (x=0; x < (long) iterator->region.width; x++)
   {
-    PixelSetQuantumColor(iterator->pixel_wand[x],p);
+    PixelSetQuantumColor(iterator->pixel_wands[x],p);
     if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
-      PixelSetBlackQuantum(iterator->pixel_wand[x],indexes[x]);
+      PixelSetBlackQuantum(iterator->pixel_wands[x],indexes[x]);
     else
       if (GetCacheViewStorageClass(iterator->view) == PseudoClass)
-        PixelSetIndex(iterator->pixel_wand[x],indexes[x]);
+        PixelSetIndex(iterator->pixel_wands[x],indexes[x]);
     p++;
   }
   *number_wands=iterator->region.width;
-  return(iterator->pixel_wand);
+  return(iterator->pixel_wands);
 }
 
 /*
@@ -501,13 +562,6 @@ WandExport PixelWand **PixelGetCurrentIteratorRow(PixelIterator *iterator,
 %    o severity: The severity of the error is returned here.
 %
 */
-
-WandExport char *PixelIteratorGetException(const PixelIterator *iterator,
-  ExceptionType *severity)
-{
-  return(PixelGetIteratorException(iterator,severity));
-}
-
 WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
   ExceptionType *severity)
 {
@@ -519,7 +573,7 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
   assert(severity != (ExceptionType *) NULL);
-  *severity=iterator->exception.severity;
+  *severity=iterator->exception->severity;
   description=(char *) AcquireMagickMemory(2*MaxTextExtent);
   if (description == (char *) NULL)
     {
@@ -532,14 +586,14 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
       message=DestroyString(message);
     }
   *description='\0';
-  if (iterator->exception.reason != (char *) NULL)
+  if (iterator->exception->reason != (char *) NULL)
     (void) CopyMagickString(description,GetLocaleExceptionMessage(
-      iterator->exception.severity,iterator->exception.reason),MaxTextExtent);
-  if (iterator->exception.description != (char *) NULL)
+      iterator->exception->severity,iterator->exception->reason),MaxTextExtent);
+  if (iterator->exception->description != (char *) NULL)
     {
       (void) ConcatenateMagickString(description," (",MaxTextExtent);
       (void) ConcatenateMagickString(description,GetLocaleExceptionMessage(
-        iterator->exception.severity,iterator->exception.description),
+        iterator->exception->severity,iterator->exception->description),
         MaxTextExtent);
       (void) ConcatenateMagickString(description,")",MaxTextExtent);
     }
@@ -557,7 +611,7 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  PixelGetIteratorRow() returns the crurent pixel iterator row.
+%  PixelGetIteratorRow() returns the current pixel iterator row.
 %
 %  The format of the PixelGetIteratorRow method is:
 %
@@ -603,19 +657,10 @@ WandExport long PixelGetIteratorRow(PixelIterator *iterator)
 %    o number_wands: The number of pixel wands.
 %
 */
-
-WandExport PixelWand **PixelGetNextRow(PixelIterator *iterator)
-{
-  unsigned long
-    number_wands;
-
-  return(PixelGetNextIteratorRow(iterator,&number_wands));
-}
-
 WandExport PixelWand **PixelGetNextIteratorRow(PixelIterator *iterator,
   unsigned long *number_wands)
 {
-  IndexPacket
+  register const IndexPacket
     *indexes;
 
   register const PixelPacket
@@ -634,22 +679,22 @@ WandExport PixelWand **PixelGetNextIteratorRow(PixelIterator *iterator,
   if (PixelSetIteratorRow(iterator,iterator->y) == MagickFalse)
     return((PixelWand **) NULL);
   p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
-    iterator->y,iterator->region.width,1,&iterator->exception);
+    iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
-  indexes=GetCacheViewIndexes(iterator->view);
+  indexes=AcquireCacheViewIndexes(iterator->view);
   for (x=0; x < (long) iterator->region.width; x++)
   {
-    PixelSetQuantumColor(iterator->pixel_wand[x],p);
+    PixelSetQuantumColor(iterator->pixel_wands[x],p);
     if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
-      PixelSetBlackQuantum(iterator->pixel_wand[x],indexes[x]);
+      PixelSetBlackQuantum(iterator->pixel_wands[x],indexes[x]);
     else
       if (GetCacheViewStorageClass(iterator->view) == PseudoClass)
-        PixelSetIndex(iterator->pixel_wand[x],indexes[x]);
+        PixelSetIndex(iterator->pixel_wands[x],indexes[x]);
     p++;
   }
   *number_wands=iterator->region.width;
-  return(iterator->pixel_wand);
+  return(iterator->pixel_wands);
 }
 
 /*
@@ -690,7 +735,7 @@ WandExport PixelWand **PixelGetPreviousRow(PixelIterator *iterator)
 WandExport PixelWand **PixelGetPreviousIteratorRow(PixelIterator *iterator,
   unsigned long *number_wands)
 {
-  IndexPacket
+  register const IndexPacket
     *indexes;
 
   register const PixelPacket
@@ -709,22 +754,22 @@ WandExport PixelWand **PixelGetPreviousIteratorRow(PixelIterator *iterator,
   if (PixelSetIteratorRow(iterator,iterator->y) == MagickFalse)
     return((PixelWand **) NULL);
   p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
-    iterator->y,iterator->region.width,1,&iterator->exception);
+    iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
-  indexes=GetCacheViewIndexes(iterator->view);
+  indexes=AcquireCacheViewIndexes(iterator->view);
   for (x=0; x < (long) iterator->region.width; x++)
   {
-    PixelSetQuantumColor(iterator->pixel_wand[x],p);
+    PixelSetQuantumColor(iterator->pixel_wands[x],p);
     if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
-      PixelSetBlackQuantum(iterator->pixel_wand[x],indexes[x]);
+      PixelSetBlackQuantum(iterator->pixel_wands[x],indexes[x]);
     else
       if (GetCacheViewStorageClass(iterator->view) == PseudoClass)
-        PixelSetIndex(iterator->pixel_wand[x],indexes[x]);
+        PixelSetIndex(iterator->pixel_wands[x],indexes[x]);
     p++;
   }
   *number_wands=iterator->region.width;
-  return(iterator->pixel_wand);
+  return(iterator->pixel_wands);
 }
 
 /*
@@ -789,7 +834,7 @@ WandExport void PixelSetFirstIteratorRow(PixelIterator *iterator)
   assert(iterator->signature == WandSignature);
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
-  iterator->active=MagickTrue;
+  iterator->active=MagickFalse;
   iterator->y=iterator->region.y;
 }
 
@@ -905,25 +950,25 @@ WandExport MagickBooleanType PixelSyncIterator(PixelIterator *iterator)
     iterator->y,iterator->region.width,1);
   if (p == (PixelPacket *) NULL)
     {
-      InheritException(&iterator->exception,
-        GetCacheViewException(iterator->view));
+      InheritException(iterator->exception,GetCacheViewException(
+        iterator->view));
       return(MagickFalse);
     }
   indexes=GetCacheViewIndexes(iterator->view);
   for (x=0; x < (long) iterator->region.width; x++)
   {
-    PixelGetQuantumColor(iterator->pixel_wand[x],p);
+    PixelGetQuantumColor(iterator->pixel_wands[x],p);
     if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
-      indexes[x]=PixelGetBlackQuantum(iterator->pixel_wand[x]);
+      indexes[x]=PixelGetBlackQuantum(iterator->pixel_wands[x]);
     else
       if (GetCacheViewStorageClass(iterator->view) == PseudoClass)
-        indexes[x]=PixelGetIndex(iterator->pixel_wand[x]);
+        indexes[x]=PixelGetIndex(iterator->pixel_wands[x]);
     p++;
   }
   if (SyncCacheView(iterator->view) == MagickFalse)
     {
-      InheritException(&iterator->exception,
-        GetCacheViewException(iterator->view));
+      InheritException(iterator->exception,GetCacheViewException(
+        iterator->view));
       return(MagickFalse);
     }
   return(MagickTrue);
