@@ -122,6 +122,114 @@ WandExport void ClearPixelWand(PixelWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C l o n e P i x e l W a n d                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ClonePixelWand() makes an exact copy of the specified wand.
+%
+%  The format of the ClonePixelWand method is:
+%
+%      PixelWand *ClonePixelWand(const PixelWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport PixelWand *ClonePixelWand(const PixelWand *wand)
+{
+  PixelWand
+    *clone_wand;
+
+  assert(wand != (PixelWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  clone_wand=(PixelWand *) AcquireMagickMemory(sizeof(*clone_wand));
+  if (clone_wand == (PixelWand *) NULL)
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=DestroyString(message);
+    }
+  (void) ResetMagickMemory(clone_wand,0,sizeof(*clone_wand));
+  clone_wand->id=AcquireWandId();
+  (void) FormatMagickString(clone_wand->name,MaxTextExtent,"%s-%lu",PixelWandId,
+    clone_wand->id);
+  clone_wand->exception=AcquireExceptionInfo();
+  InheritException(clone_wand->exception,wand->exception);
+  clone_wand->pixel=wand->pixel;
+  clone_wand->count=wand->count;
+  clone_wand->debug=IsEventLogging();
+  if (clone_wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",clone_wand->name);
+  clone_wand->signature=WandSignature;
+  return(clone_wand);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   C l o n e P i x e l W a n d s                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ClonePixelWands() makes an exact copy of the specified wands.
+%
+%  The format of the ClonePixelWands method is:
+%
+%      PixelWand **ClonePixelWands(const PixelWand **wands,
+%        const unsigned long number_wands)
+%
+%  A description of each parameter follows:
+%
+%    o wands: The magick wands.
+%
+%    o number_wands: The number of wands.
+%
+*/
+WandExport PixelWand **ClonePixelWands(const PixelWand **wands,
+  const unsigned long number_wands)
+{
+  register long
+    i;
+
+  PixelWand
+    **clone_wands;
+
+  clone_wands=(PixelWand **) AcquireMagickMemory((size_t) number_wands*
+    sizeof(*clone_wands));
+  if (clone_wands == (PixelWand **) NULL)
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=DestroyString(message);
+    }
+  for (i=0; i < (long) number_wands; i++)
+    clone_wands[i]=ClonePixelWand(wands[i]);
+  return(clone_wands);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y P i x e l W a n d                                           %
 %                                                                             %
 %                                                                             %
@@ -296,7 +404,7 @@ WandExport PixelWand *NewPixelWand(void)
   const char
     *quantum;
 
-  struct _PixelWand
+  PixelWand
     *wand;
 
   unsigned long
@@ -306,7 +414,7 @@ WandExport PixelWand *NewPixelWand(void)
   quantum=GetMagickQuantumDepth(&depth);
   if (depth != QuantumDepth)
     ThrowWandFatalException(WandError,"QuantumDepthMismatch",quantum);
-  wand=(struct _PixelWand *) AcquireMagickMemory(sizeof(*wand));
+  wand=(PixelWand *) AcquireMagickMemory(sizeof(*wand));
   if (wand == (PixelWand *) NULL)
     {
       char
@@ -357,10 +465,10 @@ WandExport PixelWand **NewPixelWands(const unsigned long number_wands)
   register long
     i;
 
-  struct _PixelWand
+  PixelWand
     **wands;
 
-  wands=(struct _PixelWand **) AcquireMagickMemory((size_t) number_wands*
+  wands=(PixelWand **) AcquireMagickMemory((size_t) number_wands*
     sizeof(*wands));
   if (wands == (PixelWand **) NULL)
     {
@@ -1611,6 +1719,40 @@ WandExport void PixelSetColorCount(PixelWand *wand,const unsigned long count)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   P i x e l S e t C o l o r F r o m W a n d                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  PixelSetColorFromWand() sets the color of the pixel wand.
+%
+%  The format of the PixelSetColorFromWand method is:
+%
+%      PixelSetColorFromWand(PixelWand *wand,const PixelWand *color)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The pixel wand.
+%
+%    o color: set the pixel wand color here.
+%
+*/
+WandExport void PixelSetColorFromWand(PixelWand *wand,const PixelWand *color)
+{
+  assert(wand != (const PixelWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  assert(color != (const PixelWand *) NULL);
+  wand->pixel=color->pixel;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   P i x e l S e t C y a n                                                   %
 %                                                                             %
 %                                                                             %
@@ -1923,6 +2065,41 @@ WandExport void PixelSetMagentaQuantum(PixelWand *wand,const Quantum magenta)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   P i x e l S e t M a g i c k C o l o r                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  PixelSetMagickColor() sets the color of the pixel wand.
+%
+%  The format of the PixelSetMagickColor method is:
+%
+%      PixelSetMagickColor(PixelWand *wand,const MagickPixelPacket *color)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The pixel wand.
+%
+%    o color: The pixel wand color.
+%
+*/
+WandExport void PixelSetMagickColor(PixelWand *wand,
+  const MagickPixelPacket *color)
+{
+  assert(wand != (const PixelWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  assert(color != (const MagickPixelPacket *) NULL);
+  wand->pixel=(*color);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   P i x e l S e t O p a c i t y                                             %
 %                                                                             %
 %                                                                             %
@@ -2008,7 +2185,7 @@ WandExport void PixelSetOpacityQuantum(PixelWand *wand,const Quantum opacity)
 %
 %    o wand: The pixel wand.
 %
-%    o color: Return the pixel wand color here.
+%    o color: The pixel wand color.
 %
 */
 WandExport void PixelSetQuantumColor(PixelWand *wand,const PixelPacket *color)
