@@ -39,6 +39,18 @@ extern "C" {
 #  endif
 #endif
 
+#if defined(_WIN64) || defined(WIN64)
+#  ifndef __WINDOWS__
+#    ifdef _WIN64
+#      define __WINDOWS__ _WIN64
+#    else
+#      ifdef WIN64
+#        define __WINDOWS__ WIN64
+#      endif
+#    endif
+#  endif
+#endif
+
 #if !defined(vms) && !defined(macintosh) && !defined(__WINDOWS__)
 # define POSIX
 #endif
@@ -108,10 +120,12 @@ extern "C" {
 # define WandGlobal  __declspec(thread)
 # if defined(_VISUALC_)
 #  pragma warning(disable : 4018)
+#  pragma warning(disable : 4068)
 #  pragma warning(disable : 4244)
 #  pragma warning(disable : 4142)
 #  pragma warning(disable : 4800)
 #  pragma warning(disable : 4786)
+#  pragma warning(disable : 4996)
 # endif
 #else
 # define WandExport
@@ -159,9 +173,20 @@ extern "C" {
 #include <signal.h>
 #include <assert.h>
 
-#if defined(HAVE_STRLCPY) && !defined(HAVE_STRLCPY_PROTOTYPE)
-extern size_t
-  strlcpy(char *,const char *,size_t);
+#if defined(HAVE_PREAD) && defined(HAVE_DECL_PREAD) && !HAVE_DECL_PREAD
+ssize_t pread(int,void *,size_t,off_t);
+#endif
+
+#if defined(HAVE_PWRITE) && defined(HAVE_DECL_PWRITE) && !HAVE_DECL_PWRITE
+ssize_t pwrite(int,const void *,size_t,off_t);
+#endif
+
+#if defined(HAVE_STRLCPY) && defined(HAVE_DECL_STRLCPY) && !HAVE_DECL_STRLCPY
+extern size_t strlcpy(char *,const char *,size_t);
+#endif
+
+#if defined(HAVE_VSNPRINTF) && defined(HAVE_DECL_VSNPRINTF) && !HAVE_DECL_VSNPRINTF
+extern int vsnprintf(char *,size_t,const char *,va_list);
 #endif
 
 #if !defined(wand_attribute)
