@@ -87,7 +87,7 @@ WandExport unsigned long AcquireWandId(void)
           wand_ids=NewSplayTree((int (*)(const void *,const void *)) NULL,
             (void *(*)(void *)) NULL,(void *(*)(void *)) NULL);
           if (IsMagickInstantiated() == MagickFalse)
-            InitializeMagick((char *) NULL);
+            MagickCoreGenesis((char *) NULL,MagickFalse);
           instantiate_wand=MagickTrue;
         }
       RelinquishSemaphoreInfo(wand_semaphore);
@@ -126,12 +126,12 @@ WandExport void RelinquishWandId(const unsigned long id)
   (void) LogMagickEvent(WandEvent,GetMagickModule(),"...");
   if (wand_ids == (SplayTreeInfo *) NULL)
     return;
-  (void) RemoveNodeByValueFromSplayTree(wand_ids,(const void *) id);
+  (void) DeleteNodeByValueFromSplayTree(wand_ids,(const void *) id);
   if ((instantiate_wand == MagickFalse) ||
       (GetNumberOfNodesInSplayTree(wand_ids) != 0))
     return;
   AcquireSemaphoreInfo(&wand_semaphore);
-  DestroyMagick();
+  MagickCoreTerminus();
   wand_ids=DestroySplayTree(wand_ids);
   instantiate_wand=MagickFalse;
   RelinquishSemaphoreInfo(wand_semaphore);
